@@ -47,6 +47,9 @@ AzureusCore
 	
 		throws AzureusCoreException;
 	
+	public boolean
+	isStarted();
+	
 		/**
 		 * stop the core and inform lifecycle listeners of stopping
 		 * @throws AzureusCoreException
@@ -95,6 +98,15 @@ AzureusCore
 	
 		throws AzureusCoreException;
 	
+	/**
+	 * 
+	 * @return
+	 * @since 3053
+	 */
+	
+	public boolean
+	isRestarting();
+	
 	public LocaleUtil
 	getLocaleUtil();
 	
