@@ -31,6 +31,7 @@ import java.util.*;
 
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.util.AERunnable;
+import org.gudy.azureus2.core3.util.BEncoder;
 import org.gudy.azureus2.core3.util.ByteFormatter;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.DelayedEvent;
@@ -42,6 +43,7 @@ import org.gudy.azureus2.core3.util.SystemTime;
 import org.gudy.azureus2.plugins.disk.DiskManagerFileInfo;
 
 import com.aelitis.azureus.core.devices.Device;
+import com.aelitis.azureus.core.devices.DeviceListener;
 import com.aelitis.azureus.core.devices.DeviceMediaRenderer;
 import com.aelitis.azureus.core.devices.TranscodeException;
 import com.aelitis.azureus.core.devices.TranscodeFile;
@@ -112,6 +114,13 @@ DeviceImpl
 
 	protected static final String	PP_TIVO_MACHINE		= "tivo_machine";
 
+	protected static final String	PP_OD_ENABLED			= "od_enabled";
+	protected static final String	PP_OD_SHOWN_FTUX		= "od_shown_ftux";
+	protected static final String	PP_OD_MANUFACTURER		= "od_manufacturer";
+	protected static final String	PP_OD_STATE_CACHE		= "od_state_cache";
+	protected static final String	PP_OD_XFER_CACHE		= "od_xfer_cache";
+	protected static final String	PP_OD_UPNP_DISC_CACHE	= "od_upnp_cache";
+
 	
 	protected static final boolean	PR_AUTO_START_DEFAULT	= true;
 	protected static final boolean	PP_AUTO_COPY_DEFAULT	= false;
@@ -150,6 +159,8 @@ DeviceImpl
 	private Map<Object,String>	errors 	= new HashMap<Object, String>();
 	private Map<Object,String>	infos	= new HashMap<Object, String>();
 	
+	private CopyOnWriteList<DeviceListener>		device_listeners;
+	
 	protected
 	DeviceImpl(
 		DeviceManagerImpl	_manager,
@@ -1011,6 +1022,13 @@ DeviceImpl
 		setPersistentIntProperty( PP_REND_TRANS_REQ, req );
 	}
 	
+	public boolean
+	isAudioCompatible(
+		TranscodeFile		file )
+	{
+		return( false );
+	}
+	
 	public boolean
 	getAlwaysCacheFiles()
 	{
@@ -1298,6 +1316,70 @@ DeviceImpl
 		}
 	}
 	
+	public <T> Map<String,T>
+	getPersistentMapProperty(
+		String					prop,
+		Map<String,T>			def )
+	{
+		synchronized( persistent_properties ){
+			
+			try{
+				Map<String,T>	value = (Map<String,T>)persistent_properties.get( prop );
+		
+				if ( value == null ){
+					
+					return( def );
+				}
+				
+				return( value );
+				
+			}catch( Throwable e ){
+				
+				Debug.printStackTrace(e);
+				
+				return( def );
+			}
+		}
+	}
+	
+	public <T>void
+	setPersistentMapProperty(
+		String					prop,
+		Map<String,T>			value )
+	{
+		boolean	dirty = false;
+		
+		synchronized( persistent_properties ){
+			
+			Map<String,T> existing = getPersistentMapProperty( prop, null );
+			
+			if ( !BEncoder.mapsAreIdentical( value, existing )){
+				
+				try{
+					if ( value == null ){
+						
+						persistent_properties.remove( prop );
+						
+					}else{
+					
+						persistent_properties.put( prop, value );
+					}
+					
+					dirty = true;
+					
+				}catch( Throwable e ){
+					
+					Debug.printStackTrace(e);
+				}
+			}
+		}
+		
+		if ( dirty ){
+			
+			setDirty();
+		}
+	}
+	
 	public void
 	removePersistentProperty(
 		String		prop )
@@ -1890,6 +1972,68 @@ DeviceImpl
 		listeners.remove( listener );
 	}
 	
+	protected void
+	fireChanged()
+	{
+		List<DeviceListener> l;
+		
+		synchronized( this ){
+			
+			if ( device_listeners != null ){
+				
+				l = device_listeners.getList();
+				
+			}else{
+				
+				return;
+			}
+		}
+		
+		for ( DeviceListener listener: l ){
+			
+			try{
+				listener.deviceChanged( this );
+				
+			}catch( Throwable e ){
+				
+				Debug.out( e );
+			}
+		}
+	}
+	
+	public void
+	addListener(
+		DeviceListener		listener )
+	{
+		synchronized( this ){
+			
+			if ( device_listeners == null ){
+				
+				device_listeners = new CopyOnWriteList<DeviceListener>();
+			}
+			
+			device_listeners.add( listener );
+		}
+	}
+	
+	public void
+	removeListener(
+		DeviceListener		listener )
+	{
+		synchronized( this ){
+			
+			if ( device_listeners != null ){
+							
+				device_listeners.remove( listener );
+				
+				if ( device_listeners.size() == 0 ){
+					
+					device_listeners = null;
+				}		
+			}
+		}
+	}
+	
 	protected void
 	log(
 		String		str )
