@@ -44,7 +44,10 @@ import org.gudy.azureus2.core3.util.SimpleTimer;
 import org.gudy.azureus2.core3.util.TimerEvent;
 import org.gudy.azureus2.core3.util.TimerEventPerformer;
 import org.gudy.azureus2.plugins.disk.DiskManagerFileInfo;
+import org.gudy.azureus2.plugins.download.Download;
 import org.gudy.azureus2.plugins.ipc.IPCInterface;
+import org.gudy.azureus2.plugins.torrent.TorrentAttribute;
+import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreRunningListener;
@@ -55,15 +58,18 @@ import com.aelitis.azureus.core.messenger.config.PlatformDevicesMessenger;
 
 public class 
 DeviceManagerImpl 
-	implements DeviceManager, AEDiagnosticsEvidenceGenerator
+	implements DeviceManager, DeviceOfflineDownloaderManager, AEDiagnosticsEvidenceGenerator
 {
 	private static final String	LOGGER_NAME 				= "Devices";
 	private static final String	CONFIG_FILE 				= "devices.config";
 	private static final String	AUTO_SEARCH_CONFIG_KEY		= "devices.config.auto_search";
+	
 	private static final String	RSS_ENABLE_CONFIG_KEY		= "devices.config.rss_enable";
-	private static final String	RSS_PORT_CONFIG_KEY			= "devices.config.rss_port";
-	private static final String	RSS_LOCAL_ONLY_CONFIG_KEY	= "devices.config.rss_local_only";
-	private static final int	RSS_PORT_CONFIG__DEFAULT	= 6905;
+	
+	private static final String OD_ENABLED_CONFIG_KEY			= "devices.config.od.enabled";
+	private static final String OD_IS_AUTO_CONFIG_KEY			= "devices.config.od.auto";
+	private static final String OD_INCLUDE_PRIVATE_CONFIG_KEY	= "devices.config.od.inc_priv";
+	
 	
 	private static final String CONFIG_DEFAULT_WORK_DIR	= "devices.config.def_work_dir";
 	
@@ -92,6 +98,9 @@ DeviceManagerImpl
 	}
 	
 	
+	private AzureusCore		azureus_core;
+	
+	private TorrentAttribute			od_manual_ta;
 	
 	private List<DeviceImpl>			device_list = new ArrayList<DeviceImpl>();
 	private Map<String,DeviceImpl>		device_map	= new HashMap<String, DeviceImpl>();
@@ -107,7 +116,7 @@ DeviceManagerImpl
 	private static final int LT_DEVICE_CHANGED		= 2;
 	private static final int LT_DEVICE_ATTENTION	= 3;
 	private static final int LT_DEVICE_REMOVED		= 4;
-	private static final int LT_INITIALIZED		= 5;
+	private static final int LT_INITIALIZED			= 5;
 	
 	private ListenerManager<DeviceManagerListener>	listeners = 
 		ListenerManager.createAsyncManager(
@@ -120,7 +129,7 @@ DeviceManagerImpl
 						int 						type, 
 						Object 						value ) 
 					{
-						Device	device = (Device)value;
+						DeviceImpl	device = (DeviceImpl)value;
 						
 						switch( type ){
 						
@@ -132,13 +141,21 @@ DeviceManagerImpl
 							}
 							case LT_DEVICE_CHANGED:{
 								
-								listener.deviceChanged( device );
+								if ( deviceAdded( device )){
+								
+									device.fireChanged();
+									
+									listener.deviceChanged( device );
+								}
 								
 								break;
 							}
 							case LT_DEVICE_ATTENTION:{
 								
-								listener.deviceAttentionRequest( device );
+								if ( deviceAdded( device )){
+								
+									listener.deviceAttentionRequest( device );
+								}
 								
 								break;
 							}
@@ -156,16 +173,28 @@ DeviceManagerImpl
 							}
 						}
 					}
+					
+					protected boolean
+					deviceAdded(
+						Device		device )
+					{
+						synchronized( DeviceManagerImpl.this ){
+							
+							return( device_list.contains( device ));
+						}
+					}
 				});
 	
 	
 	private boolean	auto_search;
-	private boolean	rss_enable		= false;
-	private boolean	rss_local_only	= true;
-	private int		rss_port		= 0;
 	
 	private DeviceManagerRSSFeed	rss_publisher;
 	
+	private boolean	od_enabled;
+	private boolean	od_is_auto;
+	private boolean od_include_private;
+	
+	
 	private boolean	closing;
 	
 	private boolean	config_unclean;
@@ -199,6 +228,12 @@ DeviceManagerImpl
 	initWithCore(
 		final AzureusCore core ) 
 	{
+		azureus_core = core;
+		
+		od_manual_ta = PluginInitializer.getDefaultInterface().getTorrentManager().getPluginAttribute( "device.manager.od.ta.manual" );
+		
+		rss_publisher = new DeviceManagerRSSFeed( this );
+
 			// need to pick up auto-search early on
 		
 		COConfigurationManager.addAndFireParameterListeners(
@@ -215,6 +250,33 @@ DeviceManagerImpl
 					}
 				});
 		
+		COConfigurationManager.addAndFireParameterListeners(
+				new String[]{
+					OD_ENABLED_CONFIG_KEY,
+					OD_IS_AUTO_CONFIG_KEY,
+					OD_INCLUDE_PRIVATE_CONFIG_KEY
+				},
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						String name ) 
+					{
+						boolean	new_od_enabled 				= COConfigurationManager.getBooleanParameter( OD_ENABLED_CONFIG_KEY, true );
+						boolean	new_od_is_auto 				= COConfigurationManager.getBooleanParameter( OD_IS_AUTO_CONFIG_KEY, true );
+						boolean	new_od_include_private_priv	= COConfigurationManager.getBooleanParameter( OD_INCLUDE_PRIVATE_CONFIG_KEY, false );
+						
+						if ( new_od_enabled != od_enabled || new_od_is_auto != od_is_auto || new_od_include_private_priv != od_include_private ){
+							
+							od_enabled			= new_od_enabled;
+							od_is_auto			= new_od_is_auto;
+							od_include_private	= new_od_include_private_priv;
+							
+							manageOD();
+						}
+					}
+				});
+		
 			// init tivo before upnp as upnp init completion starts up tivo
 		
 		tivo_manager = new DeviceTivoManager( this );
@@ -229,33 +291,6 @@ DeviceManagerImpl
 		
 		transcode_manager = new TranscodeManagerImpl( this );
 		
-		COConfigurationManager.addAndFireParameterListeners(
-			new String[]{
-				RSS_ENABLE_CONFIG_KEY,
-				RSS_LOCAL_ONLY_CONFIG_KEY,
-				RSS_PORT_CONFIG_KEY
-			},
-			new ParameterListener()
-			{
-				public void 
-				parameterChanged(
-					String name ) 
-				{
-					boolean	new_rss_enable 	= COConfigurationManager.getBooleanParameter( RSS_ENABLE_CONFIG_KEY, false );
-					int		new_rss_port 	= COConfigurationManager.getIntParameter( RSS_PORT_CONFIG_KEY, RSS_PORT_CONFIG__DEFAULT );
-					boolean	new_rss_local 	= COConfigurationManager.getBooleanParameter( RSS_LOCAL_ONLY_CONFIG_KEY, true );
-					
-					if ( new_rss_enable != rss_enable || new_rss_port != rss_port || rss_local_only != new_rss_local ){
-						
-						rss_port		= new_rss_port;
-						rss_enable		= new_rss_enable;
-						rss_local_only	= new_rss_local;
-						
-						manageRSS( core );
-					}
-				}
-			});
-		
 		core.addLifecycleListener(
 			new AzureusCoreLifecycleAdapter()
 			{
@@ -321,39 +356,21 @@ DeviceManagerImpl
 				});
 		
 		initialized = true;
+		
 		listeners.dispatch( LT_INITIALIZED, null );
 	}
 	
 	protected void
-	manageRSS(
-		final AzureusCore		core )
+	manageOD()
 	{
-		synchronized( this ){
+		DeviceImpl[] devices = getDevices();
+		
+		for ( DeviceImpl device: devices ){
 			
-			async_dispatcher.dispatch(
-				new AERunnable()
-				{
-					final boolean	f_enable 	= rss_enable;
-					final int		f_port		= rss_port;
-					final boolean	f_local		= rss_local_only;
-					
-					public void
-					runSupport()
-					{
-						synchronized( DeviceManagerImpl.this ){
-														
-							if ( rss_publisher != null ){
-								
-								rss_publisher.destroy();
-							}
-							
-							if ( f_enable ){
-							
-								rss_publisher = new DeviceManagerRSSFeed( DeviceManagerImpl.this, core, f_port, f_local );
-							}
-						}				
-					}
-				});
+			if ( device.getType() == Device.DT_OFFLINE_DOWNLOADER ){
+				
+				((DeviceOfflineDownloaderImpl)device).checkConfig();
+			}
 		}
 	}
 	
@@ -361,6 +378,22 @@ DeviceManagerImpl
 	UPnPManagerStarted()
 	{
 		tivo_manager.startUp();
+		
+		DeviceImpl[] devices = getDevices();
+		
+		for ( DeviceImpl device: devices ){
+			
+			if ( device instanceof DeviceUPnPImpl ){
+				
+				((DeviceUPnPImpl)device).UPnPInitialised();
+			}
+		}
+	}
+	
+	protected AzureusCore
+	getAzureusCore()
+	{
+		return( azureus_core );
 	}
 	
 	protected DeviceManagerUPnPImpl 
@@ -369,6 +402,19 @@ DeviceManagerImpl
 		return( upnp_manager );
 	}
 	
+	public boolean
+	isTiVoEnabled()
+	{
+		return( tivo_manager.isEnabled());
+	}
+	
+	public void
+	setTiVoEnabled(
+		boolean	enabled )
+	{
+		tivo_manager.setEnabled( enabled );
+	}
+	
 	public DeviceTemplate[] 
 	getDeviceTemplates(
 		int		device_type )
@@ -730,7 +776,7 @@ DeviceManagerImpl
 	public boolean
 	isRSSPublishEnabled()
 	{
-		return( rss_enable );
+		return( COConfigurationManager.getBooleanParameter( RSS_ENABLE_CONFIG_KEY, false ) );
 	}
 	
 	public void
@@ -739,33 +785,93 @@ DeviceManagerImpl
 	{
 		COConfigurationManager.setParameter( RSS_ENABLE_CONFIG_KEY, enabled );
 	}
+	
+	public String
+	getRSSLink()
+	{
+		return( rss_publisher.getFeedURL());
+	}
+	
+		// offline downloader stuff
+	
+	public DeviceOfflineDownloaderManager
+	getOfflineDownlaoderManager()
+	{
+		return( this );
+	}
+	
+	public boolean
+	isOfflineDownloadingEnabled()
+	{
+		return( od_enabled );
+	}
+	
+	public void
+	setOfflineDownloadingEnabled(
+		boolean		enabled )
+	{
+		COConfigurationManager.setParameter( OD_ENABLED_CONFIG_KEY, enabled );
+	}
 
 	public boolean
-	isRSSLocalOnly()
+	getOfflineDownloadingIsAuto()
 	{
-		return( rss_local_only );
+		return( od_is_auto );
 	}
 	
 	public void
-	setRSSLocalOnly(
-		boolean		local_only )
+	setOfflineDownloadingIsAuto(
+		boolean		auto )
 	{
-		COConfigurationManager.setParameter( RSS_LOCAL_ONLY_CONFIG_KEY, local_only );
+		COConfigurationManager.setParameter( OD_IS_AUTO_CONFIG_KEY, auto );
 	}
-	
-	public int
-	getRSSPort()
+
+	public boolean
+	getOfflineDownloadingIncludePrivate()
 	{
-		return( rss_port );
+		return( od_include_private );	
 	}
 	
 	public void
-	setRSSPort(
-		int		port )
+	setOfflineDownloadingIncludePrivate(
+		boolean		include )
 	{
-		COConfigurationManager.setParameter( RSS_PORT_CONFIG_KEY, port );
+		COConfigurationManager.setParameter( OD_INCLUDE_PRIVATE_CONFIG_KEY, include );
 	}
 	
+	public boolean
+	isManualDownload(
+		Download		download )
+	{
+		return( download.getBooleanAttribute( od_manual_ta ));
+	}
+	
+	public void
+	addManualDownloads(
+		Download[]		downloads )
+	{
+		for ( Download d: downloads ){
+			
+			d.setBooleanAttribute( od_manual_ta, true );
+		}
+		
+		manageOD();
+	}
+
+	public void
+	removeManualDownloads(
+		Download[]		downloads )
+	{
+		for ( Download d: downloads ){
+			
+			d.setBooleanAttribute( od_manual_ta, false );
+		}
+		
+		manageOD();
+	}
+	
+		// sdsd
+	
 	protected boolean
 	isExplicitSearch()
 	{
