@@ -57,12 +57,13 @@ import com.aelitis.net.upnp.UPnPListener;
 import com.aelitis.net.upnp.UPnPRootDevice;
 import com.aelitis.net.upnp.UPnPRootDeviceListener;
 import com.aelitis.net.upnp.UPnPService;
+import com.aelitis.net.upnp.services.UPnPOfflineDownloader;
 import com.aelitis.net.upnp.services.UPnPWANConnection;
 
 public class 
 DeviceManagerUPnPImpl 
 {
-	private final static Object KEY_LISTENER_ADDED = new Object();
+	private final static Object KEY_ROOT_DEVICE = new Object();
 	
 	private DeviceManagerImpl		manager;
 	private PluginInterface			plugin_interface;
@@ -481,6 +482,19 @@ DeviceManagerUPnPImpl
 		}
 	}
 	
+	protected void
+	injectDiscoveryCache(
+		Map		cache )
+	{
+		try{
+			upnp.injectDiscoveryCache( cache );
+			
+		}catch( Throwable e ){
+	
+			Debug.out( e );
+		}
+	}
+	
 	public UnassociatedDevice[]
 	getUnassociatedDevices()
 	{
@@ -539,6 +553,12 @@ DeviceManagerUPnPImpl
 		return( result.toArray( new UnassociatedDevice[result.size()]));
 	}
 	
+	public PluginInterface
+	getPluginInterface()
+	{
+		return( plugin_interface );
+	}
+	
 	protected IPCInterface
 	getUPnPAVIPC()
 	{
@@ -645,6 +665,8 @@ DeviceManagerUPnPImpl
 				uid = UUIDGenerator.generateUUIDString();
 				
 				COConfigurationManager.setParameter( "devices.upnp.uid." + unique_name, uid );
+				
+				COConfigurationManager.save();
 			}
 		}
 		
@@ -698,6 +720,45 @@ DeviceManagerUPnPImpl
 			}else if ( service_type.equals( "urn:schemas-upnp-org:service:ContentDirectory:1" )){
 				
 				new_devices.add( new DeviceContentDirectoryImpl( manager, device, service ));
+				
+			}else if ( service_type.equals( "urn:schemas-upnp-org:service:VuzeOfflineDownloaderService:1" )){
+				
+					// ignore local offline downloader
+				
+				try{
+					PluginInterface od_pi = plugin_interface.getPluginManager().getPluginInterfaceByID( "azofflinedownloader" );
+	
+					if ( od_pi != null ){
+					
+						String	local_usn = (String)od_pi.getIPC().invoke( "getUSN", new Object[0] );
+					
+						String	od_usn = device.getRootDevice().getUSN();
+						
+							// we end up with "::upnp:rootdevice" on the end of this - remove
+						
+						int	pos = od_usn.indexOf( "::upnp:rootdevice" );
+						
+						if ( pos > 0 ){
+							
+							od_usn = od_usn.substring( 0, pos );
+						}
+						
+						if ( od_usn.equals( local_usn )){
+							
+							continue;
+						}
+					}
+				}catch( Throwable e ){
+					
+					Debug.out( e );
+				}
+				
+				UPnPOfflineDownloader downloader = (UPnPOfflineDownloader)service.getSpecificService();
+
+				if ( downloader != null ){
+					
+					new_devices.add( new DeviceOfflineDownloaderImpl( manager, device, downloader ));
+				}
 			}
 		}
 		
@@ -712,22 +773,32 @@ DeviceManagerUPnPImpl
 		}
 		
 		for ( final DeviceUPnPImpl new_device: new_devices ){
+				
+			final DeviceImpl actual_device;
 			
-			if ( !update_if_found &&  manager.getDevice( new_device.getID()) != null ){
+			DeviceImpl existing = manager.getDevice( new_device.getID());
+			
+			if ( !update_if_found && existing != null ){
 					
-				continue;
+				actual_device = existing;
+				
+			}else{
+			
+					// grab the actual device as the 'addDevice' call will update an existing one
+					// with same id
+			
+				actual_device = manager.addDevice( new_device );
 			}
 			
-				// grab the actual device as the 'addDevice' call will update an existing one
-				// with same id
+			UPnPRootDevice current_root = device.getRootDevice();
 			
-			final DeviceImpl actual_device = manager.addDevice( new_device );
-
-			if ( actual_device.getTransientProperty( KEY_LISTENER_ADDED ) == null ){
+			UPnPRootDevice existing_root = (UPnPRootDevice)actual_device.getTransientProperty( KEY_ROOT_DEVICE );
+			
+			if ( current_root != existing_root ){
 				
-				actual_device.setTransientProperty( KEY_LISTENER_ADDED, "" );
+				actual_device.setTransientProperty( KEY_ROOT_DEVICE, current_root );
 				
-				device.getRootDevice().addListener(
+				current_root.addListener(
 					new UPnPRootDeviceListener()
 					{
 						public void
