@@ -227,6 +227,11 @@ DeviceUPnPImpl
 		super.initialise();
 	}
 	
+	protected void
+	UPnPInitialised()
+	{
+	}
+	
 	@Override
 	protected void
 	destroy()
@@ -234,6 +239,12 @@ DeviceUPnPImpl
 		super.destroy();
 	}
 	
+	protected DeviceManagerUPnPImpl
+	getUPnPDeviceManager()
+	{
+		return( upnp_manager );
+	}
+	
 	protected UPnPDevice
 	getUPnPDevice()
 	{
