@@ -53,6 +53,9 @@ DHTControl
 	seed(
 		boolean		full_wait );
 		
+	public boolean
+	isSeeded();
+	
 	public void
 	put(
 		byte[]					key,
@@ -60,6 +63,7 @@ DHTControl
 		byte[]					value,
 		byte					flags,
 		byte					life_hours,
+		byte					replication_control,
 		boolean					high_priority,
 		DHTOperationListener	listener );
 	
@@ -125,20 +129,16 @@ DHTControl
 	
 		// support methods for DB
 	
-	public List
+	public List<DHTTransportContact>
 	getClosestKContactsList(
 		byte[]		id,
 		boolean		live_only );
 	
-	public List
+	public List<DHTTransportContact>
 	getClosestContactsList(
 		byte[]		id,
 		int			num_to_return,
 		boolean		live_only );
-
-	public List
-	sortContactsByDistance(
-		List		contacts );
 	
 	public void
 	putEncodedKey(
@@ -150,10 +150,18 @@ DHTControl
 	
 	public void
 	putDirectEncodedKeys(
-		byte[][]				keys,
-		String					description,
-		DHTTransportValue[][]	value_sets,
-		List					contacts );
+		byte[][]					keys,
+		String						description,
+		DHTTransportValue[][]		value_sets,
+		List<DHTTransportContact>	contacts );
+	
+	public void
+	putDirectEncodedKeys(
+		byte[][]					keys,
+		String						description,
+		DHTTransportValue[][]		value_sets,
+		DHTTransportContact			contact,
+		DHTOperationListener		listener );
 	
 	public int
 	computeAndCompareDistances(
@@ -161,6 +169,16 @@ DHTControl
 		byte[]		n2,
 		byte[]		pivot );
 	
+	public byte[]
+	computeDistance(
+		byte[]		n1,
+		byte[]		n2 );
+	
+	public int
+	compareDistances(
+		byte[]		n1,
+		byte[]		n2 );
+	
 	public boolean
 	verifyContact(
 		DHTTransportContact c,
@@ -169,15 +187,28 @@ DHTControl
 	public boolean
 	lookup(
 		byte[]					id,
+		String					description,
 		long					timeout,
 		DHTOperationListener	listener );
 	
+	public boolean
+	lookupEncoded(
+		byte[]					id,
+		String					description,
+		long					timeout,
+		boolean					high_priority,
+		DHTOperationListener	listener );
+	
+	public byte[]
+	getObfuscatedKey(
+		byte[]		plain_key );
+	
 	/**
-	 * Returns a list of DHTContact objects
+	 * Returns a list of DHTTransportContact objects
 	 * @return
 	 */
 	
-	public List
+	public List<DHTTransportContact>
 	getContacts();
 	
 		// debug method only
