@@ -38,12 +38,14 @@ DHTControlAdapter
 
 	public byte[][]
 	diversify(
+		String				description,
 		DHTTransportContact	cause,
 		boolean				put_operation,
 		boolean				existing,
 		byte[]				key,
 		byte				type,
-		boolean				exhaustive );
+		boolean				exhaustive,
+		int					max_depth );
 	
 	public boolean
 	isDiversified(
