@@ -23,12 +23,14 @@
 package com.aelitis.azureus.core.dht.db;
 
 import java.util.Iterator;
+import java.util.List;
 
 import org.gudy.azureus2.core3.util.HashWrapper;
 
 import com.aelitis.azureus.core.dht.DHTStorageBlock;
 import com.aelitis.azureus.core.dht.control.DHTControl;
 import com.aelitis.azureus.core.dht.transport.DHTTransportContact;
+import com.aelitis.azureus.core.dht.transport.DHTTransportQueryStoreReply;
 import com.aelitis.azureus.core.dht.transport.DHTTransportValue;
 
 /**
@@ -56,7 +58,8 @@ DHTDB
 		HashWrapper		key,
 		byte[]			value,
 		byte			flags,
-		byte			life_hours );
+		byte			life_hours,
+		byte			replication_control );
 	
 		/**
 		 * Remote store
@@ -73,6 +76,12 @@ DHTDB
 		HashWrapper				key,
 		DHTTransportValue[]		values );
 	
+	public DHTTransportQueryStoreReply
+	queryStore(
+		DHTTransportContact 		originating_contact, 
+		int							header_len,
+		List<Object[]>				keys );
+	
 		/**
 		 * Internal lookup for locally originated values
 		 * @param key
@@ -83,6 +92,10 @@ DHTDB
 	get(
 		HashWrapper		key );
 	
+	public boolean
+	hasKey(
+		HashWrapper		key );
+	
 	public DHTDBLookupResult
 	get(
 		DHTTransportContact		reader,
@@ -129,7 +142,7 @@ DHTDB
 		 * @return
 		 */
 	
-	public Iterator
+	public Iterator<HashWrapper>
 	getKeys();
 	
 	public DHTDBStats
