@@ -24,6 +24,7 @@ package com.aelitis.azureus.core.dht.db.impl;
 
 import org.gudy.azureus2.core3.util.SystemTime;
 
+import com.aelitis.azureus.core.dht.DHT;
 import com.aelitis.azureus.core.dht.db.DHTDBValue;
 import com.aelitis.azureus.core.dht.impl.DHTLog;
 import com.aelitis.azureus.core.dht.transport.DHTTransportContact;
@@ -47,6 +48,7 @@ DHTDBValueImpl
 	private boolean				local;
 	private byte				flags;
 	private byte				life_hours;
+	private byte				rep_control;
 	private int					version;
 	
 	private long				store_time;
@@ -70,7 +72,8 @@ DHTDBValueImpl
 		DHTTransportContact	_sender,
 		boolean				_local,
 		int					_flags,
-		int					_life_hours )
+		int					_life_hours,
+		byte				_rep_control )
 	{
 		creation_time	= _creation_time;
 		value			= _value;
@@ -80,6 +83,7 @@ DHTDBValueImpl
 		local			= _local;
 		flags			= (byte)_flags;
 		life_hours		= (byte)_life_hours;
+		rep_control		= _rep_control;
 		
 			// we get quite a few zero length values - optimise mem usage
 		
@@ -112,7 +116,8 @@ DHTDBValueImpl
 				_sender,
 				_local,
 				_other.getFlags(),
-				_other.getLifeTimeHours());
+				_other.getLifeTimeHours(),
+				_other.getReplicationControl());
 	}
 	
 	protected void
@@ -202,6 +207,24 @@ DHTDBValueImpl
 		return( life_hours&0xff );
 	}
 	
+	public byte
+	getReplicationControl()
+	{
+		return( rep_control );
+	}
+	
+	public byte 
+	getReplicationFactor() 
+	{
+		return( rep_control == DHT.REP_FACT_DEFAULT?DHT.REP_FACT_DEFAULT:(byte)(rep_control&0x0f));
+	}
+	
+	public byte 
+	getReplicationFrequencyHours() 
+	{
+		return( rep_control == DHT.REP_FACT_DEFAULT?DHT.REP_FACT_DEFAULT:(byte)((rep_control&0xf0)>>4));
+	}
+	
 	protected void
 	setOriginatorAndSender(
 		DHTTransportContact	_originator )
@@ -238,7 +261,7 @@ DHTDBValueImpl
 		long	now = SystemTime.getCurrentTime();
 		
 		return( DHTLog.getString( value ) + " - " + new String(value) + "{v=" + version + ",f=" + 
-				Integer.toHexString(flags) +",ca=" + (now - creation_time ) + ",sa=" + (now-store_time)+
+				Integer.toHexString(flags) + ",l=" + life_hours + ",r=" + Integer.toHexString( rep_control ) + ",ca=" + (now - creation_time ) + ",sa=" + (now-store_time)+
 				",se=" + sender.getString() + ",or=" + originator.getString() +"}" );
 	}
 }
