@@ -72,8 +72,8 @@ Test
 		DHTTransportUDPImpl.TEST_EXTERNAL_IP	= true;
 	}
 	
-	int num_dhts			= 3;
-	int num_stores			= 2;
+	int num_dhts			= 6;
+	int num_stores			= 0;
 	static int MAX_VALUES	= 10000;
 	
 	boolean	udp_protocol	= true;
@@ -89,7 +89,7 @@ Test
 	static Properties	dht_props = new Properties();
 	
 	static{		
-		DHTDBImpl.ORIGINAL_REPUBLISH_INTERVAL_GRACE = 0;
+		// DHTDBImpl.ORIGINAL_REPUBLISH_INTERVAL_GRACE = 0;
 
 		dht_props.put( DHT.PR_CONTACTS_PER_NODE, new Integer(K));
 		dht_props.put( DHT.PR_NODE_SPLIT_FACTOR, new Integer(B));
@@ -355,8 +355,9 @@ Test
 							
 							pos = val.indexOf( ' ' );
 							
-							byte flags 	= 0;
-							byte life 	= 0;
+							byte flags 		= 0;
+							byte life 		= 0;
+							byte rep_fact 	= DHT.REP_FACT_DEFAULT;
 							
 							if ( pos != -1 ){
 								
@@ -372,18 +373,23 @@ Test
 									
 									if ( opt.equals( "f" )){
 										
-										flags = (byte)Integer.parseInt(y[1]);
+										flags = (byte)Integer.parseInt(y[1],16);
 										
 									}else if ( opt.equals( "l" )){
 										
 										life = (byte)Integer.parseInt(y[1]);
+										
+									}else if ( opt.equals( "r" )){
+										
+										rep_fact = (byte)Integer.parseInt(y[1]);
+
 									}
 								}
 								
 								val = val.substring(0,pos);
 							}
 							
-							dht.put( key.getBytes(), "", val.getBytes(), flags, life, false, new DHTOperationAdapter() );
+							dht.put( key.getBytes(), "", val.getBytes(), flags, life, rep_fact, false, new DHTOperationAdapter() );
 						}
 					}else if ( command == 'x' ){
 						
@@ -428,8 +434,33 @@ Test
 						
 						stats_before = dht.getTransport().getStats().snapshot();
 					
+						pos = rhs.indexOf( ' ' );
+						
+						byte flags 	= 0;
+						
+						if ( pos != -1 ){
+							
+							String	opts = rhs.substring( pos+1 );
+							
+							String[] x = opts.split( "," );
+							
+							for ( String s: x ){
+								
+								String[] y = s.split("=");
+								
+								String	opt = y[0];
+								
+								if ( opt.equals( "f" )){
+									
+									flags = (byte)Integer.parseInt(y[1]);
+								}
+							}
+							
+							rhs = rhs.substring(0,pos);
+						}
+						
 						dht.get( 
-								rhs.getBytes(), "", (byte)0, 32, 0, false, false,
+								rhs.getBytes(), "", flags, 32, 0, false, false,
 								new DHTOperationAdapter()
 								{
 									public void
@@ -523,7 +554,8 @@ Test
 									
 									public void
 									found(
-										DHTTransportContact	contact )
+										DHTTransportContact	contact,
+										boolean				is_closest )
 									{
 									}
 									
@@ -910,8 +942,9 @@ Test
 		DHTTransportValue		value )
 	{
 		return( new String( value.getValue()) + 
-				"; flags=" + value.getFlags() +
+				"; flags=" + Integer.toHexString( value.getFlags()) +
 				"; life=" + value.getLifeTimeHours() +
+				"; rep=" + Integer.toHexString( value.getReplicationControl())  +
 				", orig=" + value.getOriginator().getAddress());
 	}
 	
