@@ -53,6 +53,9 @@ DHTTransportStats
 	public long[]
 	getStores();
 	
+	public long[]
+	getQueryStores();
+	
 	public long[]
 	getData();
 	
@@ -67,6 +70,7 @@ DHTTransportStats
 	public static final int AT_STATS			= 3; 
 	public static final int AT_STORE			= 4; 
 	public static final int AT_KEY_BLOCK		= 5; 
+	public static final int AT_QUERY_STORE		= 6; 
 	
 	public long[]
 	getAliens();
@@ -95,6 +99,14 @@ DHTTransportStats
 	public long
 	getSkewAverage();
 	
+		/**
+		 * -1 if stats not yet available 
+		 * @return
+		 */
+	
+	public int
+	getRouteablePercentage();
+	
 	public String
 	getString();
 }
