@@ -51,6 +51,15 @@ DHTTransportValue
 	public int
 	getLifeTimeHours();
 	
+	public byte
+	getReplicationControl();
+	
+	public byte
+	getReplicationFactor();
+
+	public byte
+	getReplicationFrequencyHours();
+
 	public String
 	getString();
 }
