@@ -24,6 +24,8 @@ package com.aelitis.azureus.core.dht.transport.loopback;
 
 import java.io.*;
 import java.net.InetSocketAddress;
+import java.util.List;
+import java.util.Map;
 
 import com.aelitis.azureus.core.dht.impl.DHTLog;
 import com.aelitis.azureus.core.dht.netcoords.DHTNetworkPosition;
@@ -131,6 +133,14 @@ DHTTransportLoopbackContactImpl
 		return( true );
 	}
 
+	public void 
+	isAlive(
+		DHTTransportReplyHandler 	handler, 
+		long 						timeout )
+	{
+		transport.sendPing( this, handler );
+	}
+	
 	public void
 	sendPing(
 		DHTTransportReplyHandler	handler )
@@ -172,6 +182,15 @@ DHTTransportLoopbackContactImpl
 		transport.sendStore( this, handler, keys, value_sets, false );
 	}
 	
+	public void 
+	sendQueryStore(
+		DHTTransportReplyHandler 	handler,
+		int							header_length,
+		List<Object[]>			 	key_details ) 
+	{
+		transport.sendQueryStore( this, handler, header_length, key_details);
+	}
+	
 	public void
 	sendFindNode(
 		DHTTransportReplyHandler	handler,
