@@ -29,12 +29,14 @@ DiskAccessControllerFactory
 {
 	public static DiskAccessController
 	create(
-			int		max_read_threads,
-			int		max_read_mb,
-			int 	max_write_threads,
-			int		max_write_mb )
+		String		name,
+		int			max_read_threads,
+		int			max_read_mb,
+		int 		max_write_threads,
+		int			max_write_mb )
 	{
 		return( new DiskAccessControllerImpl(
+						name,
 						max_read_threads,  max_read_mb,
 						max_write_threads, max_write_mb ));
 	}
