@@ -37,4 +37,18 @@ DiskAccessRequestListener
 	requestFailed(
 		DiskAccessRequest	request,
 		Throwable			cause );
+	
+	public int
+	getPriority();
+	
+		/**
+		 * Called to indicate that an actual request operation occurred. If this request has
+		 * been aggregated with others then the byted reported will be for the contiguous
+		 * region and subsequent aggregated requests will be reported with 0 bytes
+		 * @param bytes
+		 */
+	
+	public void
+	requestExecuted(
+		long	bytes );
 }
