@@ -1,7 +1,7 @@
 /*
  * Created on 03-Aug-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -24,6 +24,11 @@ package com.aelitis.azureus.core.diskmanager.cache;
 
 import java.io.File;
 
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+
+import com.aelitis.azureus.core.util.CaseSensitiveFileMap;
+
+
 /**
  * @author parg
  *
@@ -35,10 +40,16 @@ CacheFileManager
 	public CacheFile
 	createFile(
 		CacheFileOwner	owner,
-		File			file )
+		File			file,
+		int				type )
 	
 		throws CacheFileManagerException;
 	
 	public CacheFileManagerStats
 	getStats();
+	
+	public void
+	setFileLinks(
+		TOTorrent				torrent,
+		CaseSensitiveFileMap	links );
 }
