@@ -1,7 +1,7 @@
 /*
  * Created on 03-Aug-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -28,20 +28,54 @@ package com.aelitis.azureus.core.diskmanager.cache;
  */
 public class 
 CacheFileManagerException 
-extends Exception
+	extends Exception
 {
+	private CacheFile	file;
+	private int			fail_index;
+	
 	public
 	CacheFileManagerException(
-		String		str )
+		CacheFile	_file,
+		String		_str )
 	{
-		super(str);
+		super(_str);
+		
+		file		= _file;
 	}
 	
 	public
 	CacheFileManagerException(
-		String		str,
-		Throwable	cause )
+		CacheFile	_file,
+		String		_str,
+		Throwable	_cause )
 	{
-		super( str, cause );
+		super( _str, _cause );
+		
+		file	= _file;
+	}
+	
+	public
+	CacheFileManagerException(
+		CacheFile	_file,
+		String		_str,
+		Throwable	_cause,
+		int			_fail_index )
+	{
+		super( _str, _cause );
+		
+		file		= _file;
+		fail_index	= _fail_index;
+	}
+	
+	public CacheFile
+	getFile()
+	{
+		return( file );
+	}
+	
+	public int
+	getFailIndex()
+	{
+		return( fail_index );
 	}
 }
