@@ -1388,7 +1388,7 @@ CacheFileWithCache
 				flushCachePublic( false, -1 );
 			}
 			
-			file.setStorageType( type==CT_COMPACT?FMFile.FT_COMPACT:FMFile.FT_LINEAR );
+			file.setStorageType( CacheFileManagerImpl.convertCacheToFileType( type ));
 			
 		}catch( FMFileManagerException e ){
 			
@@ -1403,7 +1403,7 @@ CacheFileWithCache
 	public int
 	getStorageType()
 	{
-		return( file.getStorageType()==FMFile.FT_COMPACT?CT_COMPACT:CT_LINEAR );
+		return( CacheFileManagerImpl.convertFileToCacheType( file.getStorageType()));
 	}
 
 	public long
@@ -1518,6 +1518,22 @@ CacheFileWithCache
 		}
 	}
 	
+	public void
+	setPieceComplete(
+		int					piece_number,
+		DirectByteBuffer	piece_data )
+	
+		throws CacheFileManagerException
+	{
+		try{
+			file.setPieceComplete( piece_number, piece_data );
+			
+		}catch( FMFileManagerException e ){
+			
+			manager.rethrow(this,e);
+		}
+	}
+	
 	public void
 	read(
 		DirectByteBuffer[]	buffers,
