@@ -276,7 +276,7 @@ CacheFileWithoutCacheMT
 	public int
 	getStorageType()
 	{
-		return( base_file.getStorageType()==FMFile.FT_COMPACT?CT_COMPACT:CT_LINEAR );
+		return( CacheFileManagerImpl.convertFileToCacheType( base_file.getStorageType()));
 	}
 
 	public long
@@ -320,6 +320,22 @@ CacheFileWithoutCacheMT
 		}
 	}
 	
+	public void
+	setPieceComplete(
+		int					piece_number,
+		DirectByteBuffer	piece_data )
+	
+		throws CacheFileManagerException
+	{
+		try{
+			base_file.setPieceComplete( piece_number, piece_data );
+			
+		}catch( FMFileManagerException e ){
+			
+			manager.rethrow(this,e);
+		}
+	}
+	
 	protected FMFile
 	getFile()
 	
