@@ -29,10 +29,10 @@ import java.util.Map;
 
 import org.gudy.azureus2.core3.torrent.TOTorrent;
 import org.gudy.azureus2.core3.torrent.TOTorrentFile;
+import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.DirectByteBuffer;
 import org.gudy.azureus2.core3.util.FileUtil;
 
-import com.aelitis.azureus.core.diskmanager.file.FMFile;
 import com.aelitis.azureus.core.diskmanager.file.FMFileManagerException;
 
 public class 
@@ -61,15 +61,15 @@ FMFileAccessCompact
 	protected
 	FMFileAccessCompact(
 		TOTorrentFile	_torrent_file,
-		File			controlFileDir,
-		String			controlFileName,
+		File			_controlFileDir,
+		String			_controlFileName,
 		FMFileAccess	_delegate )
 	
 		throws FMFileManagerException
 	{
 		torrent_file	= _torrent_file;
-		this.controlFileDir	= controlFileDir;
-		this.controlFileName = controlFileName;
+		controlFileDir	= _controlFileDir;
+		controlFileName = _controlFileName;
 		delegate		= _delegate;
 
 		try{
@@ -171,6 +171,14 @@ FMFileAccessCompact
 		return( last_piece_length );
 	}
 	
+	public void
+	aboutToOpen()
+	
+		throws FMFileManagerException
+	{
+		delegate.aboutToOpen();
+	}
+	
 	public long
 	getLength(
 		RandomAccessFile		raf )
@@ -187,16 +195,16 @@ FMFileAccessCompact
 	
 		throws FMFileManagerException
 	{
-		if(length != current_length)
+		if ( length != current_length ){
+					
+			current_length	= length;
+			
 			write_required = true;
-		
-		current_length	= length;
-		
+		}
 	}
 	
 	protected void
 	read(
-		FMFile				file,
 		RandomAccessFile	raf,
 		DirectByteBuffer	buffer,
 		long				position )
@@ -222,7 +230,7 @@ FMFileAccessCompact
 					
 					// System.out.println( "    all in first piece" );
 
-					delegate.read( file, raf, new DirectByteBuffer[]{ buffer }, position );
+					delegate.read( raf, new DirectByteBuffer[]{ buffer }, position );
 					
 					position	+= len;
 					len			= 0;
@@ -234,7 +242,7 @@ FMFileAccessCompact
 
 					buffer.limit( SS, buffer.position(SS) + available );
 					
-					delegate.read( file, raf, new DirectByteBuffer[]{ buffer }, position );
+					delegate.read( raf, new DirectByteBuffer[]{ buffer }, position );
 				
 					buffer.limit( SS, original_limit );
 					
@@ -287,7 +295,7 @@ FMFileAccessCompact
 			
 			// System.out.println( "    some in last piece" );
 
-			delegate.read( file, raf, new DirectByteBuffer[]{ buffer }, ( position - last_piece_start ) + first_piece_length );
+			delegate.read( raf, new DirectByteBuffer[]{ buffer }, ( position - last_piece_start ) + first_piece_length );
 			
 		}finally{
 			
@@ -297,7 +305,6 @@ FMFileAccessCompact
 	
 	public void
 	read(
-		FMFile					file,
 		RandomAccessFile		raf,
 		DirectByteBuffer[]		buffers,
 		long					position )
@@ -310,9 +317,16 @@ FMFileAccessCompact
 			
 			int	len = buffers[i].limit(SS) - buffers[i].position(SS);
 		
-			read( file, raf, buffer, position );
+			read( raf, buffer, position );
 			
-			position += len;
+			int	rem = buffers[i].remaining( SS );
+			
+			position += len - rem;
+			
+			if ( rem > 0 ){
+				
+				break;
+			}
 		}
 		
 		if ( position > current_length ){
@@ -455,6 +469,16 @@ FMFileAccessCompact
 		writeState();
 	}
 	
+	public void
+	setPieceComplete(
+		RandomAccessFile	raf,
+		int					piece_number,
+		DirectByteBuffer	piece_data )
+	
+		throws FMFileManagerException
+	{	
+	}
+	
 	protected void
 	readState()
 	
