@@ -43,14 +43,14 @@ FMFileImpl
 	implements FMFile
 {	
 	protected static final String		READ_ACCESS_MODE	= "r";
-	protected static final String		WRITE_ACCESS_MODE	= "rwd";
+	protected static final String		WRITE_ACCESS_MODE	= "rw"; // "rwd"; - removing this to improve performance
 	
 	private static Map			file_map = new HashMap();
 	private static AEMonitor	file_map_mon	= new AEMonitor( "FMFile:map");
 	
 	// If there is an exception that occurs, which causes us to try and perform
 	// a reopen, setting this flag to true will print it to debug.
-	private static boolean OUTPUT_REOPEN_RELATED_ERRORS = false; 
+	private static boolean OUTPUT_REOPEN_RELATED_ERRORS = true; 
 	
 	static{
 		AEDiagnostics.addEvidenceGenerator(
@@ -545,6 +545,8 @@ FMFileImpl
 				// if the subsequent open fails
 		}
 		
+		file_access.aboutToOpen();
+		
 		raf = new RandomAccessFile( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
 		
 		Debug.outNoStack( "Recovered connection to " + getName() + " after access failure" );
@@ -563,7 +565,9 @@ FMFileImpl
 
 		reserveAccess( reason );
 		
-		try{		
+		try{	
+			file_access.aboutToOpen();
+			
 			raf = new RandomAccessFile( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
 			
 		}catch( Throwable e ){
@@ -634,6 +638,16 @@ FMFileImpl
 		file_access.flush();
 	}
 	
+	protected void
+	setPieceCompleteSupport(
+		int					piece_number,
+		DirectByteBuffer	piece_data )
+	
+		throws FMFileManagerException
+	{
+		file_access.setPieceComplete( raf, piece_number, piece_data );
+	}
+	
 	public void
 	delete()
 	
@@ -669,7 +683,7 @@ FMFileImpl
 	{
 		try{
 		
-			file_access.read( this, raf, buffers, position );
+			file_access.read( raf, buffers, position );
 			
 		}catch( FMFileManagerException e ){
 			
@@ -678,7 +692,7 @@ FMFileImpl
 			try{
 				reopen();
 
-				file_access.read( this, raf, buffers, position );
+				file_access.read( raf, buffers, position );
 				
 			}catch( Throwable e2 ){
 				
