@@ -33,7 +33,6 @@ import org.gudy.azureus2.pluginsimpl.local.PluginCoreUtils;
 import org.gudy.azureus2.pluginsimpl.local.disk.DiskManagerChannelImpl;
 
 import com.aelitis.azureus.core.AzureusCore;
-import com.aelitis.azureus.core.torrent.MetaDataUpdateListener;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
 import com.aelitis.azureus.util.ExternalStimulusHandler;
 import com.aelitis.azureus.util.ExternalStimulusListener;
@@ -45,8 +44,6 @@ public class
 DownloadManagerEnhancer 
 {
 	public static final int	TICK_PERIOD				= 1000;
-	public static final int	PUBLISHING_CHECK_PERIOD	= 15000;
-	public static final int	PUBLISHING_CHECK_TICKS	= PUBLISHING_CHECK_PERIOD / TICK_PERIOD;
 	
 	private static DownloadManagerEnhancer		singleton;
 	
@@ -70,7 +67,7 @@ DownloadManagerEnhancer
 	
 	private AzureusCore		core;
 	
-	private Map				download_map = new HashMap();
+	private Map<DownloadManager,EnhancedDownloadManager>		download_map = new HashMap<DownloadManager,EnhancedDownloadManager>();
 	
 	private boolean			progressive_enabled;
 	
@@ -99,7 +96,7 @@ DownloadManagerEnhancer
 					
 					synchronized( download_map ){
 						
-						edm = (EnhancedDownloadManager)download_map.remove( dm );
+						edm = download_map.remove( dm );
 					}
 					
 					if ( edm != null ){
@@ -127,31 +124,6 @@ DownloadManagerEnhancer
 			    }
 			});
 		
-		PlatformTorrentUtils.addListener(
-			new MetaDataUpdateListener()
-			{
-				public void 
-				metaDataUpdated(
-					TOTorrent torrent )
-				{
-					 DownloadManager dm = core.getGlobalManager().getDownloadManager( torrent );
-
-					 if ( dm == null ){
-						 
-						 Debug.out( "Meta data update: download not found for " + torrent );
-						 
-					 }else{
-						
-						 EnhancedDownloadManager edm = getEnhancedDownload( dm );
-						 
-						 if ( edm != null ){
-							 
-							 edm.refreshMetaData();
-						 }
-					 }
-				}
-			});
-		
 		ExternalStimulusHandler.addListener(
 			new ExternalStimulusListener()
 			{
@@ -197,11 +169,11 @@ DownloadManagerEnhancer
 						
 						synchronized( download_map ){
 
-							Iterator it = download_map.values().iterator();
+							Iterator<EnhancedDownloadManager> it = download_map.values().iterator();
 							
 							while( it.hasNext()){
 								
-								EnhancedDownloadManager	edm = (EnhancedDownloadManager)it.next();
+								EnhancedDownloadManager	edm = it.next();
 								
 								if ( b_hash != null ){
 									
@@ -270,8 +242,6 @@ DownloadManagerEnhancer
 					{
 						tick_count++;
 						
-						boolean	check_publish = tick_count % PUBLISHING_CHECK_TICKS == 0;
-						
 						List	downloads = core.getGlobalManager().getDownloadManagers();
 						
 						for ( int i=0;i<downloads.size();i++){
@@ -290,11 +260,6 @@ DownloadManagerEnhancer
 								
 								edm.updateStats( tick_count );
 							
-								if ( 	state == DownloadManager.STATE_SEEDING &&
-										check_publish ){
-											
-									edm.checkPublishing();
-								}
 							}
 						}
 					}
@@ -314,10 +279,16 @@ DownloadManagerEnhancer
 							getEnhancedDownload(
 									PluginCoreUtils.unwrap(channel.getFile().getDownload()));
 
-						if (edm == null) {
+						if ( edm == null ){
+							
 							return;
 						}
 
+						if ( edm.getDownloadManager().isDownloadComplete( true )){
+						
+							return;
+						}
+						
 						if ( !edm.getProgressiveMode()){
 							
 							if ( edm.supportsProgressiveMode()){
@@ -387,11 +358,11 @@ DownloadManagerEnhancer
 			return( true );
 		}
 	
-		PluginInterface	ms_pi = core.getPluginManager().getPluginInterfaceByID( "azupnpav" );
+		PluginInterface	ms_pi = core.getPluginManager().getPluginInterfaceByID( "azupnpav", true );
 		
 		if ( ms_pi != null ){
 			
-			progressive_enabled = ms_pi.isOperational();
+			progressive_enabled = true;
 		}
 		
 		return( progressive_enabled );
@@ -406,12 +377,8 @@ DownloadManagerEnhancer
 	public DownloadManager findDownloadManager(String hash) {
 		synchronized (download_map) {
 
-			if (download_map == null) {
-				return null;
-			}
-
-			for (Iterator iter = download_map.keySet().iterator(); iter.hasNext();) {
-				DownloadManager dm = (DownloadManager) iter.next();
+			for (Iterator<DownloadManager> iter = download_map.keySet().iterator(); iter.hasNext();) {
+				DownloadManager dm = iter.next();
 
 				TOTorrent torrent = dm.getTorrent();
 				if (PlatformTorrentUtils.isContent(torrent, true)) {
