@@ -59,7 +59,6 @@ import com.aelitis.azureus.core.instancemanager.AZInstanceManager;
 import com.aelitis.azureus.core.instancemanager.AZInstanceManagerAdapter;
 import com.aelitis.azureus.core.instancemanager.AZInstanceManagerFactory;
 import com.aelitis.azureus.core.instancemanager.AZInstanceTracked;
-import com.aelitis.azureus.core.instancemanager.AZInstanceManagerAdapter.VCPublicAddress;
 import com.aelitis.azureus.core.nat.NATTraverser;
 import com.aelitis.azureus.core.networkmanager.NetworkManager;
 import com.aelitis.azureus.core.networkmanager.admin.NetworkAdmin;
@@ -68,6 +67,7 @@ import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminNetworkInterfac
 import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminPropertyChangeListener;
 import com.aelitis.azureus.core.networkmanager.impl.tcp.TCPNetworkManager;
 import com.aelitis.azureus.core.networkmanager.impl.udp.UDPNetworkManager;
+import com.aelitis.azureus.core.pairing.PairingManagerFactory;
 import com.aelitis.azureus.core.peermanager.PeerManager;
 import com.aelitis.azureus.core.peermanager.nat.PeerNATTraverser;
 import com.aelitis.azureus.plugins.clientid.ClientIDPlugin;
@@ -242,7 +242,7 @@ AzureusCoreImpl
 			});
 		
 			//ensure early initialization
-		
+				
 		CustomizationManagerFactory.getSingleton();
 		
 		NetworkManager.getSingleton();
@@ -901,9 +901,8 @@ AzureusCoreImpl
 						protected void
 						checkConfig()
 						{
-							String	key = TransferSpeedValidator.getActiveAutoUploadParameter( global_manager );
-							
-							speed_manager.setEnabled( COConfigurationManager.getBooleanParameter( key ));
+
+							speed_manager.setEnabled( TransferSpeedValidator.isAutoSpeedActive(global_manager) );
 						}
 						
 					});
@@ -916,6 +915,8 @@ AzureusCoreImpl
 		   global_manager.resumeDownloads();
 	   }
 	    
+	   VersionCheckClient.getSingleton().initialise();
+
 	   instance_manager.initialize();
 
 	   NetworkManager.getSingleton().initialize(this); 
@@ -1023,6 +1024,8 @@ AzureusCoreImpl
 				return;
 			}
 
+	   PairingManagerFactory.getSingleton();
+	   
 	   Object[] runningListeners;
 	   mon_coreRunningListeners.enter();
 	   try {
@@ -1089,7 +1092,7 @@ AzureusCoreImpl
 			}
 		}
 		
-		Debug.out("Core Start Complete");
+		// Debug.out("Core Start Complete");
 	}
 
 	public boolean
@@ -1346,6 +1349,15 @@ AzureusCoreImpl
 				AzureusRestarterFactory.create( this ).restart( true );
 			}
 			
+			try {
+	      Class c = Class.forName( "sun.awt.AWTAutoShutdown" );
+	      
+	      if (c != null) {
+		      c.getMethod( "notifyToolkitThreadFree", new Class[]{} ).invoke( null, new Object[]{} );
+	      }
+			} catch (Throwable t) {
+			}
+			
 			try{
 				ThreadGroup	tg = Thread.currentThread().getThreadGroup();
 				
@@ -1357,7 +1369,7 @@ AzureusCoreImpl
 					
 					final Thread	t = threads[i];
 					
-					if ( t != null && t != Thread.currentThread() && !t.isDaemon() && !AEThread2.isOurThread( t )){
+					if ( t != null && t.isAlive() && t != Thread.currentThread() && !t.isDaemon() && !AEThread2.isOurThread( t )){
 						
 						new AEThread2( "VMKiller", true )
 						{
@@ -1366,7 +1378,7 @@ AzureusCoreImpl
 							{
 								try{
 									Thread.sleep(10*1000);
-								
+									
 									Debug.out( "Non-daemon thread found '" + t.getName() + "', force closing VM" );
 									
 									SESecurityManager.exitVM(0);
