@@ -24,10 +24,7 @@ import java.util.Collection;
 import java.util.Map;
 
 import com.aelitis.azureus.core.messenger.browser.BrowserMessageDispatcher;
-import com.aelitis.azureus.core.messenger.browser.BrowserTransaction;
-import com.aelitis.azureus.core.messenger.browser.BrowserTransactionManager;
 import com.aelitis.azureus.core.messenger.browser.listeners.BrowserMessageListener;
-import com.aelitis.azureus.ui.swt.browser.msg.MessageDispatcher;
 
 /**
  * @author TuxPaper
@@ -36,37 +33,12 @@ import com.aelitis.azureus.ui.swt.browser.msg.MessageDispatcher;
  */
 public interface ClientMessageContext
 {
-
-	/**
-	 * Attaches this context and its message dispatcher to the browser.
-	 * 
-	 * @param browser the browser to be attached
-	 * @param widgetWaitingIndicator Widget to be shown when browser is loading
-	 */
-	public abstract void registerBrowser(final Object browser,
-			Object widgetWaitingIndicator);
-
-	/**
-	 * Detaches everything from this context's browser.
-	 */
-	public abstract void deregisterBrowser();
-
 	public abstract void addMessageListener(BrowserMessageListener listener);
 
 	public abstract void removeMessageListener(String listenerId);
 
 	public abstract void removeMessageListener(BrowserMessageListener listener);
 
-	public abstract BrowserTransactionManager getTransactionManager();
-
-	public abstract void registerTransactionType(String type, Class clazz);
-
-	public abstract BrowserTransaction getTransaction(String type);
-
-	public abstract BrowserTransaction startTransaction(String type);
-
-	public abstract BrowserTransaction cancelTransaction(String type);
-
 	public abstract Object getBrowserData(String key);
 
 	public abstract void setBrowserData(String key, Object value);
@@ -107,11 +79,6 @@ public interface ClientMessageContext
 
 	public BrowserMessageDispatcher getDispatcher();
 	
-	// DO NOT USE. LEGACY
-	// TODO: Remove after EMP update for 3.1.0.0
-	// THIS IS THE ONLY REMAINING SWT DEPENDENCY LEFT in core.message
-	public MessageDispatcher getMessageDispatcher();
-
 	/**
 	 * @param key
 	 * @param op
@@ -128,4 +95,28 @@ public interface ClientMessageContext
 	 * @since 3.0.5.3
 	 */
 	void setMessageDispatcher(BrowserMessageDispatcher dispatcher);
+	
+	void setTorrentURLHandler( torrentURLHandler handler );
+	
+	public interface
+	torrentURLHandler
+	{
+		public void
+		handleTorrentURL(
+			String		url );
+	}
+
+	/**
+	 * @param contentNetwork
+	 *
+	 * @since 4.0.0.5
+	 */
+	void setContentNetworkID(long id);
+
+	/**
+	 * @return
+	 *
+	 * @since 4.0.0.5
+	 */
+	long getContentNetworkID();
 }
\ No newline at end of file
