@@ -24,15 +24,17 @@ import java.util.*;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.SystemTime;
 import org.gudy.azureus2.platform.PlatformManager;
 import org.gudy.azureus2.platform.PlatformManagerFactory;
 
+import com.aelitis.azureus.core.cnetwork.ContentNetwork;
+import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
 import com.aelitis.azureus.core.messenger.PlatformMessage;
 import com.aelitis.azureus.core.messenger.PlatformMessenger;
 import com.aelitis.azureus.core.messenger.PlatformMessengerListener;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
-import com.aelitis.azureus.util.Constants;
-import com.aelitis.azureus.util.MapUtils;
+import com.aelitis.azureus.util.*;
 
 import org.gudy.azureus2.plugins.platform.PlatformManagerException;
 
@@ -45,83 +47,36 @@ public class PlatformConfigMessenger
 {
 	public static final String LISTENER_ID = "config";
 
-	public static final String SECTION_TYPE_BIGBROWSE = "browse";
-
-	public static final String SECTION_TYPE_MINIBROWSE = "minibrowse";
+	private static boolean allowSendDeviceList = false;
 
 	private static int iRPCVersion = 0;
 
-	private static String DEFAULT_RPC_WHITELIST = "https?://"
-			+ Constants.URL_ADDRESS.replaceAll("\\.", "\\\\.") + ":?[0-9]*/" + ".*";
-	
-	//private static String RPC_WHITELIST = "AZMSG%3B[0-9]+%3B.*";
-
-	private static String[] sURLWhiteList = new String[] {
-		DEFAULT_RPC_WHITELIST,
-	};
-
 	private static String playAfterURL = null;
 
-	private static boolean sendStats;
+	private static boolean sendStats = true;
 
-	protected static List listBlack = Collections.EMPTY_LIST;
-
-	protected static long buddySyncOnShareMinTime;
+	private static boolean doUrlQOS = false;
 	
-	public static void getBrowseSections(String sectionType, long maxDelayMS,
-			final GetBrowseSectionsReplyListener replyListener) {
+	private static boolean platformLoginComplete = false;
 
-		PlatformMessage message = new PlatformMessage("AZMSG", LISTENER_ID,
-				"get-browse-sections", new Object[] {
-					"section-type",
-					sectionType,
-					"locale",
-					Locale.getDefault().toString()
-				}, maxDelayMS);
-
-		PlatformMessengerListener listener = new PlatformMessengerListener() {
-			public void messageSent(PlatformMessage message) {
-				replyListener.messageSent();
-			}
-
-			public void replyReceived(PlatformMessage message, String replyType,
-					Map reply) {
-				if (reply != null) {
-					List array = (List) reply.get("value");
-					Map[] newReply = new HashMap[array.size()];
-					for (int i = 0; i < newReply.length; i++) {
-						newReply[i] = (Map) array.get(i);
-
-						String url = (String) newReply[i].get("url");
-						if (url != null && !url.startsWith("http://")) {
-							url = Constants.URL_PREFIX + url;
-							if (url.indexOf('?') < 0) {
-								url += "?";
-							} else {
-								url += "&";
-							}
-							url += Constants.URL_SUFFIX;
-
-							newReply[i].put("url", url);
-						}
-					}
-					replyListener.replyReceived(newReply);
-				} else {
-					replyListener.replyReceived(new Map[0]);
-				}
-			}
-		};
-
-		PlatformMessenger.queueMessage(message, listener);
-	}
-
-	public static void login(long maxDelayMS) {
+	protected static List platformLoginCompleteListeners = Collections.EMPTY_LIST;
+	
+	public static void login(long contentNetworkID, long maxDelayMS) {
 		PlatformManager pm = PlatformManagerFactory.getPlatformManager();
 		String azComputerID = "";
 		try {
 			azComputerID = pm.getAzComputerID();
 		} catch (PlatformManagerException e) {
 		}
+		
+		String sourceRef = null;
+		if (contentNetworkID != ConstantsVuze.DEFAULT_CONTENT_NETWORK_ID) {
+  		ContentNetwork cn = ContentNetworkManagerFactory.getSingleton().getContentNetwork(contentNetworkID);
+  		sourceRef = (String) cn.getPersistentProperty(ContentNetwork.PP_SOURCE_REF);
+		}
+		if (sourceRef == null) {
+			sourceRef = "unknown";
+		}
 
 		Object[] params = new Object[] {
 			"version",
@@ -132,9 +87,12 @@ public class PlatformConfigMessenger
 			azComputerID,
 			"vid",
 			COConfigurationManager.getStringParameter("ID"),
+			"source-ref",
+			sourceRef
 		};
 		PlatformMessage message = new PlatformMessage("AZMSG", LISTENER_ID,
 				"login", params, maxDelayMS);
+		message.setContentNetworkID(contentNetworkID);
 
 		PlatformMessengerListener listener = new PlatformMessengerListener() {
 
@@ -143,26 +101,36 @@ public class PlatformConfigMessenger
 				if (reply == null) {
 					return;
 				}
+				
+				boolean allowMulti = MapUtils.getMapBoolean(reply, "allow-multi-rpc",
+						PlatformMessenger.getAllowMulti());
+				PlatformMessenger.setAllowMulti(allowMulti);
 
 				try {
 					List listURLs = (List) MapUtils.getMapObject(reply, "url-whitelist",
 							null, List.class);
 					if (listURLs != null) {
-						String[] sNewWhiteList = new String[listURLs.size() + 1];
-						sNewWhiteList[0] = DEFAULT_RPC_WHITELIST;
-
 						for (int i = 0; i < listURLs.size(); i++) {
 							String string = (String) listURLs.get(i);
-							PlatformMessenger.debug("v3.login: got whitelist of " + string);
-							sNewWhiteList[i + 1] = string;
+							UrlFilter.getInstance().addUrlWhitelist(string);
+						}
+					}
+				} catch (Exception e) {
+					Debug.out(e);
+				}
+
+				try {
+					List listURLs = (List) MapUtils.getMapObject(reply, "url-blacklist",
+							null, List.class);
+					if (listURLs != null) {
+						for (int i = 0; i < listURLs.size(); i++) {
+							String string = (String) listURLs.get(i);
+							UrlFilter.getInstance().addUrlBlacklist(string);
 						}
-						sURLWhiteList = sNewWhiteList;
 					}
 				} catch (Exception e) {
 					Debug.out(e);
 				}
-				
-				listBlack = MapUtils.getMapList(reply, "url-blacklist", Collections.EMPTY_LIST);
 				
 
 				try {
@@ -179,13 +147,18 @@ public class PlatformConfigMessenger
 					Debug.out(e);
 				}
 				
+				if (message.getContentNetworkID() != ConstantsVuze.getDefaultContentNetwork().getID()) {
+					return;
+				}
+				
 				try {
-					sendStats = MapUtils.getMapBoolean(reply, "send-stats", true);
+					sendStats = MapUtils.getMapBoolean(reply, "send-stats", false);
+					doUrlQOS = MapUtils.getMapBoolean(reply, "do-url-qos", false);
+					allowSendDeviceList = MapUtils.getMapBoolean(reply, "send-device-list", false);
 				} catch (Exception e) {
 				}
 				
-				buddySyncOnShareMinTime = MapUtils.getMapLong(reply, "buddy-sync-on-share-min-time-secs", 60000);
-
+				
 				try {
   				iRPCVersion = MapUtils.getMapInt(reply, "rpc-version", 0);
   				playAfterURL = (String) MapUtils.getMapString(reply,
@@ -193,6 +166,18 @@ public class PlatformConfigMessenger
 				} catch (Exception e) {
 					Debug.out(e);
 				}
+				
+				platformLoginComplete = true;
+				Object[] listeners = platformLoginCompleteListeners.toArray();
+				platformLoginCompleteListeners = Collections.EMPTY_LIST;
+				for (int i = 0; i < listeners.length; i++) {
+					try {
+						PlatformLoginCompleteListener l = (PlatformLoginCompleteListener) listeners[i];
+						l.platformLoginComplete();
+					} catch (Exception e) {
+						Debug.out(e);
+					}
+				}
 			}
 
 			public void messageSent(PlatformMessage message) {
@@ -200,10 +185,10 @@ public class PlatformConfigMessenger
 
 		};
 
-		PlatformMessenger.queueMessage(message, listener);
+		PlatformMessenger.pushMessageNow(message, listener);
 	}
 
-	public static void sendUsageStats(Map stats, long timestamp,
+	public static void sendUsageStats(Map stats, long timestamp, String version,
 			PlatformMessengerListener l) {
 		if (!sendStats) {
 			return;
@@ -214,9 +199,11 @@ public class PlatformConfigMessenger
 						"stats",
 						stats,
 						"version",
-						org.gudy.azureus2.core3.util.Constants.AZUREUS_VERSION,
+						version,
 						"timestamp",
-						new Long(timestamp)
+						new Long(timestamp),
+						"ago-ms",
+						new Long(SystemTime.getCurrentTime() - timestamp),
 					}, 5000);
 
 			PlatformMessenger.queueMessage(message, l);
@@ -232,49 +219,7 @@ public class PlatformConfigMessenger
 		public void replyReceived(Map[] browseSections);
 	}
 
-	public static String[] getURLWhitelist() {
-		return sURLWhiteList;
-	}
-
-	public static boolean urlCanRPC(String url) {
-		return urlCanRPC(url, false);
-	}
 	
-	public static boolean urlCanRPC(String url,boolean showDebug) {
-		if (url == null) {
-			Debug.out("URL null and should be blocked");
-			return false;
-		}
-
-		String[] whitelist = PlatformConfigMessenger.getURLWhitelist();
-		for (int i = 0; i < whitelist.length; i++) {
-			if (url.matches(whitelist[i])) {
-				return true;
-			}
-		}
-		if(showDebug) {
-			Debug.out("urlCanRPC: URL '" + url + "' " + " does not match one of the "
-					+ whitelist.length + " whitelist entries");
-		}
-		return false;
-	}
-	
-	public static boolean isURLBlocked(String url) {
-		if (url == null) {
-			Debug.out("URL null and should be blocked");
-			return true;
-		}
-
-		for (Iterator iter = listBlack.iterator(); iter.hasNext();) {
-			String blackListed = (String) iter.next();
-			if (url.matches(blackListed)) {
-				Debug.out("URL '" + url + "' " + " is blocked by " + blackListed);
-				return true;
-			}
-		}
-		return false;
-	}
-
 	/**
 	 * @return the iRPCVersion
 	 */
@@ -290,11 +235,40 @@ public class PlatformConfigMessenger
 		return sendStats;
 	}
 
-	public static long getBuddySyncOnShareMinTimeSecs() {
-		return buddySyncOnShareMinTime;
+	/**
+	 * @return
+	 *
+	 * @since 4.0.0.1
+	 */
+	public static boolean doUrlQOS() {
+		return doUrlQOS;
+	}
+	
+	public static void addPlatformLoginCompleteListener(
+			PlatformLoginCompleteListener l) {
+		try {
+			if (l == null) {
+				return;
+			}
+			if (platformLoginComplete) {
+				l.platformLoginComplete();
+				return;
+			}
+			if (platformLoginCompleteListeners == Collections.EMPTY_LIST) {
+				platformLoginCompleteListeners = new ArrayList(1);
+			}
+			platformLoginCompleteListeners.add(l);
+		} catch (Exception e) {
+			Debug.out(e);
+		}
+	}
+	
+	public static interface PlatformLoginCompleteListener {
+		public void platformLoginComplete();
 	}
 
-	public static void setBuddySyncOnShareMinTimeSecs(long buddySyncOnShareMinTime) {
-		PlatformConfigMessenger.buddySyncOnShareMinTime = buddySyncOnShareMinTime;
+
+	public static boolean allowSendDeviceList() {
+		return allowSendDeviceList;
 	}
 }
