@@ -30,6 +30,7 @@ import java.util.*;
 
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.util.AEDiagnostics;
 import org.gudy.azureus2.core3.util.BEncoder;
@@ -65,6 +66,24 @@ EngineImpl
 {
 	private static final int DEFAULT_UPDATE_CHECK_SECS = 24*60*60;
 	
+	private static boolean logging_enabled;
+	
+	static{
+		COConfigurationManager.addAndFireParameterListeners(
+			new String[]{
+				"Logger.Enabled",
+			},
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					String parameterName) 
+				{			
+					logging_enabled = COConfigurationManager.getBooleanParameter( "Logger.Enabled" );
+				}
+			});
+	}
+	
 	protected static EngineImpl
 	importFromBEncodedMap(
 		MetaSearchImpl		meta_search,
@@ -161,6 +180,10 @@ EngineImpl
 	
 	private int			source	= ENGINE_SOURCE_UNKNOWN;
 	
+	private float		rank_bias		= 1;
+	private float		preferred_count	= 0;
+	
+	
 		// first mappings used to canonicalise names and map field to same field
 		// typically used for categories (musak->music)
 	
@@ -222,6 +245,9 @@ EngineImpl
 		
 		source			= (int)ImportExportUtils.importLong( map, "source", ENGINE_SOURCE_UNKNOWN );
 		
+		rank_bias		= ImportExportUtils.importFloat( map, "rank_bias", 1.0f );
+		preferred_count	= ImportExportUtils.importFloat( map, "pref_count", 0.0f );
+		
 		first_level_mapping 	= importBEncodedMappings( map, "l1_map" );
 		second_level_mapping 	= importBEncodedMappings( map, "l2_map" );
 		
@@ -265,6 +291,9 @@ EngineImpl
 		
 		map.put( "source", new Long( source ));
 		
+		ImportExportUtils.exportFloat( map, "rank_bias", rank_bias );
+		ImportExportUtils.exportFloat( map, "pref_count", preferred_count );
+		
 		exportBEncodedMappings( map, "l1_map", first_level_mapping );
 		exportBEncodedMappings( map, "l2_map", second_level_mapping );
 		
@@ -625,7 +654,18 @@ EngineImpl
 			Map	m1 = exportToBencodedMap();
 			Map	m2 = other.exportToBencodedMap();
 		
-			String[]	to_remove = {"type","id","last_updated","selected","select_rec","source", "version", "az_version", "uid" };
+			String[]	to_remove = 
+				{	"type", 
+					"id", 
+					"last_updated",
+					"selected",
+					"select_rec",
+					"source",
+					"rank_bias",
+					"pref_count",
+					"version", 
+					"az_version", 
+					"uid" };
 			
 			for (int i=0;i<to_remove.length;i++){
 				
@@ -645,12 +685,12 @@ EngineImpl
 		
 	public Result[]
 	search(
-		SearchParameter[] 	params,
-		Map					context,
-		int					desired_max_matches,
-		int					absolute_max_matches,
-		String				headers,
-		ResultListener		listener )
+		SearchParameter[] 		params,
+		Map						context,
+		int						desired_max_matches,
+		int						absolute_max_matches,
+		String					headers,
+		final ResultListener	listener )
 	
 		throws SearchException
 	{
@@ -660,13 +700,99 @@ EngineImpl
 		}
 		
 		try{
-			Result[] results = searchAndMap( params, context, desired_max_matches, absolute_max_matches, headers, listener) ;
+			final Set<Result>		results_informed 	= new HashSet<Result>();
+			final boolean[]			complete_informed	= { false };
+			
+			ResultListener	interceptor = 
+				new ResultListener()
+				{
+					public void 
+					contentReceived(
+						Engine 		engine, 
+						String 		content )
+					{
+						listener.contentReceived(engine, content);
+					}
+				
+					public void 
+					matchFound( 
+						Engine engine, 
+						String[] fields )
+					{
+						listener.matchFound(engine, fields);
+					}
+				
+					public void 
+					resultsReceived(
+						Engine engine,
+						Result[] 	results )
+					{
+						listener.resultsReceived(engine, results);
+						
+						synchronized( results_informed ){
+							
+							results_informed.addAll( Arrays.asList( results ));
+						}
+					}
+				
+					public void 
+					resultsComplete(
+						Engine 		engine)
+					{
+						listener.resultsComplete(engine);
+						
+						synchronized( results_informed ){
+							
+							complete_informed[0] = true;
+						}
+					}
+				
+					public void 
+					engineFailed(
+						Engine 		engine, 
+						Throwable 	cause )
+					{
+						listener.engineFailed(engine, cause);
+					}
+					
+					public void 
+					engineRequiresLogin(
+						Engine 		engine, 
+						Throwable 	cause )
+					{
+						listener.engineRequiresLogin(engine, cause);
+					}
+				};
+				
+			Result[] results = searchAndMap( params, context, desired_max_matches, absolute_max_matches, headers, listener==null?null:interceptor );
 			
 			if ( listener != null ){
 				
-				listener.resultsReceived( this, results );
+				boolean			inform_complete;
+				List<Result>	inform_result = new ArrayList<Result>();
 				
-				listener.resultsComplete( this );
+				synchronized( results_informed ){
+					
+					for ( Result r: results ){
+						
+						if ( !results_informed.contains( r )){
+							
+							inform_result.add( r );
+						}
+					}
+					
+					inform_complete = !complete_informed[0];
+				}
+				
+				if ( inform_result.size() > 0 ){
+				
+					listener.resultsReceived( this, inform_result.toArray( new Result[ inform_result.size()] ));
+				}
+				
+				if ( inform_complete ){
+				
+					listener.resultsComplete( this );
+				}
 			}
 			
 			return( results );
@@ -1007,6 +1133,62 @@ EngineImpl
 		}
 	}
 	
+	public float
+	getRankBias()
+	{
+		return( rank_bias );
+	}
+	
+	public void
+	setRankBias(
+		float	_rank_bias )
+	{
+		if ( rank_bias != _rank_bias ){
+			
+			rank_bias	= _rank_bias;
+		
+			configDirty();
+		}
+	}
+	
+	public void
+	setPreferredDelta(
+		float	 delta )
+	{
+		float new_pref = preferred_count + delta;
+		
+		new_pref = Math.max( 0, new_pref );
+		new_pref = Math.min( 10, new_pref );
+		
+		if ( new_pref != preferred_count ){
+			
+			preferred_count = new_pref;
+			
+			configDirty();
+		}
+	}
+	
+	public float
+	getPreferredWeighting()
+	{
+		return( preferred_count );
+	}
+	
+	public float
+	applyRankBias(
+		float	rank )
+	{
+		rank *= rank_bias;
+				
+		rank *= (1 + 0.025 * preferred_count );
+		
+		rank = Math.min( rank, 1.0f );
+		
+		rank = Math.max( rank, 0.0f );
+		
+		return( rank );
+	}
+	
 	public boolean
 	isMine()
 	{
@@ -1294,13 +1476,25 @@ EngineImpl
 	protected File
 	getDebugFile()
 	{
-		return( new File( AEDiagnostics.getLogDir(), "MetaSearch_Engine_" + getId() + ".txt" ));
+		if ( logging_enabled ){
+		
+			return( new File( AEDiagnostics.getLogDir(), "MetaSearch_Engine_" + getId() + ".txt" ));
+			
+		}else{
+			
+			return( null );
+		}
 	}
 	
 	protected synchronized void
 	debugStart()
 	{
-		getDebugFile().delete();
+		File f = getDebugFile();
+		
+		if ( f != null ){
+			
+			f.delete();
+		}
 	}
 	
 	protected synchronized void
@@ -1309,20 +1503,23 @@ EngineImpl
 	{
 		File f = getDebugFile();
 		
-		PrintWriter	 pw = null;
-		
-		try{
-			pw = new PrintWriter(new FileWriter( f, true ));
+		if ( f != null ){
 			
-			pw.println( str );
+			PrintWriter	 pw = null;
 			
-		}catch( Throwable e ){
-			
-		}finally{
-			
-			if ( pw != null ){
+			try{
+				pw = new PrintWriter(new FileWriter( f, true ));
 				
-				pw.close();
+				pw.println( str );
+				
+			}catch( Throwable e ){
+				
+			}finally{
+				
+				if ( pw != null ){
+					
+					pw.close();
+				}
 			}
 		}
 	}
@@ -1351,7 +1548,7 @@ EngineImpl
 	public String
 	getString()
 	{
-		return( "id=" + getId() + ", name=" + getName() + ", source=" + ENGINE_SOURCE_STRS[getSource()] + ", selected=" + SEL_STATE_STRINGS[getSelectionState()]);
+		return( "id=" + getId() + ", name=" + getName() + ", source=" + ENGINE_SOURCE_STRS[getSource()] + ", selected=" + SEL_STATE_STRINGS[getSelectionState()] + ", rb=" + rank_bias + ", pref=" + preferred_count );
 	}
 	
 	public String
