@@ -36,6 +36,7 @@ import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.DelayedEvent;
 import org.gudy.azureus2.core3.util.FileUtil;
+import org.gudy.azureus2.core3.util.HashWrapper;
 import org.gudy.azureus2.core3.util.IndentWriter;
 import org.gudy.azureus2.core3.util.SimpleTimer;
 import org.gudy.azureus2.core3.util.SystemTime;
@@ -108,6 +109,7 @@ MetaSearchImpl
 		int			type,
 		long		id,
 		long		last_updated,
+		float		rank_bias,
 		String		name,
 		String		content )
 	
@@ -458,6 +460,7 @@ MetaSearchImpl
 						details.getType()==PlatformMetaSearchMessenger.templateDetails.ENGINE_TYPE_JSON?Engine.ENGINE_TYPE_JSON:Engine.ENGINE_TYPE_REGEX,
 						details.getId(),
 						details.getModifiedDate(),
+						details.getRankBias(),
 						details.getName(),
 						details.getValue());
 				
@@ -700,6 +703,43 @@ MetaSearchImpl
 		return( search( engines, listener, search_parameters, headers, new HashMap<String,String>(), max_results_per_engine ));
 	}
 	
+	public void
+	enginePreferred(
+		Engine		engine )
+	{
+		Engine[] engines = getEngines( true, false );
+		
+		int	num_other_preferred = 0;
+		
+		for ( Engine e: engines ){
+			
+			if ( e.getId() == engine.getId()){
+				
+				e.setPreferredDelta( +1 );
+				
+			}else{
+				
+				if ( e.getPreferredWeighting() > 0 ){
+					
+					num_other_preferred++;
+				}
+			}
+		}
+				
+		if ( num_other_preferred > 0 ){
+			
+			float negative_weighting = -1 / num_other_preferred;
+		
+			for ( Engine e: engines ){
+			
+				if ( e.getId() != engine.getId() && e.getPreferredWeighting() > 0 ){
+				
+					e.setPreferredDelta( negative_weighting );
+				}
+			}
+		}
+	}
+	
 	public Engine[] 
   	search(
   		Engine[]				engines,
@@ -718,6 +758,14 @@ MetaSearchImpl
 			param_str += (i==0?"":",") + param.getMatchPattern() + "->" + param.getValue();
 		}
 		
+		String batch_millis_str = context.get( Engine.SC_BATCH_PERIOD );
+		
+		final long batch_millis = batch_millis_str==null?0:Long.parseLong( batch_millis_str );
+		
+		String rem_dups_str = context.get( Engine.SC_REMOVE_DUP_HASH );
+		
+		final boolean rem_dups = rem_dups_str==null?false:rem_dups_str.equalsIgnoreCase( "true" );
+
 		ResultListener	listener = 
 			new ResultListener()
 			{
@@ -725,7 +773,11 @@ MetaSearchImpl
 			
 				private AsyncDispatcher dispatcher = new AsyncDispatcher( 5000 );
 
-				public void 
+				final private Map<Engine,List<Result[]>>	pending_results = new HashMap<Engine,List<Result[]>>();
+				
+				final private Map<Engine,Set<String>>	result_hashes = new HashMap<Engine, Set<String>>();
+				
+				public void
 				contentReceived(
 					final Engine engine, 
 					final String content ) 
@@ -768,9 +820,52 @@ MetaSearchImpl
 							public void
 							runSupport()
 							{
-								Result[] results_to_return = truncateResults( engine, results, max_results_per_engine );
+								Result[] results_to_return = null;
 								
-								original_listener.resultsReceived( engine, results_to_return );
+								if ( batch_millis > 0 ){
+									
+									List<Result[]> list = pending_results.get( engine );
+																		
+									if ( list == null ){
+																			
+										results_to_return = results;
+										
+										pending_results.put( engine, new ArrayList<Result[]>());
+										
+										new DelayedEvent(
+											"SearchBatcher",
+											batch_millis,
+											new AERunnable()
+											{
+												public void 
+												runSupport() 
+												{
+													dispatcher.dispatch(
+														new AERunnable()
+														{
+															public void 
+															runSupport() 
+															{
+																batchResultsComplete( engine );
+															}
+														});
+												}
+											});
+									}else{
+																															
+										list.add( results );
+									}
+								}else{
+								
+									results_to_return = results;
+								}
+								
+								if ( results_to_return != null ){
+									
+									results_to_return = truncateResults( engine, results_to_return, max_results_per_engine );
+									
+									original_listener.resultsReceived( engine, results_to_return );
+								}
 							}
 						});
 				}
@@ -785,11 +880,141 @@ MetaSearchImpl
 								public void
 								runSupport()
 								{
+									if ( batch_millis > 0 ){
+
+										batchResultsComplete( engine );
+									}
+									
 									original_listener.resultsComplete( engine );
 								}
 							});
 				}
 			
+				protected void
+				batchResultsComplete(
+					Engine engine )
+				{
+					List<Result[]> list = pending_results.remove( engine );
+					
+					if ( list != null ){
+						
+						List<Result> x = new ArrayList<Result>();
+						
+						for ( Result[] y: list ){
+							
+							x.addAll( Arrays.asList( y ));
+						}
+						
+						Result[] results = x.toArray( new Result[ x.size()]);
+					
+						results = truncateResults( engine, results, max_results_per_engine );
+					
+						original_listener.resultsReceived( engine, results );
+					}
+				}
+				
+				protected Result[]
+             	truncateResults(
+             		Engine		engine,
+             		Result[] 	a_results,
+             		int			max )
+             	{
+					Set<String>	hash_set = result_hashes.get( engine );
+					
+					if ( hash_set == null ){
+						
+						hash_set = new HashSet<String>();
+						
+						result_hashes.put( engine, hash_set );
+					}
+						
+					List<Result>	results = new ArrayList<Result>( a_results.length );
+					
+					for ( Result r: a_results ){
+							
+						String name = r.getName();
+							
+						if ( name == null || name.trim().length() == 0 ){
+								
+							continue;
+						}
+					
+						if ( rem_dups ){
+
+							String hash = r.getHash();
+							
+							if ( 	hash == null ||
+									hash.length() == 0 ){
+								
+								results.add( r );
+								
+							}else{
+								
+								if ( !hash_set.contains( hash )){
+									
+									results.add( r );
+									
+									hash_set.add( hash );
+								}
+							}
+						}else{
+							
+							results.add( r );
+						}
+					}
+					
+             		if ( max < results.size() ){
+             		
+             			log( "Truncating search results for " + engine.getName() + " from " + results.size() + " to " + max );
+             			
+             			Collections.sort(
+             				results,
+             				new Comparator<Result>()
+             				{
+             					Map<Result,Float>	ranks = new HashMap<Result, Float>();
+             					
+             					public int 
+             					compare(
+             						Result r1, 
+             						Result r2) 
+             					{						
+             						Float	rank1 = (Float)ranks.get(r1);
+             						
+             						if ( rank1 == null ){	
+             							rank1 = new Float(r1.getRank());
+             							ranks.put( r1, rank1 );
+             						}
+             						
+             						Float	rank2 = (Float)ranks.get(r2);
+             						
+             						if ( rank2 == null ){	
+             							rank2 = new Float(r2.getRank());
+             							ranks.put( r2, rank2 );
+             						}
+             						
+             						return( -rank1.compareTo( rank2 ));
+             					}
+             				});
+             		
+             			Result[] x = new Result[max];
+             			
+             			int	pos = 0;
+             			
+             			while( pos < max ){
+             			
+             				x[pos] = results.get( pos );
+             				
+             				pos++;
+             			}
+             			
+             			return( x );
+             			
+             		}else{
+             			
+             			return( results.toArray( new Result[ results.size()] ));
+             		}
+             	}
+				
 				public void 
 				engineFailed(
 					final Engine 	engine,
@@ -847,57 +1072,6 @@ MetaSearchImpl
 		return( engines );
 	}
 	
-	protected Result[]
-	truncateResults(
-		Engine		engine,
-		Result[] 	results,
-		int			max )
-	{
-		if ( max < results.length ){
-		
-			log( "Truncating search results for " + engine.getName() + " from " + results.length + " to " + max );
-			
-			Arrays.sort(
-				results,
-				new Comparator<Result>()
-				{
-					Map<Result,Float>	ranks = new HashMap<Result, Float>();
-					
-					public int 
-					compare(
-						Result r1, 
-						Result r2) 
-					{						
-						Float	rank1 = (Float)ranks.get(r1);
-						
-						if ( rank1 == null ){	
-							rank1 = new Float(r1.getRank());
-							ranks.put( r1, rank1 );
-						}
-						
-						Float	rank2 = (Float)ranks.get(r2);
-						
-						if ( rank2 == null ){	
-							rank2 = new Float(r2.getRank());
-							ranks.put( r2, rank2 );
-						}
-						
-						return( -rank1.compareTo( rank2 ));
-					}
-				});
-		
-			Result[] x = new Result[max];
-			
-			System.arraycopy( results, 0, x, 0, max );
-			
-			return( x );
-			
-		}else{
-			
-			return( results );
-		}
-	}
-	
 	public void
 	addListener(
 		MetaSearchListener		listener )
