@@ -31,11 +31,7 @@ import java.nio.ByteBuffer;
 public interface
 NetworkConnection
 	extends NetworkConnectionBase
-{
-  
-	public ConnectionEndpoint
-	getEndpoint();
-  
+{  
   /**
    * Connect this connection's transport, i.e. establish the network connection.
    * If this connection is already established (from an incoming connection for example),
@@ -43,9 +39,9 @@ NetworkConnection
    * connectSuccess() will be called immediately.
    * @param listener notified on connect success or failure
    */
-  public void connect( ConnectionListener listener );
+  public void connect( int priority, ConnectionListener listener );
 
-  public void connect( ByteBuffer initial_outbound_data, ConnectionListener listener );
+  public void connect( ByteBuffer initial_outbound_data, int priority, ConnectionListener listener );
 
   /**
    * Close and shutdown this connection.
@@ -58,15 +54,21 @@ NetworkConnection
    * @param upload_group upload rate limit group to use
    * @param download_group download rate limit group to use
    */
-  public void startMessageProcessing( LimitedRateGroup upload_group, LimitedRateGroup download_group );
+  public void startMessageProcessing();
   
   
   /**
    * Upgrade the connection to high-speed transfer processing.
    * @param enable true for high-speed processing, false for normal processing
    */
-  public void enableEnhancedMessageProcessing( boolean enable );
+  public void enableEnhancedMessageProcessing( boolean enable, int partition_id );
   
+  /**
+   * Decouples the transport from this network connection so it can be reused
+   * @return null if detach failed
+   */
+  
+  public Transport detachTransport();
   
   /**
    * Get the connection's data transport interface.
@@ -108,5 +110,8 @@ NetworkConnection
      * @param error exception
      */
     public void exceptionThrown( Throwable error );
+    
+    public String
+    getDescription();
   }
 }
