@@ -23,20 +23,23 @@
 package com.aelitis.azureus.core.networkmanager;
 
 import java.nio.ByteBuffer;
+import java.util.ArrayList;
+import java.util.List;
 
-import org.gudy.azureus2.core3.config.*;
+import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.global.GlobalManagerListener;
 import org.gudy.azureus2.core3.util.Debug;
 
-
-
-import com.aelitis.azureus.core.AzureusCoreFactory;
+import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.networkmanager.impl.*;
 import com.aelitis.azureus.core.networkmanager.impl.http.HTTPNetworkManager;
 import com.aelitis.azureus.core.networkmanager.impl.tcp.TCPNetworkManager;
 import com.aelitis.azureus.core.networkmanager.impl.udp.UDPNetworkManager;
-import com.aelitis.azureus.core.peermanager.messaging.*;
+import com.aelitis.azureus.core.peermanager.messaging.MessageStreamDecoder;
+import com.aelitis.azureus.core.peermanager.messaging.MessageStreamEncoder;
+import com.aelitis.azureus.core.peermanager.messaging.MessageStreamFactory;
 import com.aelitis.azureus.core.util.FeatureAvailability;
 
 
@@ -131,24 +134,103 @@ public class NetworkManager {
   }
 
   
-  private final WriteController write_controller = new WriteController();
-  private final ReadController read_controller = new ReadController();
-
   
-  private final TransferProcessor upload_processor = new TransferProcessor( TransferProcessor.TYPE_UPLOAD, new LimitedRateGroup(){
-    public int getRateLimitBytesPerSecond() {  return max_upload_rate_bps;  }
-  });
-  private final TransferProcessor download_processor = new TransferProcessor( TransferProcessor.TYPE_DOWNLOAD, new LimitedRateGroup(){
-    public int getRateLimitBytesPerSecond() {  return max_download_rate_bps;  }
-  });
+  private final List<WriteController> 	write_controllers;
+  private final List<ReadController> 	read_controllers;
+  
+  {
+	 int	num_read = COConfigurationManager.getIntParameter( "network.control.read.processor.count" );
+	 
+	 read_controllers = new ArrayList<ReadController>(num_read);
+	 
+	 for (int i=0;i<num_read;i++){
+		 
+		 read_controllers.add( new ReadController());
+	 }
+	 
+	 int	num_write = COConfigurationManager.getIntParameter( "network.control.write.processor.count" );
+	 
+	 write_controllers = new ArrayList<WriteController>(num_write);
+	 
+	 for (int i=0;i<num_write;i++){
+		 
+		 write_controllers.add( new WriteController());
+	 }
+  }
   
   
-  private final TransferProcessor lan_upload_processor = new TransferProcessor( TransferProcessor.TYPE_UPLOAD, new LimitedRateGroup(){
-    public int getRateLimitBytesPerSecond() {  return max_lan_upload_rate_bps;  }
-  });
-  private final TransferProcessor lan_download_processor = new TransferProcessor( TransferProcessor.TYPE_DOWNLOAD, new LimitedRateGroup(){
-    public int getRateLimitBytesPerSecond() {  return max_lan_download_rate_bps;  }
-  });
+  private final TransferProcessor upload_processor = 
+	  new TransferProcessor( 
+		TransferProcessor.TYPE_UPLOAD, 
+		new LimitedRateGroup()
+		{
+			public String 
+			getName() 
+			{
+				return( "global_up" );
+			}
+			public int 
+			getRateLimitBytesPerSecond() 
+			{  
+				return max_upload_rate_bps;  
+			}
+		},
+		write_controllers.size() > 1 );
+  
+  private final TransferProcessor download_processor = 
+	  new TransferProcessor( 
+		TransferProcessor.TYPE_DOWNLOAD, 
+		new LimitedRateGroup()
+		{
+			public String 
+			getName() 
+			{
+				return( "global_down" );
+			}
+			public int 
+			getRateLimitBytesPerSecond() 
+			{
+				return max_download_rate_bps;  
+			}
+		},
+		read_controllers.size() > 1 );
+  
+  
+  private final TransferProcessor lan_upload_processor = 
+	  new TransferProcessor( 
+		TransferProcessor.TYPE_UPLOAD, 
+		new LimitedRateGroup()
+		{
+			public String 
+			getName() 
+			{
+				return( "global_lan_up" );
+			}
+			public int 
+			getRateLimitBytesPerSecond() 
+			{  
+				return max_lan_upload_rate_bps;  
+			}
+		},
+		write_controllers.size() > 1 );
+  
+  private final TransferProcessor lan_download_processor = 
+	  new TransferProcessor( 
+		TransferProcessor.TYPE_DOWNLOAD, 
+		new LimitedRateGroup()
+		{
+			public String 
+			getName() 
+			{
+				return( "global_lan_down" );
+			}
+			public int 
+			getRateLimitBytesPerSecond() 
+			{  
+				return max_lan_download_rate_bps;  
+			}
+		},
+		read_controllers.size() > 1 );
      
   public static boolean
   isLANRateEnabled()
@@ -233,10 +315,10 @@ public class NetworkManager {
 	  }
   }
   
-  public void initialize() {
+  public void initialize(AzureusCore core) {
 	HTTPNetworkManager.getSingleton();  
 	   
-    AzureusCoreFactory.getSingleton().getGlobalManager().addListener( new GlobalManagerListener() {
+    core.getGlobalManager().addListener( new GlobalManagerListener() {
       public void downloadManagerAdded( DownloadManager dm ){}
       public void downloadManagerRemoved( DownloadManager dm ){}
       public void destroyInitiated(){}
@@ -321,8 +403,17 @@ public class NetworkManager {
    * Add an upload entity for write processing.
    * @param entity to add
    */
-  public void addWriteEntity( RateControlledEntity entity ) {
-    write_controller.addWriteEntity( entity );
+  public void addWriteEntity( RateControlledEntity entity, int partition_id ) {
+	  if ( write_controllers.size() == 1 || partition_id < 0 ){
+		  
+		  write_controllers.get(0).addWriteEntity(entity);
+		  
+	  }else{
+		  
+		  WriteController controller = write_controllers.get((partition_id%(write_controllers.size()-1))+1 );
+
+		  controller.addWriteEntity( entity );
+	  }
   }
   
   
@@ -331,7 +422,13 @@ public class NetworkManager {
    * @param entity to remove
    */
   public void removeWriteEntity( RateControlledEntity entity ) {
-    write_controller.removeWriteEntity( entity );
+	  if ( write_controllers.size() == 1 ){
+		  write_controllers.get(0).removeWriteEntity( entity );
+	  }else{
+		  for (WriteController write_controller: write_controllers ){
+			  write_controller.removeWriteEntity( entity );
+		  }
+	  }
   }
   
   
@@ -339,8 +436,17 @@ public class NetworkManager {
    * Add a download entity for read processing.
    * @param entity to add
    */
-  public void addReadEntity( RateControlledEntity entity ) {
-    read_controller.addReadEntity( entity );
+  public void addReadEntity( RateControlledEntity entity, int partition_id ) {
+	  if ( read_controllers.size() == 1 || partition_id < 0 ){
+		  
+		  read_controllers.get(0).addReadEntity(entity);
+		  
+	  }else{
+		  
+		  ReadController controller = read_controllers.get((partition_id%(read_controllers.size()-1))+1 );
+
+		  controller.addReadEntity( entity );
+	  }
   }
   
   
@@ -349,7 +455,13 @@ public class NetworkManager {
    * @param entity to remove
    */
   public void removeReadEntity( RateControlledEntity entity ) {
-    read_controller.removeReadEntity( entity );
+	  if ( read_controllers.size() == 1 ){
+		  read_controllers.get(0).removeReadEntity( entity );
+	  }else{
+		  for (ReadController read_controller: read_controllers ){
+			  read_controller.removeReadEntity( entity );
+		  }
+	  }
   }  
   
   
@@ -400,14 +512,14 @@ public class NetworkManager {
    * Upgrade the given connection to high-speed network transfer handling.
    * @param peer_connection to upgrade
    */
-  public void upgradeTransferProcessing( NetworkConnectionBase peer_connection ) {
+  public void upgradeTransferProcessing( NetworkConnectionBase peer_connection, int partition_id ) {
 	  if( lan_upload_processor.isRegistered( peer_connection )) {
-  		lan_upload_processor.upgradePeerConnection( peer_connection );
-  		lan_download_processor.upgradePeerConnection( peer_connection );
+  		lan_upload_processor.upgradePeerConnection( peer_connection, partition_id );
+  		lan_download_processor.upgradePeerConnection( peer_connection, partition_id );
   	}
   	else {
-  		upload_processor.upgradePeerConnection( peer_connection );
-  		download_processor.upgradePeerConnection( peer_connection );
+  		upload_processor.upgradePeerConnection( peer_connection, partition_id );
+  		download_processor.upgradePeerConnection( peer_connection, partition_id );
   	}
   }
 
