@@ -68,6 +68,8 @@ OutgoingMessageQueue
    */
   public void destroy();
  
+  public boolean
+  isDestroyed();
   
   /**
    * Get the total number of bytes ready to be transported.
@@ -150,6 +152,16 @@ OutgoingMessageQueue
    */
   public void doListenerNotifications();
  
+  /**
+   * Force all pending messages to be delivered
+   */
+  
+  public void
+  flush();
+  
+  public void
+  setTrace(
+		boolean	on );
   
   public String getQueueTrace();
   
@@ -219,5 +231,7 @@ OutgoingMessageQueue
      * @param byte_count number of data bytes
      */
     public void dataBytesSent( int byte_count );
+    
+    public void flush();
   }
 }
