@@ -53,11 +53,13 @@ Transport
    */
   public TransportEndpoint getTransportEndpoint();  
   
+  public boolean isEncrypted();
+  
   /**
    * Return a textual description of the encryption for this transport
    * @return
    */
-  public String getEncryption();
+  public String getEncryption( boolean verbose );
       
   /**
    * fake a wakeup so that a read cycle is attempted
@@ -110,7 +112,8 @@ Transport
   public void
   connectOutbound(
 		ByteBuffer			initial_data,
-		ConnectListener 	listener );
+		ConnectListener 	listener,
+		int					priority );
    
   /**
    * Indicate that inbound connection is complete 
@@ -124,6 +127,9 @@ Transport
    */
   public void close( String reason );
   
+  public void
+  setTrace(
+		boolean	on );
   
   /**
    * Listener for notification of connection establishment.
