@@ -23,6 +23,7 @@
 
 package com.aelitis.azureus.core.networkmanager.admin.impl;
 
+import java.io.IOException;
 import java.io.PrintWriter;
 import java.net.*;
 import java.nio.channels.ServerSocketChannel;
@@ -32,9 +33,15 @@ import java.util.regex.Pattern;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
-import org.gudy.azureus2.core3.logging.*;
+import org.gudy.azureus2.core3.logging.LogAlert;
+import org.gudy.azureus2.core3.logging.LogEvent;
+import org.gudy.azureus2.core3.logging.LogIDs;
+import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.util.*;
-import org.gudy.azureus2.platform.*;
+import org.gudy.azureus2.platform.PlatformManager;
+import org.gudy.azureus2.platform.PlatformManagerCapabilities;
+import org.gudy.azureus2.platform.PlatformManagerFactory;
+import org.gudy.azureus2.platform.PlatformManagerPingCallback;
 import org.gudy.azureus2.plugins.PluginInterface;
 import org.gudy.azureus2.plugins.platform.PlatformManagerException;
 import org.gudy.azureus2.plugins.utils.Utilities;
@@ -42,7 +49,10 @@ import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
-import com.aelitis.azureus.core.instancemanager.*;
+import com.aelitis.azureus.core.instancemanager.AZInstance;
+import com.aelitis.azureus.core.instancemanager.AZInstanceManager;
+import com.aelitis.azureus.core.instancemanager.AZInstanceManagerListener;
+import com.aelitis.azureus.core.instancemanager.AZInstanceTracked;
 import com.aelitis.azureus.core.networkmanager.admin.*;
 import com.aelitis.azureus.core.networkmanager.impl.http.HTTPNetworkManager;
 import com.aelitis.azureus.core.networkmanager.impl.tcp.TCPNetworkManager;
@@ -62,14 +72,59 @@ NetworkAdminImpl
 	
 	private static final boolean	FULL_INTF_PROBE	= false;
 	
-	private Set							old_network_interfaces;
+	private static InetAddress anyLocalAddress;
+	private static InetAddress anyLocalAddressIPv4;
+	private static InetAddress anyLocalAddressIPv6;
+	private static InetAddress localhostV4;
+	private static InetAddress localhostV6;
+	
+	static
+	{
+		try
+		{
+			anyLocalAddressIPv4 	= InetAddress.getByAddress(new byte[] { 0,0,0,0 });
+			anyLocalAddressIPv6  	= InetAddress.getByAddress(new byte[] {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0});
+			anyLocalAddress			= new InetSocketAddress(0).getAddress();
+			localhostV4 = InetAddress.getByAddress(new byte[] {127,0,0,1});
+			localhostV6 = InetAddress.getByAddress(new byte[] {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,1});
+		} catch (UnknownHostException e)
+		{
+			e.printStackTrace();
+		}
+	}
+
+	
+	
+	
+	private Set<NetworkInterface>		old_network_interfaces;
 	private InetAddress[]				currentBindIPs			= new InetAddress[] { null };
 	private boolean						supportsIPv6withNIO		= true;
 	private boolean						supportsIPv6 = true;
 	private boolean						supportsIPv4 = true;
 	
+	private boolean						IPv6_enabled;
+	
+	{
+		COConfigurationManager.addAndFireParameterListener(
+				"IPV6 Enable Support",
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						String parameterName )
+					{
+						setIPv6Enabled( COConfigurationManager.getBooleanParameter("IPV6 Enable Support"));
+					}
+				});
+	}
+	
+	private int roundRobinCounterV4 = 0;
+	private int roundRobinCounterV6 = 0;
+	
+
 	private CopyOnWriteList	listeners = new CopyOnWriteList();
-		
+	
+	
 	private NetworkAdminRouteListener
 		trace_route_listener = new NetworkAdminRouteListener()
 		{
@@ -121,6 +176,8 @@ NetworkAdminImpl
 			}
 		};
 		
+	private boolean 	initialised;
+	
 	public
 	NetworkAdminImpl()
 	{
@@ -145,22 +202,42 @@ NetworkAdminImpl
 				perform(
 					TimerEvent event )
 				{
-					checkNetworkInterfaces( false );
+					checkNetworkInterfaces( false, false );
 				}
 			});
 		
 			// populate initial values
 		
-		checkNetworkInterfaces(true);
+		checkNetworkInterfaces( true, true );
 		
-		checkDefaultBindAddress(true);
+		checkDefaultBindAddress( true );
 		
 		AEDiagnostics.addEvidenceGenerator( this );
+		
+		initialised = true;
+	}
+	
+	protected void
+	setIPv6Enabled(
+		boolean enabled )
+	{
+		IPv6_enabled	= enabled;
+		
+		supportsIPv6withNIO		= enabled;
+		supportsIPv6 			= enabled;
+
+		if ( initialised ){
+			
+			checkNetworkInterfaces( false, true );
+			
+			checkDefaultBindAddress( false );
+		}
 	}
 	
 	protected void
 	checkNetworkInterfaces(
-		boolean	first_time )
+		boolean		first_time,
+		boolean		force )
 	{
 		try{
 			Enumeration 	nis = NetworkInterface.getNetworkInterfaces();
@@ -214,30 +291,33 @@ NetworkAdminImpl
 				old_network_interfaces = new_network_interfaces;
 			}
 			
-			if ( changed ){
-				
-				
+			if ( changed || force ){
+							
 				boolean newV6 = false;
 				boolean newV4 = false;
 				
-				Set interfaces = old_network_interfaces;
+				Set<NetworkInterface> interfaces = old_network_interfaces;
 				if (interfaces != null)
 				{
-					Iterator it = interfaces.iterator();
+					Iterator<NetworkInterface> it = interfaces.iterator();
 					while (it.hasNext())
 					{
-						NetworkInterface ni = (NetworkInterface) it.next();
+						NetworkInterface ni = it.next();
 						Enumeration addresses = ni.getInetAddresses();
 						while (addresses.hasMoreElements())
 						{
 							InetAddress ia = (InetAddress) addresses.nextElement();
 
-							if (ia.isLoopbackAddress())
+							if (ia.isLoopbackAddress()){
 								continue;
-							if (ia instanceof Inet6Address && !ia.isLinkLocalAddress())
-								newV6 = true;
-							else if (ia instanceof Inet4Address)
+							}
+							if (ia instanceof Inet6Address && !ia.isLinkLocalAddress()){
+								if ( IPv6_enabled ){
+									newV6 = true;
+								}
+							}else if (ia instanceof Inet4Address){
 								newV4 = true;
+							}
 						}
 					}
 				}
@@ -283,9 +363,6 @@ NetworkAdminImpl
 		}
 	}
 	
-	private int roundRobinCounterV4 = 0;
-	private int roundRobinCounterV6 = 0;
-	
 	public InetAddress getMultiHomedOutgoingRoundRobinBindAddress(InetAddress target)
 	{
 		InetAddress[]	addresses = currentBindIPs;
@@ -315,26 +392,7 @@ NetworkAdminImpl
 			roundRobinCounterV4 = i;
 		return toReturn != null ? toReturn : (v6 ? localhostV6 : localhostV4);
 	}
-	
-	private static InetAddress anyLocalAddressIPv4;
-	private static InetAddress anyLocalAddressIPv6;
-	private static InetAddress localhostV4;
-	private static InetAddress localhostV6;
-	
-	static
-	{
-		try
-		{
-			anyLocalAddressIPv4 = InetAddress.getByAddress(new byte[] { 0,0,0,0 });
-			anyLocalAddressIPv6  = InetAddress.getByAddress(new byte[] {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0});
-			localhostV4 = InetAddress.getByAddress(new byte[] {127,0,0,1});
-			localhostV6 = InetAddress.getByAddress(new byte[] {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,1});
-		} catch (UnknownHostException e)
-		{
-			e.printStackTrace();
-		}
-	}
-	
+		
 	public InetAddress[] getMultiHomedServiceBindAddresses(boolean nio)
 	{
 		InetAddress[] bindIPs = currentBindIPs;
@@ -406,77 +464,101 @@ NetworkAdminImpl
 	
 	private InetAddress[] calcBindAddresses(final String addressString, boolean enforceBind)
 	{
-		ArrayList addrs = new ArrayList();
+		ArrayList<InetAddress> addrs = new ArrayList<InetAddress>();
 		
 		Pattern addressSplitter = Pattern.compile(";");
 		Pattern interfaceSplitter = Pattern.compile("[\\]\\[]");
 		
 		String[] tokens = addressSplitter.split(addressString);
 
-			addressLoop: for(int i=0;i<tokens.length;i++)
+addressLoop: 
+		for(int i=0;i<tokens.length;i++)
+		{
+			String currentAddress = tokens[i];
+			
+			currentAddress = currentAddress.trim();
+			
+			if ( currentAddress.length() == 0 ){
+				continue;
+			}
+			
+			InetAddress parsedAddress = null;
+			
+			try
+			{ // literal ipv4 or ipv6 address
+				if(currentAddress.indexOf('.') != -1 || currentAddress.indexOf(':') != -1)
+					parsedAddress = InetAddress.getByName(currentAddress);
+			} catch (Exception e)
+			{ // ignore, could be an interface name containing a ':'
+			}
+			
+			if(parsedAddress != null)
 			{
-				String currentAddress = tokens[i];
-				InetAddress parsedAddress = null;
-				
 				try
-				{ // literal ipv4 or ipv6 address
-					if(currentAddress.indexOf('.') != -1 || currentAddress.indexOf(':') != -1)
-						parsedAddress = InetAddress.getByName(currentAddress);
-				} catch (Exception e)
-				{ // ignore, could be an interface name containing a ':'
-				}
-				
-				if(parsedAddress != null)
 				{
-					try
-					{
-						// allow wildcard address as 1st address, otherwise only interface addresses
-						if((!parsedAddress.isAnyLocalAddress() || addrs.size() > 0) && NetworkInterface.getByInetAddress(parsedAddress) == null)
-							continue;
-					} catch (SocketException e)
-					{
-						Debug.printStackTrace(e);
+					// allow wildcard address as 1st address, otherwise only interface addresses
+					if((!parsedAddress.isAnyLocalAddress() || addrs.size() > 0) && NetworkInterface.getByInetAddress(parsedAddress) == null)
 						continue;
-					}
-					addrs.add(parsedAddress);
-					continue;
-				}
-					
-				// interface name
-				String[] ifaces = interfaceSplitter.split(currentAddress);
-
-				NetworkInterface netInterface = null;
-				try
-				{
-					netInterface = NetworkInterface.getByName(ifaces[0]);
 				} catch (SocketException e)
 				{
-					e.printStackTrace(); // should not happen
-				}
-				if(netInterface == null)
+					Debug.printStackTrace(e);
 					continue;
+				}
+				addrs.add(parsedAddress);
+				continue;
+			}
+				
+			// interface name
+			String[] ifaces = interfaceSplitter.split(currentAddress);
 
-				Enumeration interfaceAddresses = netInterface.getInetAddresses();
-				if(ifaces.length != 2)
-					while(interfaceAddresses.hasMoreElements())
-						addrs.add(interfaceAddresses.nextElement());
-				else
-				{
-					int selectedAddress = 0;
-					try { selectedAddress = Integer.parseInt(ifaces[1]); }
-					catch (NumberFormatException e) {} // ignore, user could by typing atm
-					for(int j=0;interfaceAddresses.hasMoreElements();j++,interfaceAddresses.nextElement())
-						if(j==selectedAddress)
-						{
-							addrs.add(interfaceAddresses.nextElement());
-							continue addressLoop;						
-						}
+			NetworkInterface netInterface = null;
+			try
+			{
+				netInterface = NetworkInterface.getByName(ifaces[0]);
+			} catch (SocketException e)
+			{
+				e.printStackTrace(); // should not happen
+			}
+			if(netInterface == null)
+				continue;
+
+			Enumeration interfaceAddresses = netInterface.getInetAddresses();
+			if(ifaces.length != 2)
+				while(interfaceAddresses.hasMoreElements())
+					addrs.add((InetAddress)interfaceAddresses.nextElement());
+			else
+			{
+				int selectedAddress = 0;
+				try { selectedAddress = Integer.parseInt(ifaces[1]); }
+				catch (NumberFormatException e) {} // ignore, user could by typing atm
+				for(int j=0;interfaceAddresses.hasMoreElements();j++,interfaceAddresses.nextElement())
+					if(j==selectedAddress)
+					{
+						addrs.add((InetAddress)interfaceAddresses.nextElement());
+						continue addressLoop;						
+					}
+			}
+		}
+		
+		if ( !IPv6_enabled ){
+			
+			Iterator<InetAddress> it = addrs.iterator();
+			
+			while( it.hasNext()){
+				
+				if ( it.next() instanceof Inet6Address ){
+					
+					it.remove();
 				}
 			}
+		}
 		
-		if(addrs.size() < 1)
+		if(addrs.size() < 1){
 			return new InetAddress[] {enforceBind ? localhostV4 : (hasIPV6Potential() ? anyLocalAddressIPv6 : anyLocalAddressIPv4)};
-		return (InetAddress[])addrs.toArray(new InetAddress[0]);
+		}
+		
+		return( addrs.toArray(new InetAddress[addrs.size()]));
+
 	}
 	
 	
@@ -516,8 +598,10 @@ NetworkAdminImpl
 			Enumeration addresses = ni.getInetAddresses();
 			str+=ni.getName()+"\t("+ni.getDisplayName()+")\n";
 			int i = 0;
-			while(addresses.hasMoreElements())
-				str+="\t"+ni.getName()+"["+(i++)+"]\t"+((InetAddress)addresses.nextElement()).getHostAddress()+"\n";
+			while(addresses.hasMoreElements()){
+				InetAddress address = (InetAddress)addresses.nextElement();
+				str+="\t"+ni.getName()+"["+(i++)+"]\t"+(address).getHostAddress()+"\n";
+			}
 		}
 		return (str);
 	}
@@ -590,6 +674,82 @@ NetworkAdminImpl
   			}
   		}
   	}
+  	
+	public int
+	getBindablePort(
+		int	prefer_port )
+	
+		throws IOException
+	{
+		final int tries = 1024;
+		
+		Random random = new Random();
+		
+		for ( int i=1;i<=tries;i++ ){
+			
+			int port;
+			
+			if ( i == 1 && prefer_port != 0 ){
+				
+				port = prefer_port;
+				
+			}else{
+				
+				port = i==tries?0:random.nextInt(20000) + 40000;
+			}
+			
+			ServerSocketChannel ssc = null;
+			
+			try{
+				ssc = ServerSocketChannel.open();
+
+				ssc.socket().setReuseAddress( true );
+				
+				bind( ssc, null, port );
+
+				port = ssc.socket().getLocalPort();
+				
+				ssc.close();
+				
+				return( port );
+				
+			}catch( Throwable e ){
+				
+				if ( ssc != null ){
+					
+					try{
+						ssc.close();
+						
+					}catch( Throwable f ){
+						
+						Debug.printStackTrace(e);
+					}
+					
+					ssc = null;
+				}
+			}
+		}
+		
+		throw( new IOException( "No bindable ports found" ));
+	}
+	
+	protected void
+	bind(
+		ServerSocketChannel	ssc,
+		InetAddress			address,
+		int					port )
+	
+		throws IOException
+	{		
+		if ( address == null ){
+			
+			ssc.socket().bind( new InetSocketAddress( port ), 1024 );
+			
+		}else{
+			
+			ssc.socket().bind( new InetSocketAddress( address, port ), 1024 );
+		}
+	}
 	
 	public InetAddress 
 	guessRoutableBindAddress() 
@@ -895,6 +1055,45 @@ NetworkAdminImpl
 		return( utils.getPublicAddress( true ));
 	}
 	
+	@Override
+	public InetAddress getDefaultPublicAddressV6() {
+		if(!supportsIPv6)
+			return null;
+		
+		// check bindings first
+		for(InetAddress addr : currentBindIPs)
+		{
+			// found a specific bind address, use that one
+			if(AddressUtils.isGlobalAddressV6(addr))
+				return addr;
+			
+			// found v6 any-local address, check interfaces for a best match
+			if(addr instanceof Inet6Address && addr.isAnyLocalAddress())
+			{
+				ArrayList<InetAddress> addrs = new ArrayList<InetAddress>();
+				for(NetworkInterface iface : old_network_interfaces)
+					addrs.addAll(Collections.list(iface.getInetAddresses()));
+				
+				return AddressUtils.pickBestGlobalV6Address(addrs);
+			}
+		}
+		
+		return null;
+	}
+	
+	public boolean
+	hasDHTIPV6()
+	{
+		if ( hasIPV6Potential(false)){
+			
+			InetAddress v6 = getDefaultPublicAddressV6();
+			
+			return( v6 != null && !AddressUtils.isTeredo( v6 ));
+		}
+		
+		return( false );
+	}
+	
 	protected void
 	firePropertyChange(
 		String	property )
@@ -1951,6 +2150,8 @@ NetworkAdminImpl
 				
 				writer.println( "bindable: " + getString( getBindableAddresses()));
 				
+				writer.println( "ipv6_enabled=" + IPv6_enabled );
+
 				writer.println( "ipv4_potential=" + hasIPV4Potential());
 				writer.println( "ipv6_potential=" + hasIPV6Potential(false) + "/" + hasIPV6Potential(true));
 	
@@ -2356,7 +2557,14 @@ NetworkAdminImpl
 			
 			while( e.hasMoreElements()){
 				
-				addresses.add( new networkAddress((InetAddress)e.nextElement()));
+				InetAddress address = (InetAddress)e.nextElement();
+				
+				if ((address instanceof Inet6Address) && !IPv6_enabled ){
+					
+					continue;
+				}
+				
+				addresses.add( new networkAddress(address));
 			}
 	
 			return((NetworkAdminNetworkInterfaceAddress[])addresses.toArray( new NetworkAdminNetworkInterfaceAddress[addresses.size()]));
