@@ -121,7 +121,7 @@ NetworkAdminProtocolImpl
 	}
 	
 	public String
-	getName()
+	getTypeString()
 	{
 		String	res;
 		
@@ -138,6 +138,14 @@ NetworkAdminProtocolImpl
 			res = "UDP";
 		}
 		
+		return( res );
+	}
+	
+	public String
+	getName()
+	{
+		String	res = getTypeString();
+		
 		if ( port == -1 ){
 			
 			return( res + " outbound" );
