@@ -222,11 +222,10 @@ NetworkConnectionImpl
   }
   
   
-  public void enableEnhancedMessageProcessing( boolean enable ) {
+  public void enableEnhancedMessageProcessing( boolean enable, int partition_id ) {
     if( enable ) {
-    	NetworkManager.getSingleton().upgradeTransferProcessing( this );
-    }
-    else {
+    	NetworkManager.getSingleton().upgradeTransferProcessing( this, partition_id );
+    }else{
       NetworkManager.getSingleton().downgradeTransferProcessing( this );
     }
   }
@@ -296,11 +295,11 @@ NetworkConnectionImpl
 			return( false );
 		}
 		  		
-		public boolean 
+		public long 
 		isReadyForRead( 
 			EventWaiter waiter )
 		{
-			return( false );
+			return( Long.MAX_VALUE );
 		}
 		
 		public boolean 
