@@ -26,6 +26,7 @@ import java.util.*;
 
 import org.gudy.azureus2.core3.util.AEMonitor;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.SystemTime;
 
 import com.aelitis.azureus.core.networkmanager.LimitedRateGroup;
 import com.aelitis.azureus.core.networkmanager.NetworkConnectionBase;
@@ -59,18 +60,20 @@ public class TransferProcessor {
   private final HashMap connections = new HashMap();
   private final AEMonitor connections_mon;
 
+  private final boolean	multi_threaded;
   
   /**
    * Create new transfer processor for the given read/write type, limited to the given max rate.
    * @param processor_type read or write processor
    * @param max_rate_limit to use
    */
-  public TransferProcessor( int processor_type, LimitedRateGroup max_rate_limit ) {
-    this.max_rate = max_rate_limit;
+  public TransferProcessor( int processor_type, LimitedRateGroup max_rate_limit, boolean multi_threaded ) {
+    this.max_rate 		= max_rate_limit;
+    this.multi_threaded	= multi_threaded;
     
     connections_mon = new AEMonitor( "TransferProcessor:" +processor_type );
 
-    main_bucket = new ByteBucket( max_rate.getRateLimitBytesPerSecond() ); 
+    main_bucket = createBucket( max_rate.getRateLimitBytesPerSecond() ); 
 
     main_controller = new EntityHandler( processor_type, new RateHandler() {
       public int getCurrentNumBytesAllowed() {
@@ -106,20 +109,36 @@ public class TransferProcessor {
     
       for (int i=0;i<groups.length;i++){
     	  LimitedRateGroup group = groups[i];
+    	  
+		  // boolean log = group.getName().contains("parg");
+
     	  GroupData group_data = (GroupData)group_buckets.get( group );
 	      if( group_data == null ) {
 	        int limit = NetworkManagerUtilities.getGroupRateLimit( group );
-	        group_data = new GroupData( new ByteBucket( limit ) );
+	        group_data = new GroupData( createBucket( limit ) );
 	        group_buckets.put( group, group_data );
+	        
+	        /*
+	        if ( log ){
+	    	  System.out.println( "Creating RL1: " + group.getName() + " -> " + group_data );
+	        }
+	        */
 	      }
 	      group_data.group_size++;
 	      
 	      group_datas[i] = group_data;
+	      
+	      /*
+	      if ( log ){
+	    	  System.out.println( "Applying RL1: " + group.getName() + " -> " + connection );
+	      }
+	      */
       }
       conn_data.groups = groups;
       conn_data.group_datas = group_datas;
       conn_data.state = ConnectionData.STATE_NORMAL;
      
+      
       connections.put( connection, conn_data );
     }
     finally {  connections_mon.exit();  }
@@ -191,17 +210,31 @@ public class TransferProcessor {
 				  }
 			  }
 			  
+			  // boolean log = group.getName().contains("parg");
+			  
 	    	  GroupData group_data = (GroupData)group_buckets.get( group );
 	    	  
 		      if ( group_data == null ){
 		    	  
 		    	  int limit = NetworkManagerUtilities.getGroupRateLimit( group );
 
-		    	  group_data = new GroupData( new ByteBucket( limit ) );
+		    	  group_data = new GroupData( createBucket( limit ) );
 
+		    	  /*
+		    	  if ( log ){
+		    		  System.out.println( "Creating RL2: " + group.getName() + " -> " + group_data );
+		    	  }
+				  */
+		    	  
 		    	  group_buckets.put( group, group_data );
 		      }
 		      
+		      /*
+		      if ( log ){
+		    	  System.out.println( "Applying RL2: " + group.getName() + " -> " + connection );
+		      }
+			  */
+		      
 		      group_data.group_size++;
 		   
 			  GroupData[]			group_datas = conn_data.group_datas; 
@@ -293,11 +326,13 @@ public class TransferProcessor {
   }
   
 
+  // private static long last_log = 0;
+  
   /**
    * Upgrade the given connection to a high-speed transfer handler.
    * @param connection to upgrade
    */
-  public void upgradePeerConnection( final NetworkConnectionBase connection ) {
+  public void upgradePeerConnection( final NetworkConnectionBase connection, int partition_id ) {
     ConnectionData connection_data = null;
     
     try{ connections_mon.enter();
@@ -329,10 +364,25 @@ public class TransferProcessor {
 	          
 	          try{
 		           for (int i=0;i<conn_data.group_datas.length;i++){
+		        	   
+		        	  LimitedRateGroup group = conn_data.groups[i];
+		        	  
+		     		  //boolean log = group.getName().contains("parg");
+
 			          int group_rate = NetworkManagerUtilities.getGroupRateLimit( conn_data.groups[i] );
 			          
 			          ByteBucket group_bucket = conn_data.group_datas[i].bucket;
 			          
+			          /*
+			          if ( log ){
+			        	  long now = SystemTime.getCurrentTime();
+			        	  if ( now - last_log > 500 ){
+			        		  last_log = now;
+			        		  System.out.println( "    " + group.getName() + " -> " + group_rate + "/" + group_bucket.getAvailableByteCount());
+			        	  }
+			          }
+			          */
+			          
 			          if ( group_bucket.getRate() != group_rate ){
 			        	  
 			        	  group_bucket.setRate( group_rate );
@@ -367,7 +417,7 @@ public class TransferProcessor {
           }
           main_bucket.setBytesUsed( num_bytes_written );
         }
-      });
+      }, partition_id );
       
       conn_data.state = ConnectionData.STATE_UPGRADED;
     }
@@ -393,7 +443,19 @@ public class TransferProcessor {
   }
   
   
-
+  private ByteBucket
+  createBucket(
+	int	bytes_per_sec )
+  {
+	  if ( multi_threaded ){
+		  
+		  return( new ByteBucketMT( bytes_per_sec ));
+		  
+	  }else{
+		  
+		  return( new ByteBucketST( bytes_per_sec ));
+	  }
+  }
   
   private static class ConnectionData {
     private static final int STATE_NORMAL   = 0;
