@@ -26,19 +26,24 @@ import java.io.UnsupportedEncodingException;
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.URLDecoder;
+import java.net.URLEncoder;
 import java.nio.ByteBuffer;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Map;
+import java.util.Set;
 import java.util.StringTokenizer;
 
 import org.gudy.azureus2.core3.logging.LogEvent;
 import org.gudy.azureus2.core3.logging.LogIDs;
 import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.peer.impl.PEPeerTransport;
+import org.gudy.azureus2.core3.torrent.TOTorrentFile;
 import org.gudy.azureus2.core3.util.BEncoder;
 
 import com.aelitis.azureus.core.networkmanager.NetworkConnection;
 import com.aelitis.azureus.core.networkmanager.NetworkManager;
+import com.aelitis.azureus.core.networkmanager.Transport;
 import com.aelitis.azureus.core.networkmanager.impl.TransportHelper;
 import com.aelitis.azureus.core.networkmanager.impl.tcp.IncomingSocketChannelManager;
 import com.aelitis.azureus.core.peermanager.PeerManager;
@@ -47,6 +52,9 @@ import com.aelitis.azureus.core.peermanager.PeerManagerRoutingListener;
 import com.aelitis.azureus.core.peermanager.messaging.MessageStreamDecoder;
 import com.aelitis.azureus.core.peermanager.messaging.MessageStreamEncoder;
 import com.aelitis.azureus.core.peermanager.messaging.MessageStreamFactory;
+import com.aelitis.azureus.core.stats.AzureusCoreStats;
+import com.aelitis.azureus.core.stats.AzureusCoreStatsProvider;
+import com.aelitis.azureus.core.util.CopyOnWriteList;
 
 public class 
 HTTPNetworkManager 
@@ -62,9 +70,60 @@ HTTPNetworkManager
 	
 	private final IncomingSocketChannelManager http_incoming_manager;
 
+	private long	total_requests;
+	private long	total_webseed_requests;
+	private long	total_getright_requests;
+	private long	total_invalid_requests;
+	private long	total_ok_requests;
+	
+	private CopyOnWriteList<URLHandler>	url_handlers = new CopyOnWriteList<URLHandler>();
+	
 	private 
 	HTTPNetworkManager()
 	{	
+		  Set	types = new HashSet();
+		  
+		  types.add( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_COUNT );
+		  types.add( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_OK_COUNT );
+		  types.add( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_INVALID_COUNT );
+		  types.add( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_WEBSEED_COUNT );
+		  types.add( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_GETRIGHT_COUNT );
+			
+		  AzureusCoreStats.registerProvider( 
+				  types,
+				  new AzureusCoreStatsProvider()
+				  {
+						public void
+						updateStats(
+							Set		types,
+							Map		values )
+						{
+							if ( types.contains( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_COUNT )){
+								
+								values.put( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_COUNT, new Long( total_requests ));
+							}	
+							
+							if ( types.contains( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_OK_COUNT )){
+								
+								values.put( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_OK_COUNT, new Long( total_ok_requests ));
+							}					
+
+							if ( types.contains( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_INVALID_COUNT )){
+								
+								values.put( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_INVALID_COUNT, new Long( total_invalid_requests ));
+							}					
+
+							if ( types.contains( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_WEBSEED_COUNT )){
+								
+								values.put( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_WEBSEED_COUNT, new Long( total_webseed_requests ));
+							}	
+							
+							if ( types.contains( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_GETRIGHT_COUNT )){
+								
+								values.put( AzureusCoreStats.ST_NET_HTTP_IN_REQUEST_GETRIGHT_COUNT, new Long( total_getright_requests));							}					
+
+						}
+				  });
 		/*
 		try{
 			System.out.println( "/webseed?info_hash=" + URLEncoder.encode( new String( ByteFormatter.decodeString("C9C04D96F11FB5C5ECC99D418D3575FBFC2208B0"), "ISO-8859-1"), "ISO-8859-1" ));
@@ -90,12 +149,16 @@ HTTPNetworkManager
 		    		TransportHelper		transport,
 		    		ByteBuffer 			to_compare, 
 		    		int 				port ) 
-		    	{ 
+		    	{
+		    		total_requests++;
+		    		
 		    		InetSocketAddress	address = transport.getAddress();
 		    		
 		    		int old_limit 		= to_compare.limit();
 		    		int old_position 	= to_compare.position();
 
+		    		boolean 	ok = false;
+		    		
 		    		try{
 			    		byte[]	head = new byte[3];
 			    		
@@ -130,23 +193,29 @@ HTTPNetworkManager
 				    				
 				    		if ( url.indexOf( "/index.html") != -1 ){
 				    			
+				    			ok	= true;
+				    			
 					    		return( new Object[]{ transport, getIndexPage() });
 					    		
 				    		}else if ( url.indexOf( "/ping.html") != -1 ){
 					    			
 				    				// ping is used for inbound HTTP port checking
 				    			
+				    			ok	= true;
+				    			
 						    	return( new Object[]{ transport, getPingPage( url ) });
 
 				    		}else if ( url.indexOf( "/test503.html" ) != -1 ){
 				    			
+				    			ok	= true;
+				    			
 					    		return( new Object[]{ transport, getTest503()});
 				    		}
 
 				    		String	hash_str = null;
 				    		
 				    		int	hash_pos = url.indexOf( "?info_hash=" );
-				    		
+				    						    		
 				    		if ( hash_pos != -1 ){
 				    							    			
 				    			int	hash_start = hash_pos + 11;
@@ -160,7 +229,7 @@ HTTPNetworkManager
 				    				return( null );
 				    				
 				    			}else{
-				    				
+				    								    				
 				    				hash_str = url.substring( hash_start, hash_end );
 				    			}
 				    		}else{
@@ -180,7 +249,7 @@ HTTPNetworkManager
 					    				return( null );
 					    				
 					    			}else{
-					    				
+					    									    				
 					    				hash_str = url.substring( hash_start, hash_end );
 					    			}
 					    		}
@@ -200,10 +269,76 @@ HTTPNetworkManager
 			    					
 			    					String	trimmed = pos==-1?url:url.substring(0,pos);
 			    					
+			    					ok	= true;
+			    					
 			    					return( new Object[]{ trimmed, reg_data });
 			    				}
+				    		}else{
+				    			
+				    			int	link_pos = url.indexOf( "/links/" );
+				    			
+				    			if ( link_pos != -1 ){
+				    			
+			    					int	pos = url.indexOf( ' ', link_pos );
+
+			    					if ( pos == -1 ){
+			    						
+			    						return( null );
+			    					}
+			    					
+			    					String link = url.substring(0,pos).substring( link_pos+7 );
+			    					
+				    				link = URLDecoder.decode( link, "UTF-8" );
+			    					
+				    				PeerManagerRegistration reg_data = PeerManager.getSingleton().manualMatchLink( address, link );
+				    				
+				    				if ( reg_data != null ){
+
+				    					TOTorrentFile	file = reg_data.getLink( link );
+				    					
+				    					if ( file != null ){
+				    						
+					    					StringBuffer	target_url = new StringBuffer( 512 );
+					    					
+					    					target_url.append( "/files/" );
+					    					
+					    					target_url.append( URLEncoder.encode(  new String( file.getTorrent().getHash(), "ISO-8859-1" ), "ISO-8859-1" ));
+					    					
+					    					byte[][]	bits = file.getPathComponents();
+					    					
+					    					for (int i=0;i<bits.length;i++){
+					    						
+					    						target_url.append( "/" );
+					    						
+					    						target_url.append( URLEncoder.encode( new String( bits[i], "ISO-8859-1" ), "ISO-8859-1" ));
+					    					}
+					    					
+					    					ok	= true;
+					    					
+					    					return( new Object[]{ target_url.toString(), reg_data });
+				    					}
+				    				}
+				    			}
 				    		}
 				    		
+				    		String trimmed = url;
+				    		
+				    		int	pos = trimmed.indexOf( ' ' );
+				    		
+				    		if ( pos != -1 ){
+				    			
+				    			trimmed = trimmed.substring( 0, pos );
+				    		}
+				    		
+				    		for ( URLHandler handler: url_handlers ){
+				    			
+				    			if ( handler.matches( trimmed )){
+				    							    					
+			    					ok	= true;
+			    					
+			    					return( new Object[]{ handler, transport, "GET " + url });
+				    			}
+				    		}
 		   					if (Logger.isEnabled()){
 	    						Logger.log(new LogEvent(LOGID, "HTTP decode from " + address + " failed: no match for " + url ));
 	    					}
@@ -220,6 +355,14 @@ HTTPNetworkManager
 			    		}
 		    		}finally{
 		    		
+		    			if ( ok ){
+		    				
+		    				total_ok_requests++;
+		    				
+		    			}else{
+		    				
+		    				total_invalid_requests++;
+		    			}
 			    			//	restore buffer structure
 		    			
 			    		to_compare.limit( old_limit );
@@ -270,16 +413,26 @@ HTTPNetworkManager
 	        	{
 	        		Object[]	x = (Object[])_routing_data;
 	        		
-	        		if ( x[0] instanceof TransportHelper ){
+	        		Object	entry1 = x[0];
+	        		
+	        		if ( entry1 instanceof TransportHelper ){
 	        			
 	        				// routed on failure
 	        			
 	        			writeReply(connection, (TransportHelper)x[0], (String)x[1]);
 	        			
 	        			return;
+	        			
+	        		}else if ( entry1 instanceof URLHandler ){
+	        			
+	        			((URLHandler)entry1).handle(
+	        					(TransportHelper)x[1],
+	        					(String)x[2] );
+	        		
+	        			return;
 	        		}
 	        		
-	        		final String					url 			= (String)x[0];
+	        		final String					url 			= (String)entry1;
 	        		final PeerManagerRegistration	routing_data 	= (PeerManagerRegistration)x[1];
 	        		
    					if (Logger.isEnabled()){
@@ -297,13 +450,17 @@ HTTPNetworkManager
 	        					{
 	        						if ( url.indexOf( "/webseed" ) != -1 ){
 	        							
-	        							new HTTPNetworkConnectionWebSeed( HTTPNetworkManager.this, connection, peer, url );
+	        							total_webseed_requests++;
+	        							
+	        							new HTTPNetworkConnectionWebSeed( HTTPNetworkManager.this, connection, peer );
 	        							
 	        							return( true );
 	        							
 	        						}else if ( url.indexOf( "/files/" ) != -1 ){
 
-	        							new HTTPNetworkConnectionFile( HTTPNetworkManager.this, connection, peer, url );
+	        							total_getright_requests++;
+	        							
+	        							new HTTPNetworkConnectionFile( HTTPNetworkManager.this, connection, peer );
 	        							
 	        							return( true );
 	        						}
@@ -325,6 +482,78 @@ HTTPNetworkManager
 	        });
 	}
 	
+	
+	protected void
+	reRoute(
+		final HTTPNetworkConnection		old_http_connection,
+		final byte[]					old_hash,
+		final byte[]					new_hash,
+		final String					header )
+	{
+		final NetworkConnection	old_connection = old_http_connection.getConnection();
+		
+		PeerManagerRegistration reg_data = 
+			PeerManager.getSingleton().manualMatchHash( 
+					old_connection.getEndpoint().getNotionalAddress(), 
+					new_hash );
+
+		if ( reg_data == null ){
+			
+			old_http_connection.close( "Re-routing failed - registration not found" );
+			
+			return;
+		}
+	
+		final Transport transport = old_connection.detachTransport();
+		
+		old_http_connection.close( "Switching torrents" );
+		
+		final NetworkConnection new_connection = 
+			NetworkManager.getSingleton().bindTransport(
+					transport,
+					new HTTPMessageEncoder(),
+					new HTTPMessageDecoder( header ));
+		
+		PeerManager.getSingleton().manualRoute(
+				reg_data, 
+				new_connection,
+				new PeerManagerRoutingListener()
+				{
+					public boolean
+					routed(
+						PEPeerTransport		peer )
+					{
+						HTTPNetworkConnection new_http_connection;
+						
+						if ( header.indexOf( "/webseed" ) != -1 ){
+							
+							new_http_connection = new HTTPNetworkConnectionWebSeed( HTTPNetworkManager.this, new_connection, peer );
+							
+						}else if ( header.indexOf( "/files/" ) != -1 ){
+
+							new_http_connection = new HTTPNetworkConnectionFile( HTTPNetworkManager.this, new_connection, peer );
+						
+						}else{
+							
+							return( false );
+						}
+						
+							// fake a wakeup so pre-read header is processed
+						
+						new_http_connection.readWakeup();
+						
+						/*
+						System.out.println( 
+								"Re-routed " + new_connection.getEndpoint().getNotionalAddress() +
+								" from " + ByteFormatter.encodeString( old_hash ) + " to " +
+								 ByteFormatter.encodeString( new_hash ) );
+						*/
+						
+						return( true );
+					}
+				});
+	}
+	
 	public boolean
 	isHTTPListenerEnabled()
 	{
@@ -556,4 +785,32 @@ HTTPNetworkManager
 			connection.close();
 		}
 	}
+	
+	public void
+	addURLHandler(
+		URLHandler	handler )
+	{
+		url_handlers.add( handler );
+	}
+	
+	public void
+	removeURLHandler(
+		URLHandler	handler )
+	{
+		url_handlers.remove( handler );
+	}
+	
+	public interface
+	URLHandler
+	{
+		public boolean
+		matches(
+			String		url );
+		
+		public void
+		handle(
+			TransportHelper		transport,
+			String				header_so_far );
+		
+	}
 }
