@@ -92,11 +92,12 @@ ProtocolEndpointTCP
 		boolean 			allow_fallback, 
 		byte[][]			shared_secrets,
 		ByteBuffer			initial_data,
+		int					priority,
 		ConnectListener 	listener )
 	{
 		TCPTransportImpl t = new TCPTransportImpl( this, connect_with_crypto, allow_fallback, shared_secrets );
 					
-		t.connectOutbound( initial_data, listener );
+		t.connectOutbound( initial_data, listener, priority );
 		
 		return( t );
 	}
