@@ -63,7 +63,7 @@ UDPTransportHelper
 		
 	private Map	user_data;
 	
-	protected
+	public
 	UDPTransportHelper(
 		UDPConnectionManager	_manager,
 		InetSocketAddress		_address,
@@ -85,7 +85,7 @@ UDPTransportHelper
 
 	}
 	
-	protected
+	public
 	UDPTransportHelper(
 		UDPConnectionManager	_manager,
 		InetSocketAddress		_address, 
@@ -151,9 +151,10 @@ UDPTransportHelper
 	}
 	
 	public String
-	getName()
+	getName(
+		boolean verbose )
 	{
-		return( " (UDP)" );
+		return( "UDP" );
 	}
 	
 	public boolean
@@ -168,6 +169,21 @@ UDPTransportHelper
 		return( connection );
 	}
 	
+	public boolean 
+	delayWrite(
+		ByteBuffer buffer) 
+	{
+			// TODO: support this one day?
+		
+		return false;
+	}
+	
+	public boolean
+	hasDelayedWrite()
+	{
+		return( false );
+	}
+	
 	public int 
 	write( 
 		ByteBuffer 	buffer, 
@@ -209,10 +225,9 @@ UDPTransportHelper
 		
 		if ( pending_partial_write != null ){
 			
-			int	pw_len = pending_partial_write.remaining();
-			
 			try{
-			
+				int	pw_len = pending_partial_write.remaining();
+				
 				int	written = connection.write( new ByteBuffer[]{ pending_partial_write, buffer }, 0, 2 );
 				
 				if ( written >= pw_len ){
@@ -259,7 +274,44 @@ UDPTransportHelper
 			}
 		}
 		
-		return( connection.write( buffers, array_offset, length ));
+		if ( pending_partial_write != null ){
+			
+			ByteBuffer[]	buffers2 = new ByteBuffer[length+1];
+			
+			buffers2[0] = pending_partial_write;
+			
+			int	pos = 1;
+
+			for (int i=array_offset;i<array_offset+length;i++){
+				
+				buffers2[pos++] = buffers[i];
+			}
+			
+			try{
+				int	pw_len = pending_partial_write.remaining();
+				
+				int written = connection.write( buffers2, 0, buffers2.length );
+				
+				if ( written >= pw_len ){
+					
+					return( written - pw_len );
+					
+				}else{
+					
+					return( 0 );
+				}
+				
+			}finally{
+				
+				if ( pending_partial_write.remaining() == 0 ){
+					
+					pending_partial_write = null;
+				}
+			}
+		}else{
+		
+			return( connection.write( buffers, array_offset, length ));
+		}
     }
 
     public int 
@@ -548,4 +600,14 @@ UDPTransportHelper
 
 		return( user_data.get( key ));
 	}
+	
+	public void
+	setTrace(
+		boolean	on )
+	{
+	}
+	
+	public void setScatteringMode(long forBytes) {
+		// currently not implemented for UDP		
+	}
 }
