@@ -24,12 +24,22 @@ package com.aelitis.azureus.core.peermanager;
 
 import java.net.InetSocketAddress;
 
+import com.aelitis.azureus.core.networkmanager.NetworkConnection;
+
 public interface 
 PeerManagerRegistrationAdapter 
 {
 	public byte[][]
 	getSecrets();
 	
+	public boolean
+	manualRoute(
+		NetworkConnection		connection );
+	
+	public boolean
+	isPeerSourceEnabled(
+		String		peer_source );
+	
 	public boolean
 	activateRequest(
 		InetSocketAddress		remote_address );
@@ -37,4 +47,7 @@ PeerManagerRegistrationAdapter
 	public void
 	deactivateRequest(
 		InetSocketAddress		remote_address );
+	
+	public String
+	getDescription();
 }
