@@ -24,6 +24,7 @@ public interface
 PeerControlScheduler 
 {
 	public static final int SCHEDULE_PERIOD_MILLIS = COConfigurationManager.getIntParameter( "peermanager.schedule.time" );
+	public static final int SCHEDULE_PERIOD_MAX_CATCHUP = SCHEDULE_PERIOD_MILLIS>>2;
 	
 	public void
 	register(
@@ -32,4 +33,16 @@ PeerControlScheduler
 	public void
 	unregister(
 		PeerControlInstance	instance );
+	
+	public void 
+	updateScheduleOrdering();
+	
+	public SpeedTokenDispenser
+	getSpeedTokenDispenser();
+	
+	/**
+	 * 
+	 * @param override, set to true to disable weighted priorities, false to use user-configureable default
+	 */
+	public void overrideWeightedPriorities(boolean override);
 }
