@@ -36,6 +36,8 @@ import org.gudy.azureus2.core3.util.IndentWriter;
 
 public interface PiecePicker
 {
+	public static final int REQUEST_HINT_MAX_LIFE	= 120*1000;
+	
     public boolean  hasDownloadablePiece();
     /** @return long value indicated serial number of current count of changes
      * to hasNeededUndonePiece.
@@ -57,24 +59,27 @@ public interface PiecePicker
     public int      getAvailability(final int pieceNumber);
     
     public float    getMinAvailability();
+    public int		getMaxAvailability();
     public float    getAvgAvail();
-
+	public long 	getAvailWentBadTime();
+	
 	public void		allocateRequests();
 
 	public boolean	isInEndGameMode();
+	public boolean	hasEndGameModeBeenAbandoned();
 	public void		clearEndGameChunks();
 	/** adds all blocks in the piece to endGameModeChunks
 	 * @param pePiece
 	 */
 	public void		addEndGameChunks(final PEPiece pePiece);
-	/** adds only the blocks that aren't downloaded or written to endGameModeChunks
-	 * @param pePiece
-	 */
-	public void 	addEndGameBlocks(final PEPiece pePiece);
+
 	public void		removeFromEndGameModeChunks(final int pieceNumber, final int offset);
 	
-	public int
-	getNumberOfPieces();
+	public int	getNumberOfPieces();
+	
+	
+	public int		getNbPiecesDone();
+	
 	
 	public void
 	addRTAProvider(
@@ -87,7 +92,7 @@ public interface PiecePicker
 	public List
 	getRTAProviders();
 	
-	public void
+	public void 
 	addPriorityProvider(
 		PiecePriorityProvider		shaper );
 	
@@ -106,6 +111,9 @@ public interface PiecePicker
 	removeListener(
 		PiecePickerListener		listener );
 
+	public void
+	destroy();
+	
 	public void
 	generateEvidence(
 		IndentWriter	writer );
