@@ -29,9 +29,32 @@ PieceRTAProvider
 	updateRTAs(
 		PiecePicker		picker );
 	
+	public long
+	getStartTime();
+	
+	public long
+	getStartPosition();
+	
 	public long
 	getCurrentPosition();
 	
 	public long
 	getBlockingPosition();
+	
+		/**
+		 * Sets an external view of how much buffer is being maintained by an external source. This
+		 * reduces piece urgency and therefore reduces discard. 
+		 */
+	
+	public void
+	setBufferMillis(
+		long	millis );
+	
+		/**
+		 * Returns the user-agent associated with this RTA activity, if known
+		 * @return
+		 */
+	
+	public String
+	getUserAgent();
 }
