@@ -23,10 +23,11 @@
 package com.aelitis.azureus.core.peermanager.utils;
 
 import org.gudy.azureus2.core3.internat.MessageText;
+import org.gudy.azureus2.core3.util.AEDiagnostics;
+import org.gudy.azureus2.core3.util.AEDiagnosticsLogger;
 import org.gudy.azureus2.core3.util.ByteFormatter;
 import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
-import org.gudy.azureus2.core3.util.FileUtil;
 
 import java.io.*;
 import java.util.HashSet;
@@ -41,17 +42,15 @@ public class BTPeerIDByteDecoder {
 
 	static {
 		String	prop = System.getProperty("log.unknown.peerids");
-		LOG_UNKNOWN = prop != null && prop.equals("1");
+		LOG_UNKNOWN = prop == null || prop.equals("1");
 	}
 
-	private static void logUnknownClient0(byte[] peer_id_bytes, Writer log) throws IOException {
+	private static String logUnknownClient0(byte[] peer_id_bytes) throws IOException {
 		String text = new String(peer_id_bytes, 0, 20, Constants.BYTE_ENCODING);
 		text = text.replace((char)12, (char)32);
 		text = text.replace((char)10, (char)32);
 
-		log.write("[" + text + "] "); // Readable
-		log.write(ByteFormatter.encodeString(peer_id_bytes) + " "); // Usable for assertion tests.
-		log.write("\n");
+		return "[" + text + "] " + ByteFormatter.encodeString(peer_id_bytes) + " ";
 	}
 	
 	private static String asUTF8ByteString(String text) {
@@ -92,21 +91,14 @@ public class BTPeerIDByteDecoder {
 		}
 		
 		if (!LOG_UNKNOWN) {return;}
-		FileWriter log = null;
-		File log_file = FileUtil.getUserFile("identification.log");
-		try {
-			log = new FileWriter(log_file, true);
-			log.write(line_to_log);
-			log.write("\n");
-		}
-		catch (Throwable e) {
-			Debug.printStackTrace(e);
-		}
-		finally {
-			try {if (log != null) log.close();}
-			catch (IOException ignore) {/*ignore*/}
-		}
-		
+		logClientDiscrepancyToFile(line_to_log);
+	}
+	
+	private static AEDiagnosticsLogger logger = null;
+	private synchronized static void logClientDiscrepancyToFile(String line_to_log) {
+		if (logger == null) {logger = AEDiagnostics.getLogger("clientid");}
+		try {logger.log(line_to_log);}
+		catch (Throwable e) {Debug.printStackTrace(e);}
 	}
 	
 	static boolean client_logging_allowed = true;
@@ -132,19 +124,9 @@ public class BTPeerIDByteDecoder {
 		}
 		
 		if (!LOG_UNKNOWN) {return;}
-		FileWriter log = null;
-		File log_file = FileUtil.getUserFile("identification.log");
-		try {
-			log = new FileWriter(log_file, true);
-			logUnknownClient0(peer_id_bytes, log);
-		}
-		catch (Throwable e) {
-			Debug.printStackTrace(e);
-		}
-		finally {
-			try {if (log != null) log.close();}
-			catch (IOException ignore) {/*ignore*/}
-		}
+		try {logClientDiscrepancyToFile(logUnknownClient0(peer_id_bytes));}
+		catch (Throwable t) {Debug.printStackTrace(t);}
+		
 	}
 
 	static void logUnknownClient(String peer_id) {
@@ -508,6 +490,7 @@ public class BTPeerIDByteDecoder {
 		assertDecode("\u00B5Torrent 1.7.0 Beta", "2D555431 3730422D 92844644 1DB0A094 A01C01E5");
 		assertDecode("\u54c7\u560E (Vagaa) 2.6.4.4", "2D5647323634342D4FD62CDA69E235717E3BB94B");
 		assertDecode("Wyzo 0.3.0.0", "-WY0300-6huHF5Pr7Vde");
+		assertDecode("CacheLogic 25.1-26", "-PC251Q-6huHF5Pr7Vde");
 		System.out.println();
 
 		// Shadow style clients.
@@ -538,11 +521,14 @@ public class BTPeerIDByteDecoder {
 		assertDecode("BitsOnWheels", "-BOWP05-EPICNZOGQPHP"); // Seen in the wild - no idea what version that's meant to be - a pre-release?
 		assertDecode("Burst! 1.1.3", "Mbrst1-1-32e3c394b43");
 		assertDecode("Opera (Build 7685)", "OP7685f2c1495b1680bf");
+		assertDecode("Opera (Build 10063)", "O100634008270e29150a");
 		assertDecode("Rufus 0.6.9", "00455253 416E6F6E 796D6F75 7382BE42 75024AE3");
 		assertDecode("BitTorrent DNA 1.0", "444E413031303030DD01C9B2DA689E6E02803E91");
 		assertDecode("BTuga Revolution 2.1", "BTM21abcdefghijklmno");
 		assertDecode("AllPeers 0.70rc30", "4150302E3730726333302D3E3EB87B31F241DBFE"); // AP0.70rc30->>-{1-A--]"
 		assertDecode("External Webseed", "45787420EC7CC30033D7801FEEB713FBB0557AC4");
+		assertDecode("QVOD (Build 0054)", "QVOD00541234567890AB"); // Based on description on wiki.theory.org.
+		assertDecode("Top-BT 1.0.0", "TB100----abcdefghijk");
 		System.out.println();
 		
 		// BitComet/Lord/Spirit
