@@ -22,11 +22,22 @@
 
 package com.aelitis.azureus.core.peermanager.utils;
 
+import java.net.InetAddress;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+
+import org.gudy.azureus2.core3.util.Constants;
+import org.gudy.azureus2.core3.util.HostNameToIPResolver;
+import org.gudy.azureus2.core3.util.IPToHostNameResolver;
+
 /**
  * Handles peer client identification and banning.
  */
 public class PeerClassifier {
   
+	public static final String CACHE_LOGIC = "CacheLogic";
+
   /**
    * Get a client description (name and version) from the given peerID byte array. 
    * @param peer_id peerID sent in handshake
@@ -44,7 +55,7 @@ public class PeerClassifier {
    * @return printable peerID
    */
   public static String getPrintablePeerID( byte[] peer_id ) {
-    return BTPeerIDByteDecoder.getPrintablePeerID( peer_id, 0 );
+    return BTPeerIDByteDecoder.getPrintablePeerID(peer_id);
   }
   
 
@@ -59,4 +70,61 @@ public class PeerClassifier {
   }
   
 
+  
+	private static Set	platform_ips = Collections.synchronizedSet(new HashSet());
+
+	
+		/**
+		 * This only works for ones that have been explicitly set as AZ ips
+		 * @param ip
+		 * @return
+		 */
+
+	public static boolean
+	isAzureusIP(
+		final String	ip )
+	{
+		return( platform_ips.contains( ip ));
+	}
+	
+	public static void
+	setAzureusIP(
+		final String	ip )
+	{
+		platform_ips.add( ip );
+	}
+	
+		/**
+		 * SYNC call!
+		 * @param ip
+		 * @return
+		 */
+	
+	public static boolean
+	testIfAzureusIP(
+		final String	ip )
+	{
+		try{
+			InetAddress address = HostNameToIPResolver.syncResolve( ip );
+			
+			final String host_address = address.getHostAddress();
+			
+			if ( platform_ips.contains( host_address )){
+	
+				return( true );
+			}
+			
+			String name = IPToHostNameResolver.syncResolve( ip, 10000 );
+			
+			if ( Constants.isAzureusDomain( name )){
+					
+				platform_ips.add( host_address );
+					
+				return( true );
+			}
+		}catch( Throwable e ){
+		}
+		
+		return( false );
+	}
 }
