@@ -1,7 +1,7 @@
 /*
  * Created on 08-Dec-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -27,7 +27,7 @@ import java.net.InetAddress;
 import java.nio.ByteBuffer;
 import java.nio.channels.SocketChannel;
 
-import org.gudy.azureus2.core3.logging.LGLogger;
+import org.gudy.azureus2.core3.logging.*;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.HostNameToIPResolver;
 import org.gudy.azureus2.core3.util.HostNameToIPResolverListener;
@@ -44,9 +44,10 @@ public class
 AESocksProxyConnectionImpl
 	implements AESocksProxyConnection, AEProxyConnectionListener
 {
-	public static final boolean	TRACE	= true;
+	private static final LogIDs LOGID = LogIDs.NET;
+	public static final boolean	TRACE	= false;
 	
-	protected AESocksProxy			proxy;
+	protected AESocksProxyImpl		proxy;
 	protected AEProxyConnection		connection;
 	protected boolean				disable_dns_lookups;
 	
@@ -61,6 +62,8 @@ AESocksProxyConnectionImpl
 		AESocksProxyImpl						_proxy,
 		AESocksProxyPlugableConnectionFactory	_connection_factory,
 		AEProxyConnection						_connection )
+	
+		throws IOException
 	{
 		proxy		= _proxy;
 		connection	= _connection;
@@ -69,11 +72,15 @@ AESocksProxyConnectionImpl
 		
 		source_channel	= connection.getSourceChannel();
 		
-		plugable_connection	= _connection_factory.create( this );
+		try{
+			plugable_connection	= _connection_factory.create( this );
 		
-		if ( TRACE ){
+			if ( TRACE ){
+				Logger.log(new LogEvent(LOGID, "AESocksProxyProcessor: " + getName()));
+			}
+		}catch( AEProxyException e ){
 			
-			LGLogger.log( "AESocksProxyProcessor: " + getName());
+			throw( new IOException( e.getMessage()));
 		}
 	}
 	
@@ -111,7 +118,10 @@ AESocksProxyConnectionImpl
 		AEProxyConnection	con )
 	{
 		try{
-			plugable_connection.close();
+			if ( plugable_connection != null ){
+				
+				plugable_connection.close();
+			}
 			
 		}catch( Throwable e ){
 			
@@ -165,20 +175,26 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(1);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -198,6 +214,8 @@ AESocksProxyConnectionImpl
 				throw( new IOException( "Unsupported version " + version ));
 
 			}
+			
+			return( true );
 		}
 	}
 	
@@ -222,7 +240,7 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(7);
 		}
 	
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
@@ -235,14 +253,20 @@ AESocksProxyConnectionImpl
 			# of bytes:	   1    1      2              4           variable       1
 			*/
 
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
-			
+						
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -301,6 +325,8 @@ AESocksProxyConnectionImpl
 				
 				buffer = ByteBuffer.allocate(1);
 			}
+			
+			return( true );
 		}
 	}
 	
@@ -325,7 +351,7 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(1);
 		}
 	
-		protected void
+		protected boolean
 		readSupport(
 			final SocketChannel 		sc )
 		
@@ -333,14 +359,21 @@ AESocksProxyConnectionImpl
 		{
 				// dns name follows, null terminated
 
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -397,6 +430,8 @@ AESocksProxyConnectionImpl
 				
 				buffer.flip();
 			}
+			
+			return( true );
 		}
 	}
 	
@@ -432,13 +467,13 @@ AESocksProxyConnectionImpl
 			write( source_channel );
 		}
 		
-		protected void
+		protected boolean
 		writeSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			sc.write( buffer );
+			int	len = sc.write( buffer );
 			
 			if ( buffer.hasRemaining()){
 				
@@ -448,6 +483,8 @@ AESocksProxyConnectionImpl
 	
 				plugable_connection.relayData();
 			}
+			
+			return( len > 0 );
 		}
 	}
 	
@@ -468,20 +505,27 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(1);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -489,6 +533,8 @@ AESocksProxyConnectionImpl
 			int	num_methods	= buffer.get();
 			
 			new proxyStateV5Methods(num_methods);
+			
+			return( true );
 		}
 	}
 	
@@ -508,25 +554,34 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(methods);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 				// we just ignore actual method values
 			
 			new proxyStateV5MethodsReply();
+			
+			return( true );
 		}
 	}
 	
@@ -551,18 +606,20 @@ AESocksProxyConnectionImpl
 			write( source_channel );
 		}
 		
-		protected void
+		protected boolean
 		writeSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			sc.write( buffer );
+			int len = sc.write( buffer );
 			
 			if ( buffer.hasRemaining()){
 				
 				connection.requestWriteSelect( sc );
 			}
+			
+			return( len > 0 );
 		}
 	}
 	
@@ -605,20 +662,27 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(4);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -648,6 +712,8 @@ AESocksProxyConnectionImpl
 				
 				throw( new IOException( "V5: Unsupported address type" ));
 			}
+			
+			return( true );
 		}
 	}
 	
@@ -666,20 +732,27 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(4);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -691,6 +764,8 @@ AESocksProxyConnectionImpl
 			InetAddress inet_address = InetAddress.getByAddress( bytes );
 			
 			new proxyStateV5RequestPort( "", inet_address );
+			
+			return( true );
 		}
 	}
 	
@@ -710,20 +785,27 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(1);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			final SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -770,6 +852,8 @@ AESocksProxyConnectionImpl
 						});
 				}
 			}
+			
+			return( true );
 		}
 	}
 	
@@ -795,20 +879,27 @@ AESocksProxyConnectionImpl
 			buffer	= ByteBuffer.allocate(2);
 		}
 		
-		protected void
+		protected boolean
 		readSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			if ( sc.read( buffer ) == -1 ){
+			int	len = sc.read( buffer );
+			
+			if ( len == 0 ){
+				
+				return( false );
+				
+			}else if ( len == -1 ){
 				
 				throw( new IOException( "read channel shutdown" ));
 			}
 			
+			
 			if ( buffer.hasRemaining()){
 				
-				return;
+				return( true );
 			}
 			
 			buffer.flip();
@@ -818,6 +909,8 @@ AESocksProxyConnectionImpl
 			socks_version	= 5;
 			
 			plugable_connection.connect( new AESocksProxyAddressImpl( unresolved_address, address, port ));
+			
+			return( true );
 		}
 	}
 	
@@ -879,13 +972,13 @@ AESocksProxyConnectionImpl
 			write( source_channel );
 		}
 		
-		protected void
+		protected boolean
 		writeSupport(
 			SocketChannel 		sc )
 		
 			throws IOException
 		{
-			sc.write( buffer );
+			int	len = sc.write( buffer );
 			
 			if ( buffer.hasRemaining()){
 				
@@ -895,6 +988,8 @@ AESocksProxyConnectionImpl
 	
 				plugable_connection.relayData();
 			}
+			
+			return( len > 0 );
 		}
 	}
 	
