@@ -25,14 +25,27 @@ package com.aelitis.azureus.core.security;
 public interface 
 CryptoManager 
 {
+		// don't even THINK about changing this!!!!
+
+	public static final String	CRYPTO_CONFIG_PREFIX = "core.crypto.";
+	
 	public static final int HANDLER_ECC	= 1;
 	
+	public static final int[] HANDLERS = { HANDLER_ECC };
+	
 	public byte[]
 	getSecureID();
 	
 	public CryptoHandler
 	getECCHandler();
 	
+	public void
+	clearPasswords();
+	
+	public void
+	clearPasswords(
+		int	password_handler_type );
+
 	public void
 	addPasswordHandler(
 		CryptoManagerPasswordHandler		handler );
@@ -40,4 +53,12 @@ CryptoManager
 	public void
 	removePasswordHandler(
 		CryptoManagerPasswordHandler		handler );
+	
+	public void
+	addKeyListener(
+		CryptoManagerKeyListener		listener );
+	
+	public void
+	removeKeyListener(
+		CryptoManagerKeyListener		listener );
 }
