@@ -25,7 +25,6 @@ package com.aelitis.azureus.core.security.impl;
 import java.util.*;
 
 import java.nio.ByteBuffer;
-import java.security.SecureRandom;
 
 import javax.crypto.Cipher;
 import javax.crypto.SecretKey;
@@ -37,6 +36,7 @@ import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.security.SESecurityManager;
 import org.gudy.azureus2.core3.util.ByteFormatter;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.RandomUtils;
 import org.gudy.azureus2.core3.util.SHA1;
 import org.gudy.azureus2.core3.util.SimpleTimer;
 import org.gudy.azureus2.core3.util.SystemTime;
@@ -49,7 +49,6 @@ import com.aelitis.azureus.core.security.CryptoManagerException;
 import com.aelitis.azureus.core.security.CryptoManagerKeyListener;
 import com.aelitis.azureus.core.security.CryptoManagerPasswordException;
 import com.aelitis.azureus.core.security.CryptoManagerPasswordHandler;
-import com.aelitis.azureus.core.security.CryptoManagerPasswordHandler.passwordDetails;
 import com.aelitis.azureus.core.util.CopyOnWriteList;
 
 public class 
@@ -58,7 +57,7 @@ CryptoManagerImpl
 {
 	private static final int 	PBE_ITERATIONS	= 100;
 	private static final String	PBE_ALG			= "PBEWithMD5AndDES";
-	
+		
 	private static CryptoManagerImpl		singleton;
 	
 	
@@ -151,7 +150,7 @@ CryptoManagerImpl
 			
 			secure_id = new byte[20];
 		
-			new SecureRandom().nextBytes( secure_id );
+			RandomUtils.SECURE_RANDOM.nextBytes( secure_id );
 			
 			COConfigurationManager.setParameter( key, secure_id );
 			
@@ -177,7 +176,7 @@ CryptoManagerImpl
 		try{
 			byte[]	salt = new byte[8];
 			
-			new SecureRandom().nextBytes( salt );
+			RandomUtils.SECURE_RANDOM.nextBytes( salt );
 			
 			PBEKeySpec keySpec = new PBEKeySpec(password);
 		
@@ -288,6 +287,44 @@ CryptoManagerImpl
 		}
    	}
 	
+	protected passwordDetails
+	setPassword(
+		int				handler,
+		int				pw_type,
+		char[]			pw_chars,
+		long			timeout )
+	
+		throws CryptoManagerException
+	{
+		try{
+			String persist_timeout_key 	= CryptoManager.CRYPTO_CONFIG_PREFIX + "pw." + handler + ".persist_timeout";
+			String persist_pw_key 		= CryptoManager.CRYPTO_CONFIG_PREFIX + "pw." + handler + ".persist_value";
+			String persist_pw_key_type	= CryptoManager.CRYPTO_CONFIG_PREFIX + "pw." + handler + ".persist_type";
+	
+			byte[]	salt		= getPasswordSalt();
+			byte[]	pw_bytes	= new String( pw_chars ).getBytes( "UTF8" );
+			
+			SHA1 sha1 = new SHA1();
+			
+			sha1.update( ByteBuffer.wrap( salt ));
+			sha1.update( ByteBuffer.wrap( pw_bytes ));
+			
+			String	encoded_pw = ByteFormatter.encodeString( sha1.digest());
+
+			COConfigurationManager.setParameter( persist_timeout_key, timeout );
+			COConfigurationManager.setParameter( persist_pw_key_type, pw_type );
+			COConfigurationManager.setParameter( persist_pw_key, encoded_pw );
+
+			passwordDetails	result = new passwordDetails( encoded_pw.toCharArray(), pw_type );
+
+			return( result );
+			
+		}catch( Throwable e ){
+		
+			throw( new CryptoManagerException( "setPassword failed", e ));
+		}
+	}
+	
 	protected passwordDetails
 	getPassword(
 		int				handler,
