@@ -841,6 +841,14 @@ SubscriptionHistoryImpl
 		return( auto_dl_supported );
 	}
 	
+	protected void
+	setFatalError(
+		String		_error )
+	{
+		last_error		= _error;
+		consec_fails	= 1024;
+	}
+	
 	protected void
 	setLastError(
 		String		_last_error,
