@@ -58,6 +58,7 @@ import com.aelitis.azureus.core.subs.SubscriptionHistory;
 import com.aelitis.azureus.core.subs.SubscriptionListener;
 import com.aelitis.azureus.core.subs.SubscriptionManager;
 import com.aelitis.azureus.core.subs.SubscriptionPopularityListener;
+import com.aelitis.azureus.core.subs.SubscriptionResult;
 import com.aelitis.azureus.core.util.CopyOnWriteList;
 import com.aelitis.azureus.core.vuzefile.VuzeFile;
 import com.aelitis.azureus.core.vuzefile.VuzeFileHandler;
@@ -773,9 +774,22 @@ SubscriptionImpl
 	
 		throws SubscriptionException
 	{
-		SubscriptionBodyImpl body = new SubscriptionBodyImpl( manager, this );
+		try{
+			SubscriptionBodyImpl body = new SubscriptionBodyImpl( manager, this );
 
-		return( body.getJSON());
+			return( body.getJSON());
+			
+		}catch( Throwable e ){
+			
+			history.setFatalError( Debug.getNestedExceptionMessage(e));
+			
+			if ( e instanceof SubscriptionException ){
+				
+				throw((SubscriptionException)e );
+			}
+			
+			throw( new SubscriptionException( "Failed to read subscription", e ));
+		}
 	}
 	
 	public boolean
@@ -1832,6 +1846,13 @@ SubscriptionImpl
 		}
 	}
 	
+	public SubscriptionResult[]
+  	getResults(
+  		boolean		include_deleted )
+	{
+		return( getHistory().getResults( include_deleted ));
+	}
+	
 	public void
 	setUserData(
 		Object		key,
