@@ -25,24 +25,20 @@ import java.net.InetAddress;
 import java.net.URL;
 import java.util.*;
 
-import org.bouncycastle.util.encoders.Base64;
 import org.gudy.azureus2.core3.download.DownloadManager;
+import org.gudy.azureus2.core3.download.DownloadManagerState;
 import org.gudy.azureus2.core3.global.GlobalManager;
 import org.gudy.azureus2.core3.torrent.TOTorrent;
 import org.gudy.azureus2.core3.torrent.TOTorrentAnnounceURLSet;
 import org.gudy.azureus2.core3.torrent.TOTorrentException;
 import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.plugins.PluginInterface;
+import org.gudy.azureus2.plugins.torrent.Torrent;
 import org.gudy.azureus2.pluginsimpl.local.torrent.TorrentImpl;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
-import com.aelitis.azureus.core.messenger.PlatformMessenger;
-import com.aelitis.azureus.core.messenger.config.PlatformRatingMessenger;
-import com.aelitis.azureus.core.messenger.config.PlatformTorrentMessenger;
-
-import org.gudy.azureus2.plugins.PluginInterface;
-import org.gudy.azureus2.plugins.torrent.Torrent;
 
 /**
  * @author TuxPaper
@@ -51,15 +47,10 @@ import org.gudy.azureus2.plugins.torrent.Torrent;
  */
 public class PlatformTorrentUtils
 {
-	private static final long RETRY_METADATA = 10 * 60 * 1000;
-
 	private static final long MIN_SPEED_DEFAULT = 100 * 1024;
 
-	private static final long MIN_MD_REFRESH_MS = 1000 * 60;
-
-	private static final long MAX_MD_REFRESH_MS = 1000L * 60 * 60 * 24 * 30;
-
-	public static final String AELITIS_HOST_CORE	= "aelitis.com";			// needs to be lowercase
+	public static final String AELITIS_HOST_CORE	= ".aelitis.com";			// needs to be lowercase
+	public static final String VUZE_HOST_CORE		= ".vuze.com";				// needs to be lowercase
 
 	public static final boolean DEBUG_CACHING = System.getProperty(
 			"az3.debug.caching", "0").equals("1");
@@ -86,14 +77,6 @@ public class PlatformTorrentUtils
 
 	private static final String TOR_AZ_PROP_QUALITY = "Quality";
 
-	private static final String TOR_AZ_PROP_USER_RATING = "UserRating";
-
-	private static final String TOR_AZ_PROP_LASTUPDATED = "Revision Date";
-
-	private static final String TOR_AZ_PROP_CREATIONDATE = "Creation Date";
-
-	private static final String TOR_AZ_PROP_METADATA_REFRESHON = "Refresh On";
-
 	private static final String TOR_AZ_PROP_PROGRESSIVE = "Progressive";
 
 	private static final String TOR_AZ_PROP_SPEED = "Speed Bps";
@@ -108,33 +91,27 @@ public class PlatformTorrentUtils
 
 	private static final String TOR_AZ_PROP_CONTENT_NETWORK = "Content Network";
 		
-	private static final String TOR_AZ_PROP_AD_ID = "Ad ID";
-
-	private static final String TOR_AZ_PROP_AD_ENABLED = "Ad Enabled";
-
 	private static final String TOR_AZ_PROP_EXPIRESON = "Expires On";
 	
 	private static final String TOR_AZ_PROP_PRIMARY_FILE = "Primary File Index";
 
-	private static final ArrayList metaDataListeners = new ArrayList(1);
-
-	private static final ArrayList hasBeenOpenedListeners = new ArrayList(1);
+	private static final ArrayList<HasBeenOpenedListener> hasBeenOpenedListeners = new ArrayList<HasBeenOpenedListener>(1);
 
 	private static final String TOR_AZ_PROP_USE_EMP = "useEMP";
 	
 	private static final String TOR_AZ_PROP_FILE_METADATA = "File MetaData";
 	
-	private static final String TOR_AZ_PROP_WEB_AD_ENABLED = "Web Ad Enabled";
-
 	private static final String TOR_AZ_PROP_VIDEO_WIDTH = "Video Width";
 
 	private static final String TOR_AZ_PROP_VIDEO_HEIGHT = "Video Height";
 
 	private static final String TOR_AZ_PROP_VIDEO_RUNNINGTIME = "Running Time";
+	
+	private static final String TOR_AZ_PROP_DURATION_MILLIS = "Duration";
 
 	private static final String TOR_AZ_PROP_OPENED = "Opened";
 
-	private static ArrayList listPlatformHosts = null;
+	private static ArrayList<String> listPlatformHosts = null;
 
 	private static final Map mapPlatformTrackerTorrents = new WeakHashMap();
 
@@ -190,7 +167,7 @@ public class PlatformTorrentUtils
 		return mapContent;
 	}
 
-	private static String getContentMapString(TOTorrent torrent, String key) {
+	public static String getContentMapString(TOTorrent torrent, String key) {
 		if (torrent == null) {
 			return null;
 		}
@@ -296,6 +273,10 @@ public class PlatformTorrentUtils
 	public static String getContentDescription(TOTorrent torrent) {
 		return getContentMapString(torrent, TOR_AZ_PROP_DESCRIPTION);
 	}
+	
+	public static void setContentDescription(TOTorrent torrent, String desc) {
+		setContentMapString(torrent, TOR_AZ_PROP_DESCRIPTION,desc);
+	}
 
 	public static String getContentType(TOTorrent torrent) {
 		return getContentMapString(torrent, TOR_AZ_PROP_CONTENT_TYPE);
@@ -403,6 +384,10 @@ public class PlatformTorrentUtils
 		return getContentMapString(torrent, TOR_AZ_PROP_THUMBNAIL_URL);
 	}
 
+	public static void setContentThumbnailUrl(TOTorrent torrent, String url) {
+		setContentMapString(torrent, TOR_AZ_PROP_THUMBNAIL_URL, url);
+	}
+	
 	public static void setContentThumbnail(TOTorrent torrent, byte[] thumbnail) {
 		Map mapContent = getContentMap(torrent);
 		putOrRemove(mapContent, TOR_AZ_PROP_THUMBNAIL, thumbnail);
@@ -410,55 +395,6 @@ public class PlatformTorrentUtils
 		writeTorrentIfExists(torrent);
 	}
 
-	public static void setUserRating(TOTorrent torrent, int rating) {
-		if (torrent == null || getUserRating(torrent) == rating) {
-			return;
-		}
-		Map mapContent = getTempContentMap(torrent);
-		mapContent.put(TOR_AZ_PROP_USER_RATING, new Long(rating));
-		writeTorrentIfExists(torrent);
-		RatingInfoList ratingReply = new SingleUserRatingInfo(torrent);
-		PlatformRatingMessenger.invokeUpdateListeners(ratingReply);
-	}
-
-	public static void removeUserRating(TOTorrent torrent) {
-		Map mapContent = getTempContentMap(torrent);
-		if (mapContent.remove(TOR_AZ_PROP_USER_RATING) != null) {
-			writeTorrentIfExists(torrent);
-			RatingInfoList ratingReply = new SingleUserRatingInfo(torrent);
-			PlatformRatingMessenger.invokeUpdateListeners(ratingReply);
-		}
-	}
-
-	/**
-	 * 
-	 * @param torrent
-	 * @return -1: No rating
-	 */
-	public static int getUserRating(TOTorrent torrent) {
-		Map mapContent = getTempContentMap(torrent);
-		Long l = (Long) mapContent.get(TOR_AZ_PROP_USER_RATING);
-		if (l == null) {
-			return -1;
-		}
-		return l.intValue();
-	}
-
-	public static long getMetaDataRefreshOn(TOTorrent torrent) {
-		Map mapContent = getTempContentMap(torrent);
-		Long l = (Long) mapContent.get(TOR_AZ_PROP_METADATA_REFRESHON);
-		if (l == null) {
-			return 0;
-		}
-		return l.longValue();
-	}
-
-	public static void setMetaDataRefreshOn(TOTorrent torrent, long refreshOn) {
-		Map mapContent = getTempContentMap(torrent);
-		mapContent.put(TOR_AZ_PROP_METADATA_REFRESHON, new Long(refreshOn));
-		writeTorrentIfExists(torrent);
-	}
-
 	public static boolean isContent(TOTorrent torrent,
 			boolean requirePlatformTracker) {
 		if (torrent == null) {
@@ -481,9 +417,9 @@ public class PlatformTorrentUtils
 		return false;
 	}
 
-	public static List getPlatformHosts() {
+	public static List<String> getPlatformHosts() {
 		if (listPlatformHosts == null) {
-			listPlatformHosts = new ArrayList();
+			listPlatformHosts = new ArrayList<String>();
 			for (int i = 0; i < Constants.AZUREUS_DOMAINS.length; i++) {
 				listPlatformHosts.add(Constants.AZUREUS_DOMAINS[i].toLowerCase());
 			}
@@ -492,7 +428,7 @@ public class PlatformTorrentUtils
 	}
 
 	public static void addPlatformHost(String host) {
-		List platformHosts = getPlatformHosts();
+		List<String> platformHosts = getPlatformHosts();
 		host = host.toLowerCase();
 
 		if (!platformHosts.contains(host)) {
@@ -599,252 +535,54 @@ public class PlatformTorrentUtils
 		return false;
 	}
 	
-	public static boolean isUpdateDM(DownloadManager dm) {
-		Boolean oisUpdate = (Boolean) dm.getUserData("isUpdate");
+	public static boolean isAdvancedViewOnly(DownloadManager dm) {
+		Boolean oisUpdate = (Boolean) dm.getUserData("isAdvancedViewOnly");
 		if (oisUpdate != null) {
 			return oisUpdate.booleanValue();
 		}
 
-		boolean isUpdate = true;
-		TOTorrent torrent = dm.getTorrent();
-		if (torrent == null) {
-			isUpdate = false;
-		} else {
-			URL announceURL = torrent.getAnnounceURL();
-
-			if (announceURL != null) {
-				if (announceURL.getHost().indexOf(AELITIS_HOST_CORE) == -1) {
-					isUpdate = false;
-				}
-			}
+		boolean advanced_view = true;
+		
+		if ( !dm.getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE )){
 			
-			if (isUpdate) {
-				TOTorrentAnnounceURLSet[] sets = torrent.getAnnounceURLGroup().getAnnounceURLSets();
-
-				for (int i = 0; i < sets.length; i++) {
-
-					URL[] urls = sets[i].getAnnounceURLs();
-
-					for (int j = 0; j < urls.length; j++) {
-
-						if (urls[j].getHost().indexOf(AELITIS_HOST_CORE) == -1) {
-							isUpdate = false;
-							break;
+			TOTorrent torrent = dm.getTorrent();
+			if (torrent == null) {
+				advanced_view = false;
+			} else {
+				URL announceURL = torrent.getAnnounceURL();
+	
+				if (announceURL != null) {
+					String	host = announceURL.getHost();
+					
+					if (!( host.endsWith(AELITIS_HOST_CORE)|| host.endsWith( VUZE_HOST_CORE ))){
+						advanced_view = false;
+					}
+				}
+				
+				if (advanced_view) {
+					TOTorrentAnnounceURLSet[] sets = torrent.getAnnounceURLGroup().getAnnounceURLSets();
+	
+					for (int i = 0; i < sets.length; i++) {
+	
+						URL[] urls = sets[i].getAnnounceURLs();
+	
+						for (int j = 0; j < urls.length; j++) {
+	
+							String host = urls[j].getHost();
+							
+							if (!( host.endsWith(AELITIS_HOST_CORE)|| host.endsWith( VUZE_HOST_CORE ))){
+								advanced_view = false;
+								break;
+							}
 						}
 					}
 				}
 			}
 		}
-
-		dm.setUserData("isUpdate", new Boolean(isUpdate));
-		return isUpdate;
-	}
-
-	public static String getAdId(TOTorrent torrent) {
-		return getContentMapString(torrent, TOR_AZ_PROP_AD_ID);
-	}
-
-	public static void setAdId(TOTorrent torrent, String sID) {
-		Map mapContent = getContentMap(torrent);
-		putOrRemove(mapContent, TOR_AZ_PROP_AD_ID, sID);
-
-		writeTorrentIfExists(torrent);
-	}
-
-
-	/**
-	 * @param torrent
-	 * @param maxDelayMS TODO
-	 *
-	public static void updateMetaData(final TOTorrent[] torrents, long maxDelayMS) {
-		if (torrents == null) {
-			log("no torrents to update MD on");
-			return;
-		}
-
-		log("update " + torrents.length + " MD");
-
-		PlatformTorrentMessenger.getMetaData(torrents, maxDelayMS,
-				new PlatformTorrentMessenger.GetMetaDataReplyListener() {
-
-			public void messageSent() {
-			}
-
-			public void replyReceived(String replyType, Map mapHashes) {
-				for (Iterator iter = mapHashes.keySet().iterator(); iter.hasNext();) {
-					String hash = (String) iter.next();
-					updateMetaData_handleReply(null, hash, replyType, mapHashes);
-				}
-			}
-		});
-	}
-*/
-	/**
-	 * @param torrent
-	 * @param maxDelayMS TODO
-	 */
-	public static void updateMetaData(final TOTorrent torrent, long maxDelayMS) {
-		if (!isContent(torrent, true)) {
-			log(torrent, "torrent " + new String(torrent.getName())
-					+ " not az content");
-			return;
-		}
-
-		log(torrent, "updateMD");
-
-		PlatformTorrentMessenger.getMetaData(getContentNetworkID(torrent),
-				new TOTorrent[] {
-					torrent
-				}, maxDelayMS, new PlatformTorrentMessenger.GetMetaDataReplyListener() {
-
-					public void messageSent() {
-					}
-
-					public void replyReceived(String replyType, Map mapHashes) {
-						updateMetaData_handleReply(torrent, null, replyType, mapHashes);
-					}
-				});
-	}
-
-	private static void updateMetaData_handleReply(TOTorrent torrent,
-			String hash, String replyType, Map mapHashes) {
-		if (hash == null && torrent != null) {
-			try {
-				hash = torrent.getHashWrapper().toBase32String();
-			} catch (Exception e) {
-			}
-		}
-
-		GlobalManager gm = AzureusCoreFactory.getSingleton().getGlobalManager();
-		DownloadManager dm = gm.getDownloadManager(new HashWrapper(Base32.decode(hash)));
-
-		if (torrent == null && dm != null) {
-			torrent = dm.getTorrent();
-		}
-		Map contentMap = PlatformTorrentUtils.getContentMap(torrent);
-
-		final TOTorrent torrentFinal = torrent;
 		
-		if (replyType.equals(PlatformMessenger.REPLY_EXCEPTION)) {
-			if (torrent != null) {
-  			// try again in a bit
-  			log(torrent, "Exception, retrying later (~" + RETRY_METADATA + "ms)");
-  			SimpleTimer.addEvent("Update MD Retry", SystemTime.getCurrentTime()
-  					+ RETRY_METADATA, new TimerEventPerformer() {
-  				public void perform(TimerEvent event) {
-  					log(torrentFinal, "retry time");
-  					PlatformTorrentUtils.updateMetaData(torrentFinal, 15000);
-  				}
-  			});
-			}
-		} else {
-			Map jsonMapMetaData = hash == null ? null : (Map) mapHashes.get(hash);
-			if (jsonMapMetaData != null && !jsonMapMetaData.isEmpty()) {
-				long oldLastUpdated = getContentLastUpdated(torrent);
-				long expireyMins = 0;
-
-				for (Iterator iter = jsonMapMetaData.keySet().iterator(); iter.hasNext();) {
-					String key = (String) iter.next();
-					Object value = jsonMapMetaData.get(key);
-
-					if (value == null || value.equals(null)) {
-						contentMap.remove(key);
-					} else if ((key.equals("Thumbnail") || key.endsWith(".B64"))
-							&& value instanceof String) {
-						contentMap.put(key, Base64.decode((String) value));
-					} else if (key.equals("expires-in-mins") && value instanceof Long) {
-						expireyMins = ((Long) value).longValue();
-					} else {
-						contentMap.put(key, value);
-					}
-					writeTorrentIfExists(torrent);
-				}
-
-				// crappy way of updating the display name
-				if (dm != null) {
-					String title = PlatformTorrentUtils.getContentTitle(torrent);
-					if (title != null && title.length() > 0
-							&& dm.getDownloadState().getDisplayName() == null) {
-						dm.getDownloadState().setDisplayName(title);
-					}
-				}
-				triggerMetaDataUpdateListeners(torrent);
-
-				if (torrent != null) {
-					// setup next refresh
-
-  				long refreshOn;
-  				if (expireyMins > 0) {
-  					refreshOn = SystemTime.getCurrentTime() + (expireyMins * 60 * 1000L);
-  				} else {
-  					long newLastUpdated = getContentLastUpdated(torrent);
-  
-  					long diff = newLastUpdated - oldLastUpdated;
-  					log(torrent, "Last Updated: new " + new Date(newLastUpdated)
-  							+ ";old " + new Date(oldLastUpdated) + ";diff=" + diff);
-  					if (diff > 0 && oldLastUpdated != 0) {
-  						diff *= 2;
-  						if (diff < MIN_MD_REFRESH_MS) {
-  							diff = MIN_MD_REFRESH_MS;
-  						} else if (diff > MAX_MD_REFRESH_MS) {
-  							diff = MAX_MD_REFRESH_MS;
-  						}
-  						refreshOn = SystemTime.getOffsetTime(diff);
-  					} else {
-  						refreshOn = SystemTime.getCurrentTime()
-  								+ (7 * 24 * 60 * 60 * 1000L);
-  					}
-  				}
-  
-  				log(torrent, "got MD. Next refresh in "
-  						+ (refreshOn - SystemTime.getCurrentTime()));
-  				setMetaDataRefreshOn(torrent, refreshOn);
-  				SimpleTimer.addEvent("Update MD", refreshOn, new TimerEventPerformer() {
-  					public void perform(TimerEvent event) {
-  						PlatformTorrentUtils.updateMetaData(torrentFinal, 15000);
-  					}
-  				});
-				}
-			} else if (torrent != null) {
-				long refreshOn = SystemTime.getCurrentTime()
-						+ (30 * 24 * 60 * 60 * 1000L);
-				setMetaDataRefreshOn(torrent, refreshOn);
-				log(torrent, "no hash in reply. Next refresh on " + new Date(refreshOn));
-			}
-		}
-	}
-
-	public static void addListener(MetaDataUpdateListener l) {
-		if (metaDataListeners.indexOf(l) < 0) {
-			metaDataListeners.add(l);
-		}
-	}
-
-	public static void removeListener(MetaDataUpdateListener l) {
-		metaDataListeners.remove(l);
-	}
-
-	public static void triggerMetaDataUpdateListeners(TOTorrent torrent) {
-		if (torrent == null) {
-			return;
-		}
-		MetaDataUpdateListener[] listeners = (MetaDataUpdateListener[]) metaDataListeners.toArray(new MetaDataUpdateListener[0]);
-		for (int i = 0; i < listeners.length; i++) {
-			MetaDataUpdateListener listener = listeners[i];
-			try {
-				listener.metaDataUpdated(torrent);
-			} catch (Exception e) {
-				Debug.out(e);
-			}
-		}
-	}
-
-	public static long getContentLastUpdated(TOTorrent torrent) {
-		return getContentMapLong(torrent, TOR_AZ_PROP_LASTUPDATED, 0);
-	}
-
-	public static void setContentLastUpdated(TOTorrent torrent, long lastUpdate) {
-		setContentMapLong(torrent, TOR_AZ_PROP_LASTUPDATED, lastUpdate);
+		dm.setUserData("isAdvancedViewOnly", new Boolean(advanced_view));
+		
+		return advanced_view;
 	}
 
 	public static boolean isContentProgressive(TOTorrent torrent) {
@@ -859,24 +597,6 @@ public class PlatformTorrentUtils
 		return getContentMapLong(torrent, TOR_AZ_PROP_MIN_SPEED, MIN_SPEED_DEFAULT);
 	}
 
-	/**
-	 * If either Ad Enabled or Web Ad Enabled is set return true.
-	 * @param torrent
-	 * @return - boolean - true if EITHER "Ad Enabled"==1  OR  "Web Ad Enabled"==1
-	 */
-	public static boolean isContentAdEnabled(TOTorrent torrent) {
-		return (getContentMapLong(torrent, TOR_AZ_PROP_AD_ENABLED, 0) == 1 ||
-				getContentMapLong(torrent, TOR_AZ_PROP_WEB_AD_ENABLED, 0) == 1);
-	}
-
-	public static boolean isContentUnitAdEnabled(TOTorrent torrent) {
-		return getContentMapLong(torrent, TOR_AZ_PROP_WEB_AD_ENABLED, 0) == 1;
-	}
-
-	public static boolean isContentWebAdEnabled(TOTorrent torrent) {
-		return getContentMapLong(torrent, TOR_AZ_PROP_WEB_AD_ENABLED, 0) == 1;
-	}
-
 	public static boolean useEMP(TOTorrent torrent) {
 		return getContentMapLong(torrent, TOR_AZ_PROP_USE_EMP, 0) == 1;
 	}
@@ -902,12 +622,6 @@ public class PlatformTorrentUtils
 		return l.longValue();
 	}
 
-	public static void setExpiresOn(TOTorrent torrent, long expiresOn) {
-		Map mapContent = getContentMap(torrent);
-		mapContent.put(TOR_AZ_PROP_EXPIRESON, new Long(expiresOn));
-		writeTorrentIfExists(torrent);
-	}
-
 	public static int getContentPrimaryFileIndex(TOTorrent torrent ){
 		return (int)getContentMapLong(torrent, TOR_AZ_PROP_PRIMARY_FILE, -1 );
 	}
@@ -925,6 +639,14 @@ public class PlatformTorrentUtils
 		return getContentMapLong(torrent, TOR_AZ_PROP_VIDEO_RUNNINGTIME, -1);
 	}
 	
+	public static long getContentDurationMillis(TOTorrent torrent) {
+		return getContentMapLong(torrent, TOR_AZ_PROP_DURATION_MILLIS, -1);
+	}
+	
+	public static void setContentDurationMillis(TOTorrent torrent, long millis ) {
+		setContentMapLong(torrent, TOR_AZ_PROP_DURATION_MILLIS, millis );
+	}
+	
 	public static int[] getContentVideoResolution(TOTorrent torrent) {
 		long width = getContentVideoWidth(torrent);
 		if (width <= 0) {
@@ -1027,10 +749,10 @@ public class PlatformTorrentUtils
 			return true;
 		}
 		boolean opened = getContentMapLong(torrent, TOR_AZ_PROP_OPENED, -1) > 0;
-		if (opened || getAdId(torrent) != null || isUpdateDM(dm)) {
+		if (opened || isAdvancedViewOnly(dm)) {
 			return true;
 		}
-		
+
 		return false;
 	}
 
