@@ -42,6 +42,8 @@ import org.gudy.azureus2.core3.stats.transfer.*;
 import org.gudy.azureus2.core3.util.*;
 
 import org.gudy.azureus2.plugins.PluginInterface;
+import org.gudy.azureus2.plugins.utils.DelayedTask;
+import org.gudy.azureus2.pluginsimpl.local.utils.UtilitiesImpl;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
@@ -49,6 +51,8 @@ import com.aelitis.azureus.core.impl.AzureusCoreImpl;
 import com.aelitis.azureus.core.clientmessageservice.*;
 import com.aelitis.azureus.core.networkmanager.admin.NetworkAdmin;
 import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminASN;
+import com.aelitis.azureus.core.security.CryptoManagerFactory;
+import com.aelitis.azureus.core.util.DNSUtils;
 import com.aelitis.net.udp.uc.PRUDPPacketHandler;
 import com.aelitis.net.udp.uc.PRUDPPacketHandlerFactory;
 import com.aelitis.net.udp.uc.PRUDPReleasablePacketHandler;
@@ -120,6 +124,7 @@ public class VersionCheckClient {
 	  return( instance );
   }
   
+  private boolean	enable_v6;
   private boolean	prefer_v6;
 
   private Map last_check_data_v4 = null;
@@ -137,19 +142,58 @@ public class VersionCheckClient {
   private 
   VersionCheckClient()
   {
-	  COConfigurationManager.addAndFireParameterListener(
-			  "IPV6 Prefer Addresses",
+	  COConfigurationManager.addAndFireParameterListeners(
+			  new String[]{ "IPV6 Prefer Addresses", "IPV6 Enable Support" },
 			  new ParameterListener()
 			  {
 				 public void 
 				 parameterChanged(
 					String 	name )
 				 {
-					 prefer_v6 = COConfigurationManager.getBooleanParameter( name );
+					 enable_v6	= COConfigurationManager.getBooleanParameter( "IPV6 Enable Support" );
+					 prefer_v6 	= COConfigurationManager.getBooleanParameter( "IPV6 Prefer Addresses" );
 				 } 
 			  });
   }
   
+  public void
+  initialise()
+  {
+	  DelayedTask delayed_task = 
+		  UtilitiesImpl.addDelayedTask(
+	   		"VersionCheck", 
+	   		new Runnable()
+	   		{
+	   			public void
+	   			run()
+	   			{
+	   				final AESemaphore sem = new AESemaphore( "VCC:init" );
+	   				
+	   				new AEThread2( "VCC:init", true )
+	   				{
+	   					public void 
+	   					run()
+	   					{
+	   						try{
+	   							getVersionCheckInfo( REASON_UPDATE_CHECK_START );
+	   							
+	   						}finally{
+	   							
+	   							sem.release();
+	   						}
+	   					}
+	   				}.start();
+	   				
+	   				if ( !sem.reserve( 5000 )){
+	   					
+	   					Debug.out( "Timeout waiting for version check to complete" );
+	   				}
+	   			}
+	   		});
+	  
+	  delayed_task.queue();
+  }
+  
   
   
    
@@ -203,47 +247,50 @@ public class VersionCheckClient {
   {
   	if ( v6 ){
 
-	    try {  check_mon.enter();
-	    
-	      long time_diff = SystemTime.getCurrentTime() - last_check_time_v6;
-	     
-	      force = force || time_diff > CACHE_PERIOD || time_diff < 0;
-	      
-	      if( last_check_data_v6 == null || last_check_data_v6.size() == 0 || force ) {
-	    	  // if we've never checked before then we go ahead even if the "only_if_cached"
-	    	  // flag is set as its had not chance of being cached yet!
-	    	if ( only_if_cached && last_check_data_v6 != null ){
-	    		return( new HashMap() );
-	    	}
-	        try {
-	          last_check_data_v6 = performVersionCheck( constructVersionCheckMessage( reason ), true, true, true );
-	          
-	          if ( last_check_data_v6 != null && last_check_data_v6.size() > 0 ){
-	       
-	        	  COConfigurationManager.setParameter( "versioncheck.cache.v6", last_check_data_v6 );
-	          }
-	        }
-	        catch(SocketException t) {
-	        	// internet is broken
-	        	// Debug.out(t.getClass().getName() + ": " + t.getMessage());
-	        }
-	        catch(UnknownHostException t) {
-	        	// dns is broken
-	        	// Debug.out(t.getClass().getName() + ": " + t.getMessage());
-	        }
-	        catch( Throwable t ) {
-	        	Debug.out(t);
-	          last_check_data_v6 = new HashMap();
-	        }
-	      }
-	      else {
-	      	Logger.log(new LogEvent(LOGID, "VersionCheckClient is using "
-							+ "cached version check info. Using " + last_check_data_v6.size()
-							+ " reply keys.")); 
-	      }
-	    }
-	    finally {  check_mon.exit();  }
-	    
+  		if ( enable_v6 ){
+  			
+	 	    try {  check_mon.enter();
+		    
+		      long time_diff = SystemTime.getCurrentTime() - last_check_time_v6;
+		     
+		      force = force || time_diff > CACHE_PERIOD || time_diff < 0;
+		      
+		      if( last_check_data_v6 == null || last_check_data_v6.size() == 0 || force ) {
+		    	  // if we've never checked before then we go ahead even if the "only_if_cached"
+		    	  // flag is set as its had not chance of being cached yet!
+		    	if ( only_if_cached && last_check_data_v6 != null ){
+		    		return( new HashMap() );
+		    	}
+		        try {
+		          last_check_data_v6 = performVersionCheck( constructVersionCheckMessage( reason ), true, true, true );
+		          
+		          if ( last_check_data_v6 != null && last_check_data_v6.size() > 0 ){
+		       
+		        	  COConfigurationManager.setParameter( "versioncheck.cache.v6", last_check_data_v6 );
+		          }
+		        }
+		        catch(SocketException t) {
+		        	// internet is broken
+		        	// Debug.out(t.getClass().getName() + ": " + t.getMessage());
+		        }
+		        catch(UnknownHostException t) {
+		        	// dns is broken
+		        	// Debug.out(t.getClass().getName() + ": " + t.getMessage());
+		        }
+		        catch( Throwable t ) {
+		        	Debug.out(t);
+		          last_check_data_v6 = new HashMap();
+		        }
+		      }
+		      else {
+		      	Logger.log(new LogEvent(LOGID, "VersionCheckClient is using "
+								+ "cached version check info. Using " + last_check_data_v6.size()
+								+ " reply keys.")); 
+		      }
+		    }
+		    finally {  check_mon.exit();  }
+  		}
+  		
 	    if( last_check_data_v6 == null )  last_check_data_v6 = new HashMap();
 	    
 	    return last_check_data_v6;
@@ -317,6 +364,8 @@ public class VersionCheckClient {
 	    
 	    if( last_check_data_v4 == null )  last_check_data_v4 = new HashMap();
 	    
+	    last_feature_flag_cache_time = 0;
+	    
 	    return last_check_data_v4;
   	}
   }
@@ -532,23 +581,8 @@ public class VersionCheckClient {
 	Exception 	error 	= null;
 	Map			reply	= null;
 	
-	if ( use_az_message ){
 	
-		try{
-			reply = executeAZMessage( data_to_send, v6 );
-			
-			reply.put( "protocol_used", "AZMSG" );
-		}
-		catch (IOException e) {
-			error = e;
-		}
-		catch (Exception e) {
-			Debug.printStackTrace( e );
-			error = e;
-		}
-	}
-	
-	if ( reply == null && use_http ){
+	if ( use_http ){
 		
 		try{
 			reply = executeHTTP( data_to_send, v6 );
@@ -566,6 +600,22 @@ public class VersionCheckClient {
 			
 		}
 	}
+	
+	if ( reply == null && use_az_message ){
+		
+		try{
+			reply = executeAZMessage( data_to_send, v6 );
+			
+			reply.put( "protocol_used", "AZMSG" );
+		}
+		catch (IOException e) {
+			error = e;
+		}
+		catch (Exception e) {
+			Debug.printStackTrace( e );
+			error = e;
+		}
+	}
 	if ( error != null ){
 		
 		throw( error );
@@ -595,7 +645,12 @@ public class VersionCheckClient {
   
   	throws Exception
   {
-	  String	host = v6?AZ_MSG_SERVER_ADDRESS_V6:AZ_MSG_SERVER_ADDRESS_V4;
+	  if ( v6 && !enable_v6 ){
+		  
+		  throw( new Exception( "IPv6 is disabled" ));
+	  }
+
+	  String	host = getHost( v6, AZ_MSG_SERVER_ADDRESS_V6, AZ_MSG_SERVER_ADDRESS_V4 );
 	  
 	  if (Logger.isEnabled())
 		  Logger.log(new LogEvent(LOGID, "VersionCheckClient retrieving "
@@ -631,13 +686,18 @@ public class VersionCheckClient {
   
   	throws Exception
   {
-	  String	host = v6?HTTP_SERVER_ADDRESS_V6:HTTP_SERVER_ADDRESS_V4;
+	  if ( v6 && !enable_v6 ){
+		  
+		  throw( new Exception( "IPv6 is disabled" ));
+	  }
+	  
+	  String	host = getHost(v6, HTTP_SERVER_ADDRESS_V6, HTTP_SERVER_ADDRESS_V4 );
 
 	  if (Logger.isEnabled())
 		  Logger.log(new LogEvent(LOGID, "VersionCheckClient retrieving "
 				  + "version information from " + host + ":" + HTTP_SERVER_PORT + " via HTTP" )); 
 
-	  String	url_str = "http://" + host + (HTTP_SERVER_PORT==80?"":(":" + HTTP_SERVER_PORT)) + "/version?";
+	  String	url_str = "http://" + (v6?UrlUtils.convertIPV6Host(host):host) + (HTTP_SERVER_PORT==80?"":(":" + HTTP_SERVER_PORT)) + "/version?";
 
 	  url_str += URLEncoder.encode( new String( BEncoder.encode( data_to_send ), "ISO-8859-1" ), "ISO-8859-1" );
 	  
@@ -676,9 +736,9 @@ public class VersionCheckClient {
 	boolean	for_proxy,
 	boolean	v6 )
   {
-	  String	host = v6?HTTP_SERVER_ADDRESS_V6:HTTP_SERVER_ADDRESS_V4;
+	  String	host = getHost( v6, HTTP_SERVER_ADDRESS_V6, HTTP_SERVER_ADDRESS_V4 );
 
-	  String	get_str = "GET " + (for_proxy?("http://" + host + ":" + HTTP_SERVER_PORT ):"") +"/version?";
+	  String	get_str = "GET " + (for_proxy?("http://" + (v6?UrlUtils.convertIPV6Host( host ):host ) + ":" + HTTP_SERVER_PORT ):"") +"/version?";
 
 	  try{
 		  get_str += URLEncoder.encode( new String( BEncoder.encode( content ), "ISO-8859-1" ), "ISO-8859-1" );
@@ -700,7 +760,12 @@ public class VersionCheckClient {
   
   	throws Exception
   {
-	  String	host = v6?TCP_SERVER_ADDRESS_V6:TCP_SERVER_ADDRESS_V4;
+	  if ( v6 && !enable_v6 ){
+		  
+		  throw( new Exception( "IPv6 is disabled" ));
+	  }
+
+	  String	host = getHost(v6, TCP_SERVER_ADDRESS_V6, TCP_SERVER_ADDRESS_V4 );
 
 	  if (Logger.isEnabled())
 		  Logger.log(new LogEvent(LOGID, "VersionCheckClient retrieving "
@@ -838,7 +903,12 @@ public class VersionCheckClient {
   
   	throws Exception
   {
-	  String	host = v6?UDP_SERVER_ADDRESS_V6:UDP_SERVER_ADDRESS_V4;
+	  if ( v6 && !enable_v6 ){
+		  
+		  throw( new Exception( "IPv6 is disabled" ));
+	  }
+
+	  String	host = getHost( v6, UDP_SERVER_ADDRESS_V6, UDP_SERVER_ADDRESS_V4 );
 
 	  PRUDPReleasablePacketHandler handler = PRUDPPacketHandlerFactory.getReleasableHandler( bind_port );
 	  	  
@@ -1037,6 +1107,33 @@ public class VersionCheckClient {
 	  return( InetAddress.getByName( new String( address )));
   }
   
+  protected String
+  getHost(
+	boolean		v6,
+	String		v6_address,
+	String		v4_address )
+  {
+	 if ( v6 ){
+		 
+		 try{
+			 return( InetAddress.getByName( v6_address ).getHostAddress());
+			 
+		 }catch( UnknownHostException e ){
+			 
+			 try{
+				 return( DNSUtils.getIPV6ByName(v6_address ).getHostAddress());
+				 
+			 }catch( UnknownHostException f ){
+				 
+				 return( v6_address );
+			 }
+		 }
+	 }else{
+		 
+		 return( v4_address );
+	 }
+  }
+  
   /**
    * Construct the default version check message.
    * @return message to send
@@ -1092,8 +1189,16 @@ public class VersionCheckClient {
     String id = COConfigurationManager.getStringParameter( "ID", null );
 
     if( id != null && send_info ) {    	
-      message.put( "id", id );      
+      message.put( "id", id );    
+      
+      try{
+    	  byte[] id2 = CryptoManagerFactory.getSingleton().getSecureID();
     
+    	  message.put( "id2", id2 );
+    	  
+      }catch( Throwable e ){
+      }
+      
       if ( last_send_time != -1 && last_send_time < current_send_time ){    	  
     	  // time since last    	  
     	  message.put( "tsl", new Long(current_send_time-last_send_time));
@@ -1260,13 +1365,13 @@ public class VersionCheckClient {
 	  try{
 		  COConfigurationManager.initialise();
 		  
-		  boolean v6= false;
+		  boolean v6= true;
 		  
 		  // Test connectivity.
 		  if (true) {
-			//  System.out.println( "UDP:  " + getSingleton().getExternalIpAddressUDP(null,0,v6));
-			  System.out.println( "TCP:  " + getSingleton().getExternalIpAddressTCP(null,0,v6));
-			//  System.out.println( "HTTP: " + getSingleton().getExternalIpAddressHTTP(v6));
+			 // System.out.println( "UDP:  " + getSingleton().getExternalIpAddressUDP(null,0,v6));
+			 // System.out.println( "TCP:  " + getSingleton().getExternalIpAddressTCP(null,0,v6));
+			  System.out.println( "HTTP: " + getSingleton().getExternalIpAddressHTTP(v6));
 		  }
 		  
 		  Map data = constructVersionCheckMessage(VersionCheckClient.REASON_UPDATE_CHECK_START);
