@@ -36,6 +36,16 @@ VuzeFile
 		int		type,
 		Map		content );
 	
+	public byte[]
+	exportToBytes()
+	
+		throws IOException;
+	
+	public Map
+	exportToMap()
+	
+		throws IOException;
+	
 	public void
 	write(
 		File	target )
