@@ -24,6 +24,9 @@ package com.aelitis.azureus.plugins.dht;
 
 
 
+import java.net.Inet4Address;
+import java.net.Inet6Address;
+import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.util.*;
 
@@ -371,10 +374,10 @@ DHTPlugin
 											
 											for ( Map.Entry<Byte, Integer> entry: counts.entrySet()){
 											
-												ver += (ver.length()==0?"":", " ) + entry.getKey() + "=" + 100*entry.getValue()/total;
+												ver += (ver.length()==0?"":", " ) + entry.getKey() + "=" + 100*entry.getValue()/total + "%";
 											}
 											
-											log.log( "    " + ver );
+											log.log( "    contacts=" + total + ": " + ver );
 										}
 									}else if ( lc.equals( "testca" )){
 																
@@ -868,8 +871,8 @@ DHTPlugin
 												
 												if ( MAIN_DHT_V6_ENABLE ){
 													
-													if ( NetworkAdmin.getSingleton().hasIPV6Potential(false)){
-														
+													if ( NetworkAdmin.getSingleton().hasDHTIPV6()){
+															
 														main_v6_dht = 
 															new DHTPluginImpl(
 																plugin_interface,
@@ -1218,7 +1221,12 @@ DHTPlugin
 	getLocalValue(
 		byte[]		key )
 	{
-		return( main_dht.getLocalValue( key ));
+		if ( main_dht != null ){
+			
+			return( main_dht.getLocalValue( key ));
+		}
+		
+		return( cvs_dht.getLocalValue( key ));
 	}
 	
 	public void
@@ -1245,6 +1253,15 @@ DHTPlugin
 			
 		}else{
 			
+			if ( main_dht == null && main_v6_dht == null ){
+				
+					// just the cvs dht
+				
+				cvs_dht.get( original_key, description, flags, max_values, timeout, exhaustive, high_priority, original_listener );
+
+				return;
+			}
+			
 				// hook into CVS completion to prevent runaway CVS dht operations
 			
 			final int[]		completes_to_go = { 2 };
@@ -1688,6 +1705,32 @@ DHTPlugin
 		return( dhts[0].importContact( address ));
 	}
 	
+	public DHTPluginContact
+	importContact(
+		InetSocketAddress				address,
+		byte							version )
+	{
+		if ( !isEnabled()){
+			
+			throw( new RuntimeException( "DHT isn't enabled" ));
+		}
+
+		InetAddress contact_address = address.getAddress();
+		
+		for ( DHTPluginImpl dht: dhts ){
+			
+			InetAddress dht_address = dht.getLocalAddress().getAddress().getAddress();
+			
+			if ( 	( contact_address instanceof Inet4Address && dht_address instanceof Inet4Address ) ||
+					( contact_address instanceof Inet6Address && dht_address instanceof Inet6Address )){
+				
+				return( dht.importContact( address, version ));
+			}
+		}
+		
+		return( null );
+	}
+	
 	public DHTPluginContact
 	getLocalAddress()
 	{
