@@ -25,6 +25,7 @@ package com.aelitis.azureus.plugins.dht;
 import java.net.InetSocketAddress;
 import java.util.Map;
 
+
 /**
  * @author parg
  *
@@ -46,9 +47,21 @@ DHTPluginContact
 	isAlive(
 		long		timeout );
 	
+	public void
+	isAlive(
+		long						timeout,
+		DHTPluginOperationListener	listener );
+	
 	public boolean
 	isOrHasBeenLocal();
 	
 	public Map
 	openTunnel();
+	
+	public byte[]
+	read(
+		final DHTPluginProgressListener	listener,
+		final byte[]					handler_key,
+		final byte[]					key,
+		final long						timeout );
 }
