@@ -30,6 +30,10 @@ package com.aelitis.azureus.plugins.dht;
 public interface 
 DHTPluginOperationListener 
 {
+	public void
+	starts(
+		byte[]				key );
+	
 	public void
 	diversified();
 	
