@@ -165,8 +165,8 @@ DHTPluginImpl
 						_ip,
 						storage_manager.getMostRecentAddress(),
 						_port, 
-						4,
-						2,
+						3,
+						1,
 						10000, 	// udp timeout - tried less but a significant number of 
 								// premature timeouts occurred
 						send_delay, recv_delay, 
@@ -466,7 +466,7 @@ DHTPluginImpl
 				
 			log.log( "DHT " + (first?"":"re-") + "integration complete: elapsed = " + (end-start));
 			
-			dht.print();
+			dht.print( false );
 			
 		}finally{
 			
@@ -635,6 +635,10 @@ outer:
 	{
 		try{
 			return( InetAddress.getByName( v6?SEED_ADDRESS_V6:SEED_ADDRESS_V4 ));
+		}
+		catch (java.net.UnknownHostException e) {
+			Debug.out("Could not get DHT seed address: " + e);
+			return null;
 			
 		}catch( Throwable e ){
 				
@@ -652,44 +656,67 @@ outer:
 		return( dht.isDiversified( key ));
 	}
 
+	public void
+	put(
+		byte[]						key,
+		String						description,
+		byte[]						value,
+		byte						flags,
+		DHTPluginOperationListener	listener)
+	{		
+		put( key, description, value, flags, true, listener );
+	}
+	
 	public void
 	put(
 		final byte[]						key,
 		final String						description,
 		final byte[]						value,
 		final byte							flags,
+		final boolean						high_priority,
 		final DHTPluginOperationListener	listener)
 	{		
 		dht.put( 	key, 
 					description,
 					value,
 					flags,
+					high_priority,
 					new DHTOperationListener()
 					{
+						private boolean started;
+						
 						public void
 						searching(
 							DHTTransportContact	contact,
 							int					level,
 							int					active_searches )
 						{
-							String	indent = "";
-							
-							for (int i=0;i<level;i++){
+							if ( listener != null ){
 								
-								indent += "  ";
+								synchronized( this ){
+									
+									if ( started ){
+										
+										return;
+									}
+									
+									started = true;
+								}
+								
+								listener.starts( key );
 							}
-							
-							// log.log( indent + "Put: level = " + level + ", active = " + active_searches + ", contact = " + contact.getString());
 						}
 
 						public void
-						diversified()
+						diversified(
+							String		desc )
 						{
 						}
 						
 						public void
 						found(
-							DHTTransportContact	contact )
+							DHTTransportContact	contact,
+							boolean				is_closest )
 						{
 						}
 
@@ -757,26 +784,33 @@ outer:
 		dht.get( 	key, description, flags, max_values, timeout, exhaustive, high_priority, 
 					new DHTOperationListener()
 					{
+						private boolean	started = false;
+						
 						public void
 						searching(
 							DHTTransportContact	contact,
 							int					level,
 							int					active_searches )
 						{
-							/*
-							String	indent = "";
-							
-							for (int i=0;i<level;i++){
+							if ( listener != null ){
 								
-								indent += "  ";
+								synchronized( this ){
+									
+									if ( started ){
+										
+										return;
+									}
+									
+									started = true;
+								}
+								
+								listener.starts( key );
 							}
-							
-							log.log( indent + "Get: level = " + level + ", active = " + active_searches + ", contact = " + contact.getString());
-							*/
 						}
 						
 						public void
-						diversified()
+						diversified(
+							String		desc )
 						{
 							if ( listener != null ){
 								
@@ -786,7 +820,8 @@ outer:
 						
 						public void
 						found(
-							DHTTransportContact	contact )
+							DHTTransportContact	contact,
+							boolean				is_closest )
 						{
 						}
 
@@ -835,30 +870,40 @@ outer:
 						description,
 						new DHTOperationListener()
 						{
+							private boolean started;
+							
 							public void
 							searching(
 								DHTTransportContact	contact,
 								int					level,
 								int					active_searches )
 							{
-								String	indent = "";
-								
-								for (int i=0;i<level;i++){
+								if ( listener != null ){
 									
-									indent += "  ";
-								}
-								
-								// log.log( indent + "Remove: level = " + level + ", active = " + active_searches + ", contact = " + contact.getString());
+									synchronized( this ){
+										
+										if ( started ){
+											
+											return;
+										}
+										
+										started = true;
+									}
+									
+									listener.starts( key );
+								}							
 							}
-							
+		
 							public void
 							found(
-								DHTTransportContact	contact )
+								DHTTransportContact	contact,
+								boolean				is_closest )
 							{
 							}
 
 							public void
-							diversified()
+							diversified(
+								String		desc )
 							{
 							}
 							
@@ -915,30 +960,40 @@ outer:
 						description,
 						new DHTOperationListener()
 						{
+							private boolean started;
+							
 							public void
 							searching(
 								DHTTransportContact	contact,
 								int					level,
 								int					active_searches )
 							{
-								String	indent = "";
-								
-								for (int i=0;i<level;i++){
+								if ( listener != null ){
 									
-									indent += "  ";
+									synchronized( this ){
+										
+										if ( started ){
+											
+											return;
+										}
+										
+										started = true;
+									}
+									
+									listener.starts( key );
 								}
-								
-								// log.log( indent + "Remove: level = " + level + ", active = " + active_searches + ", contact = " + contact.getString());
 							}
 							
 							public void
 							found(
-								DHTTransportContact	contact )
+								DHTTransportContact	contact,
+								boolean				is_closest )
 							{
 							}
 
 							public void
-							diversified()
+							diversified(
+								String		desc )
 							{
 							}
 							
@@ -997,6 +1052,22 @@ outer:
 		}
 	}
 	
+	public DHTPluginContact
+	importContact(
+		InetSocketAddress				address,
+		byte							version )
+	{
+		try{
+			return( new DHTPluginContactImpl( this, transport.importContact( address, version )));
+			
+		}catch( DHTTransportException	e ){
+			
+			Debug.printStackTrace(e);
+			
+			return( null );
+		}
+	}
+	
 		// direct read/write support
 	
 	public void
