@@ -117,7 +117,11 @@ ExternalSeedPeer
 
 			manager	= _manager;
 			
-			if ( manager != null ){
+			if ( manager == null ){
+				
+				stats = null;
+				
+			}else{
 				
 				stats = manager.createPeerStats( this );
 			}
@@ -869,4 +873,11 @@ ExternalSeedPeer
 	public byte[] getHandshakeReservedBytes() {
 		return null;
 	}
+	
+	public boolean isPriorityConnection() {
+		return false;
+	}
+	
+	public void setPriorityConnection(boolean is_priority) {
+	}
 }
