@@ -62,6 +62,20 @@ ExternalSeedReaderFactoryGetRight
   				config.put( "url-list", obj );
   			}
   			
+ 			obj = torrent.getAdditionalProperty( "url-list-params" );
+  			
+  			if ( obj != null ){
+  				
+  				config.put( "url-list-params", obj );
+  			}
+  			
+			obj = torrent.getAdditionalProperty( "url-list-params2" );
+  			
+  			if ( obj != null ){
+  				
+  				config.put( "url-list-params2", obj );
+  			}
+  			
   			return( getSeedReaders( plugin, download, config ));
   			
   		}catch( Throwable e ){
@@ -96,12 +110,26 @@ ExternalSeedReaderFactoryGetRight
 
 				List	readers = new ArrayList();
 				
-				Object	_params = config.get( "url-list-params" );
+				Object	_global_params 		= config.get( "url-list-params" );
+				Object	_specific_params 	= config.get( "url-list-params2" );
 				
-				Map	params = _params instanceof Map?(Map)_params:new HashMap();
+				Map		global_params 		= _global_params instanceof Map?(Map)_global_params:new HashMap();
+				List	specific_params 	= _specific_params instanceof List?(List)_specific_params:new ArrayList();
 				
 				for (int i=0;i<urls.size();i++){
 					
+					Map my_params = global_params;
+					
+					if ( i < specific_params.size()){
+						
+						Object o = specific_params.get(i);
+						
+						if ( o instanceof Map ){
+							
+							my_params = (Map)o;
+						}
+					}
+					
 					try{	
 						String	url_str = new String((byte[])urls.get(i));
 						
@@ -115,7 +143,7 @@ ExternalSeedReaderFactoryGetRight
 																		
 						if ( protocol.equals( "http" )){
 							
-							readers.add( new ExternalSeedReaderGetRight(plugin, download.getTorrent(), url, params ));
+							readers.add( new ExternalSeedReaderGetRight(plugin, download.getTorrent(), url, my_params ));
 							
 						}else{
 							
@@ -154,15 +182,35 @@ ExternalSeedReaderFactoryGetRight
 			
 			Map	map = torrent.serialiseToMap();
 			
-			List	urls = new ArrayList();
-			
+			/*
+			List	urls = (List)map.get( "url-list" ); 
+				
+			if ( urls == null ){
+				
+				urls = new ArrayList();
+			}
+					
 			urls.add( "http://127.0.0.1:888/files/%DF%26%5B7w%C9%13I%88%8D%EC%E5b%2C9%0F%8D%0Co%BC/" );
 			
 			map.put( "url-list", urls);
+			*/
 			
+			/*
 			Map params = new HashMap();
 			
 			map.put( "url-list-params", params );
+			*/
+			
+			List params2 = new ArrayList();
+			
+			map.put( "url-list-params2", params2 );
+						
+			Map x_map = new HashMap();
+			
+			x_map.put( "max_speed", new Long(5*1024));
+			
+			params2.add( new Long(0));
+			params2.add( x_map );
 			
 			torrent = TOTorrentFactory.deserialiseFromMap( map );
 			
