@@ -26,17 +26,27 @@ import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.net.InetSocketAddress;
 import org.eclipse.swt.graphics.Image;
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+import org.gudy.azureus2.core3.torrent.TOTorrentFactory;
 import org.gudy.azureus2.core3.util.AEMonitor;
+import org.gudy.azureus2.core3.util.AERunnable;
 import org.gudy.azureus2.core3.util.AESemaphore;
 import org.gudy.azureus2.core3.util.AEThread2;
+import org.gudy.azureus2.core3.util.BEncoder;
 import org.gudy.azureus2.core3.util.Base32;
 import org.gudy.azureus2.core3.util.ByteFormatter;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.DelayedEvent;
 import org.gudy.azureus2.core3.util.SystemTime;
+import org.gudy.azureus2.core3.util.TorrentUtils;
+import org.gudy.azureus2.core3.util.UrlUtils;
 import org.gudy.azureus2.plugins.*;
 import org.gudy.azureus2.plugins.ddb.DistributedDatabase;
 import org.gudy.azureus2.plugins.ddb.DistributedDatabaseContact;
@@ -50,14 +60,22 @@ import org.gudy.azureus2.plugins.download.DownloadException;
 import org.gudy.azureus2.plugins.torrent.Torrent;
 import org.gudy.azureus2.plugins.ui.UIInstance;
 import org.gudy.azureus2.plugins.ui.UIManagerListener;
+import org.gudy.azureus2.plugins.ui.config.BooleanParameter;
+import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 import org.gudy.azureus2.plugins.ui.menus.MenuItem;
 import org.gudy.azureus2.plugins.ui.menus.MenuItemListener;
+import org.gudy.azureus2.plugins.ui.model.BasicPluginConfigModel;
 import org.gudy.azureus2.plugins.ui.tables.TableContextMenuItem;
 import org.gudy.azureus2.plugins.ui.tables.TableManager;
 import org.gudy.azureus2.plugins.ui.tables.TableRow;
+import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloader;
+import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloaderAdapter;
+import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloaderException;
+import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloaderFactory;
 import org.gudy.azureus2.ui.swt.plugins.UISWTInstance;
 
 import com.aelitis.azureus.core.util.CopyOnWriteList;
+import com.aelitis.azureus.core.util.FeatureAvailability;
 import com.aelitis.net.magneturi.*;
 
 /**
@@ -68,17 +86,28 @@ import com.aelitis.net.magneturi.*;
 public class 
 MagnetPlugin
 	implements Plugin
-{
+{	
+	private static final String	SECONDARY_LOOKUP 			= "http://magnet.vuze.com/";
+	private static final int	SECONDARY_LOOKUP_DELAY		= 20*1000;
+	private static final int	SECONDARY_LOOKUP_MAX_TIME	= 2*60*1000;
+	
+	private static final String	PLUGIN_NAME				= "Magnet URI Handler";
+	private static final String PLUGIN_CONFIGSECTION_ID = "plugins.magnetplugin";
+
 	private PluginInterface		plugin_interface;
 		
 	private CopyOnWriteList		listeners = new CopyOnWriteList();
 	
+	private boolean			first_download	= true;
+	
+	private BooleanParameter secondary_lookup;
+	
 	public static void
 	load(
 		PluginInterface		plugin_interface )
 	{
 		plugin_interface.getPluginProperties().setProperty( "plugin.version", 	"1.0" );
-		plugin_interface.getPluginProperties().setProperty( "plugin.name", 		"Magnet URI Handler" );
+		plugin_interface.getPluginProperties().setProperty( "plugin.name", PLUGIN_NAME );
 	}
 	
 	public void
@@ -87,6 +116,12 @@ MagnetPlugin
 	{
 		plugin_interface	= _plugin_interface;
 		
+		BasicPluginConfigModel	config = 
+			plugin_interface.getUIManager().createBasicPluginConfigModel( ConfigSection.SECTION_PLUGINS, 
+					PLUGIN_CONFIGSECTION_ID);
+		
+		secondary_lookup = config.addBooleanParameter2( "MagnetPlugin.use.lookup.service", "MagnetPlugin.use.lookup.service", true );
+		
 		MenuItemListener	listener = 
 			new MenuItemListener()
 			{
@@ -217,6 +252,7 @@ MagnetPlugin
 				download(
 					final MagnetURIHandlerProgressListener		muh_listener,
 					final byte[]								hash,
+					final String								args,
 					final InetSocketAddress[]					sources,
 					final long									timeout )
 				
@@ -264,8 +300,21 @@ MagnetPlugin
 								{
 									muh_listener.reportCompleteness( percent );
 								}
+								
+								public void
+								reportContributor(
+									InetSocketAddress	address )
+								{
+								}
+								
+								public boolean 
+								verbose() 
+								{
+									return( muh_listener.verbose());
+								}
 							},
 							hash,
+							args,
 							sources,
 							timeout ));
 				}
@@ -422,14 +471,20 @@ MagnetPlugin
 	download(
 		final MagnetPluginProgressListener		listener,
 		final byte[]							hash,
+		final String							args,
 		final InetSocketAddress[]				sources,
 		final long								timeout )
 	
 		throws MagnetURIHandlerException
 	{
 		try{
-			listener.reportActivity( getMessageText( "report.waiting_ddb" ));
-
+			if ( first_download ){
+			
+				listener.reportActivity( getMessageText( "report.waiting_ddb" ));
+				
+				first_download = false;
+			}
+			
 			final DistributedDatabase db = plugin_interface.getDistributedDatabase();
 			
 			final List			potential_contacts 		= new ArrayList();
@@ -437,61 +492,129 @@ MagnetPlugin
 			final AEMonitor		potential_contacts_mon	= new AEMonitor( "MagnetPlugin:liveones" );
 			
 			final int[]			outstanding		= {0};
-
+			final boolean[]		lookup_complete	= {false};
+			
 			listener.reportActivity(  getMessageText( "report.searching" ));
 			
 			DistributedDatabaseListener	ddb_listener = 
 				new DistributedDatabaseListener()
 				{
+					private Set	found_set = new HashSet();
+					
 					public void
 					event(
 						DistributedDatabaseEvent 		event )
 					{
 						int	type = event.getType();
 	
-						if ( type == DistributedDatabaseEvent.ET_VALUE_READ ){
+						if ( type == DistributedDatabaseEvent.ET_OPERATION_STARTS ){
+
+								// give live results a chance before kicking in explicit ones
+							
+							if ( sources.length > 0 ){
+								
+								new DelayedEvent(
+									"MP:sourceAdd",
+									10*1000,
+									new AERunnable()
+									{
+										public void
+										runSupport()
+										{
+											addExplicitSources();
+										}
+									});
+							}
+							
+						}else if ( type == DistributedDatabaseEvent.ET_VALUE_READ ){
 													
 							contactFound( event.getValue().getContact());
 			
 						}else if (	type == DistributedDatabaseEvent.ET_OPERATION_COMPLETE ||
 									type == DistributedDatabaseEvent.ET_OPERATION_TIMEOUT ){
 								
-								// now inject any explicit sources
+							listener.reportActivity( getMessageText( "report.found", String.valueOf( found_set.size())));
 							
-							for (int i=0;i<sources.length;i++){
+								// now inject any explicit sources
+
+							addExplicitSources();
+							
+							try{
+								potential_contacts_mon.enter();													
+
+								lookup_complete[0] = true;
 								
-								try{
-									contactFound( db.importContact(sources[i]));
-									
-								}catch( Throwable e ){
-									
-									Debug.printStackTrace(e);
-								}
+							}finally{
+								
+								potential_contacts_mon.exit();
 							}
 							
 							potential_contacts_sem.release();
 						}
 					}
 					
+					protected void
+					addExplicitSources()
+					{	
+						for (int i=0;i<sources.length;i++){
+							
+							try{
+								contactFound( db.importContact(sources[i]));
+								
+							}catch( Throwable e ){
+								
+								Debug.printStackTrace(e);
+							}
+						}
+					}
+					
 					public void
 					contactFound(
 						final DistributedDatabaseContact	contact )
 					{
-						listener.reportActivity( getMessageText( "report.found", contact.getName()));
-				
-						outstanding[0]++;
+						String	key = contact.getAddress().toString();
 						
-						AEThread2 t = 
-							new AEThread2( "MagnetPlugin:HitHandler", true )
+						synchronized( found_set ){
+							
+							if ( found_set.contains( key )){
+								
+								return;
+							}
+							
+							found_set.add( key );
+						}
+						
+						if ( listener.verbose()){
+						
+							listener.reportActivity( getMessageText( "report.found", contact.getName()));
+						}
+						
+						try{
+							potential_contacts_mon.enter();													
+
+							outstanding[0]++;
+							
+						}finally{
+							
+							potential_contacts_mon.exit();
+						}
+						
+						contact.isAlive(
+							20*1000,
+							new DistributedDatabaseListener()
 							{
-								public void
-								run()
+								public void 
+								event(
+									DistributedDatabaseEvent event) 
 								{
 									try{
-										boolean	alive = contact.isAlive(20*1000);
-																						
-										listener.reportActivity( 
+										boolean	alive = event.getType() == DistributedDatabaseEvent.ET_OPERATION_COMPLETE;
+											
+										if ( listener.verbose()){
+										
+											listener.reportActivity( 
 												getMessageText( alive?"report.alive":"report.dead",	contact.getName()));
+										}
 										
 										try{
 											potential_contacts_mon.enter();
@@ -522,8 +645,6 @@ MagnetPlugin
 												potential_contacts.add( entry );	// dead at end
 											}
 												
-											potential_contacts_sem.release();
-												
 										}finally{
 												
 											potential_contacts_mon.exit();
@@ -539,11 +660,11 @@ MagnetPlugin
 											
 											potential_contacts_mon.exit();
 										}
+										
+										potential_contacts_sem.release();
 									}
 								}
-							};
-													
-						t.start();
+							});
 					}
 				};
 				
@@ -555,13 +676,92 @@ MagnetPlugin
 			
 			long	remaining	= timeout;
 			
+			long 	overall_start 			= SystemTime.getMonotonousTime();
+			boolean	sl_enabled				= secondary_lookup.getValue() && FeatureAvailability.isMagnetSLEnabled();
+
+			long	secondary_lookup_time 	= -1;
+			
+			long last_found = -1;
+			
+			final Object[] secondary_result = { null };
+			
 			while( remaining > 0 ){
 					
-				long start = SystemTime.getCurrentTime();
+				try{
+					potential_contacts_mon.enter();
+
+					if ( 	lookup_complete[0] && 
+							potential_contacts.size() == 0 &&
+							outstanding[0] == 0 ){
+						
+						break;
+					}
+				}finally{
+					
+					potential_contacts_mon.exit();
+				}
+								
 				
-				potential_contacts_sem.reserve( remaining );
+				while( remaining > 0 ){
 				
-				remaining -= ( SystemTime.getCurrentTime() - start );
+					long wait_start = SystemTime.getMonotonousTime();
+
+					boolean got_sem = potential_contacts_sem.reserve( 1000 );
+		
+					long now = SystemTime.getMonotonousTime();
+					
+					remaining -= ( now - wait_start );
+				
+					if ( got_sem ){
+					
+						last_found = now;
+						
+						break;
+						
+					}else{
+						
+						if ( sl_enabled ){
+							
+							if ( secondary_lookup_time == -1 ){
+							
+								long	base_time;
+								
+								if ( last_found == -1 || now - overall_start > 60*1000 ){
+									
+									base_time = overall_start;
+									
+								}else{
+									
+									base_time = last_found;
+								}
+								
+								long	time_so_far = now - base_time;
+								
+								if ( time_so_far > SECONDARY_LOOKUP_DELAY ){
+									
+									secondary_lookup_time = SystemTime.getMonotonousTime();
+									
+									doSecondaryLookup( listener, secondary_result, hash, args );
+								}
+							}else{
+								
+								try{
+									byte[] torrent = getSecondaryLookupResult( secondary_result );
+									
+									if ( torrent != null ){
+										
+										return( torrent );
+									}
+								}catch( ResourceDownloaderException e ){
+									
+									// ignore, we just continue processing
+								}
+							}
+						}
+
+						continue;
+					}
+				}
 				
 				DistributedDatabaseContact	contact;
 				boolean						live_contact;
@@ -569,6 +769,8 @@ MagnetPlugin
 				try{
 					potential_contacts_mon.enter();
 					
+					// System.out.println( "rem=" + remaining + ",pot=" + potential_contacts.size() + ",out=" + outstanding[0] );
+					
 					if ( potential_contacts.size() == 0 ){
 						
 						if ( outstanding[0] == 0 ){
@@ -634,7 +836,27 @@ MagnetPlugin
 										
 					if ( value != null ){
 						
-						return( (byte[])value.getValue(byte[].class));
+							// let's verify the torrent
+						
+						byte[]	data = (byte[])value.getValue(byte[].class);
+
+						try{
+							TOTorrent torrent = TOTorrentFactory.deserialiseFromBEncodedByteArray( data );
+							
+							if ( Arrays.equals( hash, torrent.getHash())){
+							
+								listener.reportContributor( contact.getAddress());
+						
+								return( data );
+								
+							}else{
+								
+								listener.reportActivity( getMessageText( "report.error", "torrent invalid (hash mismatch)" ));
+							}
+						}catch( Throwable e ){
+							
+							listener.reportActivity( getMessageText( "report.error", "torrent invalid (decode failed)" ));
+						}
 					}
 				}catch( Throwable e ){
 					
@@ -644,6 +866,34 @@ MagnetPlugin
 				}
 			}
 		
+			if ( sl_enabled ){
+				
+				if ( secondary_lookup_time == -1 ){
+					
+					secondary_lookup_time = SystemTime.getMonotonousTime();
+					
+					doSecondaryLookup(listener, secondary_result, hash, args );
+				}
+				
+				while( SystemTime.getMonotonousTime() - secondary_lookup_time < SECONDARY_LOOKUP_MAX_TIME ){
+					
+					try{
+						byte[] torrent = getSecondaryLookupResult( secondary_result );
+						
+						if ( torrent != null ){
+							
+							return( torrent );
+						}
+						
+						Thread.sleep( 500 );
+						
+					}catch( ResourceDownloaderException e ){
+						
+						break;
+					}
+				}
+			}
+			
 			return( null );		// nothing found
 			
 		}catch( Throwable e ){
@@ -656,6 +906,98 @@ MagnetPlugin
 		}
 	}
 	
+	protected void
+	doSecondaryLookup(
+		final MagnetPluginProgressListener		listener,
+		final Object[]							result,
+		byte[]									hash,
+		String									args )
+	{
+		listener.reportActivity( getMessageText( "report.secondarylookup", null ));
+		
+		try{
+			ResourceDownloaderFactory rdf = plugin_interface.getUtilities().getResourceDownloaderFactory();
+		
+			URL sl_url = new URL( SECONDARY_LOOKUP + "magnetLookup?hash=" + Base32.encode( hash ) + (args.length()==0?"":("&args=" + UrlUtils.encode( args ))));
+			
+			ResourceDownloader rd = rdf.create( sl_url );
+			
+			rd.addListener(
+				new ResourceDownloaderAdapter()
+				{
+					public boolean
+					completed(
+						ResourceDownloader	downloader,
+						InputStream			data )
+					{
+						listener.reportActivity( getMessageText( "report.secondarylookup.ok", null ));
+
+						synchronized( result ){
+						
+							result[0] = data;
+						}
+						
+						return( true );
+					}
+					
+					public void
+					failed(
+						ResourceDownloader			downloader,
+						ResourceDownloaderException e )
+					{
+						synchronized( result ){
+							
+							result[0] = e;
+						}
+						
+						listener.reportActivity( getMessageText( "report.secondarylookup.fail" ));
+					}
+				});
+			
+			rd.asyncDownload();
+			
+		}catch( Throwable e ){
+			
+			listener.reportActivity( getMessageText( "report.secondarylookup.fail", Debug.getNestedExceptionMessage( e ) ));
+		}
+	}
+	
+	protected byte[]
+	getSecondaryLookupResult(
+		final Object[]	result )
+	
+		throws ResourceDownloaderException
+	{
+		Object x;
+		
+		synchronized( result ){
+			
+			x = result[0];
+			
+			result[0] = null;
+		}
+			
+		if ( x instanceof InputStream ){
+			
+			InputStream is = (InputStream)x;
+				
+			try{
+				TOTorrent t = TOTorrentFactory.deserialiseFromBEncodedInputStream( is );
+				
+				TorrentUtils.setPeerCacheValid( t );
+		
+				return( BEncoder.encode( t.serialiseToMap()));
+				
+			}catch( Throwable e ){							
+			}
+		}else if ( x instanceof ResourceDownloaderException ){
+			
+			throw((ResourceDownloaderException)x);
+		}
+		
+		return( null );
+	}
+	
 	protected String
 	getMessageText(
 		String	resource )
