@@ -25,6 +25,7 @@ import java.io.*;
 import java.net.*;
 import java.util.*;
 
+
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.download.DownloadManagerState;
@@ -567,18 +568,6 @@ BuddyPlugin
 				{
 					boolean enabled = enabled_param.getValue();
 
-					if (param != null && !enabled) {
-						UIInstance[] uis = plugin_interface.getUIManager().getUIInstances();
-						if (uis != null && uis.length > 0) {
-							int i = promptUserOnDisable(uis[0]);
-  						if (i != 0) {
-    						enabled_param.setValue(true);
-    						fireEnabledStateChanged();
-  							return;
-  						}
-						}
-					}
-					
 					nick_name_param.setEnabled( enabled );
 					
 						// only toggle overall state on a real change
@@ -674,38 +663,11 @@ BuddyPlugin
 					public void parameterChanged(
 							String parameterName) 
 					{
-						boolean enabled = COConfigurationManager.getBooleanParameter(parameterName);
-						if (enabled) {
-							fireEnabledStateChanged();
-							return;
-						}
-
-						if (promptUserOnDisable(ui) != 0) {
-							plugin_interface.getPluginState().setDisabled(false);
-							plugin_interface.getPluginState().setLoadedAtStartup(true);
-						} else {
-							fireEnabledStateChanged();
-						}
+						fireEnabledStateChanged();
 					}
 				});
 	}
 	
-	protected int
-	promptUserOnDisable(UIInstance ui)
-	{
-		if ("az2".equals(COConfigurationManager.getStringParameter("ui", "az3"))) {
-			return 0;
-		}
-		LocaleUtilities localeUtil = plugin_interface.getUtilities().getLocaleUtilities();
-		return ui.promptUser(
-				localeUtil.getLocalisedMessageText("azbuddy.ui.dialog.disable.title"),
-				localeUtil.getLocalisedMessageText("azbuddy.ui.dialog.disable.text"),
-				new String[] {
-					localeUtil.getLocalisedMessageText("Button.yes"),
-					localeUtil.getLocalisedMessageText("Button.no"),
-				}, 1);
-	}
-
 	public void
 	showConfig()
 	{
@@ -2002,71 +1964,97 @@ BuddyPlugin
 			List	buddies_config = (List)map.get( "friends" );
 				
 			if ( buddies_config != null ){
-							
-				for (int i=0;i<buddies_config.size();i++){
 					
-					Object o = buddies_config.get(i);
-		
-					if ( o instanceof Map ){
-						
-						Map	details = (Map)o;
-						
-						String	key = new String((byte[])details.get( "pk" ));
-						
-						List	recent_ygm = (List)details.get( "ygm" );
-											
-						String	nick = decodeString((byte[])details.get( "n" ));
-						
-						Long	l_seq = (Long)details.get( "ls" );
-						
-						int	last_seq = l_seq==null?0:l_seq.intValue();
-						
-						Long	l_lo = (Long)details.get( "lo" );
-						
-						long	last_time_online = l_lo==null?0:l_lo.longValue();
+				if ( buddies_config.size() == 0 ){
 					
-						if ( last_time_online > now ){
+					deleteConfig();
+					
+				}else{
+					for (int i=0;i<buddies_config.size();i++){
+						
+						Object o = buddies_config.get(i);
+			
+						if ( o instanceof Map ){
 							
-							last_time_online = now;
-						}
-						
-						Long l_subsystem = (Long)details.get( "ss" );
-						
-						int	subsystem = l_subsystem==null?SUBSYSTEM_AZ2:l_subsystem.intValue();
-						
-						Long l_ver = (Long)details.get("v");
-						
-						int	ver = l_ver==null?VERSION_INITIAL:l_ver.intValue();
-													
-						String	loc_cat = decodeString((byte[])details.get( "lc" ));
-						String	rem_cat = decodeString((byte[])details.get( "rc" ));
-						
-						BuddyPluginBuddy buddy = new BuddyPluginBuddy( this, subsystem, true, key, nick, ver, loc_cat, rem_cat, last_seq, last_time_online, recent_ygm );
-						
-						byte[]	ip_bytes = (byte[])details.get( "ip" );
-						
-						if ( ip_bytes != null ){
+							Map	details = (Map)o;
 							
-							try{
-								InetAddress ip = InetAddress.getByAddress( ip_bytes );
+							Long	l_ct = (Long)details.get( "ct" );
+							
+							long	created_time = l_ct==null?now:l_ct.longValue();
+							
+							if ( created_time > now ){
 								
-								int	tcp_port = ((Long)details.get( "tcp" )).intValue();
-								int	udp_port = ((Long)details.get( "udp" )).intValue();
-								
-								buddy.setCachedStatus( ip, tcp_port, udp_port );
-								
-							}catch( Throwable e ){
+								created_time = now;
 							}
+							
+							String	key = new String((byte[])details.get( "pk" ));
+							
+							List	recent_ygm = (List)details.get( "ygm" );
+												
+							String	nick = decodeString((byte[])details.get( "n" ));
+							
+							Long	l_seq = (Long)details.get( "ls" );
+							
+							int	last_seq = l_seq==null?0:l_seq.intValue();
+							
+							Long	l_lo = (Long)details.get( "lo" );
+							
+							long	last_time_online = l_lo==null?0:l_lo.longValue();
+						
+							if ( last_time_online > now ){
+								
+								last_time_online = now;
+							}
+							
+							Long l_subsystem = (Long)details.get( "ss" );
+							
+							int	subsystem = l_subsystem==null?SUBSYSTEM_AZ2:l_subsystem.intValue();
+							
+							if (subsystem == SUBSYSTEM_AZ3) {
+								continue;
+							}
+							
+							Long l_ver = (Long)details.get("v");
+							
+							int	ver = l_ver==null?VERSION_INITIAL:l_ver.intValue();
+														
+							String	loc_cat = decodeString((byte[])details.get( "lc" ));
+							String	rem_cat = decodeString((byte[])details.get( "rc" ));
+							
+							BuddyPluginBuddy buddy = new BuddyPluginBuddy( this, created_time, subsystem, true, key, nick, ver, loc_cat, rem_cat, last_seq, last_time_online, recent_ygm );
+							
+							byte[]	ip_bytes = (byte[])details.get( "ip" );
+							
+							if ( ip_bytes != null ){
+								
+								try{
+									InetAddress ip = InetAddress.getByAddress( ip_bytes );
+									
+									int	tcp_port = ((Long)details.get( "tcp" )).intValue();
+									int	udp_port = ((Long)details.get( "udp" )).intValue();
+									
+									buddy.setCachedStatus( ip, tcp_port, udp_port );
+									
+								}catch( Throwable e ){
+								}
+							}
+							
+							logMessage( "Loaded buddy " + buddy.getString());
+							
+							buddies.add( buddy );
+							
+							buddies_map.put( key, buddy );
 						}
-						
-						logMessage( "Loaded buddy " + buddy.getString());
-						
-						buddies.add( buddy );
-						
-						buddies_map.put( key, buddy );
 					}
 				}
 			}
+			
+			int	num_buddies = buddies.size();
+			
+			for ( BuddyPluginBuddy b: buddies ){
+				
+				b.setInitialStatus( now, num_buddies );
+			}
 		}
 	}
 	
@@ -2115,6 +2103,8 @@ BuddyPlugin
 					
 					Map	map = new HashMap();
 				
+					map.put( "ct", new Long( buddy.getCreatedTime()));
+					
 					map.put( "pk", buddy.getPublicKey());
 				
 					List	ygm = buddy.getYGMMarkers();
@@ -2170,9 +2160,16 @@ BuddyPlugin
 				
 				Map	map = new HashMap();
 				
-				map.put( "friends", buddies_config );
+				if ( buddies_config.size() > 0 ){
 				
-				writeConfig( map );
+					map.put( "friends", buddies_config );
+				
+					writeConfig( map );
+					
+				}else{
+					
+					deleteConfig();
+				}
 				
 				config_dirty = false;
 			}
@@ -2240,7 +2237,7 @@ BuddyPlugin
 			if ( buddy_to_return == null ){
 				
 				buddy_to_return = 
-					new BuddyPluginBuddy( this, subsystem, authorised, key, null, VERSION_CURRENT, null, null, 0, 0, null );
+					new BuddyPluginBuddy( this, SystemTime.getCurrentTime(), subsystem, authorised, key, null, VERSION_CURRENT, null, null, 0, 0, null );
 				
 				buddies.add( buddy_to_return );
 				
@@ -2305,11 +2302,25 @@ BuddyPlugin
 		writeConfigFile( config_file, map );
 	}
 	
+	protected void
+	deleteConfig()
+	{
+		File	config_file = new File( plugin_interface.getUtilities().getAzureusUserDir(), "friends.config" );
+		
+		Utilities utils = plugin_interface.getUtilities();
+			
+		plugin_interface.getUtilities().deleteResilientBEncodedFile(
+				config_file.getParentFile(), config_file.getName(), true );
+
+	}
+	
 	protected Map
 	readConfigFile(
 		File		name )
 	{
-		Map map = plugin_interface.getUtilities().readResilientBEncodedFile(
+		Utilities utils = plugin_interface.getUtilities();
+		
+		Map map = utils.readResilientBEncodedFile(
 						name.getParentFile(), name.getName(), true );
 		
 		if ( map == null ){
@@ -2325,8 +2336,10 @@ BuddyPlugin
 		File		name,
 		Map			data )
 	{
+		Utilities utils = plugin_interface.getUtilities();
+			
 		plugin_interface.getUtilities().writeResilientBEncodedFile(
-				name.getParentFile(), name.getName(), data, true );
+			name.getParentFile(), name.getName(), data, true );
 		
 		return( name.exists());
 	}
@@ -2452,7 +2465,9 @@ BuddyPlugin
 			
 			period += random.nextInt( 2*60*1000 );
 			
-			if ( last_check > now || now - last_check > period ){
+				// last check may be in the future as we defer checks for seemingly inactive buddies
+			
+			if ( now - last_check > period ){
 				
 				if ( !buddy.statusCheckActive()){
 			
@@ -3694,11 +3709,7 @@ BuddyPlugin
 								reportActivity(
 									String	str )
 								{
-									if ( 	str.indexOf( " found " ) == -1 &&
-											str.indexOf( " is dead " ) == -1 ){
-						
-										log( "    MagnetDownload: " + str );
-									}
+									log( "    MagnetDownload: " + str );
 								}
 								
 								public void
@@ -3712,8 +3723,15 @@ BuddyPlugin
 									InetSocketAddress	address )
 								{
 								}
+								
+								public boolean 
+								verbose() 
+								{
+									return( false );
+								}
 							},
 							hash,
+							"",
 							new InetSocketAddress[0],
 							timeout );
 						
