@@ -27,6 +27,7 @@ import java.util.*;
 import org.gudy.azureus2.core3.util.AEThread2;
 import org.gudy.azureus2.core3.util.Base32;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.RandomUtils;
 import org.gudy.azureus2.plugins.PluginInterface;
 import org.gudy.azureus2.plugins.torrent.Torrent;
 import org.gudy.azureus2.plugins.ui.UIManagerEvent;
@@ -48,7 +49,9 @@ BuddyPluginAZ2
 	public static final int RT_AZ2_REQUEST_TRACK		= 7;
 	public static final int RT_AZ2_REPLY_TRACK			= 8;
 
-	
+	public static final int RT_AZ2_REQUEST_RSS			= 9;
+	public static final int RT_AZ2_REPLY_RSS			= 10;
+
 	public static final int CHAT_MSG_TYPE_TEXT						= 1;
 	public static final int CHAT_MSG_TYPE_PARTICIPANTS_ADDED		= 2;
 	public static final int CHAT_MSG_TYPE_PARTICIPANTS_REMOVED		= 3;
@@ -234,6 +237,42 @@ BuddyPluginAZ2
 			
 				throw( new BuddyPluginException( "Unhandled request type " + type ));
 			}
+		}else if (  type == RT_AZ2_REQUEST_RSS ){
+				
+			try{
+				Map<String,Object> res = new HashMap<String, Object>();
+
+				reply.put( "msg", res );
+				reply.put( "type", new Long( RT_AZ2_REPLY_RSS ));
+
+				Map msg = (Map)request.get( "msg" );
+
+				String category = new String((byte[])msg.get( "cat"), "UTF-8" );
+				
+				byte[] hash	= (byte[])msg.get( "hash" );
+				
+				if ( hash == null ){
+					
+					byte[]	if_mod 	= (byte[])msg.get( "if_mod" );
+					
+					BuddyPlugin.feedDetails feed = plugin.getRSS( from_buddy, category, if_mod==null?null:new String( if_mod, "UTF-8" ));
+					
+					res.put( "rss", feed.getContent());
+					
+					res.put( "last_mod", feed.getLastModified());
+					
+				}else{
+					
+					res.put( "torrent", plugin.getRSSTorrent( from_buddy, category, hash ));
+				}
+			}catch( BuddyPluginException e  ){
+				
+				throw( e );
+				
+			}catch( Throwable e ){
+				
+				throw( new BuddyPluginException( "Failed to handle rss", e ));
+			}
 		}else{
 			
 			throw( new BuddyPluginException( "Unrecognised request type " + type ));
@@ -250,7 +289,7 @@ BuddyPluginAZ2
 	{
 		byte[]	id_bytes = new byte[20];
 		
-		new SecureRandom().nextBytes( id_bytes );
+		RandomUtils.SECURE_RANDOM.nextBytes( id_bytes );
 		
 		String	id = Base32.encode( id_bytes );
 		
@@ -418,6 +457,56 @@ BuddyPluginAZ2
 		}
 	}
 	
+	public void
+	sendAZ2RSSMessage(
+		BuddyPluginBuddy						buddy,
+		Map										msg,
+		final BuddyPluginAZ2TrackerListener		listener )
+	{
+		logMessage( "AZ2 request sent: " + buddy.getString() + " <- " + msg );
+
+		try{
+			Map	request = new HashMap();
+			
+			request.put( "type", new Long( RT_AZ2_REQUEST_RSS ));
+			request.put( "msg", msg );
+			
+			buddy.sendMessage(
+				BuddyPlugin.SUBSYSTEM_AZ2,
+				request,
+				SEND_TIMEOUT,
+				new BuddyPluginBuddyReplyListener()
+				{
+					public void
+					replyReceived(
+						BuddyPluginBuddy		from_buddy,
+						Map						reply )
+					{
+						int type = ((Long)reply.get( "type")).intValue();
+						
+						if ( type != RT_AZ2_REPLY_RSS ){
+							
+							sendFailed( from_buddy, new BuddyPluginException( "Mismatched reply type" ));
+						}
+						
+						listener.messageReceived( from_buddy, (Map)reply.get( "msg" ));
+					}
+					
+					public void
+					sendFailed(
+						BuddyPluginBuddy		to_buddy,
+						BuddyPluginException	cause )
+					{
+						listener.messageFailed( to_buddy, cause );
+					}
+				});
+				
+		}catch( Throwable e ){
+			
+			logMessage( "Send message failed", e );
+		}
+	}
+	
 	protected void
 	sendMessage(
 		BuddyPluginBuddy	buddy,
