@@ -24,6 +24,7 @@ package com.aelitis.azureus.plugins.net.buddy.swt;
 import java.net.InetAddress;
 import java.text.SimpleDateFormat;
 import java.util.*;
+import java.util.List;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyleRange;
@@ -31,45 +32,17 @@ import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.dnd.Clipboard;
 import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.dnd.Transfer;
-import org.eclipse.swt.events.KeyEvent;
-import org.eclipse.swt.events.KeyListener;
-import org.eclipse.swt.events.MenuEvent;
-import org.eclipse.swt.events.MenuListener;
-import org.eclipse.swt.events.ModifyEvent;
-import org.eclipse.swt.events.ModifyListener;
-import org.eclipse.swt.events.MouseAdapter;
-import org.eclipse.swt.events.MouseEvent;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.*;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
-import org.eclipse.swt.layout.FillLayout;
-import org.eclipse.swt.layout.FormAttachment;
-import org.eclipse.swt.layout.FormData;
-import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.layout.GridData;
-import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.widgets.Button;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Event;
-import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Listener;
-import org.eclipse.swt.widgets.Menu;
-import org.eclipse.swt.widgets.MenuItem;
-import org.eclipse.swt.widgets.Sash;
-import org.eclipse.swt.widgets.Shell;
-import org.eclipse.swt.widgets.Table;
-import org.eclipse.swt.widgets.TableColumn;
-import org.eclipse.swt.widgets.TableItem;
-import org.eclipse.swt.widgets.Text;
-import org.gudy.azureus2.core3.util.Base32;
-import org.gudy.azureus2.core3.util.Constants;
-import org.gudy.azureus2.core3.util.Debug;
-import org.gudy.azureus2.core3.util.DisplayFormatters;
-import org.gudy.azureus2.core3.util.SHA1Simple;
+import org.eclipse.swt.layout.*;
+import org.eclipse.swt.widgets.*;
+
+import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.plugins.PluginConfig;
 import org.gudy.azureus2.plugins.ui.UIInputReceiver;
+import org.gudy.azureus2.plugins.ui.UIInputReceiverListener;
 import org.gudy.azureus2.plugins.ui.UIInstance;
 import org.gudy.azureus2.plugins.utils.LocaleUtilities;
 import org.gudy.azureus2.ui.swt.Messages;
@@ -77,17 +50,9 @@ import org.gudy.azureus2.ui.swt.mainwindow.Colors;
 import org.gudy.azureus2.ui.swt.mainwindow.Cursors;
 import org.gudy.azureus2.ui.swt.mainwindow.SWTThread;
 
-import com.aelitis.azureus.core.security.CryptoHandler;
-import com.aelitis.azureus.core.security.CryptoManager;
-import com.aelitis.azureus.core.security.CryptoManagerFactory;
-import com.aelitis.azureus.core.security.CryptoManagerKeyListener;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPlugin;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginBuddy;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginBuddyMessage;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginBuddyMessageListener;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginBuddyRequestListener;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginException;
-import com.aelitis.azureus.plugins.net.buddy.BuddyPluginListener;
+import com.aelitis.azureus.core.security.*;
+import com.aelitis.azureus.core.util.AZ3Functions;
+import com.aelitis.azureus.plugins.net.buddy.*;
 
 public class 
 BuddyPluginViewInstance 
@@ -429,6 +394,9 @@ BuddyPluginViewInstance
 				"azbuddy.ui.table.lastseen", 
 				"azbuddy.ui.table.last_ygm", 
 				"azbuddy.ui.table.last_msg",
+				"azbuddy.ui.table.loc_cat",
+				"azbuddy.ui.table.rem_cat",
+				"azbuddy.ui.table.read_cat",
 				"azbuddy.ui.table.con",
 				"azbuddy.ui.table.msg_in",
 				"azbuddy.ui.table.msg_out",
@@ -437,9 +405,9 @@ BuddyPluginViewInstance
 				"MyTrackerView.bytesout",
 				"azbuddy.ui.table.ss" };
 
-		int[] sizes = { 250, 100, 100, 100, 200, 75, 75, 75, 75, 75, 75, 40 };
+		int[] sizes = { 250, 100, 100, 100, 200, 100, 100, 100, 75, 75, 75, 75, 75, 75, 40 };
 
-		int[] aligns = { SWT.LEFT, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.LEFT, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER };
+		int[] aligns = { SWT.LEFT, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.LEFT, SWT.LEFT, SWT.LEFT, SWT.LEFT, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER, SWT.CENTER };
 
 		for (int i = 0; i < headers.length; i++){
 
@@ -458,13 +426,16 @@ BuddyPluginViewInstance
 	    columns[2].setData(new Integer(FilterComparator.FIELD_LAST_SEEN));
 	    columns[3].setData(new Integer(FilterComparator.FIELD_YGM));
 	    columns[4].setData(new Integer(FilterComparator.FIELD_LAST_MSG));
-	    columns[5].setData(new Integer(FilterComparator.FIELD_CON));
-	    columns[6].setData(new Integer(FilterComparator.FIELD_MSG_IN));
-	    columns[7].setData(new Integer(FilterComparator.FIELD_MSG_OUT));
-	    columns[8].setData(new Integer(FilterComparator.FIELD_QUEUED));
-	    columns[9].setData(new Integer(FilterComparator.FIELD_BYTES_IN));
-	    columns[10].setData(new Integer(FilterComparator.FIELD_BYTES_OUT));
-	    columns[11].setData(new Integer(FilterComparator.FIELD_SS));
+	    columns[5].setData(new Integer(FilterComparator.FIELD_LOC_CAT));
+	    columns[6].setData(new Integer(FilterComparator.FIELD_REM_CAT));
+	    columns[7].setData(new Integer(FilterComparator.FIELD_READ_CAT));
+	    columns[8].setData(new Integer(FilterComparator.FIELD_CON));
+	    columns[9].setData(new Integer(FilterComparator.FIELD_MSG_IN));
+	    columns[10].setData(new Integer(FilterComparator.FIELD_MSG_OUT));
+	    columns[11].setData(new Integer(FilterComparator.FIELD_QUEUED));
+	    columns[12].setData(new Integer(FilterComparator.FIELD_BYTES_IN));
+	    columns[13].setData(new Integer(FilterComparator.FIELD_BYTES_OUT));
+	    columns[14].setData(new Integer(FilterComparator.FIELD_SS));
 	    
 	    
 	    final FilterComparator comparator = new FilterComparator();
@@ -551,17 +522,35 @@ BuddyPluginViewInstance
 					
 					item.setText(4, lm==null?"":lm);
 					
-					item.setText(5, "" + buddy.getConnectionsString());
+					String loc_cat = buddy.getLocalAuthorisedRSSCategoriesAsString();
+					if ( loc_cat == null ){
+						loc_cat = "";
+					}
+					item.setText(5, "" + loc_cat);
+
+					String rem_cat = buddy.getRemoteAuthorisedRSSCategoriesAsString();
+					if ( rem_cat == null ){
+						rem_cat = "";
+					}
+					item.setText(6, "" + rem_cat);
+
+					String read_cat = buddy.getLocalReadCategoriesAsString();
+					if ( read_cat == null ){
+						read_cat = "";
+					}
+					item.setText(7, "" + read_cat);
+
+					item.setText(8, "" + buddy.getConnectionsString());
 					
 					String in_frag = buddy.getMessageInFragmentDetails();
 					
-					item.setText(6, "" + buddy.getMessageInCount() + (in_frag.length()==0?"":("+" + in_frag )));
-					item.setText(7, "" + buddy.getMessageOutCount());
-					item.setText(8, "" + buddy.getMessageHandler().getMessageCount());
-					item.setText(9, "" + DisplayFormatters.formatByteCountToKiBEtc(buddy.getBytesInCount()));
-					item.setText(10, "" + DisplayFormatters.formatByteCountToKiBEtc(buddy.getBytesOutCount()));
+					item.setText(9, "" + buddy.getMessageInCount() + (in_frag.length()==0?"":("+" + in_frag )));
+					item.setText(10, "" + buddy.getMessageOutCount());
+					item.setText(11, "" + buddy.getMessageHandler().getMessageCount());
+					item.setText(12, "" + DisplayFormatters.formatByteCountToKiBEtc(buddy.getBytesInCount()));
+					item.setText(13, "" + DisplayFormatters.formatByteCountToKiBEtc(buddy.getBytesOutCount()));
 
-					item.setText(11, "" + buddy.getSubsystem() + " v" + buddy.getVersion());
+					item.setText(14, "" + buddy.getSubsystem() + " v" + buddy.getVersion());
 					
 					item.setData( buddy );
 				}
@@ -813,7 +802,7 @@ BuddyPluginViewInstance
 				widgetSelected(
 					SelectionEvent event ) 
 				{
-					TableItem[] selection = buddy_table.getSelection();
+					final TableItem[] selection = buddy_table.getSelection();
 					
 					UIInputReceiver prompter = ui_instance.getInputReceiver();
 					
@@ -821,19 +810,22 @@ BuddyPluginViewInstance
 					prompter.setLocalisedMessage( lu.getLocalisedMessageText( "azbuddy.ui.menu.send_msg" ) );
 					
 					try{
-						prompter.prompt();
-						
-						String text = prompter.getSubmittedInput();
-						
-						if ( text != null ){
-						
-							for (int i=0;i<selection.length;i++){
+						prompter.prompt(new UIInputReceiverListener() {
+							public void UIInputReceiverClosed(UIInputReceiver prompter) {
+								String text = prompter.getSubmittedInput();
 								
-								BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[i].getData();
-								
-								plugin.getAZ2Handler().sendAZ2Message( buddy, text );
+								if ( text != null ){
+									
+									for (int i=0;i<selection.length;i++){
+										
+										BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[i].getData();
+										
+										plugin.getAZ2Handler().sendAZ2Message( buddy, text );
+									}
+								}
 							}
-						}
+						});
+						
 					}catch( Throwable e ){
 						
 					}
@@ -1205,6 +1197,144 @@ BuddyPluginViewInstance
 			});
 				
 		
+			// cats
+		
+		Menu cat_menu = new Menu(menu.getShell(), SWT.DROP_DOWN);
+		MenuItem cat_item = new MenuItem(menu, SWT.CASCADE);
+		Messages.setLanguageText(cat_item, "azbuddy.ui.menu.cat" );
+		cat_item.setMenu(cat_menu);
+
+			// cats - share
+		
+		final MenuItem cat_share_item = new MenuItem(cat_menu, SWT.PUSH);
+
+		cat_share_item.setText( lu.getLocalisedMessageText( "azbuddy.ui.menu.cat.share" ) );
+
+		cat_share_item.addSelectionListener(
+			new SelectionAdapter() 
+			{
+				public void 
+				widgetSelected(
+					SelectionEvent event ) 
+				{
+					UIInputReceiver prompter = ui_instance.getInputReceiver();
+					
+					prompter.setLocalisedTitle( lu.getLocalisedMessageText( "azbuddy.ui.menu.cat.set" ));
+					prompter.setLocalisedMessage( lu.getLocalisedMessageText( "azbuddy.ui.menu.cat.set_msg" ));
+					
+					prompter.prompt(new UIInputReceiverListener() {
+						public void UIInputReceiverClosed(UIInputReceiver prompter) {
+							String cats = prompter.getSubmittedInput();
+							
+							if ( cats != null ){
+								
+								cats = cats.trim();
+								
+								if ( cats.equalsIgnoreCase( "None" )){
+									
+									cats = "";
+								}
+								
+								TableItem[] selection = buddy_table.getSelection();
+								
+								for (int i=0;i<selection.length;i++){
+									
+									BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[i].getData();
+									
+									buddy.setLocalAuthorisedRSSCategories( cats );
+								}
+							}
+						}
+					});
+					
+				};
+			});
+		
+			// cats - subscribe
+		
+		final Menu cat_subs_menu = new Menu(cat_menu.getShell(), SWT.DROP_DOWN);
+		final MenuItem cat_subs_item = new MenuItem(cat_menu, SWT.CASCADE);
+		Messages.setLanguageText(cat_subs_item, "azbuddy.ui.menu.cat_subs" );
+		cat_subs_item.setMenu(cat_subs_menu);
+
+		cat_subs_menu.addMenuListener(
+			new MenuListener()
+			{
+				public void 
+				menuShown(
+					MenuEvent arg0 ) 
+				{
+					MenuItem[] items = cat_subs_menu.getItems();
+					
+					for (int i = 0; i < items.length; i++){
+						
+						items[i].dispose();
+					}
+					
+					final AZ3Functions.provider az3 = AZ3Functions.getProvider();
+					
+					if ( az3 != null ){
+						
+						final TableItem[] selection = buddy_table.getSelection();
+						
+						Set<String> avail_cats = new TreeSet<String>();
+						
+						for (int i=0;i<selection.length;i++){
+							
+							BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[i].getData();
+							
+							Set<String> cats = buddy.getRemoteAuthorisedRSSCategories();
+							
+							if ( cats != null ){
+								
+								avail_cats.addAll( cats );
+							}
+						}
+						
+						for ( final String cat: avail_cats ){
+							
+							final MenuItem subs_item = new MenuItem( cat_subs_menu, SWT.PUSH );
+	
+							subs_item.setText( cat );
+	
+							subs_item.addSelectionListener(
+								new SelectionAdapter() 
+								{
+									public void 
+									widgetSelected(
+										SelectionEvent event ) 
+									{
+										for (int i=0;i<selection.length;i++){
+											
+											BuddyPluginBuddy buddy = (BuddyPluginBuddy)selection[i].getData();
+
+											if ( buddy.isRemoteRSSCategoryAuthorised( cat )){
+												
+												try{
+													buddy.subscribeToCategory( cat );
+													
+												}catch( Throwable e ){
+													
+													print( "Failed", e );
+												}
+											}
+										}
+									}
+								});
+						}
+					}
+				}
+				
+				public void 
+				menuHidden(
+					MenuEvent arg0 ) 
+				{
+				}
+			});
+		
+		
+			// done with menus
+		
 		buddy_table.setMenu( menu );
 			
 		menu.addMenuListener(
@@ -1603,13 +1733,16 @@ BuddyPluginViewInstance
 		static final int FIELD_LAST_SEEN 	= 2;
 		static final int FIELD_YGM		 	= 3;
 		static final int FIELD_LAST_MSG 	= 4;
-		static final int FIELD_CON		 	= 5;
-		static final int FIELD_MSG_IN	 	= 6;
-		static final int FIELD_MSG_OUT	 	= 7;
-		static final int FIELD_QUEUED	 	= 8;
-		static final int FIELD_BYTES_IN 	= 9;
-		static final int FIELD_BYTES_OUT 	= 10;
-		static final int FIELD_SS		 	= 11;
+		static final int FIELD_LOC_CAT	 	= 5;
+		static final int FIELD_REM_CAT 		= 6;
+		static final int FIELD_READ_CAT 	= 7;
+		static final int FIELD_CON		 	= 8;
+		static final int FIELD_MSG_IN	 	= 9;
+		static final int FIELD_MSG_OUT	 	= 10;
+		static final int FIELD_QUEUED	 	= 11;
+		static final int FIELD_BYTES_IN 	= 12;
+		static final int FIELD_BYTES_OUT 	= 13;
+		static final int FIELD_SS		 	= 14;
 
 		int field = FIELD_NAME;
 
@@ -1625,55 +1758,55 @@ BuddyPluginViewInstance
 			
 			if(field == FIELD_NAME){				
 				 res = b1.getName().compareTo( b2.getName());
-			}
-			
-			if(field == FIELD_ONLINE){
+			}else if(field == FIELD_ONLINE){
 				res = ( b1.isOnline( false )?1:0 ) - ( b2.isOnline( false )?1:0 );
-			}
-			
-			if(field == FIELD_LAST_SEEN){
+			}else if(field == FIELD_LAST_SEEN){
 				res = sortInt( b1.getLastTimeOnline() - b2.getLastTimeOnline());
-			}
-			
-			if(field == FIELD_YGM){
+			}else if(field == FIELD_YGM){
 				res = sortInt( b1.getLastMessagePending() - b2.getLastMessagePending());
-			}
-			
-			if(field == FIELD_LAST_MSG){
+			}else if(field == FIELD_LAST_MSG){
 				res = b1.getLastMessageReceived().compareTo( b2.getLastMessageReceived());
-			}
-			
-			if(field == FIELD_CON){
+			}else if(field == FIELD_LOC_CAT){
+				res = compareStrings( b1.getLocalAuthorisedRSSCategoriesAsString(), b2.getLocalAuthorisedRSSCategoriesAsString());
+			}else if(field == FIELD_REM_CAT){
+				res = compareStrings( b1.getRemoteAuthorisedRSSCategoriesAsString(), b2.getRemoteAuthorisedRSSCategoriesAsString());
+			}else if(field == FIELD_READ_CAT){
+				res = compareStrings( b1.getLocalReadCategoriesAsString(), b2.getLocalReadCategoriesAsString());
+			}else if(field == FIELD_CON){
 				res = b1.getConnectionsString().compareTo( b2.getConnectionsString());
-			}
-			
-			if(field == FIELD_MSG_IN){
+			}else if(field == FIELD_MSG_IN){
 				res = b1.getMessageInCount() - b2.getMessageInCount();
-			}
-			
-			if(field == FIELD_MSG_OUT){
+			}else if(field == FIELD_MSG_OUT){
 				res = b1.getMessageOutCount() - b2.getMessageOutCount();
-			}
-			
-			if(field == FIELD_QUEUED){
+			}else if(field == FIELD_QUEUED){
 				res = b1.getMessageHandler().getMessageCount() - b2.getMessageHandler().getMessageCount();
-			}
-			
-			if(field == FIELD_BYTES_IN){
+			}else if(field == FIELD_BYTES_IN){
 				res = b1.getBytesInCount() - b2.getBytesInCount();
-			}
-			
-			if(field == FIELD_BYTES_OUT){
+			}else if(field == FIELD_BYTES_OUT){
 				res = b1.getBytesOutCount() - b2.getBytesOutCount();
-			}
-			
-			if(field == FIELD_SS){
+			}else if(field == FIELD_SS){
 				res =  b1.getSubsystem() - b2.getSubsystem();
 			}
 			
 			return(( ascending ? 1 : -1) * res );
 		}
 
+		protected int
+		compareStrings(
+			String	s1,
+			String	s2 )
+		{
+			if ( s1 == null && s2 == null ){
+				return(0);
+			}else if ( s1 == null ){
+				return(-1);
+			}else if ( s2 == null ){
+				return( 1 );
+			}else{
+				return( s1.compareTo(s2));
+			}
+		}
+		
 		protected int
 		sortInt(
 			long	l )
