@@ -21,11 +21,15 @@
 
 package com.aelitis.azureus.plugins.net.netstatus.swt;
 
+import java.net.Inet6Address;
+import java.net.InetAddress;
 import java.util.*;
-import java.net.*;
 
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
 
+import com.aelitis.azureus.core.AzureusCore;
+import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.core.networkmanager.admin.*;
 import com.aelitis.azureus.plugins.net.netstatus.NetStatusPlugin;
 import com.aelitis.azureus.plugins.net.netstatus.NetStatusProtocolTesterBT;
@@ -49,7 +53,7 @@ NetStatusPluginTester
 	
 	private volatile boolean	test_cancelled;
 	
-	protected
+	public
 	NetStatusPluginTester(
 		NetStatusPlugin		_plugin,
 		int					_test_types,
@@ -67,14 +71,25 @@ NetStatusPluginTester
 		return((test_types & type ) != 0 );
 	}
 	
-	protected void
-	run()
+	public void
+	run(AzureusCore core)
 	{
 		final NetworkAdmin	admin = NetworkAdmin.getSingleton();
 		
-		Set	public_addresses = new HashSet();
-		
 		boolean	checked_public	= false;
+
+		Set<InetAddress>	public_addresses = new HashSet<InetAddress>();
+		
+		InetAddress def_pa = admin.getDefaultPublicAddress();
+		
+		if ( def_pa != null ){
+			
+			log( "Default public address is " + def_pa.getHostAddress());
+			
+			addPublicAddress( public_addresses, def_pa );
+			
+			checked_public = true;
+		}
 		
 		if ( doTest( TEST_PING_ROUTE )){
 			
@@ -372,7 +387,7 @@ NetStatusPluginTester
 	
 			checked_public = true;
 			
-			NetworkAdminNATDevice[] nat_devices = admin.getNATDevices();
+			NetworkAdminNATDevice[] nat_devices = admin.getNATDevices(core);
 			
 			log( nat_devices.length + " NAT device" + (nat_devices.length==1?"":"s") + " found" );
 			
@@ -382,17 +397,25 @@ NetStatusPluginTester
 				
 				InetAddress ext_address = device.getExternalAddress();
 				
-				if ( ext_address != null ){
-					
-					public_addresses.add( ext_address );
-				}
+				addPublicAddress( public_addresses, ext_address );
 				
 				log( "    " + device.getString());
 			}
 			
 			NetworkAdminSocksProxy[] socks_proxies = admin.getSocksProxies();
 			
-			log( socks_proxies.length + " SOCKS proxy" + (socks_proxies.length==1?"":"s") + " found" );
+			if ( socks_proxies.length == 0 ){
+				
+				log( "No SOCKS proxy found" );
+
+			}else if (  socks_proxies.length == 1 ){
+				
+				log( "One SOCKS proxy found" );
+				
+			}else{
+				
+				log( socks_proxies.length + " SOCKS proxies found" );
+			}
 			
 			for (int i=0;i<socks_proxies.length;i++){
 				
@@ -415,7 +438,7 @@ NetStatusPluginTester
 			}
 		}
 		
-		InetAddress[] bind_addresses = admin.getAllBindAddresses();
+		InetAddress[] bind_addresses = admin.getAllBindAddresses( false );
 		
 		int	num_binds = 0;
 		
@@ -429,7 +452,7 @@ NetStatusPluginTester
 		
 		if ( num_binds == 0 ){
 			
-			log( "No explicit bind addresses" );
+			log( "No explicit bind address set" );
 			
 		}else{
 		
@@ -448,7 +471,7 @@ NetStatusPluginTester
 
 			checked_public = true;
 			
-			NetworkAdminProtocol[] outbound_protocols = admin.getOutboundProtocols();
+			NetworkAdminProtocol[] outbound_protocols = admin.getOutboundProtocols(core);
 			
 			if ( outbound_protocols.length == 0 ){
 				
@@ -483,10 +506,8 @@ NetStatusPluginTester
 						
 						logSuccess( "    Test successful" );
 						
-						if ( public_address != null ){
-							
-							public_addresses.add( public_address );
-						}
+						addPublicAddress( public_addresses, public_address );
+						
 					}catch( Throwable e ){
 						
 						logError( "    Test failed", e );
@@ -499,7 +520,7 @@ NetStatusPluginTester
 
 			checked_public = true;
 			
-			NetworkAdminProtocol[] inbound_protocols = admin.getInboundProtocols();
+			NetworkAdminProtocol[] inbound_protocols = admin.getInboundProtocols(core);
 			
 			if ( inbound_protocols.length == 0 ){
 				
@@ -534,13 +555,12 @@ NetStatusPluginTester
 						
 						logSuccess( "    Test successful" );
 	
-						if ( public_address != null ){
-							
-							public_addresses.add( public_address );
-						}
+						addPublicAddress( public_addresses, public_address );
+						
 					}catch( Throwable e ){
 						
 						logError( "    Test failed", e );
+						logInfo(  "    Check your port forwarding for " + protocol.getTypeString() + " " + protocol.getPort());
 					}
 				}
 			}
@@ -554,13 +574,13 @@ NetStatusPluginTester
 				
 			}else{
 				
-				Iterator	it = public_addresses.iterator();
+				Iterator<InetAddress>	it = public_addresses.iterator();
 				
 				log( public_addresses.size() + " public/external addresses found" );
 				
 				while( it.hasNext()){
 					
-					InetAddress	pub_address = (InetAddress)it.next();
+					InetAddress	pub_address = it.next();
 					
 					log( "    " + pub_address.getHostAddress());
 					
@@ -716,12 +736,33 @@ NetStatusPluginTester
 	}
 	
 	protected void
+	addPublicAddress(
+		Set<InetAddress>	addresses,
+		InetAddress			address )
+	{
+		if ( address == null ){
+			
+			return;
+		}
+			
+		if ( 	address.isAnyLocalAddress() ||
+				address.isLoopbackAddress() ||
+				address.isLinkLocalAddress()||
+				address.isSiteLocalAddress()){
+			
+				return;
+		}
+		
+		addresses.add( address );
+	}
+	
+	public void
 	cancel()
 	{
 		test_cancelled	= true;
 	}
 	
-	protected boolean
+	public boolean
 	isCancelled()
 	{
 		return( test_cancelled );
@@ -741,6 +782,13 @@ NetStatusPluginTester
 		logger.logSuccess( str );
 	}
 	
+	protected void
+	logInfo(
+		String	str )
+	{
+		logger.logInfo( str );
+	}
+	
 	protected void
 	log(
 		String		str,
@@ -764,7 +812,7 @@ NetStatusPluginTester
 		logger.logFailure( str + ": " + e.getLocalizedMessage());
 	}
 	
-	protected interface
+	public interface
 	loggerProvider
 	{
 		public void
@@ -775,6 +823,10 @@ NetStatusPluginTester
 		logSuccess(
 			String	str );
 		
+		public void
+		logInfo(
+			String	str );
+		
 		public void
 		logFailure(
 			String	str );
