@@ -102,6 +102,19 @@ public class DefaultRankCalculator implements Comparable {
 	/** Seeding Rank value when download is marked as Share Ratio Met */
 	public static final int SR_SHARERATIOMET = -8;
 
+	public static final String[] SR_NEGATIVE_DEBUG = {
+		"?",
+		"Not Qd",
+		"FP SPRatioMet",
+		"Ratio Met",
+		"# CDs Met",
+		"FP 0 Peers",
+		"0 Peers",
+		"Share Ratio Met"
+	};
+
+	private static final long STALE_REFRESH_INTERVAL = 1000 * 60;
+
 	//
 	// Static config values
 
@@ -148,6 +161,8 @@ public class DefaultRankCalculator implements Comparable {
 
 	private static int iFirstPriorityActiveMinutes;
 
+	private static int iFirstPriorityIgnoreIdleHours;
+	
 	private static long minTimeAlive;
 
 	private static boolean bAutoStart0Peers;
@@ -165,6 +180,12 @@ public class DefaultRankCalculator implements Comparable {
 
 	private long lCDActivelyChangedOn;
 
+	private long staleCDSince;
+	
+	private long staleCDOffset;
+
+	private long lastStaleCDRefresh;
+
 	private boolean bIsFirstPriority;
 
 	/** Public for tooltip to access it */
@@ -228,43 +249,45 @@ public class DefaultRankCalculator implements Comparable {
 	public static void reloadConfigParams(PluginConfig cfg) {
 		final String PREFIX = "StartStopManager_";
 
-		iRankType = cfg.getIntParameter(PREFIX + "iRankType");
+		iRankType = cfg.getUnsafeIntParameter(PREFIX + "iRankType");
 
-		minPeersToBoostNoSeeds = cfg.getIntParameter(PREFIX
+		minPeersToBoostNoSeeds = cfg.getUnsafeIntParameter(PREFIX
 				+ "iMinPeersToBoostNoSeeds");
-		minSpeedForActiveDL = cfg.getIntParameter(PREFIX + "iMinSpeedForActiveDL");
-		minSpeedForActiveSeeding = cfg.getIntParameter(PREFIX
+		minSpeedForActiveDL = cfg.getUnsafeIntParameter(PREFIX + "iMinSpeedForActiveDL");
+		minSpeedForActiveSeeding = cfg.getUnsafeIntParameter(PREFIX
 				+ "iMinSpeedForActiveSeeding");
 
-		iRankTypeSeedFallback = cfg.getIntParameter(PREFIX
+		iRankTypeSeedFallback = cfg.getUnsafeIntParameter(PREFIX
 				+ "iRankTypeSeedFallback");
-		bPreferLargerSwarms = cfg.getBooleanParameter(PREFIX
+		bPreferLargerSwarms = cfg.getUnsafeBooleanParameter(PREFIX
 				+ "bPreferLargerSwarms");
-		minTimeAlive = cfg.getIntParameter(PREFIX + "iMinSeedingTime") * 1000;
-		bAutoStart0Peers = cfg.getBooleanParameter(PREFIX + "bAutoStart0Peers");
+		minTimeAlive = cfg.getUnsafeIntParameter(PREFIX + "iMinSeedingTime") * 1000;
+		bAutoStart0Peers = cfg.getUnsafeBooleanParameter(PREFIX + "bAutoStart0Peers");
 
 		// Ignore torrent if seed count is at least..
-		iIgnoreSeedCount = cfg.getIntParameter(PREFIX + "iIgnoreSeedCount");
-		bIgnore0Peers = cfg.getBooleanParameter(PREFIX + "bIgnore0Peers");
+		iIgnoreSeedCount = cfg.getUnsafeIntParameter(PREFIX + "iIgnoreSeedCount");
+		bIgnore0Peers = cfg.getUnsafeBooleanParameter(PREFIX + "bIgnore0Peers");
 		iIgnoreShareRatio = (int) (1000 * cfg.getFloatParameter("Stop Ratio"));
-		iIgnoreShareRatio_SeedStart = cfg.getIntParameter(PREFIX
+		iIgnoreShareRatio_SeedStart = cfg.getUnsafeIntParameter(PREFIX
 				+ "iIgnoreShareRatioSeedStart");
 		iIgnoreRatioPeers = cfg.getIntParameter("Stop Peers Ratio", 0);
-		iIgnoreRatioPeers_SeedStart = cfg.getIntParameter(PREFIX
+		iIgnoreRatioPeers_SeedStart = cfg.getUnsafeIntParameter(PREFIX
 				+ "iIgnoreRatioPeersSeedStart", 0);
 
-		minQueueingShareRatio = cfg.getIntParameter(PREFIX
+		minQueueingShareRatio = cfg.getUnsafeIntParameter(PREFIX
 				+ "iFirstPriority_ShareRatio");
-		iFirstPriorityType = cfg.getIntParameter(PREFIX + "iFirstPriority_Type");
-		iFirstPrioritySeedingMinutes = cfg.getIntParameter(PREFIX
+		iFirstPriorityType = cfg.getUnsafeIntParameter(PREFIX + "iFirstPriority_Type");
+		iFirstPrioritySeedingMinutes = cfg.getUnsafeIntParameter(PREFIX
 				+ "iFirstPriority_SeedingMinutes");
-		iFirstPriorityActiveMinutes = cfg.getIntParameter(PREFIX
+		iFirstPriorityActiveMinutes = cfg.getUnsafeIntParameter(PREFIX
 				+ "iFirstPriority_DLMinutes");
 		// Ignore FP
-		iFirstPriorityIgnoreSPRatio = cfg.getIntParameter(PREFIX
+		iFirstPriorityIgnoreSPRatio = cfg.getUnsafeIntParameter(PREFIX
 				+ "iFirstPriority_ignoreSPRatio");
-		bFirstPriorityIgnore0Peer = cfg.getBooleanParameter(PREFIX
+		bFirstPriorityIgnore0Peer = cfg.getUnsafeBooleanParameter(PREFIX
 				+ "bFirstPriority_ignore0Peer");
+		iFirstPriorityIgnoreIdleHours = cfg.getUnsafeIntParameter(PREFIX
+				+ "iFirstPriority_ignoreIdleHours");
 	}
 
 	/** Sort first by SeedingRank Descending, then by Position Ascending.
@@ -275,7 +298,15 @@ public class DefaultRankCalculator implements Comparable {
 		}
 
 		DefaultRankCalculator dlData = (DefaultRankCalculator) obj;
-		// Test Completeness
+
+		
+		// Test FP.  FP goes to top
+		if (dlData.bIsFirstPriority && !bIsFirstPriority)
+			return 1;
+		if (!dlData.bIsFirstPriority && bIsFirstPriority)
+			return -1;
+		
+		// Test Completeness.  Complete go to bottom
 		boolean aIsComplete = dlData.dl.isComplete();
 		boolean bIsComplete = dl.isComplete();
 		if (aIsComplete && !bIsComplete)
@@ -283,17 +314,11 @@ public class DefaultRankCalculator implements Comparable {
 		if (!aIsComplete && bIsComplete)
 			return 1;
 
-		// Test FP
-		if (dlData.bIsFirstPriority && !bIsFirstPriority)
-			return 1;
-		if (!dlData.bIsFirstPriority && bIsFirstPriority)
-			return -1;
-
 		if (iRankType == StartStopRulesDefaultPlugin.RANK_NONE) {
 			return dl.getPosition() - dlData.dl.getPosition();
 		}
 
-		// Check Rank
+		// Check Rank. Large to top
 		int value = dlData.dl.getSeedingRank() - dl.getSeedingRank();
 		if (value != 0)
 			return value;
@@ -401,15 +426,17 @@ public class DefaultRankCalculator implements Comparable {
 			// Not active if we aren't seeding
 			// Not active if we are AutoStarting 0 Peers, and peer count == 0
 			bIsActive = false;
+			staleCDSince = -1;
 		} else if (SystemTime.getCurrentTime() - stats.getTimeStarted() <= FORCE_ACTIVE_FOR) {
 			bIsActive = true;
+			staleCDSince = -1;
 		} else {
 			bIsActive = (stats.getUploadAverage() >= minSpeedForActiveSeeding);
 
 			if (bActivelySeeding != bIsActive) {
 				long now = SystemTime.getCurrentTime();
 				// Change
-				if (lCDActivelyChangedOn == -1) {
+				if (lCDActivelyChangedOn < 0) {
 					// Start Timer
 					lCDActivelyChangedOn = now;
 					bIsActive = !bIsActive;
@@ -417,6 +444,16 @@ public class DefaultRankCalculator implements Comparable {
 					// Continue as old state until timer finishes
 					bIsActive = !bIsActive;
 				}
+				
+				if (bActivelySeeding != bIsActive) {
+  				if (bIsActive) {
+  					staleCDSince = -1;
+  					staleCDOffset = 0;
+  				} else {
+  					staleCDSince = System.currentTimeMillis();
+  				}
+				}
+
 			} else {
 				// no change, reset timer
 				lCDActivelyChangedOn = -1;
@@ -425,6 +462,7 @@ public class DefaultRankCalculator implements Comparable {
 
 		if (bActivelySeeding != bIsActive) {
 			bActivelySeeding = bIsActive;
+
 			if (rules != null) {
 				rules.requestProcessCycle(null);
 				if (rules.bDebugLog)
@@ -631,7 +669,7 @@ public class DefaultRankCalculator implements Comparable {
 					if(lastModifiedScrapeResultPeers > lastModifiedScrapeResultSeeds * 10)
 						newSR = 100 * lastModifiedScrapeResultPeers * 10;
 					else
-						newSR = 100 * lastModifiedScrapeResultPeers * lastModifiedScrapeResultPeers/(lastModifiedScrapeResultSeeds+1);
+						newSR = (int)((long)100 * lastModifiedScrapeResultPeers * lastModifiedScrapeResultPeers/(lastModifiedScrapeResultSeeds+1));
 				}				
 				else if ((iRankType == StartStopRulesDefaultPlugin.RANK_SEEDCOUNT)
 						&& (iRankTypeSeedFallback == 0 || iRankTypeSeedFallback > lastModifiedScrapeResultSeeds))
@@ -658,6 +696,16 @@ public class DefaultRankCalculator implements Comparable {
 				if (rules.bDebugLog)
 					sExplainSR += "  Can't calculate SR, no scrape results\n";
 			}
+			
+			if (staleCDOffset > 0) {
+				// every 10 minutes of not being active, subtract one SR
+				if (newSR > staleCDOffset) {
+					newSR -= staleCDOffset;
+					sExplainSR += "  subtracted " + staleCDOffset + " due to non-activeness\n";
+				} else {
+					staleCDOffset = 0; 
+				}
+			}
 
 			if (newSR < 0)
 				newSR = 1;
@@ -715,21 +763,30 @@ public class DefaultRankCalculator implements Comparable {
 		
 		List listeners = rules.getFPListeners();
 		StringBuffer fp_listener_debug = null;
-		if (rules.bDebugLog && !listeners.isEmpty()) {fp_listener_debug = new StringBuffer();}
-		for (Iterator iter = listeners.iterator(); iter.hasNext();) {
-			StartStopRulesFPListener l = (StartStopRulesFPListener) iter.next();
-			boolean result = l.isFirstPriority(dl, lastModifiedScrapeResultSeeds, lastModifiedScrapeResultPeers, fp_listener_debug);
-			if (fp_listener_debug != null && fp_listener_debug.length() > 0) {
-				char last_ch = fp_listener_debug.charAt(fp_listener_debug.length()-1);
-				if (last_ch != '\n') {fp_listener_debug.append('\n');}
-				sExplainFP += fp_listener_debug;
-				fp_listener_debug.setLength(0);
-			}
-			if (result) {
-				return true;
+		if (!listeners.isEmpty())
+		{
+			if (rules.bDebugLog)
+				fp_listener_debug = new StringBuffer();
+			for (Iterator iter = listeners.iterator(); iter.hasNext();)
+			{
+				StartStopRulesFPListener l = (StartStopRulesFPListener) iter.next();
+				boolean result = l.isFirstPriority(dl, lastModifiedScrapeResultSeeds, lastModifiedScrapeResultPeers, fp_listener_debug);
+				if (fp_listener_debug != null && fp_listener_debug.length() > 0)
+				{
+					char last_ch = fp_listener_debug.charAt(fp_listener_debug.length() - 1);
+					if (last_ch != '\n')
+						fp_listener_debug.append('\n');
+					sExplainFP += fp_listener_debug;
+					fp_listener_debug.setLength(0);
+				}
+				if (result)
+				{
+					return true;
+				}
 			}
 		}
 
+
 		// FP doesn't apply when S:P >= set SPratio (SPratio = 0 means ignore)
 		if (lastModifiedScrapeResultPeers > 0 && lastModifiedScrapeResultSeeds > 0
 				&& (lastModifiedScrapeResultSeeds / lastModifiedScrapeResultPeers) >= iFirstPriorityIgnoreSPRatio
@@ -746,6 +803,19 @@ public class DefaultRankCalculator implements Comparable {
 			return false;
 		}
 
+		if (iFirstPriorityIgnoreIdleHours > 0) {
+			long lastUploadSecs = dl.getStats().getSecondsSinceLastUpload();
+			if (lastUploadSecs < 0) {
+				lastUploadSecs = dl.getStats().getSecondsOnlySeeding();
+			}
+			if (lastUploadSecs > 60 * 60 * iFirstPriorityIgnoreIdleHours) {
+				if (rules.bDebugLog)
+					sExplainFP += "Not FP: " + lastUploadSecs + "s > "
+							+ iFirstPriorityIgnoreIdleHours + "h of no upload\n";
+				return false;
+			}
+		}
+
 		int shareRatio = dl.getStats().getShareRatio();
 		boolean bLastMatched = (shareRatio != -1)
 				&& (shareRatio < minQueueingShareRatio);
@@ -848,6 +918,10 @@ public class DefaultRankCalculator implements Comparable {
 			if (iIgnoreShareRatio != 0 && shareRatio >= iIgnoreShareRatio
 					&& (numSeeds >= iIgnoreShareRatio_SeedStart || !lastScrapeResultOk)
 					&& shareRatio != -1) {
+				if (rules.bDebugLog) {
+					rules.log.log(dl.getTorrent(), LoggerChannel.LT_INFORMATION,
+							"somethingChanged: shareRatio changeChecker");
+				}
 				return true;
 			}
 		}
@@ -865,6 +939,19 @@ public class DefaultRankCalculator implements Comparable {
 						"somethingChanged: Download is ready");
 			return true;
 		}
+		
+		if (staleCDSince > 0) {
+			long now = SystemTime.getCurrentTime(); 
+			if (now - lastStaleCDRefresh > STALE_REFRESH_INTERVAL) {
+				staleCDOffset += (now - lastStaleCDRefresh) / STALE_REFRESH_INTERVAL;
+				lastStaleCDRefresh = now;
+				if (rules.bDebugLog) {
+					rules.log.log(dl.getTorrent(), LoggerChannel.LT_INFORMATION,
+							"somethingChanged: staleCD changeChecker");
+				}
+				return true;
+			}
+		}
 
 		return false;
 	}
