@@ -25,9 +25,11 @@ import java.util.*;
 
 import org.gudy.azureus2.core3.config.COConfigurationListener;
 import org.gudy.azureus2.core3.config.COConfigurationManager;
-import org.gudy.azureus2.core3.config.impl.ConfigurationDefaults;
 import org.gudy.azureus2.core3.util.*;
-import org.gudy.azureus2.plugins.*;
+import org.gudy.azureus2.plugins.Plugin;
+import org.gudy.azureus2.plugins.PluginConfig;
+import org.gudy.azureus2.plugins.PluginInterface;
+import org.gudy.azureus2.plugins.PluginListener;
 import org.gudy.azureus2.plugins.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.plugins.download.*;
 import org.gudy.azureus2.plugins.logging.LoggerChannel;
@@ -316,7 +318,7 @@ public class StartStopRulesDefaultPlugin implements Plugin,
 		configModel.addBooleanParameter2("StartStopManager_bAutoReposition",
 				"ConfigView.label.seeding.autoReposition", false);
 		configModel.addIntParameter2("StartStopManager_iMinSeedingTime",
-				"ConfigView.label.minSeedingTime", 60 * 3);
+				"ConfigView.label.minSeedingTime", 60 * 10);
 
 		// ignore rules subsection
 		// ---------
@@ -492,6 +494,8 @@ public class StartStopRulesDefaultPlugin implements Plugin,
 			}
 		}
 	}
+	
+	private volatile boolean immediateProcessingScheduled = false;
 
 	/** Listen to Download changes and recalc SR if needed 
 	 */
@@ -503,12 +507,17 @@ public class StartStopRulesDefaultPlugin implements Plugin,
 			if (dlData != null) {
 				// force a SR recalc, so that it gets position properly next process()
 				requestProcessCycle(dlData);
-				if (new_state == Download.ST_READY || new_state == Download.ST_WAITING) {
-					new AEThread2("processReady", true) {
-						public void run() {
-							process();
-						}
-					}.start();
+				if ((new_state == Download.ST_READY || new_state == Download.ST_WAITING)) {
+					if (immediateProcessingScheduled) { 
+						requestProcessCycle(dlData);
+					} else {
+						immediateProcessingScheduled = true;
+						new AEThread2("processReady", true) {
+							public void run() {
+								process();
+							}
+						}.start();
+					}
 				}
 				
 				if (bDebugLog)
@@ -1371,6 +1380,8 @@ public class StartStopRulesDefaultPlugin implements Plugin,
 				}
 				processLastComplete = now;
 			}
+			
+			immediateProcessingScheduled = false;
 
 			this_mon.exit();
 		}
