@@ -21,23 +21,19 @@
 package com.aelitis.azureus.plugins.startstoprules.defaultplugin.ui.swt;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.Event;
-import org.eclipse.swt.widgets.Listener;
-import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.*;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.util.AERunnable;
-import org.gudy.azureus2.ui.swt.ImageRepository;
 import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.config.*;
 import org.gudy.azureus2.ui.swt.plugins.UISWTConfigSection;
 
+import com.aelitis.azureus.ui.swt.imageloader.ImageLoader;
+
 /** Seeding Automation Specific options
  * @author TuxPaper
  * @created Jan 12, 2004
@@ -82,7 +78,6 @@ public class ConfigSectionSeeding implements UISWTConfigSection {
     label = new Label(cSeeding, SWT.NULL);
     Messages.setLanguageText(label, "ConfigView.label.minSeedingTime");
     gridData = new GridData();
-    gridData.widthHint = 40;
     new IntParameter(cSeeding, "StartStopManager_iMinSeedingTime").setLayoutData(gridData);
 
     gridData = new GridData();
@@ -103,7 +98,6 @@ public class ConfigSectionSeeding implements UISWTConfigSection {
     label = new Label(cSeeding, SWT.NULL);
     Messages.setLanguageText(label, "ConfigView.label.seeding.addForSeedingDLCopyCount");
     gridData = new GridData();
-    gridData.widthHint = 40;
     new IntParameter(cSeeding, "StartStopManager_iAddForSeedingDLCopyCount").setLayoutData(gridData);
 
     label = new Label(cSeeding, SWT.NULL);
@@ -119,7 +113,6 @@ public class ConfigSectionSeeding implements UISWTConfigSection {
     cArea.setLayoutData(gridData);
 
     gridData = new GridData();
-    gridData.widthHint = 20;
     final IntParameter paramFakeFullCopy = new IntParameter(cArea, "StartStopManager_iNumPeersAsFullCopy");
     paramFakeFullCopy.setLayoutData(gridData);
 
@@ -138,18 +131,15 @@ public class ConfigSectionSeeding implements UISWTConfigSection {
     gridData.horizontalSpan = 2;
     cFullCopyOptionsArea.setLayoutData(gridData);
     
-    label = new Label(cFullCopyOptionsArea, SWT.NULL);
-    Image img = ImageRepository.getImage("subitem");
-    img.setBackground(label.getBackground());
+		label = new Label(cFullCopyOptionsArea, SWT.NULL);
+		ImageLoader.getInstance().setLabelImage(label, "subitem");
     gridData = new GridData(GridData.VERTICAL_ALIGN_BEGINNING);
     label.setLayoutData(gridData);
-    label.setImage(img);
     
     label = new Label(cFullCopyOptionsArea, SWT.NULL);
     Messages.setLanguageText(label, "ConfigView.label.seeding.fakeFullCopySeedStart");
 
     gridData = new GridData();
-    gridData.widthHint = 20;
     new IntParameter(cFullCopyOptionsArea, "StartStopManager_iFakeFullCopySeedStart").setLayoutData(gridData);
     label = new Label(cFullCopyOptionsArea, SWT.NULL);
     Messages.setLanguageText(label, "ConfigView.label.seeds");
