@@ -66,7 +66,6 @@ public class ConfigSectionSeedingAutoStarting implements UISWTConfigSection {
     Label label;
 
     Composite gQR = new Composite(parent, SWT.NULL);
-    gQR.addControlListener(new Utils.LabelWrapControlListener());
 
     layout = new GridLayout();
     layout.numColumns = 1;
@@ -122,7 +121,6 @@ public class ConfigSectionSeedingAutoStarting implements UISWTConfigSection {
     Messages.setLanguageText(label, "ConfigView.label.seeding.rankType.seed.fallback");
 
     gridData = new GridData(GridData.VERTICAL_ALIGN_BEGINNING);
-    gridData.widthHint = 20;
     IntParameter intParamFallBack = new IntParameter(gSeedCount, "StartStopManager_iRankTypeSeedFallback");
     intParamFallBack.setLayoutData(gridData);
 
