@@ -102,6 +102,11 @@ DHTTrackerPlugin
 	private static final int	INTERESTING_INIT_RAND_OTHERS	=   30*60*1000;
 	private static final int	INTERESTING_INIT_MIN_OTHERS		=    5*60*1000;
 
+	private static final int	INTERESTING_DHT_CHECK_PERIOD	= 1*60*60*1000;
+	private static final int	INTERESTING_DHT_INIT_RAND		=    5*60*1000;
+	private static final int	INTERESTING_DHT_INIT_MIN		=    2*60*1000;
+	
+	
 	private static final int	INTERESTING_AVAIL_MAX		= 8;	// won't pub if more
 	private static final int	INTERESTING_PUB_MAX_DEFAULT	= 30;	// limit on pubs
 	
@@ -123,6 +128,9 @@ DHTTrackerPlugin
 	private static final int	DL_DERIVED_MAX_TRACK		= 20;
 	private static final int	DIRECT_INJECT_PEER_MAX		= 5;
 	
+	private static boolean ADD_ASN_DERIVED_TARGET			= true;
+	private static boolean ADD_NETPOS_DERIVED_TARGETS		= false;
+	
 	private static URL	DEFAULT_URL;
 	
 	static{
@@ -523,9 +531,22 @@ DHTTrackerPlugin
 						}
 					}else{
 						
+						int	min;
+						int	rand;
+						
+						if ( TorrentUtils.isDecentralised( torrent.getAnnounceURL())){
+							
+							min		= INTERESTING_DHT_INIT_MIN;	
+							rand	= INTERESTING_DHT_INIT_RAND;
+
+						}else{
+							
+							min		= INTERESTING_INIT_MIN_OTHERS;	
+							rand	= INTERESTING_INIT_RAND_OTHERS;
+						}
+						
 						delay = plugin_interface.getUtilities().getCurrentSystemTime() + 
-									INTERESTING_INIT_MIN_OTHERS + 
-									random.nextInt( INTERESTING_INIT_RAND_OTHERS );
+									min + random.nextInt( rand );
 					}
 					
 					try{
@@ -2330,8 +2351,9 @@ DHTTrackerPlugin
 	protected void
 	processNonRegistrations()
 	{
-		Download	ready_download = null;
-	
+		Download	ready_download 				= null;
+		long		ready_download_next_check	= -1;
+		
 		long	now = plugin_interface.getUtilities().getCurrentSystemTime();
 		
 			// unfortunately getting scrape results can acquire locks and there is a vague
@@ -2402,7 +2424,7 @@ DHTTrackerPlugin
 					
 					if ( !force ){
 						
-						if ( !dht.isReachable()){
+						if ( false && !dht.isReachable()){
 							
 							continue;
 						}
@@ -2429,15 +2451,18 @@ DHTTrackerPlugin
 					
 					long	target = ((Long)interesting_downloads.get( download )).longValue();
 					
+					long check_period = TorrentUtils.isDecentralised( torrent.getAnnounceURL())?INTERESTING_DHT_CHECK_PERIOD:INTERESTING_CHECK_PERIOD;
+					
 					if ( target <= now ){
 						
-						ready_download	= download;
+						ready_download				= download;
+						ready_download_next_check 	= now + check_period;
 						
-						interesting_downloads.put( download, new Long( now + INTERESTING_CHECK_PERIOD ));
+						interesting_downloads.put( download, new Long( ready_download_next_check ));
 						
-					}else if ( target - now > INTERESTING_CHECK_PERIOD ){
+					}else if ( target - now > check_period ){
 						
-						interesting_downloads.put( download, new Long( now + (target%INTERESTING_CHECK_PERIOD)));
+						interesting_downloads.put( download, new Long( now + (target%check_period)));
 					}
 				}
 			}
@@ -2468,7 +2493,8 @@ DHTTrackerPlugin
 			
 				//System.out.println( "presence query for " + ready_download.getName());
 				
-				final long start = now;
+				final long start 		= now;
+				final long f_next_check = ready_download_next_check;
 				
 				dht.get(	ready_download.getTorrent().getHash(), 
 							"Presence query for '" + ready_download.getName() + "'",
@@ -2479,7 +2505,8 @@ DHTTrackerPlugin
 							new DHTPluginOperationListener()
 							{
 								private boolean diversified;
-								private int total = 0;
+								private int 	leechers = 0;
+								private int 	seeds	 = 0;
 								
 								public void
 								diversified()
@@ -2498,7 +2525,14 @@ DHTTrackerPlugin
 									DHTPluginContact	originator,
 									DHTPluginValue		value )
 								{
-									total++;
+									if (( value.getFlags() & DHTPlugin.FLAG_DOWNLOADING ) == 1 ){
+
+										leechers++;
+										
+									}else{
+										
+										seeds++;
+									}
 								}
 								
 								public void
@@ -2515,6 +2549,8 @@ DHTTrackerPlugin
 								{
 									// System.out.println( "    presence query for " + f_ready_download.getName() + "->" + total + "/div = " + diversified );
 	
+									int	total = leechers + seeds;
+									
 									log.log( f_ready_download.getTorrent(), LoggerChannel.LT_INFORMATION,
 											"Presence query for '" + f_ready_download.getName() + "': availability="+
 											(total==INTERESTING_AVAIL_MAX?(INTERESTING_AVAIL_MAX+"+"):(total+"")) + ",div=" + diversified +
@@ -2590,6 +2626,64 @@ DHTTrackerPlugin
 												});
 	
 									}
+									
+									f_ready_download.setScrapeResult(
+										new DownloadScrapeResult()
+										{
+											public Download
+											getDownload()
+											{
+												return( null );
+											}
+											
+											public int
+											getResponseType()
+											{
+												return( RT_SUCCESS );
+											}
+											
+											public int
+											getSeedCount()
+											{
+												return( seeds );
+											}
+											
+											public int
+											getNonSeedCount()
+											{
+												return( leechers );
+											}
+	
+											public long
+											getScrapeStartTime()
+											{
+												return( SystemTime.getCurrentTime());
+											}
+												
+											public void 
+											setNextScrapeStartTime(
+												long nextScrapeStartTime)
+											{
+											}
+											
+											public long
+											getNextScrapeStartTime()
+											{
+												return( f_next_check );
+											}
+											
+											public String
+											getStatus()
+											{
+												return( "OK" );
+											}
+	
+											public URL
+											getURL()
+											{
+												return( f_ready_download.getTorrent().getAnnounceURL());
+											}
+										});
 								}
 							});
 	
@@ -2625,7 +2719,12 @@ DHTTrackerPlugin
 			this_mon.exit();
 		}
 		
-		checkDownloadForRegistration( download, false );
+			// don't do anything if paused as we want things to just continue as they are (we would force an announce here otherwise)
+		
+		if ( !download.isPaused()){
+		
+			checkDownloadForRegistration( download, false );
+		}
 	}
  
 	public void
@@ -2671,6 +2770,7 @@ DHTTrackerPlugin
 		}
 	}
 	
+	/*
 	public DownloadScrapeResult
 	scrape(
 		byte[]		hash )
@@ -2790,6 +2890,7 @@ DHTTrackerPlugin
 					}
 				});
 	}
+	*/
 	
 	protected void
 	increaseActive(
@@ -2993,7 +3094,7 @@ DHTTrackerPlugin
 			}
 		}
 		
-		protected boolean
+		protected void
     	getTrackerTargets(
     		Download		download,
     		int				type )
@@ -3007,129 +3108,134 @@ DHTTrackerPlugin
     			result.add( new trackerTarget( torrent_hash, REG_TYPE_FULL, "" ));
     		}
     		
-    	    NetworkAdminASN net_asn = NetworkAdmin.getSingleton().getCurrentASN();
-    	      
-    	    String	as 	= net_asn.getAS();
-    	    String	asn = net_asn.getASName();
-
-    		if ( as.length() > 0 && asn.length() > 0 ){
-    			 
-    			String	key = "azderived:asn:" + as;
+    		if ( ADD_ASN_DERIVED_TARGET ){
     			
-    			try{
-    				byte[] asn_bytes = key.getBytes( "UTF-8" );
-    			
-    				byte[] key_bytes = new byte[torrent_hash.length + asn_bytes.length];
-    				
-    				System.arraycopy( torrent_hash, 0, key_bytes, 0, torrent_hash.length );
-    				
-    				System.arraycopy( asn_bytes, 0, key_bytes, torrent_hash.length, asn_bytes.length );
-    				
-    				result.add( new trackerTarget( key_bytes, REG_TYPE_DERIVED, asn + "/" + as ));
-    				
-    			}catch( Throwable e ){
-    				
-    				Debug.printStackTrace(e);
-    			}
-    		}
-    		
-    		long	now = SystemTime.getMonotonousTime();
-    		
-    		boolean	do_it;
-    		
-       		Long	metric = (Long)download.getUserData( DL_DERIVED_METRIC_KEY );
-       	 
-       		boolean	do_it_now = metric != null;
-       		
-    		if ( derived_active_start >= 0 && now - derived_active_start <= DERIVED_ACTIVE_MIN_MILLIS ){
-    			
-    			do_it = true;
-    			
-    			if ( metric == null ){
-    				
-    				metric = new Long( previous_metric );
-    			}
-    		}else{
-    			
-    			if ( do_it_now ){
-    				
-    				do_it = true;
-    				
-    			}else{
-    				
-    				derived_active_start = -1;
-    				
-    				do_it = false;
-    			}
-    		}
-    		
-    		boolean	newly_active = false;
-    		
-    		if ( do_it_now ){
-    			
-    			newly_active = derived_active_start == -1;
-    			
-    			derived_active_start = now;
-    		}
-     		  
-    		List<trackerTarget>	skipped_targets = null;
-    		
-    		if ( do_it ){
-    			
-    			previous_metric = metric.longValue();
-    			
-	    		try{
-	    			DHTNetworkPosition[] positions = getNetworkPositions();
-	    		
-	    			for (int i=0;i<positions.length;i++){
-	    				
-	    				DHTNetworkPosition pos = positions[i];
-	    				
-	    				if ( pos.getPositionType() == DHTNetworkPosition.POSITION_TYPE_VIVALDI_V2 ){
-	    					
-	    					if ( pos.isValid()){
-	    						
-	    						List<Object[]>	derived_results = getVivaldiTargets( torrent_hash, pos.getLocation());
-	    						
-	    		    			int	num_to_add = metric.intValue() * derived_results.size() / 100;
-    				 			
-	    		    			// System.out.println( download.getName() + ": metric=" + metric + ", adding=" + num_to_add );
-	    		    			
-	    						for (int j=0;j<derived_results.size();j++){
-	    							
-	    							Object[] entry = derived_results.get(j);
-	    							
-	    							// int	distance = ((Integer)entry[0]).intValue();
-	    							
-	    							trackerTarget	target= (trackerTarget)entry[1];
-	    								    						
-	    							if ( j < num_to_add ){
-	    							
-	    								result.add( target );
-	    								
-	    							}else{
-	    								
-	    								if ( skipped_targets == null ){
-	    									
-	    									skipped_targets = new ArrayList<trackerTarget>();
-	    								}
-	    								
-	    								skipped_targets.add( target );
-	    							}
-	    						}
-	    					}
-	    				}
-	    			}
-	    		}catch( Throwable e ){
+	    	    NetworkAdminASN net_asn = NetworkAdmin.getSingleton().getCurrentASN();
+	    	      
+	    	    String	as 	= net_asn.getAS();
+	    	    String	asn = net_asn.getASName();
+	
+	    		if ( as.length() > 0 && asn.length() > 0 ){
+	    			 
+	    			String	key = "azderived:asn:" + as;
 	    			
-	    			Debug.printStackTrace(e);
+	    			try{
+	    				byte[] asn_bytes = key.getBytes( "UTF-8" );
+	    			
+	    				byte[] key_bytes = new byte[torrent_hash.length + asn_bytes.length];
+	    				
+	    				System.arraycopy( torrent_hash, 0, key_bytes, 0, torrent_hash.length );
+	    				
+	    				System.arraycopy( asn_bytes, 0, key_bytes, torrent_hash.length, asn_bytes.length );
+	    				
+	    				result.add( new trackerTarget( key_bytes, REG_TYPE_DERIVED, asn + "/" + as ));
+	    				
+	    			}catch( Throwable e ){
+	    				
+	    				Debug.printStackTrace(e);
+	    			}
 	    		}
     		}
     		
-    		put_targets 	= result.toArray( new trackerTarget[result.size()]);
-    		not_put_targets = skipped_targets;
+    		if ( ADD_NETPOS_DERIVED_TARGETS ){
+	    			
+	    		long	now = SystemTime.getMonotonousTime();
+	    		
+	    		boolean	do_it;
+	    		
+	       		Long	metric = (Long)download.getUserData( DL_DERIVED_METRIC_KEY );
+	       	 
+	       		boolean	do_it_now = metric != null;
+	       		
+	    		if ( derived_active_start >= 0 && now - derived_active_start <= DERIVED_ACTIVE_MIN_MILLIS ){
+	    			
+	    			do_it = true;
+	    			
+	    			if ( metric == null ){
+	    				
+	    				metric = new Long( previous_metric );
+	    			}
+	    		}else{
+	    			
+	    			if ( do_it_now ){
+	    				
+	    				do_it = true;
+	    				
+	    			}else{
+	    				
+	    				derived_active_start = -1;
+	    				
+	    				do_it = false;
+	    			}
+	    		}
+	    		
+	    		boolean	newly_active = false;
+	    		
+	    		if ( do_it_now ){
+	    			
+	    			newly_active = derived_active_start == -1;
+	    			
+	    			derived_active_start = now;
+	    		}
+	     		  
+	    		List<trackerTarget>	skipped_targets = null;
+	    		
+	    		if ( do_it ){
+	    			
+	    			previous_metric = metric.longValue();
+	    			
+		    		try{
+		    			DHTNetworkPosition[] positions = getNetworkPositions();
+		    		
+		    			for (int i=0;i<positions.length;i++){
+		    				
+		    				DHTNetworkPosition pos = positions[i];
+		    				
+		    				if ( pos.getPositionType() == DHTNetworkPosition.POSITION_TYPE_VIVALDI_V2 ){
+		    					
+		    					if ( pos.isValid()){
+		    						
+		    						List<Object[]>	derived_results = getVivaldiTargets( torrent_hash, pos.getLocation());
+		    						
+		    		    			int	num_to_add = metric.intValue() * derived_results.size() / 100;
+	    				 			
+		    		    			// System.out.println( download.getName() + ": metric=" + metric + ", adding=" + num_to_add );
+		    		    			
+		    						for (int j=0;j<derived_results.size();j++){
+		    							
+		    							Object[] entry = derived_results.get(j);
+		    							
+		    							// int	distance = ((Integer)entry[0]).intValue();
+		    							
+		    							trackerTarget	target= (trackerTarget)entry[1];
+		    								    						
+		    							if ( j < num_to_add ){
+		    							
+		    								result.add( target );
+		    								
+		    							}else{
+		    								
+		    								if ( skipped_targets == null ){
+		    									
+		    									skipped_targets = new ArrayList<trackerTarget>();
+		    								}
+		    								
+		    								skipped_targets.add( target );
+		    							}
+		    						}
+		    					}
+		    				}
+		    			}
+		    		}catch( Throwable e ){
+		    			
+		    			Debug.printStackTrace(e);
+		    		}
+	    		}
     		
-    		return( newly_active );
+	    		not_put_targets = skipped_targets;
+    		}
+    		
+	    	put_targets 	= result.toArray( new trackerTarget[result.size()]);
     	}
 	}
 	
