@@ -32,10 +32,14 @@ import java.net.URL;
 
 import org.gudy.azureus2.plugins.*;
 import org.gudy.azureus2.plugins.logging.*;
+import org.gudy.azureus2.plugins.network.*;
 import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.ui.model.*;
 import org.gudy.azureus2.plugins.ui.config.*;
+import org.gudy.azureus2.plugins.utils.DelayedTask;
 import org.gudy.azureus2.plugins.utils.UTTimer;
+import org.gudy.azureus2.plugins.utils.UTTimerEvent;
+import org.gudy.azureus2.plugins.utils.UTTimerEventPerformer;
 import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloaderFactory;
 import org.gudy.azureus2.plugins.utils.xml.simpleparser.SimpleXMLParserDocument;
 import org.gudy.azureus2.plugins.utils.xml.simpleparser.SimpleXMLParserDocumentException;
@@ -96,11 +100,11 @@ UPnPPlugin
 	private BooleanParameter	ignore_bad_devices;
 	private LabelParameter		ignored_devices_list;
 	
-	private List	mappings	= new ArrayList();
-	private List	services	= new ArrayList();
+	private List<UPnPMapping>		mappings	= new ArrayList<UPnPMapping>();
+	private List<UPnPPluginService>	services	= new ArrayList<UPnPPluginService>();
 	
-	private Map	root_info_map		= new HashMap();
-	private Map log_no_repeat_map	= new HashMap();
+	private Map<URL,String> 	root_info_map		= new HashMap<URL, String>();
+	private Map<String,String> log_no_repeat_map	= new HashMap<String,String>();
 	
 	protected AEMonitor	this_mon 	= new AEMonitor( "UPnPPlugin" );
 	   
@@ -147,7 +151,7 @@ UPnPPlugin
 					Parameter	param )
 				{
 					try{
-						plugin_interface.getUIManager().openURL( new URL( "http://azureus.aelitis.com/wiki/index.php/NATPMP" ));
+						plugin_interface.getUIManager().openURL( new URL( "http://www.azureuswiki.com/index.php/NATPMP" ));
 						
 					}catch( Throwable e ){
 						
@@ -177,7 +181,7 @@ UPnPPlugin
 			// UPNP
 		
 		upnp_config.addLabelParameter2( "upnp.info" );
-		upnp_config.addHyperlinkParameter2("upnp.wiki_link", "http://azureus.aelitis.com/wiki/index.php/UPnP");
+		upnp_config.addHyperlinkParameter2("upnp.wiki_link", "http://www.azureuswiki.com/index.php/UPnP");
 		
 		
 		upnp_enable_param = 
@@ -200,6 +204,28 @@ UPnPPlugin
 				}
 			});
 
+		// Auto-refresh mappings every minute when enabled.
+		final BooleanParameter auto_refresh_on_bad_nat_param = upnp_config.addBooleanParameter2( "upnp.refresh_on_bad_nat", "upnp.refresh_mappings_on_bad_nat", false);
+		plugin_interface.getUtilities().createTimer("upnp mapping auto-refresh", true).addPeriodicEvent(1*60*1000, new UTTimerEventPerformer() {
+			private long last_bad_nat = 0;
+			public void perform(UTTimerEvent event) {
+				if (upnp == null) {return;}
+				if (!auto_refresh_on_bad_nat_param.getValue()) {return;}
+				if (!upnp_enable_param.getValue()) {return;}
+				int status = plugin_interface.getConnectionManager().getNATStatus();
+				if (status == ConnectionManager.NAT_BAD) {
+					// Only try to refresh the mappings if this is the first bad NAT
+					// message we've been given in the last 15 minutes - we don't want
+					// to endlessly retry performing the mappings
+					long now = plugin_interface.getUtilities().getCurrentSystemTime();
+					if (last_bad_nat + (15*60*1000) < now ) {
+						last_bad_nat = now;
+						log.log(LoggerChannel.LT_WARNING, "NAT status is firewalled - trying to refresh UPnP mappings");
+						refreshMappings(true);
+					}
+				}
+			}
+		});
 		
 		upnp_config.addLabelParameter2( "blank.resource" );
 		
@@ -309,19 +335,30 @@ UPnPPlugin
 					model.getLogArea().appendText( error.toString()+"\n");
 				}
 			});
-		
+
+		// startup() used to be called on initializationComplete()
+		// Moved to delayed task because rootDeviceFound can take
+		// a lot of CPU cycle.  Let's hope nothing breaks
+		DelayedTask dt = plugin_interface.getUtilities().createDelayedTask(new Runnable() {
+			public void 
+			run() 
+			{
+				if ( enabled ){
+					
+					updateIgnoreList();
+					
+					startUp();			
+				}
+			}
+		});
+		dt.queue();
+
 		plugin_interface.addListener(
 				new PluginListener()
 				{
 					public void
 					initializationComplete()
 					{	
-						if ( enabled ){
-							
-							updateIgnoreList();
-							
-							startUp();			
-						}
 					}
 					
 					public void
@@ -820,7 +857,7 @@ UPnPPlugin
 				
 					root_info_map.put( device.getLocation(), device.getInfo());
 				
-					Iterator	it = root_info_map.values().iterator();
+					Iterator<String>	it = root_info_map.values().iterator();
 					
 					String	all_info = "";
 						
@@ -1361,6 +1398,34 @@ UPnPPlugin
 		}
 	}
 	
+	public UPnPPluginService[]
+	getServices(
+		UPnPDevice	device )
+	{
+		String	target_usn = device.getRootDevice().getUSN();
+		
+		List<UPnPPluginService> res = new ArrayList<UPnPPluginService>();
+		
+		try{
+			this_mon.enter();
+						
+			for ( UPnPPluginService service: services ){
+				
+				String	this_usn = service.getService().getGenericService().getDevice().getRootDevice().getUSN();
+				
+				if ( this_usn.equals( target_usn )){
+					
+					res.add( service );
+				}
+			}
+		}finally{
+			
+			this_mon.exit();
+		}
+		
+		return( res.toArray( new UPnPPluginService[res.size()] ));
+	}
+	
 		// for external use, e.g. webui
 	
 	public UPnPMapping
@@ -1381,6 +1446,18 @@ UPnPPlugin
 		return( mapping_manager.getMapping( tcp, port ));
 	}
 	
+	public UPnPMapping[]
+	getMappings()
+	{
+		return( mapping_manager.getMappings());
+	}
+	
+	public boolean
+	isEnabled()
+	{
+		return( upnp_enable_param.getValue());
+	}
+	
 	protected void
 	setNATPMPEnableState()
 	{
@@ -1444,6 +1521,19 @@ UPnPPlugin
 	 * Provided for use by other plugins.
 	 */
 	public void refreshMappings() {
-		this.upnp.reset();
+		refreshMappings(false);
+	}
+
+	/**
+	 * Provided for use by other plugins.
+	 */
+	public void refreshMappings(boolean force) {
+		if (force) {
+			closeDown(true);
+			startUp();
+		}
+		else {
+			this.upnp.reset();
+		}
 	}
 }
