@@ -19,6 +19,7 @@
  */
 package com.aelitis.azureus.ui;
 
+
 /**
  * @author TuxPaper
  * @created May 29, 2006
@@ -26,12 +27,57 @@ package com.aelitis.azureus.ui;
  */
 public interface IUIIntializer
 {
-	public void stopIt(boolean isForRestart, boolean isCloseAreadyInPorgress);
+	public void stopIt(boolean isForRestart, boolean isCloseAreadyInProgress);
+
+	public void run();
 
 	/**
-	 * @param swtThread TODO
-	 * @param thread 
+	 * Add a listener that gets triggered on progress changes (tasks, percent)
 	 * 
+	 * @param listener
+	 *
+	 * @since 3.0.1.3
 	 */
-	public void run();
+	public void addListener(InitializerListener listener);
+
+	/**
+	 * Remove listener that gets triggered on progress changes (tasks, percent)
+	 * 
+	 * @param listener
+	 *
+	 * @since 3.0.1.3
+	 */
+	public void removeListener(InitializerListener listener);
+
+	/**
+	 * 
+	 *
+	 * @since 3.0.4.3
+	 */
+	void increaseProgress();
+	
+	/**
+	 *
+	 * @since 3.0.4.3
+	 */
+	void abortProgress();
+
+	/**
+	 * @param currentTaskString
+	 *
+	 * @since 3.0.4.3
+	 */
+	void reportCurrentTask(String currentTaskString);
+	
+	void reportPercent(int percent);
+	
+	void initializationComplete();
+
+	/**
+	 * Code that will be executed in the SWT Thread before {@link #run()} is
+	 * invoked
+	 * 
+	 * @since 4.2.0.1
+	 */
+	public void runInSWTThread();
 }
