@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA 
  */
- 
+
 package com.aelitis.azureus.ui.selectedcontent;
 
 /**
@@ -25,5 +25,6 @@ package com.aelitis.azureus.ui.selectedcontent;
  */
 public interface SelectedContentListener
 {
-	public void currentlySectedContentChanged(ISelectedContent[] currentContent);
+	public void currentlySelectedContentChanged(
+			ISelectedContent[] currentContent, String viewID);
 }
