@@ -19,7 +19,8 @@
  */
 package com.aelitis.azureus.ui.skin;
 
-import java.util.Properties;
+import java.util.ResourceBundle;
+
 
 /**
  * Interface for reading Skin properties (might be better)
@@ -36,7 +37,7 @@ public interface SkinProperties
 	 * 
 	 * @return all the properties
 	 */
-	Properties getProperties();
+	//Properties getProperties();
 
 	/**
 	 * Add a property key/value pair to the list
@@ -76,4 +77,41 @@ public interface SkinProperties
 	int[] getColorValue(String name);
 
 	boolean getBooleanValue(String name, boolean def);
-}
\ No newline at end of file
+
+	/**
+	 * 
+	 *
+	 * @since 3.1.1.1
+	 */
+	void clearCache();
+
+	/**
+	 * @param name
+	 * @return
+	 *
+	 * @since 3.1.1.1
+	 */
+	boolean hasKey(String name);
+
+	/**
+	 * @param name
+	 * @return
+	 *
+	 * @since 3.1.1.1
+	 */
+	String getReferenceID(String name);
+
+	/**
+	 * @param subBundle
+	 *
+	 * @since 4.0.0.5
+	 */
+	void addResourceBundle(ResourceBundle subBundle);
+
+	/**
+	 * @return
+	 *
+	 * @since 4.0.0.5
+	 */
+	ClassLoader getClassLoader();
+}
