@@ -40,12 +40,15 @@ import org.gudy.azureus2.plugins.utils.StaticUtilities;
 import org.gudy.azureus2.plugins.utils.resourcedownloader.ResourceDownloader;
 import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 import org.gudy.azureus2.ui.swt.Utils;
+import org.gudy.azureus2.ui.swt.components.shell.ShellFactory;
+import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 
 import com.aelitis.azureus.core.messenger.ClientMessageContextImpl;
+import com.aelitis.azureus.core.messenger.browser.BrowserMessage;
 import com.aelitis.azureus.core.messenger.browser.listeners.BrowserMessageListener;
 import com.aelitis.azureus.core.vuzefile.VuzeFile;
 import com.aelitis.azureus.core.vuzefile.VuzeFileHandler;
-import com.aelitis.azureus.plugins.net.netstatus.swt.NetStatusPluginTester.loggerProvider;
 import com.aelitis.azureus.ui.swt.browser.msg.MessageDispatcherSWT;
 import com.aelitis.azureus.util.ConstantsVuze;
 import com.aelitis.azureus.util.JSONUtils;
@@ -53,7 +56,7 @@ import com.aelitis.azureus.util.UrlFilter;
 
 /**
  * Manages the context for a single SWT {@link Browser} component,
- * including transactions, listeners and messages.
+ * including listeners and messages.
  * 
  * @author dharkness
  * @created Jul 19, 2006
@@ -84,7 +87,7 @@ public class BrowserContext
 	
 	private MessageDispatcherSWT messageDispatcherSWT;
 
-	protected boolean wiggleBrowser = org.gudy.azureus2.core3.util.Constants.isOSX;
+	protected boolean wiggleBrowser = Utils.isCarbon;
 
 	private torrentURLHandler		torrentURLHandler;
 
@@ -193,7 +196,7 @@ public class BrowserContext
 				/*
 				 * The browser might have been disposed already by the time this method is called 
 				 */
-				if(true == browser.isDisposed()){
+				if (browser.isDisposed() || browser.getShell().isDisposed()) {
 					return;
 				}
 				
@@ -217,7 +220,7 @@ public class BrowserContext
 				/*
 				 * The browser might have been disposed already by the time this method is called 
 				 */
-				if(true == browser.isDisposed()){
+				if (browser.isDisposed() || browser.getShell().isDisposed()) {
 					return;
 				}
 				
@@ -259,10 +262,13 @@ public class BrowserContext
 		
 		browser.addOpenWindowListener(new OpenWindowListener() {
 			public void open(WindowEvent event) {
+				if (browser.isDisposed() || browser.getShell().isDisposed()) {
+					return;
+				}
 				event.required = true;
 				
 				if (browser.getUrl().contains("js.debug=1")) {
-  				Shell shell = new Shell(Utils.findAnyShell(), SWT.SHELL_TRIM);
+  				Shell shell = ShellFactory.createMainShell(SWT.SHELL_TRIM);
   				shell.setLayout(new FillLayout());
 					Browser subBrowser = new Browser(shell,
 							Utils.getInitialBrowserStyle(SWT.NONE));
@@ -302,6 +308,9 @@ public class BrowserContext
 			private TimerEvent timerevent;
 
 			public void changed(LocationEvent event) {
+				if (browser.isDisposed() || browser.getShell().isDisposed()) {
+					return;
+				}
 				debug("browser.changed " + event.location);
 				if (timerevent != null) {
 					timerevent.cancel();
@@ -316,8 +325,9 @@ public class BrowserContext
 				if (!event.top) {
 					return;
 				}
-				boolean isWebURL = event.location.startsWith("http://")
-						|| event.location.startsWith("https://");
+				String location = event.location.toLowerCase();
+				boolean isWebURL = location.startsWith("http://")
+						|| location.startsWith("https://");
 				if (!isWebURL) {
 					if (event.location.startsWith("res://")) {
 						fillWithRetry(event.location, "top changed");
@@ -338,8 +348,7 @@ public class BrowserContext
 				/*
 				 * The browser might have been disposed already by the time this method is called 
 				 */
-				
-				if ( browser.isDisposed()){
+				if (browser.isDisposed() || browser.getShell().isDisposed()) {
 					return;
 				}
 				
@@ -357,8 +366,20 @@ public class BrowserContext
 					return;
 				}
 
-				boolean isWebURL = event_location.startsWith("http://")
-						|| event_location.startsWith("https://");
+				
+				String lowerLocation = event_location.toLowerCase();
+				boolean isOurURI = lowerLocation.startsWith("magnet:")
+						|| lowerLocation.startsWith("vuze:")
+						|| lowerLocation.startsWith("dht:");
+
+				if (isOurURI) {
+					event.doit = false;
+					TorrentOpener.openTorrent(event_location);
+					return;
+				}
+
+				boolean isWebURL = lowerLocation.startsWith("http://")
+						|| lowerLocation.startsWith("https://");
 				if (!isWebURL) {
 					// we don't get a changed state on non URLs (mailto, javascript, etc)
 					return;
@@ -368,8 +389,8 @@ public class BrowserContext
 
 				if (blocked) {
 					event.doit = false;
-					Utils.openMessageBox(Utils.findAnyShell(), SWT.OK, "URL blocked",
-							"Tried to open " + event_location + " but it's blocked");
+					new MessageBoxShell(SWT.OK, "URL blocked", "Tried to open "
+							+ event_location + " but it's blocked").open(null);
 					browser.back();
 				} else {
 					if (UrlFilter.getInstance().isWhitelisted(event_location)) {
@@ -647,10 +668,12 @@ public class BrowserContext
 		}
 
 		// System.out.println( "Unregistered browser context: id=" + getID());
-	
-		browser.setData(CONTEXT_KEY, null);
-		browser.removeDisposeListener(this);
-		messageDispatcherSWT.deregisterBrowser(browser);
+
+		if (!browser.isDisposed()) {
+  		browser.setData(CONTEXT_KEY, null);
+  		browser.removeDisposeListener(this);
+  		messageDispatcherSWT.deregisterBrowser(browser);
+		}
 		browser = null;
 
 		if (checkURLEvent != null && !checkURLEvent.isCancelled()) {
