@@ -8,7 +8,15 @@ import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.widgets.Display;
 
+import org.gudy.azureus2.core3.download.DownloadManager;
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+import org.gudy.azureus2.core3.torrent.TOTorrentFactory;
 import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.plugins.PluginInterface;
+import org.gudy.azureus2.plugins.PluginManager;
+import org.gudy.azureus2.plugins.ui.UIInstance;
+import org.gudy.azureus2.plugins.ui.UIManager;
+import org.gudy.azureus2.plugins.ui.UIManagerListener;
 import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.donations.DonationWindow;
@@ -21,24 +29,19 @@ import com.aelitis.azureus.core.messenger.browser.BrowserMessage;
 import com.aelitis.azureus.core.messenger.browser.listeners.AbstractBrowserMessageListener;
 import com.aelitis.azureus.core.subs.Subscription;
 import com.aelitis.azureus.core.subs.SubscriptionManagerFactory;
+import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
 import com.aelitis.azureus.ui.selectedcontent.*;
 import com.aelitis.azureus.ui.swt.shells.BrowserWindow;
 import com.aelitis.azureus.ui.swt.skin.*;
-import com.aelitis.azureus.ui.swt.views.skin.FriendsToolbar;
 import com.aelitis.azureus.ui.swt.views.skin.SkinViewManager;
 import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBar;
 import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarEntrySWT;
 import com.aelitis.azureus.util.ContentNetworkUtils;
+import com.aelitis.azureus.util.JSONUtils;
 import com.aelitis.azureus.util.MapUtils;
 
-import org.gudy.azureus2.plugins.PluginInterface;
-import org.gudy.azureus2.plugins.PluginManager;
-import org.gudy.azureus2.plugins.ui.UIInstance;
-import org.gudy.azureus2.plugins.ui.UIManager;
-import org.gudy.azureus2.plugins.ui.UIManagerListener;
-
 public class DisplayListener
 	extends AbstractBrowserMessageListener
 {
@@ -63,13 +66,11 @@ public class DisplayListener
 
 	public static final String VZ_NON_ACTIVE = "vz-non-active";
 
-	public static final String OP_INVITE_FRIEND = "invite";
-
 	public static final String OP_SET_SELECTED_CONTENT = "set-selected-content";
 
-	public static final String OP_SHOW_DONATION_WINDOW = "show-donation-window";
+	public static final String OP_GET_SELECTED_CONTENT = "get-selected-content";
 
-	public static final String OP_INVITE_FRIEND_PARAM_MESSAGE = "message";
+	public static final String OP_SHOW_DONATION_WINDOW = "show-donation-window";
 
 	public static final String OP_OPEN_SEARCH = "open-search";
 
@@ -100,7 +101,7 @@ public class DisplayListener
 				launchUrl(MapUtils.getMapString(decodedMap, "url", null));
 			} else {
 				String ref = message.getReferer();
-				if (target.equals("browse") && ref != null) {
+				if (target != null && target.equals("browse") && ref != null) {
 					ContentNetwork cn = ContentNetworkManagerFactory.getSingleton().getContentNetworkForURL(
 							ref);
 					if (cn != null) {
@@ -171,21 +172,16 @@ public class DisplayListener
 		} else if (OP_REFRESH_TAB.equals(opid)) {
 			Map decodedMap = message.getDecodedMap();
 			refreshTab(MapUtils.getMapString(decodedMap, "browser-id", ""));
-		} else if (OP_INVITE_FRIEND.equals(opid)) {
-			Map decodedMap = message.getDecodedMap();
-			FriendsToolbar friendsToolbar = (FriendsToolbar) SkinViewManager.getByClass(FriendsToolbar.class);
-			if(friendsToolbar != null) {
-				friendsToolbar.addBuddy(MapUtils.getMapString(decodedMap, OP_INVITE_FRIEND_PARAM_MESSAGE,	null));
-			}
-			
-//			VuzeFriendUtils.getInstance().invite(
-//					MapUtils.getMapString(decodedMap, OP_INVITE_FRIEND_PARAM_MESSAGE,
-//							null));
 		} else if (OP_SET_SELECTED_CONTENT.equals(opid)) {
 			Map decodedMap = message.getDecodedMap();
 			if (decodedMap != null) {
 				setSelectedContent(message, decodedMap);
 			}
+		} else if (OP_GET_SELECTED_CONTENT.equals(opid)) {
+			Map decodedMap = message.getDecodedMap();
+			if (decodedMap != null) {
+				getSelectedContent(message, decodedMap);
+			}
 		} else if (OP_SHOW_DONATION_WINDOW.equals(opid)) {
 			Map decodedMap = message.getDecodedMap();
 			DonationWindow.open(true, MapUtils.getMapString(decodedMap, "source-ref",
@@ -201,6 +197,51 @@ public class DisplayListener
 		}
 	}
 
+	private void getSelectedContent(BrowserMessage message, Map decodedMap) {
+		String callback = MapUtils.getMapString(decodedMap, "callback", null);
+		if (callback == null) {
+			return;
+		}
+		
+		List<Map> list = new ArrayList<Map>();
+		
+		DownloadManager[] dms = SelectedContentManager.getDMSFromSelectedContent();
+		for (DownloadManager dm : dms) {
+			if (dm != null) {
+				Map<String, Object> mapDM = new HashMap<String, Object>();
+				TOTorrent torrent = dm.getTorrent();
+				if (torrent != null && !TorrentUtils.isReallyPrivate(torrent)) {
+					try {
+  					// make a copy of the torrent
+  
+  					Map torrent_map = torrent.serialiseToMap();
+  					TOTorrent torrent_to_send = TOTorrentFactory.deserialiseFromMap( torrent_map );
+  					Map	vuze_map = (Map)torrent_map.get( "vuze" );
+  					// remove any non-standard stuff (e.g. resume data)
+  					torrent_to_send.removeAdditionalProperties();
+  					torrent_map = torrent_to_send.serialiseToMap();
+  					if ( vuze_map != null ){
+  						torrent_map.put( "vuze", vuze_map );
+  					}
+  					
+  					byte[] encode = BEncoder.encode(torrent_map);
+  					
+  					mapDM.put("name", PlatformTorrentUtils.getContentTitle2(dm));
+  					mapDM.put("torrent", Base32.encode(encode));
+  					
+  					list.add(mapDM);
+					} catch (Throwable t) {
+						Debug.out(t);
+					}
+				}
+			}
+		}
+		
+		if (list.size() > 0 && context != null) {
+			context.executeInBrowser(callback + "(" + JSONUtils.encodeToJSON(list) + ")");
+		}
+	}
+
 	/**
 	 * @param message 
 	 * @param decodedMap
