@@ -46,7 +46,6 @@ import com.aelitis.azureus.core.AzureusCoreFactory;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
 import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
 import com.aelitis.azureus.core.custom.CustomizationManagerFactory;
-import com.aelitis.azureus.core.impl.AzureusCoreImpl;
 import com.aelitis.azureus.core.messenger.browser.BrowserMessage;
 import com.aelitis.azureus.core.messenger.browser.listeners.AbstractBrowserMessageListener;
 import com.aelitis.azureus.core.metasearch.*;
@@ -77,6 +76,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 		
 	public static final String OP_GET_ENGINES 			= "get-engines";
 	public static final String OP_GET_ALL_ENGINES 		= "get-all-engines";
+	public static final String OP_ENGINE_PREFERRED		= "engine-preferred";
 
 	public static final String OP_CHANGE_ENGINE_SELECTION 	= "change-engine-selection";
 	
@@ -253,6 +253,19 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 
 			search( decodedMap, null );
 
+		}else if ( OP_ENGINE_PREFERRED.equals( opid )){
+			
+			final Map decodedMap = message.getDecodedMap();
+			
+			long engine_id = ((Long)decodedMap.get("engine_id")).longValue();
+
+			Engine engine = getEngineFromId( engine_id );
+
+			if ( engine != null ){
+				
+				metaSearchManager.getMetaSearch().enginePreferred( engine );
+			}
+
 		} else if(OP_ENGINE_LOGIN.equals(opid)) {
 			
 			final Map decodedMap = message.getDecodedMap();
@@ -434,11 +447,9 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			String subscriptionId  = null;
 			
 			try {
-				if(message.isParamObject()) {
-					final Map decodedMap = message.getDecodedMap();
+				final Map decodedMap = message.getDecodedMap();
 
-					subscriptionId		= ((String)decodedMap.get("subs_id"));
-				}
+				subscriptionId		= ((String)decodedMap.get("subs_id"));
 			} catch(Exception e) {
 				//No parameters
 			}
@@ -1059,17 +1070,14 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 				});
 		}else if ( OP_OPEN_SEARCH_RESULTS.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap()
-					: new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			openCloseSearchDetailsListener.openSearchResults(decodedMap);
 		}else if ( OP_CLOSE_SEARCH_RESULTS.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap()
-					: new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			openCloseSearchDetailsListener.closeSearchResults(decodedMap);
 		}else if(OP_LOAD_TORRENT.equals(opid)) {
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap()
-					: new HashMap();			
+			Map decodedMap = message.getDecodedMap();
 			
 			String torrentUrl		= (String) decodedMap.get( "torrent_url" );
 			String referer_str	= (String) decodedMap.get( "referer_url" );
@@ -1177,7 +1185,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			
 		}else if(OP_CREATE_SUBSCRIPTION.equals(opid)) {
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			Long	 tid = (Long) decodedMap.get("tid");
 
@@ -1221,7 +1229,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			}
 		}else if( OP_READ_SUBSCRIPTION.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			final Long	 tid = (Long) decodedMap.get("tid");
 
@@ -1290,7 +1298,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			}
 		}else if (OP_UPDATE_SUBSCRIPTION.equals(opid)) {
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			final Long	 tid = (Long) decodedMap.get("tid");
 			
@@ -1360,7 +1368,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			
 		}else if (OP_SUBSCRIPTION_SET_AUTODL.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			String 	sid = (String)decodedMap.get("id");
 			
@@ -1396,7 +1404,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			
 		}else if(OP_READ_SUBSCRIPTION_RESULTS.equals(opid)) {
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			final Long	 tid = (Long) decodedMap.get("tid");
 			
@@ -1472,7 +1480,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			}
 		}else if( OP_DELETE_SUBSCRIPTION_RESULTS.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 						
 			String sid = (String)decodedMap.get("id");
 			
@@ -1511,7 +1519,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			}
 		}else if( OP_MARK_SUBSCRIPTION_RESULTS.equals(opid)){
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 						
 			String sid = (String)decodedMap.get("id");
 			
@@ -1555,7 +1563,7 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 			}
 		}else if( OP_DOWNLOAD_SUBSCRIPTION.equals(opid)) {
 			
-			Map decodedMap = message.isParamObject() ? message.getDecodedMap():new HashMap();
+			Map decodedMap = message.getDecodedMap();
 			
 			final Long	 tid = (Long) decodedMap.get("tid");
 
@@ -1941,6 +1949,10 @@ public class MetaSearchListener extends AbstractBrowserMessageListener {
 		
 		context.put( Engine.SC_FORCE_FULL, "true" );
 		
+		context.put( Engine.SC_BATCH_PERIOD, "1000" );
+		
+		context.put( Engine.SC_REMOVE_DUP_HASH, "true" );
+		
 		if ( target == null ){
 		
 			metaSearchManager.getMetaSearch().search( listener, parameters, headers, context, max_per_engine );
