@@ -24,16 +24,15 @@ package com.aelitis.azureus.ui.swt.content;
 
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 
 import org.eclipse.swt.widgets.TreeItem;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.util.AERunnable;
+import org.gudy.azureus2.core3.util.AsyncDispatcher;
 import org.gudy.azureus2.core3.util.ByteArrayHashMap;
 import org.gudy.azureus2.core3.util.ByteFormatter;
-import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.plugins.PluginInterface;
 import org.gudy.azureus2.plugins.download.Download;
@@ -82,8 +81,19 @@ import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarEntrySWT;
 
 public class 
 RelatedContentUI 
-{	
-	private static final boolean	DISABLE_ALL_UI	= !Constants.isCVSVersion();
+{		
+	private static RelatedContentUI	singleton;
+	
+	public static synchronized RelatedContentUI
+	getSingleton()
+	{
+		if ( singleton == null ){
+			
+			singleton = new RelatedContentUI();
+		}
+		
+		return( singleton );
+	}
 	
 	private PluginInterface		plugin_interface;
 	private UIManager			ui_manager;
@@ -98,6 +108,8 @@ RelatedContentUI
 	
 	private ByteArrayHashMap<RCMItem>	rcm_item_map = new ByteArrayHashMap<RCMItem>();
 	
+	private AsyncDispatcher	async_dispatcher = new AsyncDispatcher();
+	
 	public 
 	RelatedContentUI()
 	{
@@ -192,7 +204,7 @@ RelatedContentUI
 		try{	
 			manager 	= RelatedContentManager.getSingleton();
 
-			if ( DISABLE_ALL_UI || !manager.isEnabled()){
+			if ( !manager.isUIEnabled()){
 				
 				return;
 			}
@@ -424,6 +436,8 @@ RelatedContentUI
 							main_view_info.getTitle(),
 							main_view_info, null, false, index  );
 					
+					main_sb_entry.setImageLeftID( "image.sidebar.rcm" );
+					
 					main_sb_entry.setDatasource(
 						new RelatedContentEnumerator()
 						{
@@ -570,23 +584,31 @@ RelatedContentUI
 	protected void
 	addSearch(
 		final Download		download )
+	{
+		Torrent	torrent = download.getTorrent();
+		
+		if ( torrent == null ){
+			
+			return;
+		}
+		
+		final byte[] hash = torrent.getHash();
+		
+		addSearch( hash, download.getName());
+	}
+	
+	protected void
+	addSearch(
+		final byte[]		hash,
+		final String		name )
 	{
 		synchronized( this ){
-				
-			Torrent	torrent = download.getTorrent();
-			
-			if ( torrent == null ){
-				
-				return;
-			}
-			
-			final byte[] hash = torrent.getHash();
 			
 			final RCMItem existing_si = rcm_item_map.get( hash );
 			
 			if (  existing_si == null ){
 	
-				final RCMItem new_si = new RCMItem( download, hash );
+				final RCMItem new_si = new RCMItem( hash );
 				
 				rcm_item_map.put( hash, new_si );
 				
@@ -603,7 +625,7 @@ RelatedContentUI
 									return;
 								}
 								
-								RCMView view = new RCMView( SideBar.SIDEBAR_SECTION_RELATED_CONTENT, download );
+								RCMView view = new RCMView( SideBar.SIDEBAR_SECTION_RELATED_CONTENT, name );
 								
 								new_si.setView( view );
 								
@@ -715,17 +737,17 @@ RelatedContentUI
 		implements 	ViewTitleInfo
 	{
 		private String			parent_key;
-		private Download		download;
+		private String			name;
 		
 		private int				num_unread;
 		
 		protected
 		RCMView(
 			String			_parent_key,
-			Download		_download )
+			String			_name )
 		{
 			parent_key	= _parent_key;
-			download	= _download;
+			name		= _name;
 		}
 		
 		public Object 
@@ -753,7 +775,7 @@ RelatedContentUI
 		public String
 		getTitle()
 		{
-			return( download.getName());
+			return( name );
 		}
 		
 		protected void
@@ -797,7 +819,6 @@ RelatedContentUI
 	RCMItem
 		implements RelatedContentEnumerator, SideBarCloseListener
 	{	
-		private Download			download;
 		private byte[]				hash;
 		
 		private RCMView				view;
@@ -817,10 +838,8 @@ RelatedContentUI
 		
 		protected
 		RCMItem(
-			Download	_download,
 			byte[]		_hash )
 		{
-			download	= _download;
 			hash		= _hash;
 		}
 		
@@ -842,7 +861,7 @@ RelatedContentUI
 				showIcon( spinner, null );
 				
 				manager.lookupContent(
-					download,
+					hash,
 					new RelatedContentLookupListener()
 					{
 						public void
@@ -860,7 +879,10 @@ RelatedContentUI
 								
 									for ( RelatedContent c: content ){
 									
-										content_list.add( c );
+										if ( !content_list.contains( c )){
+										
+											content_list.add( c );
+										}
 									}
 								}
 							}
@@ -914,23 +936,12 @@ RelatedContentUI
 			boolean deleted = false;
 			
 			synchronized( RCMItem.this ){
-				
-				Iterator<RelatedContent> it = content_list.iterator();
-				
-				while( it.hasNext()){
-					
-					RelatedContent rc = it.next();
-					
-					for ( RelatedContent x: content ){
+									
+				for ( RelatedContent c: content ){
 						
-						if ( x == rc ){
-							
-							it.remove();
-							
-							deleted = true;
-							
-							break;
-						}
+					if ( content_list.remove( c )){
+														
+						deleted = true;
 					}
 				}
 			}
@@ -944,8 +955,6 @@ RelatedContentUI
 		protected void
 		updateNumUnread()
 		{
-			boolean	changed = false;
-			
 			synchronized( RCMItem.this ){
 				
 				int	num = 0;
@@ -962,14 +971,24 @@ RelatedContentUI
 					
 					num_unread = num;
 					
-					changed = true;
+					final int f_num = num;
+										
+					async_dispatcher.dispatch(
+						new AERunnable()
+						{
+							public void
+							runSupport()
+							{
+								if ( async_dispatcher.getQueueSize() > 0 ){
+									
+									return;
+								}
+								
+								view.setNumUnread( f_num );
+							}
+						});
 				}
 			}
-			
-			if ( changed ){
-				
-				view.setNumUnread( num_unread );
-			}
 		}
 		
 		public void
