@@ -23,18 +23,26 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Set;
+import java.util.regex.Pattern;
 
 import org.eclipse.swt.SWT;
 
+import org.eclipse.swt.custom.CLabel;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.KeyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.layout.FormAttachment;
+import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.*;
 
 import org.gudy.azureus2.core3.internat.MessageText;
+import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.UrlUtils;
+
+import org.gudy.azureus2.core3.util.TorrentUtils;
 import org.gudy.azureus2.plugins.ui.UIManager;
 import org.gudy.azureus2.plugins.ui.tables.TableColumn;
 import org.gudy.azureus2.plugins.ui.tables.TableColumnCreationListener;
@@ -42,7 +50,7 @@ import org.gudy.azureus2.plugins.ui.tables.TableManager;
 import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 import org.gudy.azureus2.ui.swt.*;
 
-import org.gudy.azureus2.ui.swt.views.table.TableViewSWTMenuFillListener;
+import org.gudy.azureus2.ui.swt.views.table.*;
 import org.gudy.azureus2.ui.swt.views.table.impl.TableViewSWTImpl;
 
 import com.aelitis.azureus.core.AzureusCore;
@@ -55,8 +63,13 @@ import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
 import com.aelitis.azureus.ui.common.table.*;
 import com.aelitis.azureus.ui.common.updater.UIUpdatable;
+import com.aelitis.azureus.ui.selectedcontent.DownloadUrlInfo;
+import com.aelitis.azureus.ui.selectedcontent.ISelectedContent;
+import com.aelitis.azureus.ui.selectedcontent.SelectedContentManager;
 import com.aelitis.azureus.ui.swt.content.columns.*;
 import com.aelitis.azureus.ui.swt.skin.SWTSkinObject;
+import com.aelitis.azureus.ui.swt.skin.SWTSkinObjectContainer;
+import com.aelitis.azureus.ui.swt.toolbar.ToolBarEnablerSelectedContent;
 import com.aelitis.azureus.ui.swt.views.skin.SkinView;
 import com.aelitis.azureus.ui.swt.views.skin.SkinViewManager;
 import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBar;
@@ -66,7 +79,7 @@ import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarEntrySWT;
 public class 
 SBC_RCMView
 	extends SkinView
-	implements UIUpdatable, IconBarEnabler
+	implements UIUpdatable, IconBarEnabler, TableViewFilterCheck<RelatedContent>
 {
 	public static final String TABLE_RCM = "RCM";
 
@@ -84,11 +97,14 @@ SBC_RCMView
 		}
 	}
 	
-	private TableViewSWTImpl<RelatedContent> tv_related_content;
+	private TableViewSWT<RelatedContent> tv_related_content;
 
 	private SideBarEntrySWT 	sidebar_entry;
 	private Composite			table_parent;
+	private boolean				space_reserved;
 	
+	
+	private Text txtFilter;
 
 	public Object 
 	skinObjectInitialShow(
@@ -113,8 +129,35 @@ SBC_RCMView
 			sidebar_entry = sidebar.getCurrentEntry();
 			
 			sidebar_entry.setIconBarEnabler(this);
-		}
+
+			if ( !sidebar_entry.getId().equals( SideBar.SIDEBAR_SECTION_RELATED_CONTENT )){
 		
+				manager.reserveTemporarySpace();
+				
+				space_reserved = true;
+			}
+		}
+
+		SWTSkinObject soFilterArea = getSkinObject("filterarea");
+		if (soFilterArea != null) {
+			Composite parent = (Composite) soFilterArea.getControl();
+			FormData fd;
+			CLabel lblFilter = new CLabel(parent, SWT.CENTER);
+			Messages.setLanguageText(lblFilter, "MyTorrentsView.filter");
+			fd = Utils.getFilledFormData();
+			fd.right = null;
+			lblFilter.setLayoutData(fd);
+
+			txtFilter = new Text(parent, SWT.BORDER);
+			fd = new FormData();
+			fd.left = new FormAttachment(lblFilter, 10);
+			fd.top = new FormAttachment(lblFilter, 0, SWT.CENTER);
+			fd.right = new FormAttachment(100, -10);
+			txtFilter.setLayoutData(fd);
+			
+			parent.layout(true);
+		}
+
 		return null;
 	}
 
@@ -209,6 +252,34 @@ SBC_RCMView
 						}
 					});
 		
+		tableManager.registerColumn(
+				RelatedContent.class, 
+				ColumnRC_Created.COLUMN_ID,
+					new TableColumnCreationListener() {
+						public void tableColumnCreated(TableColumn column) {
+							new ColumnRC_Created(column);
+						}
+					});
+		tableManager.registerColumn(
+				RelatedContent.class, 
+				ColumnRC_Seeds.COLUMN_ID,
+					new TableColumnCreationListener() {
+						public void tableColumnCreated(TableColumn column) {
+							new ColumnRC_Seeds(column);
+						}
+					});
+
+		tableManager.registerColumn(
+				RelatedContent.class, 
+				ColumnRC_Peers.COLUMN_ID,
+					new TableColumnCreationListener() {
+						public void tableColumnCreated(TableColumn column) {
+							new ColumnRC_Peers(column);
+						}
+					});
+
+		
+		
 		tableManager.registerColumn(
 				RelatedContent.class, 
 				ColumnRC_LastSeen.COLUMN_ID,
@@ -277,6 +348,11 @@ SBC_RCMView
 			table_parent,
 		});
 
+		if ( space_reserved ){
+		
+			manager.releaseTemporarySpace();
+		}
+		
 		return( super.skinObjectDestroyed(skinObject, params));
 	}
 	
@@ -284,18 +360,24 @@ SBC_RCMView
 	initTable(
 		Composite control ) 
 	{
-
-		tv_related_content = 
-			new TableViewSWTImpl<RelatedContent>(
-					RelatedContent.class, 
-					TABLE_RCM,
-					TABLE_RCM, 
-					new TableColumnCore[0], 
-					ColumnRC_New.COLUMN_ID, 
-					SWT.MULTI | SWT.FULL_SELECTION | SWT.VIRTUAL );
-		
+		tv_related_content = new TableViewSWTImpl<RelatedContent>(
+				RelatedContent.class, 
+				TABLE_RCM,
+				TABLE_RCM, 
+				new TableColumnCore[0], 
+				ColumnRC_New.COLUMN_ID, 
+				SWT.MULTI | SWT.FULL_SELECTION | SWT.VIRTUAL );
+		if (txtFilter != null) {
+			tv_related_content.enableFilterCheck(txtFilter, this);
+		}
 		tv_related_content.setRowDefaultHeight(16);
-		tv_related_content.setHeaderVisible(true);
+		SWTSkinObject soSizeSlider = getSkinObject("table-size-slider");
+		if (soSizeSlider instanceof SWTSkinObjectContainer) {
+			SWTSkinObjectContainer so = (SWTSkinObjectContainer) soSizeSlider;
+			if (!tv_related_content.enableSizeSlider(so.getComposite(), 16, 100)) {
+				so.setVisible(false);
+			}
+		}
 		
 		table_parent = new Composite(control, SWT.NONE);
 		table_parent.setLayoutData(Utils.getFilledFormData());
@@ -305,7 +387,34 @@ SBC_RCMView
 
 		tv_related_content.addSelectionListener(new TableSelectionListener() {
 
-			public void selected(TableRowCore[] row) {
+			public void 
+			selected(
+				TableRowCore[] rows) 
+			{				
+				ArrayList<ISelectedContent>	valid = new ArrayList<ISelectedContent>();
+				
+				for (int i=0;i<rows.length;i++){
+					
+					final RelatedContent rc = (RelatedContent)rows[i].getDataSource();
+					
+					if ( rc.getHash() != null ){
+
+						valid.add(
+							new ToolBarEnablerSelectedContent( SBC_RCMView.this )
+							{
+								public DownloadUrlInfo 
+								getDownloadInfo() 
+								{
+									return(	new DownloadUrlInfo( UrlUtils.getMagnetURI( rc.getHash())));
+								}
+							});
+					}
+				}
+				
+				ISelectedContent[] sels = valid.toArray( new ISelectedContent[valid.size()] );
+				
+				SelectedContentManager.changeCurrentlySelectedContent( "IconBarEnabler", sels, null );
+				
 				UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
 				if (uiFunctions != null) {
 					uiFunctions.refreshIconBar();
@@ -341,140 +450,123 @@ SBC_RCMView
 			{
 				private Set<RelatedContent>	content_set = new HashSet<RelatedContent>();
 				
-				private boolean destroyed;
+				private int liveness_marker;
+				
+				private RelatedContentManagerListener current_rcm_listener;
 				
-				private RelatedContentManagerListener rcm_listener = 
-					new RelatedContentManagerListener()
-					{
-						public void
-						contentFound(
-							RelatedContent[]	content )
-						{							
-						}
-
-						public void
-						contentChanged(
-							RelatedContent[]	content )
-						{
-							boolean	hit = false;
-
-							synchronized( content_set ){
-								
-								if ( destroyed ){
-									
-									return;
-								}							
-							
-								for ( RelatedContent c: content ){
-
-									if ( content_set.contains( c )){
-								
-										hit = true;
-									}
-								}
-							}
-							
-							if ( hit ){
-								
-								Utils.execSWTThread(
-										new Runnable()
-										{
-											public void
-											run()
-											{
-												if ( tv_related_content != null && !tv_related_content.isDisposed()){
-													
-													tv_related_content.refreshTable( false );
-												}
-											}
-										});
-							}
-						}
-						
-						public void 
-						contentRemoved(
-							final RelatedContent[] content )
-						{
-							final java.util.List<RelatedContent> hits = new ArrayList<RelatedContent>( content.length );
-							
-							synchronized( content_set ){
-								
-								if ( destroyed ){
-									
-									return;
-								}
-							
-								for ( RelatedContent c: content ){
-								
-									if ( content_set.remove( c )){
-								
-										hits.add( c );
-									}
-								}
-							}
-							
-							if ( hits.size() > 0 ){
-								
-								Utils.execSWTThread(
-										new Runnable()
-										{
-											public void
-											run()
-											{
-												if ( tv_related_content != null && !tv_related_content.isDisposed()){
-													
-													tv_related_content.removeDataSources( hits.toArray( new RelatedContent[ hits.size()] ));
-												}
-											}
-										});
-							}
-						}
-						
-						public void
-						contentChanged()
-						{
-							Utils.execSWTThread(
-									new Runnable()
-									{
-										public void
-										run()
-										{
-											if ( tv_related_content != null && !tv_related_content.isDisposed()){
-												
-												tv_related_content.refreshTable( false );
-											}
-										}
-									});
-						}
-						
-						public void
-						contentReset()
-						{
-							Utils.execSWTThread(
-									new Runnable()
-									{
-										public void
-										run()
-										{
-											if ( tv_related_content != null && !tv_related_content.isDisposed()){
-												
-												tv_related_content.removeAllTableRows();
-											}
-										}
-									});
-						}
-					};
 				
 				public void 
 				tableViewInitialized() 
 				{
-					manager.addListener( rcm_listener );
+					final int current_liveness_marker = ++liveness_marker;
 					
+					current_rcm_listener = 
+						new RelatedContentManagerListener()
+						{
+							public void
+							contentFound(
+								RelatedContent[]	content )
+							{							
+							}
+
+							public void
+							contentChanged(
+								RelatedContent[]	content )
+							{
+								final java.util.List<RelatedContent> hits = new ArrayList<RelatedContent>( content.length );
+
+								synchronized( content_set ){
+									
+									if ( liveness_marker != current_liveness_marker ){
+										
+										return;
+									}							
+								
+									for ( RelatedContent c: content ){
+
+										if ( content_set.contains( c )){
+									
+											hits.add( c );
+										}
+									}
+								}
+								
+								if ( hits.size() > 0 ){
+									
+									for (RelatedContent rc : hits) {
+										TableRowCore row = tv_related_content.getRow(rc);
+										if (row != null) {
+											row.refresh(true);
+										}
+									}
+								}
+							}
+							
+							public void 
+							contentRemoved(
+								final RelatedContent[] content )
+							{
+								final java.util.List<RelatedContent> hits = new ArrayList<RelatedContent>( content.length );
+								
+								synchronized( content_set ){
+									
+									if ( liveness_marker != current_liveness_marker ){
+										
+										return;
+									}
+								
+									for ( RelatedContent c: content ){
+									
+										if ( content_set.remove( c )){
+									
+											hits.add( c );
+										}
+									}
+								}
+								
+								if ( hits.size() > 0 ){
+									
+									Utils.execSWTThread(
+											new Runnable()
+											{
+												public void
+												run()
+												{
+													if ( tv_related_content != null ){
+														
+														tv_related_content.removeDataSources( hits.toArray( new RelatedContent[ hits.size()] ));
+													}
+												}
+											});
+								}
+							}
+							
+							public void
+							contentChanged()
+							{
+								if ( tv_related_content != null ){
+									
+									tv_related_content.refreshTable( false );
+								}
+							}
+							
+							public void
+							contentReset()
+							{
+								if ( tv_related_content != null ){
+									
+									tv_related_content.removeAllTableRows();
+								}
+							}
+						};
+						
+					manager.addListener( current_rcm_listener );
+				
 					Object data_source = sidebar_entry.getDatasource();
 					
 					if ( data_source instanceof RelatedContentEnumerator ){
 						
-						final TableViewSWTImpl<RelatedContent> f_table = tv_related_content;
+						final TableViewSWT<RelatedContent> f_table = tv_related_content;
 						
 						((RelatedContentEnumerator)data_source).enumerate(
 							new RelatedContentEnumerator.RelatedContentEnumeratorListener()
@@ -487,7 +579,7 @@ SBC_RCMView
 									
 									synchronized( content_set ){
 										
-										if ( destroyed ){
+										if ( liveness_marker != current_liveness_marker ){
 											
 											return;
 										}
@@ -537,11 +629,11 @@ SBC_RCMView
 												public void
 												run()
 												{
-													if ( tv_related_content == f_table && !tv_related_content.isDisposed()){
+													if ( tv_related_content == f_table ){
 													
 														synchronized( content_set ){
 															
-															if ( destroyed ){
+															if ( liveness_marker != current_liveness_marker ){
 																
 																return;
 															}
@@ -560,11 +652,11 @@ SBC_RCMView
 				public void 
 				tableViewDestroyed() 
 				{
-					manager.removeListener( rcm_listener );
-
+					manager.removeListener( current_rcm_listener );
+					
 					synchronized( content_set ){
 						
-						destroyed = true;
+						liveness_marker++;
 					
 						content_set.clear();
 					}
@@ -583,6 +675,69 @@ SBC_RCMView
 
 					System.arraycopy(_related_content, 0, related_content, 0, related_content.length);
 
+					final MenuItem assoc_item = new MenuItem(menu, SWT.PUSH);
+
+					assoc_item.setText(MessageText.getString("rcm.contextmenu.lookupassoc"));
+
+					final ArrayList<RelatedContent> assoc_ok = new ArrayList<RelatedContent>();
+					
+					for ( RelatedContent c: related_content ){
+						
+						if ( c.getHash() != null ){
+							
+							assoc_ok.add( c );
+						}
+					}
+					
+					assoc_item.addSelectionListener(new SelectionAdapter() {
+						public void widgetSelected(SelectionEvent e ){
+							
+							int	 i = 0;
+							
+							RelatedContentUI ui = RelatedContentUI.getSingleton();
+							
+							for ( RelatedContent c: assoc_ok ){
+							
+								ui.addSearch( c.getHash(), c.getTitle());
+								
+								i++;
+								
+								if ( i > 8 ){
+									
+									break;
+								}
+							}
+						};
+					});
+					
+					if ( assoc_ok.size() == 0 ){
+						
+						assoc_item.setEnabled( false );
+					}
+
+					MenuItem item = new MenuItem(menu, SWT.PUSH);
+					item.setText("gis");
+					item.addSelectionListener(new SelectionAdapter() {
+						public void widgetSelected(SelectionEvent e) {
+							String s = related_content[0].getTitle();
+							s = s.replaceAll("[-_]", " ");
+							Utils.launch("http://images.google.com/images?q=" + UrlUtils.encode(s));
+						};
+					});
+
+					item = new MenuItem(menu, SWT.PUSH);
+					item.setText("g");
+					item.addSelectionListener(new SelectionAdapter() {
+						public void widgetSelected(SelectionEvent e) {
+							String s = related_content[0].getTitle();
+							s = s.replaceAll("[-_]", " ");
+							Utils.launch("http://google.com/search?q=" + UrlUtils.encode(s));
+						};
+					});
+
+					
+					new MenuItem(menu, SWT.SEPARATOR );
+
 					final MenuItem remove_item = new MenuItem(menu, SWT.PUSH);
 
 					remove_item.setText(MessageText.getString("azbuddy.ui.menu.remove"));
@@ -700,4 +855,27 @@ SBC_RCMView
 			tv_related_content.refreshTable( false );
 		}
 	}
+
+
+	// @see org.gudy.azureus2.ui.swt.views.table.TableViewFilterCheck#filterCheck(java.lang.Object, java.lang.String, boolean)
+	public boolean filterCheck(RelatedContent ds, String filter, boolean regex) {
+		if ( filter == null || filter.length() == 0 ){
+			
+			return( true );
+		}
+
+		try {
+			String name = ds.getTitle();
+			String s = regex ? filter : "\\Q" + filter.replaceAll("[|;]", "\\\\E|\\\\Q") + "\\E";
+  		Pattern pattern = Pattern.compile(s, Pattern.CASE_INSENSITIVE);
+  
+  		return pattern.matcher(name).find();
+		} catch (Exception e) {
+			return true;
+		}
+	}
+	
+	// @see org.gudy.azureus2.ui.swt.views.table.TableViewFilterCheck#filterSet(java.lang.String)
+	public void filterSet(String filter) {
+	}
 }
