@@ -26,16 +26,13 @@ package com.aelitis.azureus.ui.swt.devices;
 import java.io.File;
 import java.net.InetAddress;
 import java.util.*;
+import java.util.List;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.DirectoryDialog;
-import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Shell;
-import org.eclipse.swt.widgets.TreeItem;
+import org.eclipse.swt.widgets.*;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.internat.MessageText;
@@ -45,20 +42,17 @@ import org.gudy.azureus2.plugins.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.plugins.download.Download;
 import org.gudy.azureus2.plugins.installer.PluginInstaller;
 import org.gudy.azureus2.plugins.installer.StandardPlugin;
-import org.gudy.azureus2.plugins.ui.UIInstance;
-import org.gudy.azureus2.plugins.ui.UIManager;
-import org.gudy.azureus2.plugins.ui.UIManagerListener;
+import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.ui.config.*;
 import org.gudy.azureus2.plugins.ui.menus.*;
+import org.gudy.azureus2.plugins.ui.menus.MenuItem;
 import org.gudy.azureus2.plugins.ui.model.BasicPluginConfigModel;
 import org.gudy.azureus2.plugins.ui.sidebar.*;
 import org.gudy.azureus2.plugins.ui.tables.TableContextMenuItem;
 import org.gudy.azureus2.plugins.ui.tables.TableManager;
 import org.gudy.azureus2.plugins.ui.tables.TableRow;
 import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
-import org.gudy.azureus2.ui.swt.PropertiesWindow;
-import org.gudy.azureus2.ui.swt.UIExitUtilsSWT;
-import org.gudy.azureus2.ui.swt.Utils;
+import org.gudy.azureus2.ui.swt.*;
 import org.gudy.azureus2.ui.swt.plugins.UISWTInputReceiver;
 import org.gudy.azureus2.ui.swt.plugins.UISWTInstance;
 import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
@@ -76,6 +70,7 @@ import com.aelitis.azureus.core.download.DiskManagerFileInfoFile;
 import com.aelitis.azureus.core.messenger.config.PlatformDevicesMessenger;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
+import com.aelitis.azureus.ui.UserPrompterResultListener;
 import com.aelitis.azureus.ui.common.viewtitleinfo.ViewTitleInfo;
 import com.aelitis.azureus.ui.common.viewtitleinfo.ViewTitleInfoManager;
 import com.aelitis.azureus.ui.selectedcontent.ISelectedContent;
@@ -111,7 +106,8 @@ DeviceManagerUI
 	private static final String INFO_IMAGE_ID		= "image.sidebar.vitality.info";
 	private static final String ALERT_IMAGE_ID		= "image.sidebar.vitality.alert";
 
-	private static final boolean	SHOW_VITALITY = false;
+	private static final boolean	SHOW_RENDERER_VITALITY 	= false;
+	private static final boolean	SHOW_OD_VITALITY 		= true;
 	
 	private static final String[] to_copy_indicator_colors = { "#000000", "#000000", "#168866", "#1c5620" };
 	
@@ -152,6 +148,9 @@ DeviceManagerUI
 	
 	private MenuItemFillListener will_browse_listener;
 	
+	private boolean	offline_menus_setup;
+	
+	
 	static {
 		try {
   		if (Constants.isOSX) {
@@ -249,35 +248,27 @@ DeviceManagerUI
   						
   						return( true );
   					}
-					
-  					boolean allowQuit =
-  						Utils.execSWTThreadWithBool(
-  							"quitTranscoding",
-  							new AERunnableBoolean() {
-  								public boolean runSupport() {
-  									String title = MessageText.getString("device.quit.transcoding.title");
-  									String text = MessageText.getString(
-  											"device.quit.transcoding.text",
-  											new String[] {
-  												job.getName(),
-  												job.getTarget().getDevice().getName(),
-  												String.valueOf( job.getPercentComplete())
-  											});
-  
-  									MessageBoxShell mb = new MessageBoxShell(
-  											Utils.findAnyShell(),
-  											title,
-  											text,
-  											new String[] {
-  												MessageText.getString("UpdateWindow.quit"),
-  												MessageText.getString("Content.alert.notuploaded.button.abort")
-  											}, 1, null, null, false, 0);
-  
-  									return mb.open() == 0;
-  								}
-  							}, 0);
-  					
-  					return( allowQuit );
+
+						String title = MessageText.getString("device.quit.transcoding.title");
+						String text = MessageText.getString(
+								"device.quit.transcoding.text",
+								new String[] {
+									job.getName(),
+									job.getTarget().getDevice().getName(),
+									String.valueOf( job.getPercentComplete())
+								});
+
+						MessageBoxShell mb = new MessageBoxShell(
+								title,
+								text,
+								new String[] {
+									MessageText.getString("UpdateWindow.quit"),
+									MessageText.getString("Content.alert.notuploaded.button.abort")
+								}, 1);
+						mb.open(null);
+						mb.waitUntilClosed();
+						return mb.getResult() == 0;
+
 					} catch (Exception e) {
 						Debug.out(e);
 						return true;
@@ -447,20 +438,20 @@ DeviceManagerUI
 				device_manager.getAutoSearch());
 		
 		as.addListener(
-				new ParameterListener()
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
 				{
-					public void 
-					parameterChanged(
-						Parameter param) 
-					{
-						device_manager.setAutoSearch( as.getValue());
+					device_manager.setAutoSearch( as.getValue());
+					
+					if ( device_manager.getAutoSearch()){
 						
-						if ( device_manager.getAutoSearch()){
-							
-							search();
-						}
+						search();
 					}
-				});
+				}
+			});
 		
 		final BooleanParameter qosParam = configModel.addBooleanParameter2(
 				PlatformDevicesMessenger.CFG_SEND_QOS, "devices.turnon.qos", false);
@@ -477,25 +468,6 @@ DeviceManagerUI
 				}
 			});
 
-			// max xcode
-		
-		final IntParameter max_xcode = 
-			configModel.addIntParameter2( 
-				"device.config.xcode.maxbps", "device.config.xcode.maxbps",
-				(int)(device_manager.getTranscodeManager().getQueue().getMaxBytesPerSecond()/1024), 
-				0, Integer.MAX_VALUE );
-		
-		max_xcode.addListener(
-			new ParameterListener()
-			{
-				public void 
-				parameterChanged(
-					Parameter param) 
-				{
-					device_manager.getTranscodeManager().getQueue().setMaxBytesPerSecond( max_xcode.getValue()*1024 );
-				}
-			});
-
 			// config - simple view
 		
 		final BooleanParameter config_simple_view = 
@@ -504,15 +476,15 @@ DeviceManagerUI
 				side_bar_view_type == SBV_SIMPLE );
 		
 		config_simple_view.addListener(
-				new ParameterListener()
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
 				{
-					public void 
-					parameterChanged(
-						Parameter param) 
-					{
-						COConfigurationManager.setParameter( CONFIG_VIEW_TYPE, config_simple_view.getValue()?SBV_SIMPLE:SBV_FULL );
-					}
-				});	
+					COConfigurationManager.setParameter( CONFIG_VIEW_TYPE, config_simple_view.getValue()?SBV_SIMPLE:SBV_FULL );
+				}
+			});	
 		
 		COConfigurationManager.addParameterListener(
 			CONFIG_VIEW_TYPE,
@@ -532,6 +504,8 @@ DeviceManagerUI
 				"!" + CONFIG_VIEW_HIDE_REND_GENERIC + "!", "devices.sidebar.hide.rend.generic",
 				side_bar_hide_rend_gen );
 		
+		// transcoding
+		
 			// default dir
 		
 		String def = device_manager.getDefaultWorkingDirectory().getAbsolutePath();
@@ -551,81 +525,28 @@ DeviceManagerUI
 				}
 			});
 		
-			// rss
+			// max xcode
 		
-		final BooleanParameter rss_enable = 
-			configModel.addBooleanParameter2( 
-				"device.rss.enable", "device.rss.enable",
-				device_manager.isRSSPublishEnabled());
-		
-		rss_enable.addListener(
-				new ParameterListener()
-				{
-					public void 
-					parameterChanged(
-						Parameter param) 
-					{
-						device_manager.setRSSPublishEnabled( rss_enable.getValue());
-					}
-				});
-		
-		
-		final IntParameter rss_port = 
+		final IntParameter max_xcode = 
 			configModel.addIntParameter2( 
-				"device.rss.port", "device.rss.port",
-				device_manager.getRSSPort());
+				"device.config.xcode.maxbps", "device.config.xcode.maxbps",
+				(int)(device_manager.getTranscodeManager().getQueue().getMaxBytesPerSecond()/1024), 
+				0, Integer.MAX_VALUE );
 		
-		final BooleanParameter rss_localonly = 
-			configModel.addBooleanParameter2( 
-				"device.rss.localonly", "device.rss.localonly",
-				device_manager.isRSSLocalOnly());
-		
-		rss_localonly.addListener(
-				new ParameterListener()
-				{
-					public void 
-					parameterChanged(
-						Parameter param) 
-					{
-						device_manager.setRSSLocalOnly( rss_localonly.getValue());
-					}
-				});
-		
-		final HyperlinkParameter rss_view = 
-			configModel.addHyperlinkParameter2(
-				"device.rss.view", getRSSLink( rss_port.getValue()));
-		
-		rss_port.addListener(
-				new ParameterListener()
-				{
-					public void 
-					parameterChanged(
-						Parameter param) 
-					{
-						int port =  rss_port.getValue();
-						
-						device_manager.setRSSPort( port );
-						
-						rss_view.setHyperlink( getRSSLink( port ));
-					}
-				});
-
-
-		
-		rss_enable.addEnabledOnSelection( rss_localonly );
-		rss_enable.addEnabledOnSelection( rss_port );
-		rss_enable.addEnabledOnSelection( rss_view );
-		
-		configModel.createGroup(
-			"device.rss.group",
-			new Parameter[]
+		max_xcode.addListener(
+			new ParameterListener()
 			{
-					rss_enable, rss_port, rss_view, rss_localonly,
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					device_manager.getTranscodeManager().getQueue().setMaxBytesPerSecond( max_xcode.getValue()*1024 );
+				}
 			});
-		
+
 			// itunes
 		
-		final ActionParameter btnITunes = configModel.addActionParameter2(null, "devices.button.installitunes");
+		final ActionParameter btnITunes = configModel.addActionParameter2("devices.button.installitunes", "UpdateWindow.columns.install");
 		btnITunes.setEnabled(false);
 		AzureusCoreFactory.addCoreRunningListener(new AzureusCoreRunningListener() {
 			public void azureusCoreRunning(AzureusCore core) {
@@ -653,10 +574,136 @@ DeviceManagerUI
 				});
 			}
 		});
+		
+		configModel.createGroup(
+			"device.xcode.group",
+			new Parameter[]
+			{
+					def_work_dir, max_xcode, btnITunes
+			});
+		
+			// rss
+		
+		final BooleanParameter rss_enable = 
+			configModel.addBooleanParameter2( 
+				"device.rss.enable", "device.rss.enable",
+				device_manager.isRSSPublishEnabled());
+		
+		rss_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					device_manager.setRSSPublishEnabled( rss_enable.getValue());
+				}
+			});
+				
+		HyperlinkParameter rss_view = 
+			configModel.addHyperlinkParameter2(
+				"device.rss.view", device_manager.getRSSLink());
+		
+		rss_enable.addEnabledOnSelection( rss_view );
+		
+		configModel.createGroup(
+			"device.rss.group",
+			new Parameter[]
+			{
+					rss_enable, rss_view,
+			});
 
+			// offline downloaders
+		
+				// enable
+		
+		final DeviceOfflineDownloaderManager dodm = device_manager.getOfflineDownlaoderManager();
+		
+		final BooleanParameter od_enable = 
+			configModel.addBooleanParameter2( 
+				"device.od.enable", "device.od.enable",
+				dodm.isOfflineDownloadingEnabled());
+		
+		od_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					dodm.setOfflineDownloadingEnabled( od_enable.getValue());
+					
+					rebuildSideBar();
+				}
+			});
+		
+				// auto manage
+		
+		final BooleanParameter od_auto_enable = 
+			configModel.addBooleanParameter2( 
+				"device.odauto.enable", "device.odauto.enable",
+				dodm.getOfflineDownloadingIsAuto());
+		
+		od_auto_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					dodm.setOfflineDownloadingIsAuto( od_auto_enable.getValue());
+				}
+			});
+		
+				// private torrents
+		
+		final BooleanParameter od_pt_enable = 
+			configModel.addBooleanParameter2( 
+				"device.odpt.enable", "device.odpt.enable",
+				dodm.getOfflineDownloadingIncludePrivate());
+		
+		od_pt_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					dodm.setOfflineDownloadingIncludePrivate( od_pt_enable.getValue());
+				}
+			});
+		
+		od_auto_enable.addEnabledOnSelection( od_pt_enable );
+		
+		configModel.createGroup(
+			"device.od.group",
+			new Parameter[]
+			{
+				od_enable, od_auto_enable, od_pt_enable,
+			});
+		
+		final BooleanParameter tivo_enable = 
+			configModel.addBooleanParameter2( 
+				"device.tivo.enable", "device.tivo.enable", false );
+		
+		tivo_enable.setValue(device_manager.isTiVoEnabled());
+		
+		tivo_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					device_manager.setTiVoEnabled( tivo_enable.getValue());
+					
+					rebuildSideBar();
+				}
+			});
+		
 		addAllDevices();
 	
-		setupMenus();
+		setupTranscodeMenus();
 	}
 	
 	protected String
@@ -717,7 +764,7 @@ DeviceManagerUI
 							
 							SideBarEntry info = (SideBarEntry) target;
 							
-							Device device = (Device)info.getDatasource();
+							final Device device = (Device)info.getDatasource();
 							
 							UISWTInputReceiver entry = (UISWTInputReceiver)swt_ui.getInputReceiver();
 							
@@ -727,21 +774,24 @@ DeviceManagerUI
 							
 							entry.allowEmptyInput( false );
 							
-							entry.setTitle("MyTorrentsView.menu.rename");
-							
-							entry.prompt();
-							
-							if (!entry.hasSubmittedInput()){
-								
-								return;
-							}
-							
-							String input = entry.getSubmittedInput().trim();
-							
-							if ( input.length() > 0 ){
-							
-								device.setName( input );
-							}
+							entry.setLocalisedTitle(MessageText.getString("label.rename",
+									new String[] {
+								device.getName()
+							}));
+	
+							entry.prompt(new UIInputReceiverListener() {
+								public void UIInputReceiverClosed(UIInputReceiver entry) {
+									if (!entry.hasSubmittedInput()) {
+										return;
+									}
+									String input = entry.getSubmittedInput().trim();
+									
+									if ( input.length() > 0 ){
+										
+										device.setName( input );
+									}
+								}
+							});		
 						}
 					}
 				};
@@ -951,8 +1001,8 @@ DeviceManagerUI
 						
 						menu.setEnabled( enabled );
 					}
-				};
 			
+				};
 		side_bar.addListener(
 			new SideBarListener()
 			{
@@ -991,7 +1041,6 @@ DeviceManagerUI
 									{
 										MessageBoxShell mb = 
 											new MessageBoxShell(
-												Utils.findAnyShell(),
 												MessageText.getString("message.confirm.delete.title"),
 												MessageText.getString("message.confirm.delete.text",
 														new String[] {
@@ -1003,10 +1052,13 @@ DeviceManagerUI
 												},
 												1 );
 										
-										int result = mb.open();
-										if (result == 0) {
-											device.remove();
-										}
+										mb.open(new UserPrompterResultListener() {
+											public void prompterClosed(int result) {
+												if (result == 0) {
+													device.remove();
+												}
+											}
+										});
 									}
 								})};
 										
@@ -1030,22 +1082,7 @@ DeviceManagerUI
 					
 					side_bar_hide_rend_gen = COConfigurationManager.getBooleanParameter( CONFIG_VIEW_HIDE_REND_GENERIC, true );
 
-					if ( sidebar_built ){
-						
-						Utils.execSWTThread(
-								new Runnable()
-								{
-									public void
-									run()
-									{
-										removeAllDevices();
-										
-										buildSideBar( true );
-										
-										addAllDevices();
-									}
-								});
-					}
+					rebuildSideBar();
 				}
 			});
 	}
@@ -1075,6 +1112,27 @@ DeviceManagerUI
 		x.setVisible( true );
 	}
 	
+	protected void
+	rebuildSideBar()
+	{
+		if ( sidebar_built ){
+			
+			Utils.execSWTThread(
+					new Runnable()
+					{
+						public void
+						run()
+						{
+							removeAllDevices();
+							
+							buildSideBar( true );
+							
+							addAllDevices();
+						}
+					});
+		}
+	}
+	
 	protected void
 	buildSideBar(
 		boolean			rebuild )	
@@ -1183,9 +1241,20 @@ DeviceManagerUI
 										
 										if ( device instanceof DeviceMediaRenderer ){
 									
-											DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
+											if ( SHOW_RENDERER_VITALITY ){
+												
+												DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
+												
+												last_indicator += renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+											}
+										}else if ( device instanceof DeviceOfflineDownloader ){
 											
-											last_indicator += renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+											if ( SHOW_OD_VITALITY ){
+												
+												DeviceOfflineDownloader	dod = (DeviceOfflineDownloader)device;
+												
+												last_indicator += dod.getTransferingCount();
+											}
 										}
 									}
 									
@@ -1210,11 +1279,8 @@ DeviceManagerUI
 									}
 									
 									if ( last_indicator > 0 ){
-											
-										if ( SHOW_VITALITY ){
-											
-											return( String.valueOf( last_indicator ));
-										}
+																						
+										return( String.valueOf( last_indicator ));
 									}
 								}else{
 									
@@ -1224,6 +1290,7 @@ DeviceManagerUI
 								}
 							}else if ( propertyID == TITLE_INDICATOR_COLOR ){
 									
+								/*
 								if ( last_indicator > 0 ){
 									
 									if ( SHOW_VITALITY ){
@@ -1231,6 +1298,7 @@ DeviceManagerUI
 										return( to_copy_indicator_colors );
 									}
 								}
+								*/
 							}
 
 							return null;
@@ -1382,7 +1450,7 @@ DeviceManagerUI
 	
 					// routers
 				
-				categoryView routers_category			= addDeviceCategory( Device.DT_INTERNET_GATEWAY, "device.router.view.title", 			"image.sidebar.device.router" );
+				categoryView routers_category			= addDeviceCategory( Device.DT_INTERNET_GATEWAY, "device.router.view.title", "image.sidebar.device.router" );
 				
 				categories.add( routers_category );
 				
@@ -1409,6 +1477,15 @@ DeviceManagerUI
 							}
 						});
 				
+					// offline downloaders
+				
+				if ( device_manager.getOfflineDownlaoderManager().isOfflineDownloadingEnabled()){
+					
+					categoryView od_category	= addDeviceCategory( Device.DT_OFFLINE_DOWNLOADER, "device.offlinedownloader.view.title", "image.sidebar.device.offlinedownloader" );
+					
+					categories.add( od_category );
+				}
+				
 					// internet
 				
 				categoryView internet_category	= addDeviceCategory( Device.DT_INTERNET, "MainWindow.about.section.internet", "image.sidebar.device.internet" );
@@ -1467,7 +1544,7 @@ DeviceManagerUI
 	}
 
 	private void 
-	setupMenus()
+	setupTranscodeMenus()
 	{					
 			// top level menus
 				
@@ -1637,6 +1714,134 @@ DeviceManagerUI
 		}
 	}
 	
+	private void 
+	setupOfflineDownloadingMenus()
+	{					
+		final String[] tables = {
+				TableManager.TABLE_MYTORRENTS_INCOMPLETE,
+				TableManager.TABLE_MYTORRENTS_INCOMPLETE_BIG,
+				TableManager.TABLE_MYTORRENTS_ALL_BIG,
+			};
+		
+		TableManager table_manager = plugin_interface.getUIManager().getTableManager();
+		
+		final DeviceOfflineDownloaderManager dodm = device_manager.getOfflineDownlaoderManager();
+		
+		MenuItemFillListener	menu_fill_listener = 
+			new MenuItemFillListener()
+			{
+				public void
+				menuWillBeShown(
+					MenuItem	menu,
+					Object		_target )
+				{
+					menu.removeAllChildItems();
+
+					if ( dodm.getOfflineDownloadingIsAuto()){
+						
+						menu.setEnabled( true );
+						
+						TableContextMenuItem auto_item =
+							plugin_interface.getUIManager().getTableManager().addContextMenuItem(
+								(TableContextMenuItem)menu,
+								"devices.contextmenu.od.auto");
+						
+						auto_item.setEnabled( false );
+
+						return;
+					}
+			
+					final TableRow[]	target;
+					
+					if ( _target instanceof TableRow ){
+						
+						target = new TableRow[]{ (TableRow)_target };
+						
+					}else{
+						
+						target = (TableRow[])_target;
+					}
+										
+					boolean	all_non_manual	= true;
+					boolean all_manual		= true;
+					
+					final List<Download> downloads = new ArrayList<Download>();
+					
+					for ( TableRow row: target ){
+						
+						Object obj = row.getDataSource();
+					
+						if ( obj instanceof Download ){
+						
+							Download download = (Download)obj;
+
+							downloads.add( download );
+							
+							if ( dodm.isManualDownload( download )){
+								
+								all_non_manual = false;
+								
+							}else{
+								
+								all_manual = false;
+							}
+						}
+					}
+					
+					boolean	enabled = downloads.size() > 0;
+
+					menu.setEnabled( enabled );
+										
+					if ( enabled ){
+						
+						TableContextMenuItem manual_item =
+							plugin_interface.getUIManager().getTableManager().addContextMenuItem(
+								(TableContextMenuItem)menu,
+								"devices.contextmenu.od.enable" + (all_manual?"d":""));
+						
+						final boolean f_all_manual = all_manual;
+						
+						manual_item.setData( new Boolean( f_all_manual ));
+						
+						manual_item.setStyle( MenuItem.STYLE_CHECK );
+						
+						manual_item.addListener(
+							new MenuItemListener()
+							{
+								public void
+								selected(
+									MenuItem			menu,
+									Object 				target )
+								{
+									Download[] d = downloads.toArray( new Download[ downloads.size()]);
+									
+									if ( f_all_manual ){
+										
+										dodm.removeManualDownloads( d );
+										
+									}else{
+										
+										dodm.addManualDownloads( d );
+									}
+								}
+							});
+					}
+				}
+			};
+		
+		// TUX TODO: make a table_manager.addContentMenuItem(Class forDataSourceType, String resourceKey)
+		//           instead of forcing a loop like this
+			
+		for( String table: tables ){
+				
+			TableContextMenuItem menu = table_manager.addContextMenuItem(table, "devices.contextmenu.od" );
+			
+			menu.setStyle(TableContextMenuItem.STYLE_MENU);
+		
+			menu.addFillListener( menu_fill_listener );				
+		}
+	}
+	
 	protected void
 	search()
 	{
@@ -1663,6 +1868,11 @@ DeviceManagerUI
 	{
 		int	type = device.getType();
 		
+		if ( !device_manager.getOfflineDownlaoderManager().isOfflineDownloadingEnabled() && type == Device.DT_OFFLINE_DOWNLOADER ){
+			
+			return;
+		}
+		
 		String parent_key = null;
 		
 		if ( side_bar_view_type == SBV_FULL ){
@@ -1678,7 +1888,7 @@ DeviceManagerUI
 			}
 		}else{
 			
-			if ( type != Device.DT_MEDIA_RENDERER ){
+			if ( type != Device.DT_MEDIA_RENDERER && type != Device.DT_OFFLINE_DOWNLOADER ){
 				
 				return;
 			}
@@ -1711,15 +1921,38 @@ DeviceManagerUI
 			
 			return;
 		}
-		
+				
 		final String parent = parent_key;
 		
 		synchronized( this ){
-			
+
 			final deviceItem existing_di = (deviceItem)device.getTransientProperty( DEVICE_IVIEW_KEY );
 			
 			if (  existing_di == null ){
 	
+				if ( type == Device.DT_OFFLINE_DOWNLOADER ){
+
+					if ( !offline_menus_setup ){
+					
+						offline_menus_setup = true;
+					
+						setupOfflineDownloadingMenus();
+					}
+					
+					DeviceOfflineDownloader	dod = (DeviceOfflineDownloader)device;
+					
+					if ( !dod.hasShownFTUX()){
+						
+						try{
+							new DevicesODFTUX( dod );
+														
+						}catch( Throwable e ){
+							
+							Debug.out( "Failed to show offline downloader FTUX", e );
+						}
+					}
+				}
+				
 				if ( !device.isHidden()){
 					
 					final deviceItem new_di = new deviceItem();
@@ -1747,7 +1980,9 @@ DeviceManagerUI
 
 									final SideBarEntrySWT	entry;
 									
-									if ( device.getType() == Device.DT_MEDIA_RENDERER ){
+									int	device_type = device.getType();
+									
+									if ( device_type == Device.DT_MEDIA_RENDERER ){
 
 										entry = 
 											side_bar.createEntryFromSkinRef(
@@ -1789,10 +2024,39 @@ DeviceManagerUI
 											entry.setImageLeftID(id);
 										}
 										
-										entry.setDatasource(device);
+									}else if ( device_type == Device.DT_OFFLINE_DOWNLOADER ){
+										
+										entry = 
+											side_bar.createEntryFromSkinRef(
+												parent,
+												key, "devicesodview",
+												device.getName(),
+												view, null, false, -1);
+										
+											
+										DeviceOfflineDownloader dod = (DeviceOfflineDownloader)device;
+										
+										String	id;
+										
+										String manufacturer = dod.getManufacturer();
+										
+										if ( manufacturer.toLowerCase().contains( "vuze" )){
+											
+											id = "vuze";
+
+										}else if ( manufacturer.toLowerCase().contains( "belkin" )){
+											
+											id = "bel";
+											
+										}else{
+											
+											id = "other";
+										}
+										
+										entry.setImageLeftID( "image.sidebar.device.od." + id + ".small" );
 
 									}else{
-
+										
 										side_bar.createTreeItemFromIView(
 												parent, 
 												view,
@@ -1805,6 +2069,8 @@ DeviceManagerUI
 										entry = SideBar.getEntry( key );
 									}
 									
+									entry.setDatasource( device );
+									
 									entry.setLogID(parent + "-" + device.getName());
 
 									new_di.setTreeItem( entry.getTreeItem(), entry );
@@ -1816,12 +2082,12 @@ DeviceManagerUI
 										entry.addListener(
 											new SideBarDropListener()
 											{
-												public void 
+												public boolean 
 												sideBarEntryDrop(
 													SideBarEntry 		entry, 
 													Object 				payload  )
 												{
-													handleDrop((TranscodeTarget)device, payload );
+													return handleDrop((TranscodeTarget)device, payload );
 												}
 											});
 									}
@@ -2172,6 +2438,56 @@ DeviceManagerUI
 										}
 									}
 
+									if ( device instanceof DeviceOfflineDownloader ){
+
+										final DeviceOfflineDownloader	dod = (DeviceOfflineDownloader)device;
+										
+										need_sep = true;
+										
+										MenuItem configure_menu_item = menu_manager.addMenuItem("sidebar." + key, "device.configure");
+											
+
+										configure_menu_item.addFillListener(new MenuItemFillListener() {
+											public void menuWillBeShown(MenuItem menu, Object data) {
+												menu.setEnabled( dod.isAlive());
+											}
+										});
+
+										configure_menu_item.addListener(
+											new MenuItemListener()
+											{
+												public void 
+												selected(
+													MenuItem 	menu,
+													Object 		target ) 
+												{
+													try{
+														new DevicesODFTUX( dod );
+														
+													}catch( Throwable e ){
+														
+														Debug.out( e );
+													}
+												}
+											});
+										
+										MenuItem enabled_menu_item = menu_manager.addMenuItem("sidebar." + key, "devices.contextmenu.od.enable" );
+										
+										enabled_menu_item.setStyle(MenuItem.STYLE_CHECK);
+
+										enabled_menu_item.addFillListener(new MenuItemFillListener() {
+											public void menuWillBeShown(MenuItem menu, Object data) {
+												menu.setData(new Boolean( dod.isEnabled()));
+											}
+										});
+										
+										enabled_menu_item.addListener(new MenuItemListener() {
+											public void selected(MenuItem menu, Object target) {
+								 				dod.setEnabled((Boolean) menu.getData());
+											}
+										});
+									}
+									
 									if ( device.isBrowsable()){
 										
 										need_sep = true;
@@ -2273,11 +2589,14 @@ DeviceManagerUI
 		}
 	}
 	
-	public static void
+	public static boolean
 	handleDrop(
 		TranscodeTarget			target,
 		final Object			payload )
 	{
+		if (!(payload instanceof String[]) && !(payload instanceof String)) {
+			return false;
+		}
 		TranscodeChooser deviceChooser = new TranscodeChooser(target) {
 			
 			public void 
@@ -2295,6 +2614,7 @@ DeviceManagerUI
 		};
 		
 		deviceChooser.show();
+		return true;
 	}
 
 	protected static void
@@ -2644,12 +2964,12 @@ DeviceManagerUI
 		entry.addListener(
 				new SideBarDropListener()
 				{
-					public void 
+					public boolean 
 					sideBarEntryDrop(
 						SideBarEntry 		entry, 
 						Object 				payload  )
 					{
-						handleDrop(null, payload);
+						return handleDrop(null, payload);
 					}
 				});
 	}
@@ -2754,7 +3074,7 @@ DeviceManagerUI
 				
 			}else if ( propertyID == TITLE_INDICATOR_TEXT ){
 			
-				if ( device_type == Device.DT_MEDIA_RENDERER ){ 
+				if ( device_type == Device.DT_MEDIA_RENDERER || device_type == Device.DT_OFFLINE_DOWNLOADER ){ 
 				
 					if ( spinner != null ){
 					
@@ -2788,9 +3108,20 @@ DeviceManagerUI
 							
 							if ( device instanceof DeviceMediaRenderer ){
 						
-								DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
+								if ( SHOW_RENDERER_VITALITY ){
+									
+									DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
+									
+									last_indicator += renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+								}
+							}else if ( device instanceof DeviceOfflineDownloader ){
 								
-								last_indicator += renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+								if ( SHOW_OD_VITALITY ){
+									
+									DeviceOfflineDownloader dod = (DeviceOfflineDownloader)device;
+									
+									last_indicator += dod.getTransferingCount();
+								}
 							}
 						}
 						
@@ -2813,11 +3144,8 @@ DeviceManagerUI
 						}
 						
 						if ( last_indicator > 0 ){
-							
-							if ( SHOW_VITALITY ){
-							
-								return( String.valueOf( last_indicator ));
-							}
+														
+							return( String.valueOf( last_indicator ));
 						}
 					}else{
 						
@@ -2826,14 +3154,16 @@ DeviceManagerUI
 					}
 				}
 			}else if ( propertyID == TITLE_INDICATOR_COLOR ){
-					
+				
+				/*
 				if ( last_indicator > 0 ){
-					
+				
 					if ( SHOW_VITALITY ){
 					
 						return( to_copy_indicator_colors );
 					}
 				}
+				*/
 			}
 			
 			return null;
@@ -3001,20 +3331,29 @@ DeviceManagerUI
 				
 				if ( device instanceof DeviceMediaRenderer ){
 					
-					DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
+					if ( SHOW_RENDERER_VITALITY ){
 					
-					last_indicator = renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+						DeviceMediaRenderer	renderer = (DeviceMediaRenderer)device;
 					
-					if ( last_indicator > 0 ){
-						
-						if ( SHOW_VITALITY ){
-						
-							return( String.valueOf( last_indicator ));
-						}
+					
+						last_indicator = renderer.getCopyToDevicePending() + renderer.getCopyToFolderPending();
+					}
+				}else if ( device instanceof DeviceOfflineDownloader ){
+					
+					if ( SHOW_OD_VITALITY ){
+					
+						DeviceOfflineDownloader	dod = (DeviceOfflineDownloader)device;
+					
+						last_indicator = dod.getTransferingCount();
 					}
 				}
+				
+				if ( last_indicator > 0 ){
+										
+					return( String.valueOf( last_indicator ));
+				}
 			}else if ( propertyID == TITLE_INDICATOR_COLOR ){
-					
+				/*	
 				if ( last_indicator > 0 ){
 						
 					if ( SHOW_VITALITY ){
@@ -3022,6 +3361,7 @@ DeviceManagerUI
 						return( to_copy_indicator_colors );
 					}
 				}
+				*/
 			}else if ( propertyID == TITLE_ACTIVE_STATE ){
 
 				if ( device.isLivenessDetectable()){
