@@ -1,18 +1,9 @@
 package com.aelitis.azureus.ui.swt.shells.main;
 
-import java.util.Arrays;
-import java.util.Comparator;
-
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
-import org.eclipse.swt.events.MenuEvent;
-import org.eclipse.swt.events.MenuListener;
-import org.eclipse.swt.widgets.Event;
-import org.eclipse.swt.widgets.Listener;
-import org.eclipse.swt.widgets.Menu;
-import org.eclipse.swt.widgets.MenuItem;
-import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.events.*;
+import org.eclipse.swt.widgets.*;
+
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.config.impl.ConfigurationDefaults;
@@ -24,25 +15,16 @@ import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.mainwindow.IMainMenu;
 import org.gudy.azureus2.ui.swt.mainwindow.IMenuConstants;
 import org.gudy.azureus2.ui.swt.mainwindow.MenuFactory;
-import org.gudy.azureus2.ui.swt.plugins.UISWTViewEventListener;
 
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
-import com.aelitis.azureus.core.cnetwork.ContentNetworkManager;
-import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
 import com.aelitis.azureus.ui.skin.SkinConstants;
-import com.aelitis.azureus.ui.swt.UIFunctionsManagerSWT;
 import com.aelitis.azureus.ui.swt.skin.SWTSkin;
 import com.aelitis.azureus.ui.swt.skin.SWTSkinObject;
-import com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBrowser;
 import com.aelitis.azureus.ui.swt.skin.SWTSkinUtils;
 import com.aelitis.azureus.ui.swt.toolbar.ToolBarItem;
-import com.aelitis.azureus.ui.swt.utils.ContentNetworkUIManagerWindow;
-import com.aelitis.azureus.ui.swt.views.skin.FriendsToolbar;
 import com.aelitis.azureus.ui.swt.views.skin.SkinViewManager;
 import com.aelitis.azureus.ui.swt.views.skin.ToolBarView;
 import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBar;
-import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarEntrySWT;
-import com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBar.UISWTViewEventListenerSkinObject;
 import com.aelitis.azureus.util.ConstantsVuze;
 import com.aelitis.azureus.util.ContentNetworkUtils;
 
@@ -88,12 +70,8 @@ public class MainMenu
 		//addViewMenu();
 		addSimpleViewMenu();
 
-		addContentNetworksMenu();
-
 		addCommunityMenu();
 
-		addPublishMenu();
-
 		addToolsMenu();
 
 		/*
@@ -119,156 +97,7 @@ public class MainMenu
 		 */
 		MenuFactory.updateEnabledStates(menuBar);
 	}
-
-	/**
-	 * 
-	 *
-	 * @since 4.0.0.3
-	 */
-	private void addContentNetworksMenu() {
-		try {
-			MenuItem contentNetworkItem = MenuFactory.createTopLevelMenuItem(menuBar,
-					MENU_ID_CONTENT_NETWORKS);
-			final Menu contentNetworkMenu = contentNetworkItem.getMenu();
-
-			contentNetworkMenu.addListener(SWT.Show, new Listener() {
-				public void handleEvent(Event event) {
-					try {
-						MenuItem[] menuItems = contentNetworkMenu.getItems();
-						Utils.disposeSWTObjects(menuItems);
-
-						buildContentNetworkMenu(contentNetworkMenu);
-
-					} catch (Exception e) {
-						Debug.out("Error creating Menu", e);
-					}
-
-				}
-			});
-		} catch (Exception e) {
-			Debug.out("Error creating Menu", e);
-		}
-	}
-
-	/**
-	 * @param contentNetworkMenu
-	 *
-	 * @since 4.0.0.3
-	 */
-	protected void buildContentNetworkMenu(final Menu contentNetworkMenu) {
-		ContentNetworkManager cnManager = ContentNetworkManagerFactory.getSingleton();
-		if (cnManager == null) {
-			return;
-		}
-		ContentNetwork[] contentNetworks = cnManager.getContentNetworks();
-		Arrays.sort(contentNetworks, new Comparator() {
-			public int compare(Object o1, Object o2) {
-				String p1 = ""
-						+ ((ContentNetwork) o1).getProperty(ContentNetwork.PROPERTY_ORDER);
-				String p2 = ""
-						+ ((ContentNetwork) o2).getProperty(ContentNetwork.PROPERTY_ORDER);
-
-				return p1.compareTo(p2);
-			}
-		});
-		for (int i = 0; i < contentNetworks.length; i++) {
-			ContentNetwork contentNetwork = contentNetworks[i];
-			addContentNetworkItem(contentNetworkMenu, contentNetwork);
-		}
-		
-		MenuFactory.addSeparatorMenuItem(contentNetworkMenu);
-
-		MenuFactory.addMenuItem(contentNetworkMenu, MENU_ID_CONTENT_NETWORKS
-				+ ".manage", new Listener() {
-			public void handleEvent(Event event) {
-				new ContentNetworkUIManagerWindow();
-			}			
-		});
-
-		MenuFactory.addSeparatorMenuItem(contentNetworkMenu);
-
-		MenuFactory.addMenuItem(contentNetworkMenu, MENU_ID_CONTENT_NETWORKS
-				+ ".about", new Listener() {
-			public void handleEvent(Event event) {
-				String url = "AboutHDNetworks.start";
-				UIFunctionsManagerSWT.getUIFunctionsSWT().viewURL(url, "_blank", 0,
-						0, true, false);
-			}			
-		});
-	}
-
 	
-	/**
-	 * @param contentNetworkMenu
-	 * @param cn
-	 *
-	 * @since 4.0.0.3
-	 */
-	private void addContentNetworkItem(Menu contentNetworkMenu,
-			ContentNetwork cn) {
-		if (cn == null) {
-			return;
-		}
-
-		Object prop = cn.getProperty(ContentNetwork.PROPERTY_REMOVEABLE);
-		boolean removable = (prop instanceof Boolean) ? ((Boolean) prop).booleanValue()
-				: false;
-		
-		if (removable) {
-  		prop = cn.getPersistentProperty(ContentNetwork.PP_SHOW_IN_MENU);
-  		boolean show = (prop instanceof Boolean) ? ((Boolean) prop).booleanValue()
-  				: true;
-  		
-  		if (!show) {
-  			return;
-  		}
-		}
-
-
-		final MenuItem item = MenuFactory.addMenuItem(contentNetworkMenu,
-				SWT.CHECK,
-				null,
-				new Listener() {
-					public void handleEvent(Event event) {
-						MenuItem item = (MenuItem) event.widget;
-						ContentNetwork contentNetwork = (ContentNetwork) item.getData("ContentNetwork");
-						if (contentNetwork == null) {
-							return;
-						}
-
-						SideBar sideBar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-						if (sideBar == null) {
-							return;
-						}
-						String sidebarID = ContentNetworkUtils.getTarget(contentNetwork);
-
-						ContentNetworkUtils.setSourceRef(contentNetwork, "menu", false);
-						sideBar.showEntryByTabID(sidebarID);
-					}
-				});
-
-		item.setText(cn.getName());
-
-		item.setData("ContentNetwork", cn);
-	}
-
-	/**
-	 * 
-	 *
-	 * @since 3.1.1.1
-	 */
-	private void addPublishMenu() {
-		try {
-			MenuItem publishItem = MenuFactory.createPublishMenuItem(menuBar);
-			final Menu publishMenu = publishItem.getMenu();
-
-			addPublishMenuItems(publishMenu);
-
-		} catch (Exception e) {
-			Debug.out("Error creating View Menu", e);
-		}
-	}
-
 	/**
 	 * Creates the File menu and all its children
 	 */
@@ -278,20 +107,13 @@ public class MainMenu
 		builFileMenu(fileMenu);
 
 		fileMenu.addListener(SWT.Show, new Listener() {
-			private boolean isAZ3_ADV = MenuFactory.isAZ3_ADV;
-
 			public void handleEvent(Event event) {
-				if (isAZ3_ADV != MenuFactory.isAZ3_ADV) {
-
-					MenuItem[] menuItems = fileMenu.getItems();
-					for (int i = 0; i < menuItems.length; i++) {
-						menuItems[i].dispose();
-					}
-
-					builFileMenu(fileMenu);
-
-					isAZ3_ADV = MenuFactory.isAZ3_ADV;
+				MenuItem[] menuItems = fileMenu.getItems();
+				for (int i = 0; i < menuItems.length; i++) {
+					menuItems[i].dispose();
 				}
+
+				builFileMenu(fileMenu);
 			}
 		});
 	}
@@ -310,7 +132,7 @@ public class MainMenu
 
 		int userMode = COConfigurationManager.getIntParameter("User Mode");
 
-		if ( MenuFactory.isAZ3_ADV || userMode > 0 ){
+		if ( userMode > 0 ){
 			Menu shareSubMenu = MenuFactory.createShareMenuItem(fileMenu).getMenu();
 			MenuFactory.addShareFileMenuItem(shareSubMenu);
 			MenuFactory.addShareFolderMenuItem(shareSubMenu);
@@ -331,9 +153,11 @@ public class MainMenu
 		/*
 		 * No need for restart and exit on OS X since it's already handled on the application menu
 		 */
-		if (false == Constants.isOSX) {
+		if (!Utils.isCarbon) {
 			MenuFactory.addSeparatorMenuItem(fileMenu);
 			MenuFactory.addRestartMenuItem(fileMenu);
+		}
+		if (!Constants.isOSX) {
 			MenuFactory.addExitMenuItem(fileMenu);
 		}
 	}
@@ -587,13 +411,6 @@ public class MainMenu
 								SkinConstants.VIEWID_PLUGINBAR, true, 0);
 					}
 
-					if (null == MenuFactory.findMenuItem(viewToolBarsMenu, PREFIX_V3
-							+ ".view." + SkinConstants.VIEWID_BUDDIES_VIEWER)) {
-						createViewMenuItem(skin, viewToolBarsMenu, PREFIX_V3 + ".view."
-								+ SkinConstants.VIEWID_BUDDIES_VIEWER, "Friends.visible",
-								SkinConstants.VIEWID_BUDDIES_VIEWER, true, -1);
-					}
-
 				}
 
 				public void menuHidden(MenuEvent e) {
@@ -622,82 +439,6 @@ public class MainMenu
 			}
 		});
 
-		MenuFactory.addMenuItem(viewMenu, PREFIX_V3 + ".publish", new Listener() {
-			public void handleEvent(Event event) {
-				SideBar sidebar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-				sidebar.showEntryByID(SideBar.SIDEBAR_SECTION_PUBLISH);
-			}
-		});
-
-	}
-
-	private void addPublishMenuItems(Menu publishMenu) {
-		MenuFactory.addMenuItem(publishMenu, PREFIX_V3 + ".publish.new",
-				new Listener() {
-					public void handleEvent(Event event) {
-						String sURL = ContentNetworkUtils.getUrl(
-								ConstantsVuze.getDefaultContentNetwork(),
-								ContentNetwork.SERVICE_PUBLISH_NEW);
-
-						SideBar sidebar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-						SideBarEntrySWT entry = SideBar.getEntry(SideBar.SIDEBAR_SECTION_PUBLISH);
-						if (entry.getIView() == null) {
-							entry = sidebar.createEntryFromSkinRef(
-									SideBar.SIDEBAR_SECTION_BROWSE,
-									SideBar.SIDEBAR_SECTION_PUBLISH, "publishtab.area",
-									"Publish", null, sURL, true, -1);
-						} else {
-							UISWTViewEventListener eventListener = entry.getEventListener();
-							if (eventListener instanceof UISWTViewEventListenerSkinObject) {
-								SWTSkinObject so = ((UISWTViewEventListenerSkinObject) eventListener).getSkinObject();
-								if (so instanceof SWTSkinObjectBrowser) {
-									((SWTSkinObjectBrowser) so).setURL(sURL);
-								}
-							}
-						}
-						sidebar.showEntryByID(SideBar.SIDEBAR_SECTION_PUBLISH);
-					}
-				});
-
-		MenuFactory.addMenuItem(publishMenu, PREFIX_V3 + ".publish.mine",
-				new Listener() {
-					public void handleEvent(Event event) {
-						String sURL = ContentNetworkUtils.getUrl(
-								ConstantsVuze.getDefaultContentNetwork(),
-								ContentNetwork.SERVICE_PUBLISH);
-
-						SideBar sidebar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-						SideBarEntrySWT entry = SideBar.getEntry(SideBar.SIDEBAR_SECTION_PUBLISH);
-						if (entry.getIView() == null) {
-							entry = sidebar.createEntryFromSkinRef(
-									SideBar.SIDEBAR_SECTION_BROWSE,
-									SideBar.SIDEBAR_SECTION_PUBLISH, "publishtab.area",
-									"Publish", null, sURL, true, -1);
-						} else {
-							UISWTViewEventListener eventListener = entry.getEventListener();
-							if (eventListener instanceof UISWTViewEventListenerSkinObject) {
-								SWTSkinObject so = ((UISWTViewEventListenerSkinObject) eventListener).getSkinObject();
-								if (so instanceof SWTSkinObjectBrowser) {
-									((SWTSkinObjectBrowser) so).setURL(sURL);
-								}
-							}
-						}
-						sidebar.showEntryByID(SideBar.SIDEBAR_SECTION_PUBLISH);
-					}
-				});
-
-		MenuFactory.addSeparatorMenuItem(publishMenu);
-
-		MenuFactory.addMenuItem(publishMenu, PREFIX_V3 + ".publish.about",
-				new Listener() {
-					public void handleEvent(Event event) {
-						String sURL = ContentNetworkUtils.getUrl(
-								ConstantsVuze.getDefaultContentNetwork(),
-								ContentNetwork.SERVICE_PUBLISH_ABOUT);
-						Utils.launch(sURL);
-					}
-				});
-
 	}
 
 	/**
@@ -714,6 +455,7 @@ public class MainMenu
 
 		MenuFactory.addTransferBarToMenu(toolsMenu);
 		MenuFactory.addAllPeersMenuItem(toolsMenu);
+		MenuFactory.addClientStatsMenuItem(toolsMenu);
 		MenuFactory.addBlockedIPsMenuItem(toolsMenu);
 
 		MenuFactory.addSeparatorMenuItem(toolsMenu);
@@ -790,8 +532,7 @@ public class MainMenu
 	 * Creates the Torrent menu and all its children
 	 */
 	private void addTorrentMenu() {
-		MenuFactory.setEnablementKeys(MenuFactory.createTorrentMenuItem(menuBar),
-				FOR_AZ2 | FOR_AZ3_ADV);
+		MenuFactory.createTorrentMenuItem(menuBar);
 	}
 
 	public Menu getMenu(String id) {
@@ -839,18 +580,6 @@ public class MainMenu
 						ConstantsVuze.getDefaultContentNetwork(), ContentNetwork.SERVICE_FAQ));
 			}
 		});
-
-		MenuFactory.addSeparatorMenuItem(communityMenu);
-
-		MenuFactory.addMenuItem(communityMenu, MENU_ID_COMMUNITY_ADD_FRIENDS,
-				new Listener() {
-					public void handleEvent(Event e) {
-						FriendsToolbar friendsToolbar = (FriendsToolbar) SkinViewManager.getByClass(FriendsToolbar.class);
-						if (friendsToolbar != null) {
-							friendsToolbar.addBuddy();
-						}
-					}
-				});
 	}
 
 	//====================================
