@@ -20,6 +20,7 @@
 package com.aelitis.azureus.ui.swt.shells.main;
 
 import java.io.*;
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
 import java.net.URLDecoder;
 import java.util.*;
@@ -43,8 +44,6 @@ import org.gudy.azureus2.core3.torrent.TOTorrentException;
 import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.core3.util.Constants;
 
-import org.gudy.azureus2.plugins.PluginInterface;
-import org.gudy.azureus2.plugins.download.Download;
 import org.gudy.azureus2.plugins.ui.sidebar.SideBarEntry;
 import org.gudy.azureus2.plugins.ui.sidebar.SideBarOpenListener;
 import org.gudy.azureus2.ui.swt.*;
@@ -62,13 +61,9 @@ import org.gudy.azureus2.ui.swt.shells.MessageSlideShell;
 import org.gudy.azureus2.ui.swt.views.IView;
 import org.gudy.azureus2.ui.swt.views.table.utils.TableColumnManager;
 import org.gudy.azureus2.ui.swt.views.utils.ManagerUtils;
-import org.gudy.azureus2.ui.swt.views.utils.ManagerUtils.RunDownloadManager;
 import org.gudy.azureus2.ui.systray.SystemTraySWT;
 
 import com.aelitis.azureus.activities.VuzeActivitiesManager;
-import com.aelitis.azureus.buddy.VuzeBuddy;
-import com.aelitis.azureus.buddy.VuzeBuddyCreator;
-import com.aelitis.azureus.buddy.impl.VuzeBuddyManager;
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
 import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
@@ -78,22 +73,15 @@ import com.aelitis.azureus.core.messenger.browser.BrowserMessage;
 import com.aelitis.azureus.core.messenger.browser.BrowserMessageDispatcher;
 import com.aelitis.azureus.core.messenger.config.*;
 import com.aelitis.azureus.core.messenger.config.PlatformConfigMessenger.PlatformLoginCompleteListener;
-import com.aelitis.azureus.core.torrent.GlobalRatingUtils;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
 import com.aelitis.azureus.core.versioncheck.VersionCheckClient;
 import com.aelitis.azureus.launcher.Launcher;
-import com.aelitis.azureus.login.NotLoggedInException;
-import com.aelitis.azureus.plugins.startstoprules.defaultplugin.StartStopRulesDefaultPlugin;
-import com.aelitis.azureus.plugins.startstoprules.defaultplugin.StartStopRulesFPListener;
 import com.aelitis.azureus.ui.IUIIntializer;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
-import com.aelitis.azureus.ui.common.updater.UIUpdatable;
 import com.aelitis.azureus.ui.skin.SkinConstants;
 import com.aelitis.azureus.ui.swt.*;
 import com.aelitis.azureus.ui.swt.Initializer;
-import com.aelitis.azureus.ui.swt.buddy.impl.VuzeBuddyFakeSWTImpl;
-import com.aelitis.azureus.ui.swt.buddy.impl.VuzeBuddySWTImpl;
 import com.aelitis.azureus.ui.swt.columns.utils.TableColumnCreatorV3;
 import com.aelitis.azureus.ui.swt.extlistener.StimulusRPC;
 import com.aelitis.azureus.ui.swt.skin.*;
@@ -126,12 +114,6 @@ public class MainWindow
 
 	private SWTSkin skin;
 
-	private org.gudy.azureus2.ui.swt.mainwindow.MainWindow oldMW_tab;
-
-	private org.gudy.azureus2.ui.swt.mainwindow.MainWindow oldMW_SB;
-
-	private org.gudy.azureus2.ui.swt.mainwindow.MainWindow oldMainWindow;
-
 	private MainMenu menu;
 
 	private UISWTInstanceImpl uiSWTInstanceImpl;
@@ -191,23 +173,6 @@ public class MainWindow
 
 		disposedOrDisposing = false;
 
-		VuzeBuddyManager.init(new VuzeBuddyCreator() {
-			public VuzeBuddy createBuddy(String publicKey) {
-				VuzeBuddyManager.log("created buddy: " + publicKey);
-				return new VuzeBuddySWTImpl(publicKey);
-			}
-
-			public VuzeBuddy createBuddy() {
-				VuzeBuddyManager.log("created buddy");
-				return new VuzeBuddySWTImpl();
-			}
-
-			// @see com.aelitis.azureus.buddy.VuzeBuddyCreator#createPotentialBuddy(Map)
-			public VuzeBuddy createPotentialBuddy(Map map) {
-				return new VuzeBuddyFakeSWTImpl(map);
-			}
-		});
-
 		// Hack for 3014 -> 3016 upgrades on Vista who become an Administrator
 		// user after restart.
 		if (Constants.isWindows
@@ -230,11 +195,13 @@ public class MainWindow
 						fos.close();
 
 						COConfigurationManager.setParameter("vista.adminquit", true);
-						MessageBoxShell.open(shell,
+						MessageBoxShell mb = new MessageBoxShell(
 								MessageText.getString("mb.azmustclose.title"),
 								MessageText.getString("mb.azmustclose.text"), new String[] {
 									MessageText.getString("Button.ok")
 								}, 0);
+						mb.open(null);
+						mb.waitUntilClosed();
 						if (uiInitializer != null) {
 							uiInitializer.abortProgress();
 						}
@@ -293,40 +260,7 @@ public class MainWindow
 
 					throws GlobalManagerDownloadRemovalVetoException {
 				TOTorrent torrent = dm.getTorrent();
-				if (PublishUtils.isPublished(dm)) {
-					String title = MessageText.getString("v3.mb.delPublished.title");
-
-					ContentNetwork cn = DataSourceUtils.getContentNetwork(torrent);
-					if (cn == null) {
-						return;
-					}
-
-					String site = ContentNetworkUtils.getUrl(cn,
-							ContentNetwork.SERVICE_SITE);
-
-					String site_host = (String) cn.getProperty(ContentNetwork.PROPERTY_SITE_HOST);
-
-					String text = MessageText.getString("v3.mb.delPublished.text",
-							new String[] {
-								dm.getDisplayName(),
-								site,
-								site_host,
-								ContentNetworkUtils.getUrl(cn,
-										ContentNetwork.SERVICE_PUBLISH_ABOUT)
-							});
-
-					MessageBoxShell mb = new MessageBoxShell(shell, title, text,
-							new String[] {
-								MessageText.getString("v3.mb.delPublished.delete"),
-								MessageText.getString("v3.mb.delPublished.cancel")
-							}, 1);
-					mb.setRelatedObject(dm);
-
-					int result = mb.open();
-					if (result != 0) {
-						throw new GlobalManagerDownloadRemovalVetoException("", true);
-					}
-				} else if (PlatformTorrentUtils.isContentDRM(torrent) && remove_data) {
+				if (PlatformTorrentUtils.isContentDRM(torrent) && remove_data) {
 
 					String prefix = "v3.mb.deletePurchased.";
 					String title = MessageText.getString(prefix + "title");
@@ -334,14 +268,15 @@ public class MainWindow
 						dm.getDisplayName()
 					});
 
-					MessageBoxShell mb = new MessageBoxShell(shell, title, text,
+					MessageBoxShell mb = new MessageBoxShell(title, text,
 							new String[] {
 								MessageText.getString(prefix + "button.delete"),
 								MessageText.getString(prefix + "button.cancel")
 							}, 1);
 					mb.setRelatedObject(dm);
 
-					int result = mb.open();
+					mb.open(null);
+					int result = mb.waitUntilClosed();
 					if (result != 0) {
 						throw new GlobalManagerDownloadRemovalVetoException("", true);
 					}
@@ -428,23 +363,6 @@ public class MainWindow
 			uiFunctions.showGlobalTransferBar();
 		}
 
-		VuzeBuddyManager.init(new VuzeBuddyCreator() {
-			public VuzeBuddy createBuddy(String publicKey) {
-				VuzeBuddyManager.log("created buddy: " + publicKey);
-				return new VuzeBuddySWTImpl(publicKey);
-			}
-
-			public VuzeBuddy createBuddy() {
-				VuzeBuddyManager.log("created buddy");
-				return new VuzeBuddySWTImpl();
-			}
-
-			// @see com.aelitis.azureus.buddy.VuzeBuddyCreator#createPotentialBuddy(Map)
-			public VuzeBuddy createPotentialBuddy(Map map) {
-				return new VuzeBuddyFakeSWTImpl(map);
-			}
-		});
-
 		// Hack for 3014 -> 3016 upgrades on Vista who become an Administrator
 		// user after restart.
 		if (Constants.isWindows
@@ -467,11 +385,13 @@ public class MainWindow
 						fos.close();
 
 						COConfigurationManager.setParameter("vista.adminquit", true);
-						MessageBoxShell.open(shell,
+						MessageBoxShell mb = new MessageBoxShell(
 								MessageText.getString("mb.azmustclose.title"),
 								MessageText.getString("mb.azmustclose.text"), new String[] {
 									MessageText.getString("Button.ok")
 								}, 0);
+						mb.open(null);
+						mb.waitUntilClosed();
 						if (uiInitializer != null) {
 							uiInitializer.abortProgress();
 						}
@@ -483,34 +403,11 @@ public class MainWindow
 			}
 		}
 
-		try {
-			DCAdManager.getInstance().initialize(core);
-		} catch (Throwable e) {
-		}
-
 		StimulusRPC.hookListeners(core, this);
 
 		uiSWTInstanceImpl = new UISWTInstanceImpl(core);
 		uiSWTInstanceImpl.init(uiInitializer);
 
-		PluginInterface pi = core.getPluginManager().getPluginInterfaceByID(
-				"azbpstartstoprules");
-		if (pi != null) {
-			// plugin is built in, so instead of using IPC, just cast it
-			StartStopRulesDefaultPlugin plugin = (StartStopRulesDefaultPlugin) pi.getPlugin();
-			plugin.addListener(new StartStopRulesFPListener() {
-				public boolean isFirstPriority(Download dl, int numSeeds, int numPeers,
-						StringBuffer debug) {
-					// FP while our content doesn't have another seed
-					boolean b = dl.getState() == Download.ST_SEEDING && numSeeds == 0
-							&& dl.getStats().getAvailability() < 2
-							&& PublishUtils.isPublished(dl); // do last as most costly
-
-					return b;
-				}
-			});
-		}
-
 		VuzeActivitiesManager.initialize(core);
 
 		// When a download is added, check for new meta data and
@@ -547,40 +444,7 @@ public class MainWindow
 
 					throws GlobalManagerDownloadRemovalVetoException {
 				TOTorrent torrent = dm.getTorrent();
-				if (PublishUtils.isPublished(dm)) {
-					String title = MessageText.getString("v3.mb.delPublished.title");
-
-					ContentNetwork cn = DataSourceUtils.getContentNetwork(torrent);
-					if (cn == null) {
-						return;
-					}
-
-					String site = ContentNetworkUtils.getUrl(cn,
-							ContentNetwork.SERVICE_SITE);
-
-					String site_host = (String) cn.getProperty(ContentNetwork.PROPERTY_SITE_HOST);
-
-					String text = MessageText.getString("v3.mb.delPublished.text",
-							new String[] {
-								dm.getDisplayName(),
-								site,
-								site_host,
-								ContentNetworkUtils.getUrl(cn,
-										ContentNetwork.SERVICE_PUBLISH_ABOUT)
-							});
-
-					MessageBoxShell mb = new MessageBoxShell(shell, title, text,
-							new String[] {
-								MessageText.getString("v3.mb.delPublished.delete"),
-								MessageText.getString("v3.mb.delPublished.cancel")
-							}, 1);
-					mb.setRelatedObject(dm);
-
-					int result = mb.open();
-					if (result != 0) {
-						throw new GlobalManagerDownloadRemovalVetoException("", true);
-					}
-				} else if (PlatformTorrentUtils.isContentDRM(torrent) && remove_data) {
+				if (PlatformTorrentUtils.isContentDRM(torrent) && remove_data) {
 
 					String prefix = "v3.mb.deletePurchased.";
 					String title = MessageText.getString(prefix + "title");
@@ -588,14 +452,15 @@ public class MainWindow
 						dm.getDisplayName()
 					});
 
-					MessageBoxShell mb = new MessageBoxShell(shell, title, text,
+					MessageBoxShell mb = new MessageBoxShell(title, text,
 							new String[] {
 								MessageText.getString(prefix + "button.delete"),
 								MessageText.getString(prefix + "button.cancel")
 							}, 1);
 					mb.setRelatedObject(dm);
 
-					int result = mb.open();
+					mb.open(null);
+					int result = mb.waitUntilClosed();
 					if (result != 0) {
 						throw new GlobalManagerDownloadRemovalVetoException("", true);
 					}
@@ -658,7 +523,6 @@ public class MainWindow
 	}
 
 	private void downloadAdded(final DownloadManager[] dms) {
-		ArrayList<TOTorrent> toUpdateGlobalRating = new ArrayList();
 		boolean oneIsNotPlatform = false;
 		for (final DownloadManager dm : dms) {
 			if (dm == null) {
@@ -696,7 +560,8 @@ public class MainWindow
 				}
 			}
 
-			boolean isContent = PlatformTorrentUtils.isContent(torrent, true);
+			boolean isContent = PlatformTorrentUtils.isContent(torrent, true)
+					|| PlatformTorrentUtils.getContentNetworkID(torrent) == ContentNetwork.CONTENT_NETWORK_VHDNL;
 
 			if (!oneIsNotPlatform && !isContent
 					&& !dmState.getFlag(DownloadManagerState.FLAG_LOW_NOISE)) {
@@ -706,43 +571,7 @@ public class MainWindow
 			final String fHash = hash;
 
 			if (isContent) {
-				if (PlatformTorrentUtils.getUserRating(torrent) == -2) {
-					PlatformTorrentUtils.setUserRating(torrent, -1);
-					PlatformRatingMessenger.getUserRating(
-							PlatformTorrentUtils.getContentNetworkID(torrent), new String[] {
-								PlatformRatingMessenger.RATE_TYPE_CONTENT
-							}, new String[] {
-								hash
-							}, 5000);
-				}
-
 				long now = SystemTime.getCurrentTime();
-				long mdRefreshOn = PlatformTorrentUtils.getMetaDataRefreshOn(torrent);
-				if (mdRefreshOn < now) {
-					PlatformTorrentUtils.log(torrent, "addDM, update MD NOW");
-					PlatformTorrentUtils.updateMetaData(torrent, 5000);
-				} else {
-					PlatformTorrentUtils.log(torrent, "addDM, update MD on "
-							+ new Date(mdRefreshOn));
-					SimpleTimer.addEvent("Update MD", mdRefreshOn,
-							new TimerEventPerformer() {
-								public void perform(TimerEvent event) {
-									PlatformTorrentUtils.updateMetaData(torrent, 15000);
-								}
-							});
-				}
-
-				long grRefreshOn = GlobalRatingUtils.getRefreshOn(torrent);
-				if (grRefreshOn <= now) {
-					toUpdateGlobalRating.add(torrent);
-				} else {
-					SimpleTimer.addEvent("Update G.Rating", grRefreshOn,
-							new TimerEventPerformer() {
-								public void perform(TimerEvent event) {
-									PlatformRatingMessenger.updateGlobalRating(torrent, 15000);
-								}
-							});
-				}
 
 				long expiresOn = PlatformTorrentUtils.getExpiresOn(torrent);
 				if (expiresOn > now) {
@@ -755,22 +584,12 @@ public class MainWindow
 								}
 							});
 				}
-
-				if (PublishUtils.isPublished(dm)
-						&& dm.getStats().getShareRatio() < 1000 && !dm.isForceStart()) {
-					dm.setForceStart(true);
-				}
 			} // isContent
 		}
 
 		if (oneIsNotPlatform && dms_Startup == null) {
 			DonationWindow.checkForDonationPopup();
 		}
-
-		if (toUpdateGlobalRating.size() > 0) {
-			TOTorrent[] torrents = toUpdateGlobalRating.toArray(new TOTorrent[0]);
-			PlatformRatingMessenger.updateGlobalRating(torrents, 5000);
-		}
 	}
 
 	/**
@@ -868,22 +687,47 @@ public class MainWindow
 					+ (SystemTime.getCurrentTime() - startTime) + "ms");
 			startTime = SystemTime.getCurrentTime();
 
-			if (org.gudy.azureus2.core3.util.Constants.isOSX
-					&& SWT.getPlatform().equals("carbon")) {
-				try {
+			if (Constants.isOSX) {
+				if (Utils.isCarbon) {
+  				try {
+  
+  					Class<?> ehancerClass = Class.forName("org.gudy.azureus2.ui.swt.osx.CarbonUIEnhancer");
+  
+  					Method method = ehancerClass.getMethod("registerToolbarToggle",
+  							new Class[] {
+  								Shell.class
+  							});
+  					method.invoke(null, new Object[] {
+  						shell
+  					});
+  
+  				} catch (Exception e) {
+  					Debug.printStackTrace(e);
+  				}
+				} else if (Utils.isCocoa) {
+					try {
 
-					Class ehancerClass = Class.forName("org.gudy.azureus2.ui.swt.osx.CarbonUIEnhancer");
+						Class<?> ehancerClass = Class.forName("org.gudy.azureus2.ui.swt.osx.CocoaUIEnhancer");
 
-					Method method = ehancerClass.getMethod("registerToolbarToggle",
-							new Class[] {
-								Shell.class
+						Method mGetInstance = ehancerClass.getMethod("getInstance",
+								new Class[0]);
+						Object claObj = mGetInstance.invoke(null, new Object[0]);
+
+						Method mregTBToggle = claObj.getClass().getMethod(
+								"registerToolbarToggle", new Class[] {
+									Shell.class
+								});
+						if (mregTBToggle != null) {
+							mregTBToggle.invoke(claObj, new Object[] {
+								shell
 							});
-					method.invoke(null, new Object[] {
-						shell
-					});
+						}
+
+					} catch (Throwable e) {
+
+						Debug.printStackTrace(e);
+					}
 
-				} catch (Exception e) {
-					Debug.printStackTrace(e);
 				}
 
 				Listener toggleListener = new Listener() {
@@ -937,6 +781,15 @@ public class MainWindow
 					}
 				}
 
+				public void shellActivated(ShellEvent e) {
+					Shell shellAppModal = Utils.findFirstShellWithStyle(SWT.APPLICATION_MODAL);
+					if (shellAppModal != null) {
+						shellAppModal.forceActive();
+					} else {
+						shell.forceActive();
+					}
+				}
+
 				public void shellIconified(ShellEvent event) {
 					if (disposedOrDisposing) {
 						return;
@@ -966,11 +819,6 @@ public class MainWindow
 			startTime = SystemTime.getCurrentTime();
 
 			if (core != null) {
-				try {
-					DCAdManager.getInstance().initialize(core);
-				} catch (Throwable e) {
-				}
-
 				StimulusRPC.hookListeners(core, this);
 			}
 
@@ -1030,37 +878,6 @@ public class MainWindow
 			increaseProgress(uiInitializer, "splash.initializeGui");
 			startTime = SystemTime.getCurrentTime();
 
-			if (core != null) {
-				PluginInterface pi = core.getPluginManager().getPluginInterfaceByID(
-						"azbpstartstoprules");
-				if (pi != null) {
-					// plugin is built in, so instead of using IPC, just cast it
-					StartStopRulesDefaultPlugin plugin = (StartStopRulesDefaultPlugin) pi.getPlugin();
-					plugin.addListener(new StartStopRulesFPListener() {
-						public boolean isFirstPriority(Download dl, int numSeeds,
-								int numPeers, StringBuffer debug) {
-							// FP while our content doesn't have another seed
-							boolean b = dl.getState() == Download.ST_SEEDING && numSeeds == 0
-									&& dl.getStats().getAvailability() < 2
-									&& PublishUtils.isPublished(dl); // do last as most costly
-
-							return b;
-						}
-					});
-				}
-			}
-
-			ManagerUtils.setRunRunnable(new RunDownloadManager() {
-				public void run(DownloadManager dm) {
-					TOTorrent torrent = dm.getTorrent();
-					if (PlatformTorrentUtils.isContent(torrent, true)
-							&& PlatformTorrentUtils.isContentAdEnabled(torrent)) {
-						TorrentListViewsUtils.playOrStream(dm);
-					} else {
-						Utils.launch(dm.getSaveLocation().toString());
-					}
-				}
-			});
 		} catch (Throwable t) {
 			Debug.out(t);
 		} finally {
@@ -1074,12 +891,6 @@ public class MainWindow
 					COConfigurationManager.getBooleanParameter(configID)
 							&& COConfigurationManager.getIntParameter("User Mode") > 1);
 
-			configID = "Friends.visible";
-			if (false == ConfigurationDefaults.getInstance().doesParameterDefaultExist(
-					configID)) {
-				COConfigurationManager.setBooleanDefault(configID, true);
-			}
-
 			setVisible(WINDOW_ELEMENT_TABBAR, true);
 
 			shell.layout(true, true);
@@ -1131,32 +942,7 @@ public class MainWindow
 
 									uif.bringToFront();
 								}
-							} else if (type == NavigationHelper.COMMAND_BUDDY_SYNC) {
-
-								try {
-									PlatformRelayMessenger.fetch(0);
-									PlatformBuddyMessenger.sync(null);
-									PlatformBuddyMessenger.getInvites();
-								} catch (NotLoggedInException e1) {
-								}
-
 							} else if (type == NavigationHelper.COMMAND_CONDITION_CHECK) {
-
-								if (args[0].equals(NavigationHelper.COMMAND_CHECK_BUDDY_MANAGER)) {
-
-									if (args[1].equals(NavigationHelper.COMMAND_CHECK_BUDDY_MANAGER_ENABLED)) {
-
-										if (!VuzeBuddyManager.isEnabled()) {
-
-											VuzeBuddyManager.showDisabledDialog();
-
-											if (uif != null) {
-
-												uif.bringToFront();
-											}
-										}
-									}
-								}
 							}
 						}
 					});
@@ -1177,31 +963,38 @@ public class MainWindow
 
 		Utils.execSWTThreadLater(0, new AERunnable() {
 			public void runSupport() {
+				final String CFG_STARTTAB = "v3.StartTab";
 				String startTab;
 				boolean showWelcome = COConfigurationManager.getBooleanParameter("v3.Show Welcome");
-				boolean startAdv = COConfigurationManager.getBooleanParameter("v3.Start Advanced");
 
 				ContentNetwork startupCN = ContentNetworkManagerFactory.getSingleton().getStartupContentNetwork();
 				if (!startupCN.isServiceSupported(ContentNetwork.SERVICE_WELCOME)) {
 					showWelcome = false;
 				}
 
-				if (showWelcome && !startAdv) {
+				if (showWelcome) {
 					startTab = SideBar.SIDEBAR_SECTION_WELCOME;
 				} else {
-					if (showWelcome && startAdv) {
-						sidebar.showEntryByID(SideBar.SIDEBAR_SECTION_WELCOME);
+					if (!COConfigurationManager.hasParameter(CFG_STARTTAB, true)) {
+						COConfigurationManager.setParameter(CFG_STARTTAB,
+								SideBar.SIDEBAR_SECTION_LIBRARY);
 					}
-					if (COConfigurationManager.getBooleanParameter("v3.Start Advanced")) {
+					startTab = COConfigurationManager.getStringParameter(CFG_STARTTAB);
+					if (!SideBar.entryExists(startTab)) {
 						startTab = SideBar.SIDEBAR_SECTION_LIBRARY;
-					} else {
-						startTab = "ContentNetwork." + startupCN.getID();
-						ContentNetworkUtils.setSourceRef(startTab, "startup", false);
 					}
 				}
 				sidebar.showEntryByTabID(startTab);
 			}
 		});
+		
+		sidebar.addListener(new SideBarListener() {
+			public void sidebarItemSelected(SideBarEntrySWT newSideBarEntry,
+					SideBarEntrySWT oldSideBarEntry) {
+				COConfigurationManager.setParameter("v3.StartTab",
+						newSideBarEntry.getId());
+			}
+		});
 
 		//		System.out.println("Activate sidebar " + startTab + " took "
 		//				+ (SystemTime.getCurrentTime() - startTime) + "ms");
@@ -1256,24 +1049,14 @@ public class MainWindow
 		isReady = false;
 
 		disposedOrDisposing = true;
-		if (oldMainWindow != null) {
-			boolean res = oldMainWindow.dispose(bForRestart, bCloseAlreadyInProgress);
-			oldMainWindow = null;
-
-			if (res == false) {
-				disposedOrDisposing = false;
-				return false;
-			}
-		} else {
-			if (core != null
-					&& !UIExitUtilsSWT.canClose(core.getGlobalManager(), bForRestart)) {
-				disposedOrDisposing = false;
-				return false;
-			}
-
-			UIExitUtilsSWT.uiShutdown();
+		if (core != null
+				&& !UIExitUtilsSWT.canClose(core.getGlobalManager(), bForRestart)) {
+			disposedOrDisposing = false;
+			return false;
 		}
 
+		UIExitUtilsSWT.uiShutdown();
+
 		if (systemTraySWT != null) {
 			systemTraySWT.dispose();
 		}
@@ -1457,14 +1240,8 @@ public class MainWindow
 	}
 
 	private void showMainWindow() {
-		if (oldMainWindow != null) {
-			//oldMainWindow.postPluginSetup(-1, 0);
-		}
-
 		boolean isOSX = org.gudy.azureus2.core3.util.Constants.isOSX;
-		// No tray access on OSX yet
-		boolean bEnableTray = COConfigurationManager.getBooleanParameter("Enable System Tray")
-				&& (!isOSX || SWT.getVersion() > 3300);
+		boolean bEnableTray = COConfigurationManager.getBooleanParameter("Enable System Tray");
 		boolean bPassworded = COConfigurationManager.getBooleanParameter("Password enabled");
 		boolean bStartMinimize = bEnableTray
 				&& (bPassworded || COConfigurationManager.getBooleanParameter("Start Minimized"));
@@ -1487,16 +1264,21 @@ public class MainWindow
 			if (!isOSX) {
 				shell.forceActive();
 			}
-		} else if (isOSX) {
-			shell.setMinimized(true);
+		} else if (Utils.isCarbon) {
 			shell.setVisible(true);
+			shell.setMinimized(true);
 		}
 		
 
 		if (delayedCore) {
-			// TODO: Check if update window takes control and messes things up
-  		while (!display.isDisposed() && display.readAndDispatch());
-  		System.out.println("---------DONE DISPATCH AT "
+			// max 5 seconds of dispatching.  We don't display.sleep here because
+			// we only want to clear the backlog of SWT events, and sleep would
+			// add new ones
+			long endSWTDispatchOn = SystemTime.getOffsetTime(5000);
+			while (SystemTime.getCurrentTime() < endSWTDispatchOn
+					&& !display.isDisposed() && display.readAndDispatch());
+
+			System.out.println("---------DONE DISPATCH AT "
   				+ SystemTime.getCurrentTime() + ";"
   				+ (SystemTime.getCurrentTime() - Initializer.startTime) + "ms");
   		if (display.isDisposed()) {
@@ -1511,6 +1293,7 @@ public class MainWindow
 
 			} catch (Throwable e) {
 
+				e.printStackTrace();
 				Logger.log(new LogEvent(LOGID, LogEvent.LT_ERROR,
 						"Upgrade to SWT3.0M8 or later for system tray support."));
 			}
@@ -1598,7 +1381,9 @@ public class MainWindow
 				}
 
 				if (visible) {
-					shell.setMinimized(false);
+					if (shell.getMinimized()) {
+						shell.setMinimized(false);
+					}
 					if (!currentlyVisible
 							&& COConfigurationManager.getBooleanParameter("window.maximized")) {
 						shell.setMaximized(true);
@@ -1816,14 +1601,10 @@ public class MainWindow
 		 * before it's even shown for the first time
 		 */
 		Class[] forceInits = new Class[] {
-			BuddiesViewer.class,
 			SideBar.class,
-			FriendsToolbar.class
 		};
 		String[] forceInitsIDs = new String[] {
-			SkinConstants.VIEWID_BUDDIES_VIEWER,
 			SkinConstants.VIEWID_SIDEBAR,
-			SkinConstants.VIEWID_FRIENDS_TOOLBAR
 		};
 
 		for (int i = 0; i < forceInits.length; i++) {
@@ -1903,11 +1684,6 @@ public class MainWindow
 						topbarMenu);
 			}
 		}
-
-		/*
-		 * Init the user area for login/logout info
-		 */
-		new UserAreaUtils(skin, uiFunctions);
 	}
 
 	private void addMenuAndNonTextChildren(Composite parent, Menu menu) {
@@ -2115,7 +1891,7 @@ public class MainWindow
 		if (fd == null || fd.width <= 0) {
 			return;
 		}
-		if (clientArea.width > 1024 && fd.width == 260) {
+		if (clientArea.width > 1024 && fd.width == 195) {
 			return;
 		}
 		SWTSkinObject soTabBar = skin.getSkinObject(SkinConstants.VIEWID_TAB_BAR);
@@ -2127,8 +1903,8 @@ public class MainWindow
 		fd.width = clientArea.width - (size.x - oldWidth) - 5;
 		if (fd.width < 100) {
 			fd.width = 100;
-		} else if (fd.width > 260) {
-			fd.width = 260;
+		} else if (fd.width > 195) {
+			fd.width = 195;
 		}
 
 		if (oldWidth != fd.width) {
@@ -2243,46 +2019,6 @@ public class MainWindow
 		}
 	}
 
-	/**
-	 * 
-	 */
-	private org.gudy.azureus2.ui.swt.mainwindow.MainWindow createOldMainWindow() {
-		if (oldMainWindow != null || disposedOrDisposing) {
-			return oldMainWindow;
-		}
-
-		SideBar sideBar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-		if (sideBar != null) {
-			sideBar.showEntryByID(SideBar.SIDEBAR_SECTION_ADVANCED);
-		}
-
-		SkinView skinView = SkinViewManager.getByClass(SBC_AdvancedView.class);
-		if (skinView instanceof SBC_AdvancedView) {
-			oldMainWindow = ((SBC_AdvancedView) skinView).getOldMainWindow();
-		}
-		return oldMainWindow;
-	}
-
-	public org.gudy.azureus2.ui.swt.mainwindow.MainWindow getOldMainWindow(
-			boolean bForceCreate) {
-		if (oldMW_SB == null && bForceCreate) {
-			oldMainWindow = createOldMainWindow();
-		}
-		oldMainWindow = oldMW_SB;
-
-		return oldMainWindow;
-	}
-
-	public UIFunctionsSWT getOldUIFunctions(boolean bCreateOld) {
-		if (oldMainWindow == null && bCreateOld) {
-			createOldMainWindow();
-		}
-		if (oldMainWindow != null) {
-			return oldMainWindow.getUIFunctions();
-		}
-		return null;
-	}
-
 	public UISWTInstance getUISWTInstanceImpl() {
 		return uiSWTInstanceImpl;
 	}
@@ -2293,23 +2029,6 @@ public class MainWindow
 	 */
 	public void showURL(final String url, String target) {
 
-		if (url.startsWith("AZMSG%3B") && false) {
-			try {
-				BrowserMessage browserMsg;
-				browserMsg = new BrowserMessage(URLDecoder.decode(url, "utf-8"));
-				ClientMessageContext context = PlatformMessenger.getClientMessageContext();
-				BrowserMessageDispatcher dispatcher = context.getDispatcher();
-				if (dispatcher != null) {
-					dispatcher.dispatch(browserMsg);
-					dispatcher.resetSequence();
-				} else {
-					browserMsg.debug("no dispatcher for showURL action");
-				}
-			} catch (UnsupportedEncodingException e) {
-			}
-			return;
-		}
-
 		if ("_blank".equalsIgnoreCase(target)) {
 			Utils.launch(url);
 			return;
@@ -2371,12 +2090,6 @@ public class MainWindow
 
 	public boolean isVisible(int windowElement) {
 		if (windowElement == IMainWindow.WINDOW_ELEMENT_TOOLBAR) {
-			/*
-			 * Only the (embedded) old main window has a toolbar which is available only in Vuze Advanced
-			 */
-			if (null != oldMainWindow) {
-				return oldMainWindow.isVisible(windowElement);
-			}
 		} else if (windowElement == IMainWindow.WINDOW_ELEMENT_TOPBAR) {
 			SWTSkinObject skinObject = skin.getSkinObject(SkinConstants.VIEWID_PLUGINBAR);
 			if (skinObject != null) {
@@ -2398,12 +2111,6 @@ public class MainWindow
 
 	public void setVisible(int windowElement, boolean value) {
 		if (windowElement == IMainWindow.WINDOW_ELEMENT_TOOLBAR) {
-			if (null != oldMainWindow) {
-				/*
-				 * Only the (embedded) old main window has a toolbar which is available only in Vuze Advanced
-				 */
-				oldMainWindow.setVisible(windowElement, value);
-			}
 		} else if (windowElement == IMainWindow.WINDOW_ELEMENT_TOPBAR) {
 
 			SWTSkinUtils.setVisibility(skin, SkinConstants.VIEWID_PLUGINBAR
@@ -2422,12 +2129,6 @@ public class MainWindow
 
 	public Rectangle getMetrics(int windowElement) {
 		if (windowElement == IMainWindow.WINDOW_ELEMENT_TOOLBAR) {
-			if (null != oldMainWindow) {
-				/*
-				 * Only the (embedded) old main window has a toolbar which is available only in Vuze Advanced
-				 */
-				return oldMainWindow.getMetrics(windowElement);
-			}
 		} else if (windowElement == IMainWindow.WINDOW_ELEMENT_TOPBAR) {
 
 			SWTSkinObject skinObject = skin.getSkinObject(SkinConstants.VIEWID_PLUGINBAR);
@@ -2510,6 +2211,9 @@ public class MainWindow
 	public void openView(final String parentID, final Class cla, String id,
 			final Object data, final boolean closeable) {
 		final SideBar sideBar = (SideBar) SkinViewManager.getByClass(SideBar.class);
+		if (sideBar == null) {
+			return;
+		}
 
 		if (id == null) {
 			id = cla.getName();
@@ -2528,56 +2232,39 @@ public class MainWindow
 		Utils.execSWTThreadLater(0, new AERunnable() {
 
 			public void runSupport() {
-				if (sideBar != null) {
-					if (isOnAdvancedView()) {
-						try {
-							final IView view = (IView) cla.newInstance();
-
-							Tab mainTabSet = oldMainWindow.getMainTabSet();
-							mainTabSet.createTabItem(view, true);
-						} catch (Exception e) {
-							Debug.out(e);
-						}
-					} else {
-						if (sideBar.showEntryByID(_id)) {
-							return;
-						}
-						if (UISWTViewEventListener.class.isAssignableFrom(cla)) {
-							try {
-								UISWTViewEventListener l = (UISWTViewEventListener) cla.newInstance();
-								sideBar.createTreeItemFromEventListener(parentID, null, l, _id,
-										closeable, data);
-							} catch (Exception e) {
-								Debug.out(e);
-							}
-						} else {
-							sideBar.createTreeItemFromIViewClass(parentID, _id, null, cla,
-									null, null, data, null, true);
-						}
-						sideBar.showEntryByID(_id);
-					}
+				if (sideBar.showEntryByID(_id)) {
+					return;
 				}
+				if (UISWTViewEventListener.class.isAssignableFrom(cla)) {
+					UISWTViewEventListener l = null;
+					try {
+						Constructor<?> constructor = cla.getConstructor(new Class[] {
+							data.getClass()
+						});
+						l = (UISWTViewEventListener) constructor.newInstance(new Object[] {
+							data
+						});
+					} catch (Exception e) {
+					}
+					try {
+						if (l == null) {
+							l = (UISWTViewEventListener) cla.newInstance();
+						}
+						sideBar.createTreeItemFromEventListener(parentID, null, l, _id,
+								closeable, data);
+					} catch (Exception e) {
+						Debug.out(e);
+					}
+				} else {
+					sideBar.createTreeItemFromIViewClass(parentID, _id, null, cla,
+							null, null, data, null, true);
+				}
+				sideBar.showEntryByID(_id);
 			}
 		});
 
 	}
 
-	public boolean isOnAdvancedView() {
-		SideBar sideBar = (SideBar) SkinViewManager.getByClass(SideBar.class);
-		if (sideBar == null) {
-			return false;
-		}
-		SideBarEntrySWT currentSB = sideBar.getCurrentEntry();
-		if (currentSB == null) {
-			return false;
-		}
-		if (oldMainWindow != null && currentSB.id != null
-				&& currentSB.id.equals(SideBar.SIDEBAR_SECTION_ADVANCED)) {
-			return true;
-		}
-		return false;
-	}
-
 	// @see com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarListener#sidebarItemSelected(com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarInfoSWT, com.aelitis.azureus.ui.swt.views.skin.sidebar.SideBarInfoSWT)
 	public void sidebarItemSelected(SideBarEntrySWT newSideBarEntry,
 			SideBarEntrySWT oldSideBarEntry) {
@@ -2600,20 +2287,6 @@ public class MainWindow
 			updateMapTrackUsage(id2);
 		}
 
-		if (newSideBarEntry.id.equals(SideBar.SIDEBAR_SECTION_ADVANCED)
-				&& oldMW_SB == null) {
-			SkinView[] advViews = SkinViewManager.getMultiByClass(SBC_AdvancedView.class);
-			if (advViews != null) {
-				for (int i = 0; i < advViews.length; i++) {
-					SBC_AdvancedView advView = (SBC_AdvancedView) advViews[i];
-					if (oldMW_tab == null || advView.getOldMainWindow() != oldMW_tab) {
-						oldMW_SB = advView.getOldMainWindow();
-					}
-				}
-			}
-			oldMainWindow = oldMW_SB;
-		}
-
 		if (mapTrackUsage != null) {
 			newSideBarEntry.addListener((SideBarLogIdListener) this);
 		}
