@@ -29,6 +29,8 @@ import org.eclipse.swt.events.PaintListener;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.widgets.*;
 
+import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.logging.LogEvent;
@@ -45,6 +47,7 @@ import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.mainwindow.*;
 import org.gudy.azureus2.ui.swt.mainwindow.MainWindow;
 import org.gudy.azureus2.ui.swt.minibar.AllTransfersBar;
+import org.gudy.azureus2.ui.swt.minibar.MiniBarManager;
 import org.gudy.azureus2.ui.swt.plugins.*;
 import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTInstanceImpl;
 import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTViewImpl;
@@ -52,6 +55,7 @@ import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
 import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.update.FullUpdateWindow;
 import org.gudy.azureus2.ui.swt.views.*;
+import org.gudy.azureus2.ui.swt.views.clientstats.ClientStatsView;
 import org.gudy.azureus2.ui.swt.views.stats.StatsView;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
 
@@ -59,9 +63,7 @@ import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
 import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
-import com.aelitis.azureus.ui.InitializerListener;
-import com.aelitis.azureus.ui.UIFunctionsUserPrompter;
-import com.aelitis.azureus.ui.UIStatusTextClickListener;
+import com.aelitis.azureus.ui.*;
 import com.aelitis.azureus.ui.common.updater.UIUpdater;
 import com.aelitis.azureus.ui.selectedcontent.SelectedContentManager;
 import com.aelitis.azureus.ui.swt.Initializer;
@@ -105,30 +107,32 @@ public class UIFunctionsImpl
 	 */
 	private SWTSkin skin = null;
 
+	protected boolean isTorrentMenuVisible;
+
 	/**
 	 * @param window
 	 */
 	public UIFunctionsImpl(
 			com.aelitis.azureus.ui.swt.shells.main.MainWindow window) {
 		this.mainWindow = window;
+		
+		COConfigurationManager.addAndFireParameterListener(
+				"Menu.show.torrent.menu", new ParameterListener() {
+					public void parameterChanged(String parameterName) {
+						isTorrentMenuVisible = COConfigurationManager.getBooleanParameter("Menu.show.torrent.menu");
+					}
+				});
 	}
 
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#addPluginView(org.gudy.azureus2.plugins.PluginView)
 	public void addPluginView(PluginView view) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				pluginViews_mon.enter();
-				try {
-					mapPluginViews.put(view, null);
-				} finally {
-					pluginViews_mon.exit();
-				}
-				return;
+			pluginViews_mon.enter();
+			try {
+				mapPluginViews.put(view, null);
+			} finally {
+				pluginViews_mon.exit();
 			}
-
-			uiFunctions.addPluginView(view);
-
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "addPluginView", e));
 		}
@@ -154,19 +158,12 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#addPluginView(org.gudy.azureus2.ui.swt.plugins.UISWTPluginView)
 	public void addPluginView(UISWTPluginView view) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				pluginViews_mon.enter();
-				try {
-					mapPluginViews.put(view, null);
-				} finally {
-					pluginViews_mon.exit();
-				}
-				return;
+			pluginViews_mon.enter();
+			try {
+				mapPluginViews.put(view, null);
+			} finally {
+				pluginViews_mon.exit();
 			}
-
-			uiFunctions.addPluginView(view);
-
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "addPluginView", e));
 		}
@@ -197,12 +194,11 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#closeDownloadBars()
 	public void closeDownloadBars() {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				return;
-			}
-
-			uiFunctions.closeDownloadBars();
+			Utils.execSWTThreadLater(0, new AERunnable() {
+				public void runSupport() {
+					MiniBarManager.getManager().closeAll();
+				}
+			});
 
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "closeDownloadBars", e));
@@ -213,11 +209,6 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#closePluginView(org.gudy.azureus2.ui.swt.views.IView)
 	public void closePluginView(IView view) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions != null) {
-				uiFunctions.closePluginView(view);
-			}
-
 			SkinView sideBarView = SkinViewManager.getByClass(SideBar.class);
 			if (sideBarView instanceof SideBar) {
 				SideBar sideBar = (SideBar) sideBarView;
@@ -243,11 +234,6 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#closePluginViews(java.lang.String)
 	public void closePluginViews(String sViewID) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions != null) {
-				uiFunctions.closePluginViews(sViewID);
-			}
-
 			SkinView sideBarView = SkinViewManager.getByClass(SideBar.class);
 			if (sideBarView instanceof SideBar) {
 				SideBar sideBar = (SideBar) sideBarView;
@@ -286,13 +272,7 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#getPluginViews()
 	public UISWTView[] getPluginViews() {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(true);
-			if (uiFunctions == null) {
-				return new UISWTView[0];
-			}
-
-			return uiFunctions.getPluginViews();
-
+			return new UISWTView[0];
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "getPluginViews", e));
 		}
@@ -370,11 +350,6 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.UIFunctions#refreshIconBar()
 	public void refreshIconBar() {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions != null) {
-				uiFunctions.refreshIconBar();
-			}
-
 			ToolBarView tb = (ToolBarView) SkinViewManager.getByClass(ToolBarView.class);
 			if (tb != null) {
 				tb.refreshCoreToolBarItems();
@@ -391,13 +366,6 @@ public class UIFunctionsImpl
 		try {
 			mainWindow.setSelectedLanguageItem();
 			
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				return;
-			}
-
-			uiFunctions.refreshLanguage();
-
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "refreshLanguage", e));
 		}
@@ -407,13 +375,8 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.UIFunctions#removeManagerView(org.gudy.azureus2.core3.download.DownloadManager)
 	public void removeManagerView(DownloadManager dm) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				return;
-			}
-
-			uiFunctions.removeManagerView(dm);
-
+			// TODO: ????!
+			
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "removeManagerView", e));
 		}
@@ -423,19 +386,14 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#removePluginView(java.lang.String)
 	public void removePluginView(String viewID) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				pluginViews_mon.enter();
-				try {
-					mapPluginViews.remove(viewID);
-				} finally {
-					pluginViews_mon.exit();
-				}
-				PluginsMenuHelper.getInstance().removePluginViews(viewID);
-				return;
-			}
 
-			uiFunctions.removePluginView(viewID);
+			pluginViews_mon.enter();
+			try {
+				mapPluginViews.remove(viewID);
+			} finally {
+				pluginViews_mon.exit();
+			}
+			PluginsMenuHelper.getInstance().removePluginViews(viewID);
 
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "removePluginView", e));
@@ -446,19 +404,14 @@ public class UIFunctionsImpl
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#removePluginView(org.gudy.azureus2.ui.swt.plugins.UISWTPluginView)
 	public void removePluginView(UISWTPluginView view) {
 		try {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions == null) {
-				pluginViews_mon.enter();
-				try {
-					mapPluginViews.remove(view);
-				} finally {
-					pluginViews_mon.exit();
-				}
-				PluginsMenuHelper.getInstance().removePluginView(view, view.getPluginViewName());
-				return;
-			}
 
-			uiFunctions.removePluginView(view);
+			pluginViews_mon.enter();
+			try {
+				mapPluginViews.remove(view);
+			} finally {
+				pluginViews_mon.exit();
+			}
+			PluginsMenuHelper.getInstance().removePluginView(view, view.getPluginViewName());
 
 		} catch (Exception e) {
 			Logger.log(new LogEvent(LOGID, "removePluginView", e));
@@ -502,15 +455,15 @@ public class UIFunctionsImpl
 		return false;
 	}
 
-	public void openView(int viewID, Object data) {
-		if (mainWindow.isOnAdvancedView()) {
-			UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-			if (uiFunctions != null) {
-				uiFunctions.openView(viewID, data);
-				return;
+	public void openView(final int viewID, final Object data) {
+		Utils.execSWTThread(new AERunnable() {
+			public void runSupport() {
+				_openView(viewID, data);
 			}
-		}
-
+		});
+	}
+		
+	private void _openView(int viewID, Object data) {
 		switch (viewID) {
 			case VIEW_CONSOLE:
 				mainWindow.openView(SideBar.SIDEBAR_SECTION_TOOLS, LoggerView.class,
@@ -522,6 +475,11 @@ public class UIFunctionsImpl
 						null, data, true);
 				break;
 
+			case VIEW_PEERS_STATS:
+				mainWindow.openView(SideBar.SIDEBAR_SECTION_TOOLS, ClientStatsView.class,
+						null, data, true);
+				break;
+
 			case VIEW_CONFIG:
 				showConfig((data instanceof String) ? (String) data : null);
 				break;
@@ -670,20 +628,20 @@ public class UIFunctionsImpl
 	}
 
 	// @see com.aelitis.azureus.ui.UIFunctions#promptUser(java.lang.String, java.lang.String, java.lang.String[], int, java.lang.String, java.lang.String, boolean, int)
-	public int promptUser(String title, String text, String[] buttons,
+	public void promptUser(String title, String text, String[] buttons,
 			int defaultOption, String rememberID, String rememberText,
-			boolean rememberByDefault, int autoCloseInMS) {
-		return MessageBoxShell.open(getMainShell(), title, text, buttons,
+			boolean rememberByDefault, int autoCloseInMS, UserPrompterResultListener l) {
+		MessageBoxShell.open(getMainShell(), title, text, buttons,
 				defaultOption, rememberID, rememberText, rememberByDefault,
-				autoCloseInMS);
+				autoCloseInMS, l);
 	}
 
 	// @see com.aelitis.azureus.ui.UIFunctions#getUserPrompter(java.lang.String, java.lang.String, java.lang.String[], int)
 	public UIFunctionsUserPrompter getUserPrompter(String title, String text,
 			String[] buttons, int defaultOption) {
 
-		MessageBoxShell mb = new MessageBoxShell(getMainShell(), title, text,
-				buttons, defaultOption);
+		MessageBoxShell mb = new MessageBoxShell(title, text, buttons,
+				defaultOption);
 		return mb;
 	}
 
@@ -712,21 +670,15 @@ public class UIFunctionsImpl
 	}
 
 	public void refreshTorrentMenu() {
+		if (!isTorrentMenuVisible) {
+			return;
+		}
 		try {
-			if (mainWindow.isOnAdvancedView()) {
-				UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-
-				if (uiFunctions != null) {
-					uiFunctions.refreshTorrentMenu();
-				}
-				return;
-			}
-
 			Utils.execSWTThread(new AERunnable() {
 				public void runSupport() {
 					final MenuItem torrentItem = MenuFactory.findMenuItem(
 							mainWindow.getMainMenu().getMenu(IMenuConstants.MENU_ID_MENU_BAR),
-							MenuFactory.MENU_ID_TORRENT);
+							MenuFactory.MENU_ID_TORRENT, false);
 
 					if (null != torrentItem) {
 
@@ -776,12 +728,6 @@ public class UIFunctionsImpl
 	
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#closeAllDetails()
 	public void closeAllDetails() {
-		UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-		if (uiFunctions != null) {
-			uiFunctions.closeAllDetails();
-			return;
-		}
-
 		SkinView sideBarView = SkinViewManager.getByClass(SideBar.class);
 		if (sideBarView instanceof SideBar) {
 			SideBar sideBar = (SideBar) sideBarView;
@@ -799,10 +745,6 @@ public class UIFunctionsImpl
 	
 	// @see com.aelitis.azureus.ui.swt.UIFunctionsSWT#hasDetailViews()
 	public boolean hasDetailViews() {
-		UIFunctionsSWT uiFunctions = mainWindow.getOldUIFunctions(false);
-		if (uiFunctions != null) {
-			return uiFunctions.hasDetailViews();
-		}
 		SkinView sideBarView = SkinViewManager.getByClass(SideBar.class);
 		if (sideBarView instanceof SideBar) {
 			SideBar sideBar = (SideBar) sideBarView;
@@ -853,13 +795,13 @@ public class UIFunctionsImpl
 				public void paintControl(PaintEvent e) {
 					Control c = (Control) e.widget;
 					Point size = c.getSize();
-					e.gc.setBackground(ColorCache.getColor(e.display, "#0000ff"));
+					e.gc.setBackground(ColorCache.getColor(e.display, "#23a7df"));
 					Object data = soWaitProgress.getData("progress");
 					if (data instanceof Long) {
 						int waitProgress = ((Long) data).intValue();
 						int breakX = size.x * waitProgress / 100;
 						e.gc.fillRectangle(0, 0, breakX, size.y);
-						e.gc.setBackground(ColorCache.getColor(e.display, "#808080"));
+						e.gc.setBackground(ColorCache.getColor(e.display, "#cccccc"));
 						e.gc.fillRectangle(breakX, 0, size.x - breakX, size.y);
 					}
 				}
