@@ -3,6 +3,8 @@
  */
 package com.aelitis.azureus.ui.swt.skin;
 
+import java.util.ArrayList;
+
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
@@ -16,7 +18,7 @@ import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.ui.swt.Utils;
 
-import com.aelitis.azureus.ui.swt.utils.ImageLoader;
+import com.aelitis.azureus.ui.swt.imageloader.ImageLoader;
 
 /**
  * @author TuxPaper
@@ -28,12 +30,18 @@ public class SWTBGImagePainter
 {
 	private static boolean DEBUG = false;
 
-	private static boolean TEST_SWT_PAINTING = Constants.isOSX;
+	private static boolean TEST_SWT_PAINTING = false; //Constants.isOSX;
 
-	private Rectangle lastResizeRect = new Rectangle(0, 0, 0, 0);
+	private Rectangle lastResizeRect = Utils.EMPTY_RECT;
 
 	private final Shell shell;
 
+	private String imgSrcID;
+
+	private String imgSrcLeftID;
+
+	private String imgSrcRightID;
+
 	private Image imgSrc;
 
 	private Image imgSrcLeft;
@@ -50,7 +58,7 @@ public class SWTBGImagePainter
 
 	boolean inEvent = false;
 
-	Rectangle lastBounds = new Rectangle(0, 0, 0, 0);
+	Rectangle lastBounds = Utils.EMPTY_RECT;
 
 	Point lastShellBGSize = new Point(0, 0);
 
@@ -60,6 +68,12 @@ public class SWTBGImagePainter
 
 	private boolean bDirty;
 
+	private int fdWidth = -1;
+
+	private int fdHeight = -1;
+
+	private ImageLoader imageLoader = null;
+
 	private SWTBGImagePainter(Control control, int tileMode) {
 		this.control = control;
 		this.shell = control.getShell();
@@ -75,26 +89,6 @@ public class SWTBGImagePainter
 			Image bgImageRight, Image bgImage, int tileMode) {
 		this(control, tileMode);
 		setImages(bgImageLeft, bgImageRight, bgImage);
-		// TODO: Change layoutdata if image size changes?
-		if ((tileMode & SWTSkinUtils.TILE_BOTH) != SWTSkinUtils.TILE_BOTH) {
-			int width = SWT.DEFAULT;
-			int height = SWT.DEFAULT;
-
-			if (tileMode == SWTSkinUtils.TILE_Y || tileMode == SWTSkinUtils.TILE_NONE) {
-				width = imgSrcBounds.width + imgSrcLeftBounds.width
-						+ imgSrcRightBounds.width;
-			}
-			if (tileMode == SWTSkinUtils.TILE_X || tileMode == SWTSkinUtils.TILE_NONE) {
-				height = imgSrcBounds.height;
-			}
-			FormData fd = (FormData) control.getLayoutData();
-			if (fd == null) {
-				fd = new FormData();
-			}
-			fd.width = width;
-			fd.height = height;
-			control.setLayoutData(fd);
-		}
 
 		if (bDirty) {
 			if (control.isVisible()) {
@@ -110,7 +104,28 @@ public class SWTBGImagePainter
 
 		control.addListener(SWT.Dispose, this);
 	}
-	
+
+	public SWTBGImagePainter(Control control, ImageLoader imageLoader,
+			String bgImageLeftId,
+			String bgImageRightId, String bgImageId, int tileMode) {
+		this(control, tileMode);
+		setImage(imageLoader, bgImageLeftId, bgImageRightId, bgImageId);
+
+		if (bDirty) {
+			if (control.isVisible()) {
+				buildBackground(control);
+			}
+		}
+
+		if (!TEST_SWT_PAINTING) {
+			control.addListener(SWT.Resize, this);
+			control.addListener(SWT.Paint, this);
+			control.getShell().addListener(SWT.Show, this);
+		}
+
+		control.addListener(SWT.Dispose, this);
+	}
+
 	public void dispose() {
 		if (control == null || control.isDisposed()) {
 			return;
@@ -149,6 +164,21 @@ public class SWTBGImagePainter
 		}
 	}
 
+	public void setImage(ImageLoader imageLoader, String idLeft, String idRight,
+			String id) {
+		setImages(imageLoader, idLeft, idRight, id);
+		if (bDirty) {
+			Utils.execSWTThread(new AERunnable() {
+				public void runSupport() {
+					if (!control.isVisible()) {
+						return;
+					}
+					buildBackground(control);
+				}
+			});
+		}
+	}
+
 	private boolean imagesEqual(Image image1, Image image2) {
 		if (image1 == image2) {
 			return true;
@@ -169,10 +199,15 @@ public class SWTBGImagePainter
 			}
 			return;
 		}
+		
+		imgSrcLeftID = null;
+		imgSrcRightID = null;
+		imgSrcID = null;
+
 
 		if (DEBUG) {
 			System.out.println("SI " + bgImageLeft + ";" + bgImageRight + ";"
-					+ bgImage + ";" + control.getData("SkinObject") + "/"
+					+ bgImage + ";" + control.getData("SkinObject") + "/" + control.isVisible() + control.getSize() + "\\"
 					+ Debug.getStackTrace(true, false));
 		}
 
@@ -186,15 +221,16 @@ public class SWTBGImagePainter
 			imgSrcLeftBounds = imgSrcLeft.getBounds();
 		} else {
 			imgSrcLeft = null;
-			imgSrcLeftBounds = new Rectangle(0, 0, 0, 0);
+			imgSrcLeftBounds = Utils.EMPTY_RECT;
 		}
 		if (ImageLoader.isRealImage(bgImageRight)) {
 			imgSrcRight = bgImageRight;
 			imgSrcRightBounds = imgSrcRight.getBounds();
 		} else {
 			imgSrcRight = null;
-			imgSrcRightBounds = new Rectangle(0, 0, 0, 0);
+			imgSrcRightBounds = Utils.EMPTY_RECT;
 		}
+		
 
 		if (TEST_SWT_PAINTING) {
 			control.removeListener(SWT.Resize, this);
@@ -212,28 +248,190 @@ public class SWTBGImagePainter
 		} else {
 			bDirty = true;
 		}
+
+
+		if ((tileMode & SWTSkinUtils.TILE_BOTH) != SWTSkinUtils.TILE_BOTH) {
+			int width = SWT.DEFAULT;
+			int height = SWT.DEFAULT;
+
+			if (tileMode == SWTSkinUtils.TILE_Y || tileMode == SWTSkinUtils.TILE_NONE) {
+				width = imgSrcBounds.width + imgSrcLeftBounds.width
+						+ imgSrcRightBounds.width;
+			}
+			if (tileMode == SWTSkinUtils.TILE_X || tileMode == SWTSkinUtils.TILE_NONE) {
+				height = imgSrcBounds.height;
+			}
+			FormData fd = (FormData) control.getLayoutData();
+			if (fd == null) {
+				fd = new FormData();
+			}
+
+			if (fd.width == fdWidth || fd.height == fdHeight) {
+
+				if (fd.width == fdWidth) {
+					fdWidth = fd.width = width;
+				}
+				if (fd.height == fdHeight) {
+					fdHeight = fd.height = height;
+				}
+				control.setLayoutData(fd);
+				if (control.isVisible()) {
+					bDirty = true;
+					control.getParent().layout(true, true);
+				}
+			}
+		}
+
 	}
+	
+	/**
+	 * @param bgImageLeftId
+	 * @param bgImageRightId
+	 * @param bgImageId
+	 *
+	 * @since 4.0.0.5
+	 */
+	public void setImages(ImageLoader imageLoader, String bgImageLeftId, String bgImageRightId,
+			String bgImageId) {
+		this.imageLoader = imageLoader;
+		imgSrcLeftID = bgImageLeftId;
+		imgSrcRightID = bgImageRightId;
+		imgSrcID = bgImageId;
+		
+		imgSrcLeftBounds = Utils.EMPTY_RECT;
+		imgSrcRightBounds = Utils.EMPTY_RECT;
+
+		if (imgSrcID != null) {
+			Image imgSrc = imageLoader.getImage(imgSrcID);
+			imgSrcBounds = imgSrc.getBounds();
+			imageLoader.releaseImage(imgSrcID);
+		}
+		Image imgSrcLeft = imageLoader.getImage(imgSrcLeftID);
+		if (ImageLoader.isRealImage(imgSrcLeft)) {
+			imgSrcLeftBounds = imgSrcLeft.getBounds();
+		}
+		imageLoader.releaseImage(imgSrcLeftID);
+		
+		Image imgSrcRight = imageLoader.getImage(imgSrcRightID);
+		if (ImageLoader.isRealImage(imgSrcRight)) {
+			imgSrcRightBounds = imgSrcRight.getBounds();
+		}
+		imageLoader.releaseImage(imgSrcRightID);
+
+		if (TEST_SWT_PAINTING) {
+			control.removeListener(SWT.Resize, this);
+			control.removeListener(SWT.Paint, this);
+
+			control.addListener(SWT.Resize, this);
+			control.addListener(SWT.Paint, this);
+			bDirty = true;
+			buildBackground(control);
+		} else {
+			bDirty = true;
+		}
+
+
+		if ((tileMode & SWTSkinUtils.TILE_BOTH) != SWTSkinUtils.TILE_BOTH) {
+			int width = SWT.DEFAULT;
+			int height = SWT.DEFAULT;
+
+			if (tileMode == SWTSkinUtils.TILE_Y || tileMode == SWTSkinUtils.TILE_NONE) {
+				width = imgSrcBounds.width + imgSrcLeftBounds.width
+						+ imgSrcRightBounds.width;
+			}
+			if (tileMode == SWTSkinUtils.TILE_X || tileMode == SWTSkinUtils.TILE_NONE) {
+				height = imgSrcBounds.height;
+			}
+			FormData fd = (FormData) control.getLayoutData();
+			if (fd == null) {
+				fd = new FormData();
+			}
+
+			if (fd.width == fdWidth || fd.height == fdHeight) {
+
+				if (fd.width == fdWidth) {
+					fdWidth = fd.width = width;
+				}
+				if (fd.height == fdHeight) {
+					fdHeight = fd.height = height;
+				}
+				control.setLayoutData(fd);
+				if (control.isVisible()) {
+					bDirty = true;
+					control.getParent().layout(true, true);
+				}
+			}
+		}
+
+	}
+
 
 	public void buildBackground(Control control) {
 		if (inEvent || shell == null || shell.isDisposed() || control == null
 				|| control.isDisposed()) {
 			return;
 		}
-		
+
 		//System.out.println("BB: " + control.getData("ConfigID"));
 
 		inEvent = true;
+		
+		ArrayList<String> imagesToRelease = new ArrayList<String>(0);
+		
+		if (imgSrcLeftID != null && imageLoader.imageExists(imgSrcLeftID)) {
+			imagesToRelease.add(imgSrcLeftID);
+			imgSrcLeft = imageLoader.getImage(imgSrcLeftID);
+			imgSrcLeftBounds = imgSrcLeft.getBounds();
+		}
+		if (imgSrcRightID != null && imageLoader.imageExists(imgSrcRightID)) {
+			imagesToRelease.add(imgSrcRightID);
+			imgSrcRight = imageLoader.getImage(imgSrcRightID);
+			imgSrcRightBounds = imgSrcRight.getBounds();
+		}
+		if (imgSrcID != null) {
+			Image[] images = imageLoader.getImages(imgSrcID);
+			imagesToRelease.add(imgSrcID);
+			if (images.length == 1) {
+  			imgSrc = images[0];
+  			imgSrcBounds = imgSrc.getBounds();
+			} else if (images.length == 2) {
+				imgSrcLeft = images[0];
+				imgSrcLeftBounds = imgSrcLeft.getBounds();
+  			imgSrc = images[1];
+  			imgSrcBounds = imgSrc.getBounds();
+				imgSrcRight = images[1];
+				imgSrcRightBounds = imgSrcRight.getBounds();
+			} else if (images.length == 3) {
+				imgSrcLeft = images[0];
+				imgSrcLeftBounds = imgSrcLeft.getBounds();
+  			imgSrc = images[1];
+  			imgSrcBounds = imgSrc.getBounds();
+				imgSrcRight = images[2];
+				imgSrcRightBounds = imgSrcRight.getBounds();
+			}
+		}
+		
+		try {
 
 		Point size = control.getSize();
-		if (size.x <= 0 || size.y <= 0) {
-			inEvent = false;
+		if (size.x <= 0 || size.y <= 0 || imgSrc == null || imgSrc.isDisposed()) {
 			if (DEBUG) {
 				System.out.println("- size " + control.getData("ConfigID"));
 			}
 			Image image = new Image(shell.getDisplay(), 1, 1);
 			control.setBackgroundImage(image);
 
+			if (lastImage != null) {
+				lastImage.dispose();
+			}
+
+			lastImage = image;
+			imgSrc = image;
+			imgSrcBounds = new Rectangle(0,0,1,1);
+
 			lastBounds = control.getBounds();
+
+			inEvent = false;
 			return;
 		}
 
@@ -279,7 +477,6 @@ public class SWTBGImagePainter
 		}
 
 		//control.setRedraw(false);
-		try {
 			if (DEBUG) {
 				System.out.println(System.currentTimeMillis() + "@"
 						+ Integer.toHexString(hashCode()) + "BGPain: "
@@ -406,6 +603,19 @@ public class SWTBGImagePainter
 			bDirty = false;
 
 		} finally {
+			for (String key : imagesToRelease) {
+				imageLoader.releaseImage(key);
+			}
+			if (imgSrcID != null && imgSrc != null) {
+				imgSrc = null;
+			}
+			if (imgSrcLeftID != null && imgSrcLeft != null) {
+				imgSrcLeft = null;
+			}
+			if (imgSrcRightID != null && imgSrcRight != null) {
+				imgSrcRight = null;
+			}
+			
 			//control.setRedraw(true);
 			//control.update();
 			//control.getShell().update();
