@@ -34,9 +34,13 @@ public class SWTSkinFactory
 		}
 		return instance;
 	}
-	
+
 	public static void setInstance(SWTSkin skin) {
 		instance = skin;
 	}
 
+	public static SWTSkin getNonPersistentInstance(ClassLoader classLoader, String skinPath,
+			String mainSkinFile) {
+		return new SWTSkin(classLoader, skinPath, mainSkinFile);
+	}
 }
