@@ -26,9 +26,12 @@ import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Group;
 
 import org.gudy.azureus2.core3.util.AERunnable;
+import org.gudy.azureus2.core3.util.AERunnableObject;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.ui.swt.Utils;
 
@@ -44,6 +47,8 @@ public class SWTSkinObjectContainer
 {
 	boolean bPropogate = false;
 
+	boolean bPropogateDown = false;
+
 	public SWTSkinObjectContainer(SWTSkin skin, SWTSkinProperties properties,
 			String sID, String sConfigID, SWTSkinObject parent) {
 		super(skin, properties, sID, sConfigID, "container", parent);
@@ -55,6 +60,8 @@ public class SWTSkinObjectContainer
 			SWTSkinObject parent) {
 		super(skin, properties, sID, sConfigID, type, parent);
 
+		triggerListeners(SWTSkinObjectListener.EVENT_CREATED);
+
 		if (control != null) {
 			setControl(control);
 		}
@@ -65,6 +72,9 @@ public class SWTSkinObjectContainer
 		if (properties.getIntValue(sConfigID + ".border", 0) == 1) {
 			style = SWT.BORDER;
 		}
+		if (properties.getBooleanValue(sConfigID + ".doublebuffer", false)) {
+			style |= SWT.DOUBLE_BUFFERED;
+		}
 
 		Composite createOn;
 		if (parent == null) {
@@ -73,12 +83,14 @@ public class SWTSkinObjectContainer
 			createOn = (Composite) parent.getControl();
 		}
 
+		final int minWidth = properties.getIntValue(sConfigID + ".minwidth", -1);
+
 		Composite parentComposite;
 		if (SWTSkin.DEBUGLAYOUT) {
 			System.out.println("linkIDtoParent: Create Composite " + sID + " on "
 					+ createOn);
 			parentComposite = new Group(createOn, style);
-			((Group) parentComposite).setText(sConfigID);
+			((Group) parentComposite).setText(sConfigID == null ? sID : sConfigID);
 			parentComposite.setData("DEBUG", "1");
 		} else {
 			// Lovely SWT has a default size of 64x64 if no children have sizes.
@@ -98,6 +110,9 @@ public class SWTSkinObjectContainer
 						}
 						return new Point(1, 1);
 					}
+					if (minWidth > 0 && size.x < minWidth) {
+						size.x = minWidth;
+					}
 					return size;
 				}
 				
@@ -115,6 +130,9 @@ public class SWTSkinObjectContainer
 						}
 						return new Point(1, 1);
 					}
+					if (minWidth > 0 && size.x < minWidth) {
+						size.x = minWidth;
+					}
 					return size;
 				}
 			};
@@ -125,6 +143,13 @@ public class SWTSkinObjectContainer
 
 		setControl(control);
 	}
+	
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBasic#setControl(org.eclipse.swt.widgets.Control)
+	public void setControl(Control control) {
+		bPropogateDown = properties.getIntValue(sConfigID + ".propogateDown", 1) == 1;
+		
+		super.setControl(control);
+	}
 
 	protected void setViewID(String viewID) {
 		super.setViewID(viewID);
@@ -133,8 +158,39 @@ public class SWTSkinObjectContainer
 		}
 	}
 
-	// TODO: Need find child(view id)
 	public SWTSkinObject[] getChildren() {
+		if (isDisposed()) {
+			return new SWTSkinObject[0];
+		}
+		SWTSkinObject[] so = (SWTSkinObject[]) Utils.execSWTThreadWithObject(
+				"getChildren", new AERunnableObject() {
+
+					public Object runSupport() {
+						if (control.isDisposed()) {
+							return new SWTSkinObject[0];
+						}
+						Control[] swtChildren = ((Composite) control).getChildren();
+						ArrayList list = new ArrayList(swtChildren.length);
+						for (int i = 0; i < swtChildren.length; i++) {
+							Control childControl = swtChildren[i];
+							SWTSkinObject so = (SWTSkinObject) childControl.getData("SkinObject");
+							if (so != null) {
+								list.add(so);
+							}
+						}
+
+						return (SWTSkinObject[]) list.toArray(new SWTSkinObject[list.size()]);
+					}
+				}, 2000);
+		if (so == null) {
+			System.err.println("Tell Tux to fix this " + Debug.getCompressedStackTrace());
+			return oldgetChildren();
+		}
+		return so;
+	}
+
+	// TODO: Need find child(view id)
+	public SWTSkinObject[] oldgetChildren() {
 		String[] widgets = properties.getStringArray(sConfigID + ".widgets");
 		if (widgets == null) {
 			return new SWTSkinObject[0];
@@ -160,15 +216,19 @@ public class SWTSkinObjectContainer
 	}
 
 	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBasic#switchSuffix(java.lang.String)
-	public String switchSuffix(String suffix, int level, boolean walkUp) {
-		String sFullsuffix = super.switchSuffix(suffix, level, walkUp);
+	public String switchSuffix(final String suffix, final int level, boolean walkUp, boolean walkDown) {
+		String sFullsuffix = super.switchSuffix(suffix, level, walkUp, walkDown);
 
-		if (bPropogate && suffix != null && control != null
+		if (bPropogateDown && walkDown && suffix != null && control != null
 				&& !control.isDisposed()) {
-			SWTSkinObject[] children = getChildren();
-			for (int i = 0; i < children.length; i++) {
-				children[i].switchSuffix(suffix, level, false);
-			}
+			Utils.execSWTThread(new AERunnable() {
+				public void runSupport() {
+					SWTSkinObject[] children = getChildren();
+					for (int i = 0; i < children.length; i++) {
+						children[i].switchSuffix(suffix, level, false);
+					}
+				}
+			});
 		}
 		return sFullsuffix;
 	}
@@ -184,4 +244,38 @@ public class SWTSkinObjectContainer
 	public boolean getPropogation() {
 		return bPropogate;
 	}
+	
+	public void setDebugAndChildren(boolean b) {
+		setDebug(true);
+		SWTSkinObject[] children = getChildren();
+		for (int i = 0; i < children.length; i++) {
+			if (children[i] instanceof SWTSkinObjectContainer) {
+				((SWTSkinObjectContainer)children[i]).setDebugAndChildren(b);
+			} else {
+				children[i].setDebug(b);
+			}
+		}
+	}
+	
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBasic#setIsVisible(boolean)
+	protected boolean setIsVisible(boolean visible, boolean walkup) {
+		boolean changed = super.setIsVisible(visible, walkup);
+		
+		// Currently we ignore "changed" and set visibility on children to ensure
+		// things display
+		if (!changed || true) {
+  		SWTSkinObject[] children = getChildren();
+  		for (int i = 0; i < children.length; i++) {
+  			if (children[i] instanceof SWTSkinObjectBasic) {
+  				SWTSkinObjectBasic child = ((SWTSkinObjectBasic)children[i]);
+  				Control childControl = child.getControl();
+  				if (childControl != null && !childControl.isDisposed()) {
+  					//child.setIsVisible(visible, false);
+  					child.setIsVisible(childControl.isVisible(), false);
+  				}
+  			}
+  		}
+		}
+		return changed;
+	}
 }
