@@ -30,9 +30,15 @@ import org.eclipse.swt.widgets.*;
 
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.util.AERunnable;
+import org.gudy.azureus2.core3.util.Constants;
+import org.gudy.azureus2.core3.util.UrlUtils;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.shells.GCStringPrinter;
+import org.gudy.azureus2.ui.swt.shells.GCStringPrinter.URLInfo;
 
+import com.aelitis.azureus.core.cnetwork.ContentNetwork;
+import com.aelitis.azureus.core.cnetwork.ContentNetworkManager;
+import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
 import com.aelitis.azureus.ui.swt.utils.ColorCache;
 
 /**
@@ -63,9 +69,9 @@ public class SWTSkinObjectText2
 	private int antialiasMode = SWT.DEFAULT;
 
 	private boolean isAllcaps;
-	
+
 	private boolean hasShadow;
-	
+
 	private int hpadding;
 
 	private int vpadding;
@@ -76,6 +82,10 @@ public class SWTSkinObjectText2
 
 	private static Font font = null;
 
+	private GCStringPrinter lastStringPrinter;
+
+	private Color colorUrl;
+
 	public SWTSkinObjectText2(SWTSkin skin,
 			final SWTSkinProperties skinProperties, String sID,
 			final String sConfigID, String[] typeParams, SWTSkinObject parent) {
@@ -94,10 +104,12 @@ public class SWTSkinObjectText2
 		String sVAlign = skinProperties.getStringValue(sConfigID + ".v-align");
 		if (sVAlign != null) {
 			int align = SWTSkinUtils.getAlignment(sVAlign, SWT.NONE);
-			if (align != SWT.NONE) {
-				style |= align;
-			} else {
-				style |= SWT.TOP;
+			if (align != SWT.CENTER) {
+				if (align != SWT.NONE) {
+					style |= align;
+				} else {
+					style |= SWT.TOP;
+				}
 			}
 		} else {
 			style |= SWT.TOP;
@@ -113,7 +125,7 @@ public class SWTSkinObjectText2
 			antialiasMode = (sAntiAlias.equals("1") || sAntiAlias.toLowerCase().equals(
 					"true")) ? SWT.ON : SWT.OFF;
 		}
-		
+
 		relayoutOnTextChange = skinProperties.getBooleanValue(sConfigID
 				+ ".text.relayoutOnChange", true);
 
@@ -154,9 +166,13 @@ public class SWTSkinObjectText2
 					}
 				}
 
-				pt = gc.textExtent(sDisplayText);
-				pt.x += border + hpadding;
-				pt.y += border + vpadding;
+				GCStringPrinter sp = new GCStringPrinter(gc, sDisplayText,
+						new Rectangle(0, 0, wHint == -1 ? 999999 : wHint, hHint == -1
+								? 999999 : hHint), true, false, style & SWT.WRAP);
+				sp.calculateMetrics();
+				pt = sp.getCalculatedSize();
+				pt.x += border + hpadding * 2;
+				pt.y += border + vpadding * 2;
 				gc.dispose();
 
 				if (isUnderline) {
@@ -203,16 +219,67 @@ public class SWTSkinObjectText2
 		if (typeParams.length > 1) {
 			bIsTextDefault = true;
 			sText = typeParams[1];
+
+			for (int i = 2; i < typeParams.length; i++) {
+				sText += ", " + typeParams[i];
+			}
 			this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase()
 					: sText;
 		}
 
-		canvas.addPaintListener(this);
+		canvas.addMouseListener(new MouseListener() {
+			public void mouseUp(MouseEvent e) {
+				if (lastStringPrinter != null) {
+					URLInfo hitUrl = lastStringPrinter.getHitUrl(e.x, e.y);
+					if (hitUrl != null) {
+						String url = hitUrl.url;
+						try {
+  						ContentNetwork cn = ContentNetworkManagerFactory.getSingleton().getContentNetworkForURL(url);
+  						if (cn != null) {
+  							url = cn.appendURLSuffix(url, false, false);
+  						}
+  						if (url.contains("?")) {
+  							url += "&";
+  						} else {
+  							url += "?";
+  						}
+  						url += "fromWeb=false&os.name=" + UrlUtils.encode(Constants.OSName)
+  								+ "&os.version="
+  								+ UrlUtils.encode(System.getProperty("os.version"))
+  								+ "&java.version=" + UrlUtils.encode(Constants.JAVA_VERSION); 
+						} catch (Throwable t) {
+							// ignore
+						}
+						Utils.launch(url);
+					}
+				}
+			}
+
+			public void mouseDown(MouseEvent e) {
+			}
+
+			public void mouseDoubleClick(MouseEvent e) {
+			}
+		});
+
+		canvas.addMouseMoveListener(new MouseMoveListener() {
+			public void mouseMove(MouseEvent e) {
+				if (lastStringPrinter != null && lastStringPrinter.hasHitUrl()) {
+					URLInfo hitUrl = lastStringPrinter.getHitUrl(e.x, e.y);
+					canvas.setCursor(hitUrl == null ? null
+							: canvas.getDisplay().getSystemCursor(SWT.CURSOR_HAND));
+				}
+			}
+		});
+
+		setAlwaysHookPaintListener(true);
+
 		updateFont("");
 	}
 
-	public String switchSuffix(String suffix, int level, boolean walkUp) {
-		suffix = super.switchSuffix(suffix, level, walkUp);
+	public String switchSuffix(String suffix, int level, boolean walkUp,
+			boolean walkDown) {
+		suffix = super.switchSuffix(suffix, level, walkUp, walkDown);
 		if (suffix == null) {
 			return null;
 		}
@@ -243,12 +310,17 @@ public class SWTSkinObjectText2
 	private void updateFont(String suffix) {
 		String sPrefix = sConfigID + ".text";
 
+		Color newColorURL = properties.getColor(sPrefix + ".urlcolor" + suffix);
+		if (newColorURL != null) {
+			colorUrl = newColorURL;
+		}
+
 		Color color = properties.getColor(sPrefix + ".color" + suffix);
 		//System.out.println(this + "; " + sPrefix + ";" + suffix + "; " + color + "; " + text);
 		if (color != null) {
 			canvas.setData("color", color);
 		}
-		
+
 		hpadding = properties.getIntValue(sPrefix + ".h-padding", 0);
 		vpadding = properties.getIntValue(sPrefix + ".v-padding", 0);
 
@@ -295,7 +367,7 @@ public class SWTSkinObjectText2
 							iFontWeight |= SWT.ITALIC;
 						}
 						bNewFont = true;
-						isItalic  = true;
+						isItalic = true;
 					} else {
 						isItalic = false;
 					}
@@ -329,7 +401,7 @@ public class SWTSkinObjectText2
 					if (s.equals("normal")) {
 						bNewFont = true;
 					}
-					
+
 					if (s.equals("shadow")) {
 						hasShadow = true;
 					}
@@ -404,7 +476,6 @@ public class SWTSkinObjectText2
 				canvas.setData("Font" + suffix, canvasFont);
 			}
 		}
-		
 
 		canvas.redraw();
 	}
@@ -422,7 +493,8 @@ public class SWTSkinObjectText2
 		}
 
 		this.sText = text;
-		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase() : sText;
+		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase()
+				: sText;
 		this.sKey = null;
 		bIsTextDefault = false;
 		// Doing execSWTThreadLater delays the relayout for too long at skin startup
@@ -441,51 +513,59 @@ public class SWTSkinObjectText2
 		});
 	}
 
-	public void paintControl(PaintEvent e) {
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBasic#paintControl(org.eclipse.swt.graphics.GC)
+	public void paintControl(GC gc) {
 		if (sText == null || sText.length() == 0) {
 			return;
 		}
-		
-		super.paintControl(e.gc);
 
-		Composite composite = (Composite) e.widget;
+		super.paintControl(gc);
+
+		Composite composite = (Composite) control;
 		Rectangle clientArea = composite.getClientArea();
+		clientArea.x += hpadding;
+		clientArea.width -= hpadding * 2;
+		clientArea.y += vpadding;
+		clientArea.height -= vpadding * 2;
 
 		Font existingFont = (Font) canvas.getData("font");
 		Color existingColor = (Color) canvas.getData("color");
 
 		if (existingFont != null) {
-			e.gc.setFont(existingFont);
+			gc.setFont(existingFont);
 		}
-		
+
 		if (existingColor != null) {
-			e.gc.setForeground(existingColor);
+			gc.setForeground(existingColor);
 		}
 
 		if (antialiasMode != SWT.DEFAULT) {
 			try {
-				e.gc.setTextAntialias(antialiasMode);
+				gc.setTextAntialias(antialiasMode);
 			} catch (Exception ex) {
 				// Ignore ERROR_NO_GRAPHICS_LIBRARY error or any others
 			}
 		}
-	
+
 		if (hasShadow) {
-			Rectangle r = new Rectangle(clientArea.x + 1, clientArea.y + 1, clientArea.width,
-					clientArea.height);
-			
-			Color foreground = e.gc.getForeground();
-			Color color = ColorCache.getColor(e.gc.getDevice(), 0, 0, 0);
-			e.gc.setForeground(color);
-			e.gc.setAlpha(128);
-			GCStringPrinter.printString(e.gc, sDisplayText, r, true, false,
-					style);
-			e.gc.setAlpha(255);
-			e.gc.setForeground(foreground);
+			Rectangle r = new Rectangle(clientArea.x + 1, clientArea.y + 1,
+					clientArea.width, clientArea.height);
+
+			Color foreground = gc.getForeground();
+			Color color = ColorCache.getColor(gc.getDevice(), 0, 0, 0);
+			gc.setForeground(color);
+			gc.setAlpha(64);
+			GCStringPrinter.printString(gc, sDisplayText, r, true, false, style);
+			gc.setAlpha(255);
+			gc.setForeground(foreground);
 		}
-		
-		GCStringPrinter.printString(e.gc, sDisplayText, clientArea, true, false,
-				style);
+
+		lastStringPrinter = new GCStringPrinter(gc, sDisplayText, clientArea, true,
+				false, style);
+		if (colorUrl != null) {
+			lastStringPrinter.setUrlColor(colorUrl);
+		}
+		lastStringPrinter.printString();
 	}
 
 	public void setTextID(String key) {
@@ -498,12 +578,16 @@ public class SWTSkinObjectText2
 		}
 
 		this.sText = MessageText.getString(key);
-		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase() : sText;
+		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase()
+				: sText;
 		this.sKey = key;
 		bIsTextDefault = false;
 
 		Utils.execSWTThreadLater(0, new AERunnable() {
 			public void runSupport() {
+				if (canvas == null || canvas.isDisposed()) {
+					return;
+				}
 				canvas.redraw();
 				if (relayoutOnTextChange) {
 					canvas.layout(true);
@@ -522,17 +606,20 @@ public class SWTSkinObjectText2
 		 * KN: disabling the caching of the key since this is parameterized it may be called
 		 * multiple times with different parameters
 		 */
-//		else if (key.equals(sKey)) {
-//			return;
-//		}
-
+		//		else if (key.equals(sKey)) {
+		//			return;
+		//		}
 		this.sText = MessageText.getString(key, params);
-		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase() : sText;
+		this.sDisplayText = isAllcaps && sText != null ? sText.toUpperCase()
+				: sText;
 		this.sKey = key;
 		bIsTextDefault = false;
 
 		Utils.execSWTThreadLater(0, new AERunnable() {
 			public void runSupport() {
+				if (canvas == null || canvas.isDisposed()) {
+					return;
+				}
 				canvas.redraw();
 				if (relayoutOnTextChange) {
 					canvas.layout(true);
@@ -541,4 +628,27 @@ public class SWTSkinObjectText2
 			}
 		});
 	}
+
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectBasic#triggerListeners(int, java.lang.Object)
+	public void triggerListeners(int eventType, Object params) {
+		if (eventType == SWTSkinObjectListener.EVENT_LANGUAGE_CHANGE) {
+			if (sKey != null) {
+				setTextID(sKey);
+			}
+		}
+		super.triggerListeners(eventType, params);
+	}
+
+	public int getStyle() {
+		return style;
+	}
+
+	public void setStyle(int style) {
+		this.style = style;
+	}
+
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinObjectText#getText()
+	public String getText() {
+		return sDisplayText;
+	}
 }
