@@ -19,7 +19,7 @@
  */
 package com.aelitis.azureus.ui.swt.skin;
 
-import java.util.Properties;
+import java.util.ResourceBundle;
 
 import org.eclipse.swt.graphics.Color;
 
@@ -144,10 +144,6 @@ public class SWTSkinPropertiesClone
 		return properties.getIntValue(sTemplateConfigID + name, def);
 	}
 
-	public Properties getProperties() {
-		return properties.getProperties();
-	}
-
 	public String[] getStringArray(String name) {
 		if (name == null) {
 			return null;
@@ -305,4 +301,54 @@ public class SWTSkinPropertiesClone
 		}
 		return properties.getBooleanValue(sTemplateConfigID + name, def);
 	}
+	
+	// @see com.aelitis.azureus.ui.skin.SkinProperties#clearCache()
+	public void clearCache() {
+		properties.clearCache();
+	}
+	
+	// @see com.aelitis.azureus.ui.skin.SkinProperties#contains(java.lang.String)
+	public boolean hasKey(String name) {
+		return properties.hasKey(name);
+	}
+
+	public Color getColor(String name, Color def) {
+		Color color = getColor(name);
+		if (color == null) {
+			return def;
+		}
+		return color;
+	}
+	
+	// @see com.aelitis.azureus.ui.skin.SkinProperties#getReferenceID(java.lang.String)
+	public String getReferenceID(String name) {
+		if (name == null) {
+			return null;
+		}
+		if (DEBUG) {
+			checkName(name);
+		}
+		if (name.length() > 0 && name.charAt(0) != '.') {
+			return properties.getReferenceID(name);
+		}
+
+		if (!name.equals(IGNORE_NAME)) {
+			String val = properties.getReferenceID(sCloneConfigID + name);
+			if (val != null) {
+				return val;
+			}
+		}
+
+		return properties.getReferenceID(sTemplateConfigID + name);
+	}
+	
+	// @see com.aelitis.azureus.ui.skin.SkinProperties#addResourceBundle(java.util.ResourceBundle)
+	public void addResourceBundle(ResourceBundle subBundle) {
+		properties.addResourceBundle(subBundle);
+	}
+	
+	// @see com.aelitis.azureus.ui.skin.SkinProperties#getClassLoader()
+	public ClassLoader getClassLoader() {
+		return properties.getClassLoader();
+	}
 }
