@@ -19,12 +19,13 @@
  */
 package com.aelitis.azureus.ui.swt.skin;
 
-import java.util.HashMap;
 import java.util.Map;
 
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.widgets.Display;
 
+import org.gudy.azureus2.core3.util.LightHashMap;
+
 import com.aelitis.azureus.ui.skin.SkinPropertiesImpl;
 import com.aelitis.azureus.ui.swt.utils.ColorCache;
 
@@ -37,9 +38,7 @@ public class SWTSkinPropertiesImpl
 	extends SkinPropertiesImpl
 	implements SWTSkinProperties
 {
-	private static Map colorMap = new HashMap();
-
-	private static Map mapFallBack = new HashMap();
+	private static Map colorMap = new LightHashMap();
 
 	/**
 	 * @param skinPath
@@ -69,7 +68,7 @@ public class SWTSkinPropertiesImpl
 				color = ColorCache.getColor(Display.getCurrent(), rgb[0], rgb[1],
 						rgb[2]);
 			} else {
-				color = null;
+				color = ColorCache.getColor(Display.getCurrent(), getStringValue(sID));
 			}
 		} catch (Exception e) {
 			//				IMP.getLogger().log(LoggerChannel.LT_ERROR,
@@ -77,15 +76,19 @@ public class SWTSkinPropertiesImpl
 			color = null;
 		}
 
-		if (color == null) {
-			String sFallBackID = (String) mapFallBack.get(sID);
-			if (sFallBackID != null) {
-				color = getColor(sFallBackID);
-			}
-		}
-
 		colorMap.put(sID, color);
 
 		return color;
 	}
+
+	// @see com.aelitis.azureus.ui.swt.skin.SWTSkinProperties#getColor(java.lang.String, org.eclipse.swt.graphics.Color)
+	public Color getColor(String name, Color def) {
+		Color color = getColor(name);
+		if (color == null) {
+			return def;
+		}
+		return color;
+	}
+	
+	
 }
