@@ -30,6 +30,8 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.browser.ProgressEvent;
 import org.eclipse.swt.browser.ProgressListener;
+import org.eclipse.swt.events.DisposeEvent;
+import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
@@ -47,6 +49,7 @@ import org.gudy.azureus2.plugins.torrent.Torrent;
 import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.ui.config.BooleanParameter;
 import org.gudy.azureus2.plugins.ui.config.ConfigSection;
+import org.gudy.azureus2.plugins.ui.config.HyperlinkParameter;
 import org.gudy.azureus2.plugins.ui.config.IntParameter;
 import org.gudy.azureus2.plugins.ui.config.Parameter;
 import org.gudy.azureus2.plugins.ui.config.ParameterListener;
@@ -63,7 +66,6 @@ import org.gudy.azureus2.plugins.utils.Utilities;
 import org.gudy.azureus2.pluginsimpl.local.PluginCoreUtils;
 import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 import org.gudy.azureus2.ui.swt.CategoryAdderWindow;
-import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.PropertiesWindow;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
@@ -76,7 +78,6 @@ import org.gudy.azureus2.ui.swt.views.table.TableCellSWT;
 
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
 import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
-import com.aelitis.azureus.core.devices.TranscodeFile;
 import com.aelitis.azureus.core.messenger.ClientMessageContext;
 import com.aelitis.azureus.core.metasearch.Engine;
 import com.aelitis.azureus.core.metasearch.impl.web.WebEngine;
@@ -84,6 +85,7 @@ import com.aelitis.azureus.core.subs.*;
 import com.aelitis.azureus.core.vuzefile.VuzeFile;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
+import com.aelitis.azureus.ui.UserPrompterResultListener;
 import com.aelitis.azureus.ui.common.viewtitleinfo.ViewTitleInfo;
 import com.aelitis.azureus.ui.common.viewtitleinfo.ViewTitleInfoManager;
 import com.aelitis.azureus.ui.selectedcontent.ISelectedContent;
@@ -109,6 +111,10 @@ SubscriptionManagerUI
 	public static final Object	SUB_IVIEW_KEY 		= new Object();
 	public static final Object	SUB_EDIT_MODE_KEY 	= new Object();
 	
+	public static final String ALERT_IMAGE_ID	= "image.sidebar.vitality.alert";
+	public static final String AUTH_IMAGE_ID	= "image.sidebar.vitality.auth";
+	
+
 	private static final String EDIT_MODE_MARKER	= "&editMode=1";
 	
 	private Graphic	icon_rss_big;
@@ -532,6 +538,37 @@ SubscriptionManagerUI
 			});
 
 		
+			// rss
+		
+		final BooleanParameter rss_enable = 
+			configModel.addBooleanParameter2( 
+				"subscriptions.rss.enable", "subscriptions.rss.enable",
+				subs_man.isRSSPublishEnabled());
+		
+		rss_enable.addListener(
+			new ParameterListener()
+			{
+				public void 
+				parameterChanged(
+					Parameter param) 
+				{
+					subs_man.setRSSPublishEnabled( rss_enable.getValue());
+				}
+			});
+				
+		HyperlinkParameter rss_view = 
+			configModel.addHyperlinkParameter2(
+				"device.rss.view", subs_man.getRSSLink());
+		
+		rss_enable.addEnabledOnSelection( rss_view );
+		
+		configModel.createGroup(
+			"device.rss.group",
+			new Parameter[]
+			{
+					rss_enable, rss_view,
+			});
+		
 		SideBar sideBar = (SideBar)SkinViewManager.getByClass(SideBar.class);
 		
 		if ( sideBar != null ){
@@ -698,7 +735,7 @@ SubscriptionManagerUI
 				public void tableColumnCreated(TableColumn result) {
 					result.setAlignment(TableColumn.ALIGN_CENTER);
 					result.setPosition(TableColumn.POSITION_LAST);
-					result.setWidth(75);
+					result.setWidth(72);
 					result.setRefreshInterval(TableColumn.INTERVAL_INVALID_ONLY);
 					result.setType(TableColumn.TYPE_GRAPHIC);
 				
@@ -840,7 +877,7 @@ SubscriptionManagerUI
 		
 		if (mainSBEntry != null) {
 			
-			SideBarVitalityImage addSub = mainSBEntry.addVitalityImage("image.sidebar.subs.add");
+			SideBarVitalityImage addSub 	= mainSBEntry.addVitalityImage("image.sidebar.subs.add");
 			
 			addSub.setToolTip("Add Subscription");
 			
@@ -850,6 +887,10 @@ SubscriptionManagerUI
 				}
 			});
 			
+			final SideBarVitalityImage warnSub 	= mainSBEntry.addVitalityImage( ALERT_IMAGE_ID );
+			
+			warnSub.setVisible( false );
+			
 			mainSBEntry.setImageLeftID("image.sidebar.subscriptions");
 
 			mainSBEntry.setTitleInfo(
@@ -867,17 +908,38 @@ SubscriptionManagerUI
 
 							boolean expanded = mainSBEntry.getTreeItem().getExpanded();
 
-							if ( !expanded ){
+							if ( expanded ){
 								
-								int	total = 0;
+								warnSub.setVisible( false );
+								
+							}else{
+								
+								int		total 	= 0;
+								boolean	warn 	= false;
 								
 								Subscription[] subs = subs_man.getSubscriptions();
 								
 								for ( Subscription s: subs ){
 									
-									total += s.getHistory().getNumUnread();
+									SubscriptionHistory history = s.getHistory();
+
+									total += history.getNumUnread();
+									
+									String	last_error = history.getLastError();
+
+									if ( last_error != null ){
+										
+										boolean	auth_fail = history.isAuthFail();
+																		
+										if ( history.getConsecFails() >= 3 || auth_fail ){
+										
+											warn = true;
+										}
+									}
 								}
 								
+								warnSub.setVisible( warn );
+								
 								if ( total > 0 ){
 								
 									return( String.valueOf( total ));
@@ -985,13 +1047,13 @@ SubscriptionManagerUI
 			public void selected(MenuItem menu, Object target) {
 				if (target instanceof SideBarEntry) {
 					SideBarEntry info = (SideBarEntry) target;
-					Subscription subs = (Subscription) info.getDatasource();
+					final Subscription subs = (Subscription) info.getDatasource();
 					try{
 						Engine engine = subs.getEngine();
 						
 						if ( engine instanceof WebEngine ){
 							
-							WebEngine we = (WebEngine)engine;
+							final WebEngine we = (WebEngine)engine;
 							
 							UISWTInputReceiver entry = (UISWTInputReceiver)swt_ui.getInputReceiver();
 							
@@ -1007,20 +1069,28 @@ SubscriptionManagerUI
 							entry.maintainWhitespace(false);
 							entry.allowEmptyInput( false );
 							entry.setTitle("general.enter.cookies");
-							entry.prompt();
-							if (!entry.hasSubmittedInput()){
-								
-								return;
-							}
-							
-							String input = entry.getSubmittedInput().trim();
-							
-							if ( input.length() > 0 ){
-							
-								we.setCookies( input );
-								
-								subs.getManager().getScheduler().downloadAsync(subs, true);
-							}
+							entry.prompt(new UIInputReceiverListener() {
+								public void UIInputReceiverClosed(UIInputReceiver entry) {
+									if (!entry.hasSubmittedInput()){
+										
+										return;
+									}
+
+									try {
+  									String input = entry.getSubmittedInput().trim();
+  									
+  									if ( input.length() > 0 ){
+  										
+  										we.setCookies( input );
+  										
+  										subs.getManager().getScheduler().downloadAsync(subs, true);
+  									}
+									}catch( Throwable e ){
+										
+										Debug.printStackTrace(e);
+									}
+								}
+							});
 						}
 					}catch( Throwable e ){
 						
@@ -1116,31 +1186,37 @@ SubscriptionManagerUI
 			public void selected(MenuItem menu, Object target) {
 				if (target instanceof SideBarEntry) {
 					SideBarEntry info = (SideBarEntry) target;
-					Subscription subs = (Subscription) info.getDatasource();
+					final Subscription subs = (Subscription) info.getDatasource();
 					
 					UISWTInputReceiver entry = (UISWTInputReceiver)swt_ui.getInputReceiver();
 					entry.setPreenteredText(subs.getName(), false );
 					entry.maintainWhitespace(false);
 					entry.allowEmptyInput( false );
-					entry.setTitle("MyTorrentsView.menu.rename");
-					entry.prompt();
-					if (!entry.hasSubmittedInput()){
-						
-						return;
-					}
-					
-					String input = entry.getSubmittedInput().trim();
-					
-					if ( input.length() > 0 ){
-						
-						try{
-							subs.setName( input );
+					entry.setLocalisedTitle(MessageText.getString("label.rename",
+							new String[] {
+								subs.getName()
+							}));
+					entry.prompt(new UIInputReceiverListener() {
+						public void UIInputReceiverClosed(UIInputReceiver entry) {
+							if (!entry.hasSubmittedInput()){
+								
+								return;
+							}
 							
-						}catch( Throwable e ){
+							String input = entry.getSubmittedInput().trim();
 							
-							Debug.printStackTrace(e);
+							if ( input.length() > 0 ){
+								
+								try{
+									subs.setName( input );
+									
+								}catch( Throwable e ){
+									
+									Debug.printStackTrace(e);
+								}
+							}
 						}
-					}
+					});
 				}
 			}
 		};
@@ -1296,7 +1372,7 @@ SubscriptionManagerUI
 	{
 		if ( subs.isSubscribed()){
 			
-			addSubscription( side_bar, subs, true );
+			addSubscription( side_bar, subs, false );
 			
 		}else{
 			
@@ -1326,6 +1402,19 @@ SubscriptionManagerUI
 				final sideBarItem new_si = new sideBarItem();
 				
 				subs.setUserData( SUB_IVIEW_KEY, new_si );
+
+				// GetEngine used to be near menu item created, but was moved here
+				// since it takes time on first start and we don't want it stalling
+				// the UI Thread
+				Engine e = null;
+				try{
+					e = subs.getEngine();
+					
+				}catch( Throwable ex ){
+					
+					Debug.printStackTrace(ex);
+				}
+				final Engine engine = e;
 				
 				Utils.execSWTThread(
 					new Runnable()
@@ -1386,11 +1475,9 @@ SubscriptionManagerUI
 								menuItem.addListener(resetResultsListener);
 
 								try{
-									Engine e = subs.getEngine();
-									
-									if ( e instanceof WebEngine ){
+									if ( engine instanceof WebEngine ){
 										
-										if (((WebEngine)e).isNeedsAuth()){
+										if (((WebEngine)engine).isNeedsAuth()){
 											
 											menuItem = menuManager.addMenuItem("sidebar." + key,"Subscription.menu.resetauth");
 											menuItem.addListener(resetAuthListener);
@@ -1621,11 +1708,10 @@ SubscriptionManagerUI
 	
 	protected static void
 	removeWithConfirm(
-		Subscription	subs )
+		final Subscription	subs )
 	{
 		MessageBoxShell mb = 
 			new MessageBoxShell(
-				Utils.findAnyShell(),
 				MessageText.getString("message.confirm.delete.title"),
 				MessageText.getString("message.confirm.delete.text",
 						new String[] {
@@ -1637,10 +1723,13 @@ SubscriptionManagerUI
 				},
 				1 );
 		
-		int result = mb.open();
-		if (result == 0) {
-			subs.remove();
-		}
+		mb.open(new UserPrompterResultListener() {
+			public void prompterClosed(int result) {
+				if (result == 0) {
+					subs.remove();
+				}
+			}
+		});
 	}
 	
 	protected void
@@ -1859,15 +1948,6 @@ SubscriptionManagerUI
 		}
 		
 		public void delete() {
-			// Fix/Hack for SWT Browser disposal bug + memory leak
-			if(mainBrowser != null && ! mainBrowser.isDisposed()) {
-				mainBrowser.setUrl("about:blank");
-				mainBrowser.setVisible(false);
-			}
-			if(detailsBrowser != null && ! detailsBrowser.isDisposed()) {
-				detailsBrowser.setUrl("about:blank");
-				detailsBrowser.setVisible(false);
-			}
 			super.delete();
 		}
 		
@@ -2019,6 +2099,13 @@ SubscriptionManagerUI
 		{
 			try{
 				mainBrowser = new Browser(composite,Utils.getInitialBrowserStyle(SWT.NONE));
+				mainBrowser.addDisposeListener(new DisposeListener() {
+					public void widgetDisposed(DisposeEvent e) {
+						((Browser)e.widget).setUrl("about:blank");
+						((Browser)e.widget).setVisible(false);
+						while (!e.display.isDisposed() && e.display.readAndDispatch());
+					}
+				});
 				BrowserContext context = 
 					new BrowserContext("browser-window"	+ Math.random(), mainBrowser, null, true);
 				
@@ -2067,6 +2154,13 @@ SubscriptionManagerUI
 				mainBrowser.setLayoutData(data);
 				
 				detailsBrowser = new Browser(composite,Utils.getInitialBrowserStyle(SWT.NONE));
+				detailsBrowser.addDisposeListener(new DisposeListener() {
+					public void widgetDisposed(DisposeEvent e) {
+						((Browser)e.widget).setUrl("about:blank");
+						((Browser)e.widget).setVisible(false);
+						while (!e.display.isDisposed() && e.display.readAndDispatch());
+					}
+				});
 				BrowserContext detailsContext = 
 					new BrowserContext("browser-window"	+ Math.random(), detailsBrowser, null, false);
 				detailsContext.addListener(new BrowserContext.loadingListener(){
@@ -2121,7 +2215,6 @@ SubscriptionManagerUI
 				detailsContext.addMessageListener(new VuzeListener());
 				detailsContext.addMessageListener(new DisplayListener(detailsBrowser));
 				detailsContext.addMessageListener(new ConfigListener(detailsBrowser));
-				detailsContext.addMessageListener(new LightBoxBrowserRequestListener());
 				url = "about:blank";
 				detailsBrowser.setUrl(url);
 				detailsBrowser.setData("StartURL", url);
@@ -2187,9 +2280,6 @@ SubscriptionManagerUI
 		{
 			if ( mainBrowser != null ){
 			
-				//OSX bug : browsers don't really get disposed
-				mainBrowser.setUrl("about:blank");
-				
 				mainBrowser.dispose();
 				
 				mainBrowser = null;
@@ -2197,9 +2287,6 @@ SubscriptionManagerUI
 			
 			if ( detailsBrowser != null ){
 				
-				//OSX bug : browsers don't really get disposed
-				detailsBrowser.setUrl("about:blank");
-			
 				detailsBrowser.dispose();
 
 				detailsBrowser = null;
@@ -2429,9 +2516,6 @@ SubscriptionManagerUI
 	public static class
 	sideBarItem
 	{
-		public static final String ALERT_IMAGE_ID	= "image.sidebar.vitality.alert";
-		public static final String AUTH_IMAGE_ID	= "image.sidebar.vitality.auth";
-		
 		private subscriptionView	view;
 		private SideBarEntrySWT		sb_entry;
 		private TreeItem			tree_item;
