@@ -22,7 +22,6 @@ package com.aelitis.azureus.ui.swt.utils;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -46,10 +45,11 @@ import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.ui.swt.*;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
 import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 
 import com.aelitis.azureus.core.AzureusCore;
-import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.core.AzureusCoreFactory;
+import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
 import com.aelitis.azureus.ui.UIFunctionsManager;
@@ -128,12 +128,12 @@ public class TorrentUIUtilsV3
 
 						}.start();
 					} else {
-						Utils.openMessageBox(Utils.findAnyShell(), SWT.OK,
+						new MessageBoxShell(SWT.OK,
 								MSG_ALREADY_EXISTS, new String[] {
 									" ",
 									dm.getDisplayName(),
 									MessageText.getString(MSG_ALREADY_EXISTS_NAME),
-								});
+								}).open(null);
 					}
 					return;
 				}
@@ -280,18 +280,13 @@ public class TorrentUIUtilsV3
 						return;
 					}
 
-					boolean showHomeHint = true;
 					if (playNow || playPrepare) {
 						if (playNow) {
-							showHomeHint = !TorrentListViewsUtils.playOrStream(dm);
+							TorrentListViewsUtils.playOrStream(dm);
 						} else {
 							PlayUtils.prepareForPlay(dm);
-							showHomeHint = false;
 						}
 					}
-					if (showHomeHint) {
-						TorrentListViewsUtils.showHomeHint(dm);
-					}
 				} catch (Exception e) {
 					Debug.out(e);
 				}
@@ -342,7 +337,7 @@ public class TorrentUIUtilsV3
 	 *
 	 * @since 4.0.0.5
 	 */
-	public static Image getContentImage(Object datasource, boolean big,
+	public static Image[] getContentImage(Object datasource, boolean big,
 			final ContentImageLoadedListener l) {
 		if (l == null) {
 			return null;
@@ -353,13 +348,16 @@ public class TorrentUIUtilsV3
 			return null;
 		}
 
-		ImageLoader imageLoader = ImageLoader.getInstance();
+		final ImageLoader imageLoader = ImageLoader.getInstance();
 
 		String thumbnailUrl = PlatformTorrentUtils.getContentThumbnailUrl(torrent);
 
+		//System.out.println("thumburl= " + thumbnailUrl);
 		if (thumbnailUrl != null && imageLoader.imageExists(thumbnailUrl)) {
-			l.contentImageLoaded(imageLoader.getImage(thumbnailUrl), true);
-			return null;
+			//System.out.println("return thumburl");
+			Image image = imageLoader.getImage(thumbnailUrl);
+			l.contentImageLoaded(image, true);
+			return new Image[] { image };
 		}
 
 		String hash = null;
@@ -372,15 +370,17 @@ public class TorrentUIUtilsV3
 			return null;
 		}
 
-		String id = "Thumbnail." + hash;
+		final String id = "Thumbnail." + hash;
 
 		Image image = imageLoader.imageAdded(id) ? imageLoader.getImage(id) : null;
+		//System.out.println("image = " + image);
 		if (image != null && !image.isDisposed()) {
 			l.contentImageLoaded(image, true);
-			return image;
+			return new Image[] { image };
 		}
 
 		final byte[] imageBytes = PlatformTorrentUtils.getContentThumbnail(torrent);
+		//System.out.println("imageBytes = " + imageBytes);
 		if (imageBytes != null) {
 			image = (Image) Utils.execSWTThreadWithObject("thumbcreator",
 					new AERunnableObject() {
@@ -393,16 +393,22 @@ public class TorrentUIUtilsV3
 						}
 					}, 500);
 		}
+/**
 		if ((image == null || image.isDisposed()) && thumbnailUrl != null) {
+			//System.out.println("get image from " + thumbnailUrl);
 			image = imageLoader.getUrlImage(thumbnailUrl,
 					new ImageDownloaderListener() {
 						public void imageDownloaded(Image image, boolean returnedImmediately) {
 							l.contentImageLoaded(image, returnedImmediately);
+							//System.out.println("got image from thumburl");
 						}
 					});
-			return image;
+			//System.out.println("returning " + image + " (url loading)");
+			return image == null ? null : new Image[] { image };
 		}
+**/
 		if (image == null || image.isDisposed()) {
+			//System.out.println("build image from files");
 			DownloadManager dm = DataSourceUtils.getDM(datasource);
 			/*
 			 * Try to get an image from the OS
@@ -420,25 +426,29 @@ public class TorrentUIUtilsV3
 				path = dm.getDownloadState().getPrimaryFile();
 			}
 			if (path != null) {
-				// Don't ever dispose of PathIcon, it's cached and may be used elsewhere
-				Image icon = ImageRepository.getPathIcon(path, big, torrent != null
-						&& !torrent.isSimpleTorrent());
-				if (icon != null) {
-					image = new Image(Display.getDefault(), icon, SWT.IMAGE_COPY);
+				image = ImageRepository.getPathIcon(path, big, false);
+				
+				if (image != null && torrent != null && !torrent.isSimpleTorrent()) {
+					Image[] images = new Image[] {
+						image,
+						ImageRepository.getPathIcon(new File(path).getParent(), false, false)
+					};
+					return images;
 				}
 			}
 
 			if (image == null) {
-				imageLoader.addImage(id, ImageLoader.noImage);
+				imageLoader.addImageNoDipose(id, ImageLoader.noImage);
 			} else {
-				imageLoader.addImage(id, image);
+				imageLoader.addImageNoDipose(id, image);
 			}
 		} else {
+			//System.out.println("has mystery image");
 			imageLoader.addImage(id, image);
 		}
 
 		l.contentImageLoaded(image, true);
-		return image;
+		return new Image[] { image };
 	}
 
 	public static void releaseContentImage(Object datasource) {
