@@ -31,7 +31,6 @@ import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.global.GlobalManager;
 import org.gudy.azureus2.core3.torrent.TOTorrent;
 import org.gudy.azureus2.core3.util.AERunnable;
-import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.pluginsimpl.local.PluginCoreUtils;
 import org.gudy.azureus2.ui.swt.IconBarEnabler;
@@ -47,6 +46,7 @@ import com.aelitis.azureus.core.devices.TranscodeException;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
 import com.aelitis.azureus.ui.common.table.TableView;
 import com.aelitis.azureus.ui.selectedcontent.ISelectedContent;
+import com.aelitis.azureus.ui.selectedcontent.ISelectedVuzeFileContent;
 import com.aelitis.azureus.ui.selectedcontent.SelectedContentListener;
 import com.aelitis.azureus.ui.selectedcontent.SelectedContentManager;
 import com.aelitis.azureus.ui.swt.UIFunctionsManagerSWT;
@@ -216,23 +216,6 @@ public class ToolBarView
   		first = false;
 		}
 
-		// ==share
-		item = new ToolBarItem("share", "image.button.share", "iconBar.share") {
-			// @see com.aelitis.azureus.ui.swt.toolbar.ToolBarItem#triggerToolBarItem()
-			public void triggerToolBarItem() {
-				String viewID = SelectedContentManager.getCurrentySelectedViewID();
-				if (viewID == null && triggerIViewToolBar(getId())) {
-					return;
-				}
-				ISelectedContent[] contents = SelectedContentManager.getCurrentlySelectedContent();
-				if (contents.length > 0) {
-					VuzeShareUtils.getInstance().shareContent(contents[0], null, "ToolBar");
-				}
-			}
-		};
-		addToolBarItem(item, first ? "toolbar.area.sitem.left" : "toolbar.area.sitem", so2nd);
-		addSeperator(so2nd);
-
 		// ==run
 		item = new ToolBarItem("run", "image.toolbar.run", "iconBar.run") {
 			public void triggerToolBarItem() {
@@ -659,7 +642,6 @@ public class ToolBarView
 				String[] TBKEYS = new String[] {
 					"download",
 					"play",
-					"share",
 					"run",
 					"up",
 					"down",
@@ -722,13 +704,6 @@ public class ToolBarView
 			}
 		}
 
-		item = getToolBarItem("share");
-		if (item != null) {
-			boolean canShare = has1SelectionWithHash
-					&& VuzeShareUtils.getInstance().canShare(currentContent[0]);
-			item.setEnabled(canShare);
-		}
-
 		item = getToolBarItem("run");
 		if (item != null) {
 			boolean canRun = has1Selection;
@@ -756,9 +731,6 @@ public class ToolBarView
 
 						canRun = false;
 
-					} else if (PlatformTorrentUtils.getAdId(torrent) != null) {
-
-						canRun = false;
 					}
 				}
 			}
@@ -775,11 +747,12 @@ public class ToolBarView
 		}
 		item = getToolBarItem("play");
 		if (item != null) {
-			item.setEnabled(has1Selection && PlayUtils.canPlayDS(currentContent[0]));
+			item.setEnabled(has1Selection && (!(currentContent[0] instanceof ISelectedVuzeFileContent )) && PlayUtils.canPlayDS(currentContent[0]));
 		}
 		item = getToolBarItem("download");
 		if (item != null) {
 			boolean enabled = has1Selection
+					&& (!(currentContent[0] instanceof ISelectedVuzeFileContent ))
 					&& currentContent[0].getDownloadManager() == null
 					&& (currentContent[0].getHash() != null || currentContent[0].getDownloadInfo() != null);
 			item.setEnabled(enabled);
@@ -845,13 +818,21 @@ public class ToolBarView
 		} else {
 			SideBar sidebar = (SideBar) SkinViewManager.getByClass(SideBar.class);
 			if (sidebar != null) {
+				ToolBarItem[] allToolBarItems = getAllToolBarItems();
 				SideBarEntrySWT entry = sidebar.getCurrentEntry();
 				IconBarEnabler enabler = entry.getIconBarEnabler();
-				if (enabler == null && entry.iview != null) {
-					enabler = entry.iview;
+				if (enabler == null) {
+					if (entry.iview != null) {
+						enabler = entry.iview;
+					} else {
+						for (int i = 0; i < allToolBarItems.length; i++) {
+							ToolBarItem toolBarItem = allToolBarItems[i];
+							toolBarItem.setEnabled(false);
+						}
+						return;
+					}
 				}
 
-				ToolBarItem[] allToolBarItems = getAllToolBarItems();
 				for (int i = 0; i < allToolBarItems.length; i++) {
 					ToolBarItem toolBarItem = allToolBarItems[i];
 					toolBarItem.setEnabled(enabler.isEnabled(toolBarItem.getId()));
