@@ -50,9 +50,7 @@ import org.gudy.azureus2.ui.common.util.MenuItemManager;
 import org.gudy.azureus2.ui.swt.MenuBuildUtils;
 import org.gudy.azureus2.ui.swt.URLTransfer;
 import org.gudy.azureus2.ui.swt.Utils;
-import org.gudy.azureus2.ui.swt.mainwindow.Colors;
-import org.gudy.azureus2.ui.swt.mainwindow.MenuFactory;
-import org.gudy.azureus2.ui.swt.mainwindow.PluginsMenuHelper;
+import org.gudy.azureus2.ui.swt.mainwindow.*;
 import org.gudy.azureus2.ui.swt.mainwindow.PluginsMenuHelper.IViewInfo;
 import org.gudy.azureus2.ui.swt.mainwindow.PluginsMenuHelper.PluginAddedViewListener;
 import org.gudy.azureus2.ui.swt.plugins.UISWTViewEvent;
@@ -62,6 +60,7 @@ import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTViewEventCancelledException;
 import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTViewImpl;
 import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
 import org.gudy.azureus2.ui.swt.shells.GCStringPrinter;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT.TriggerInThread;
 import org.gudy.azureus2.ui.swt.views.*;
 import org.gudy.azureus2.ui.swt.views.stats.StatsView;
@@ -112,6 +111,14 @@ public class SideBar
 	implements UIUpdatable, ViewTitleInfoListener
 {
 	private static final boolean END_INDENT = Constants.isLinux || Constants.isWindows2000 || Constants.isWindows9598ME;
+	
+	private static final boolean USE_PAINTITEM = Utils.isCocoa || Constants.isWindows;
+	
+	// Need to use paint even on Cocoa, because there's cases where an area
+	// will become invalidated and we don't get a paintitem :(
+	private static final boolean USE_PAINT = !Constants.isWindows;
+	
+	private static final boolean HIDE_NATIVE_EXPANDER = false;
 
 	private static final int SIDEBAR_SPACING = 2;
 
@@ -131,16 +138,12 @@ public class SideBar
 
 	public static final String SIDEBAR_SECTION_WELCOME = "Welcome";
 
-	public static final String SIDEBAR_SECTION_PUBLISH = "Publish";
-
 	public static final String SIDEBAR_SECTION_SUBSCRIPTIONS = "Subscriptions";
 
 	public static final String SIDEBAR_SECTION_DEVICES = "Devices";
 	
 	public static final String SIDEBAR_SECTION_RELATED_CONTENT = "RelatedContent";
 
-	public static final String SIDEBAR_SECTION_ADVANCED = "Advanced";
-
 	public static final boolean SHOW_ALL_PLUGINS = false;
 
 	public static final boolean SHOW_TOOLS = false;
@@ -153,7 +156,7 @@ public class SideBar
 
 	private static final int IMAGELEFT_GAP = 5;
 
-	private static final boolean ALWAYS_IMAGE_GAP = false;
+	private static final boolean ALWAYS_IMAGE_GAP = true;
 
 	private static final String[] default_indicator_colors = {
 		"#000000",
@@ -162,6 +165,8 @@ public class SideBar
 		"#1c2056"
 	};
 
+	private static final boolean DO_OUR_OWN_TREE_INDENT = false;
+
 	private SWTSkin skin;
 
 	private SWTSkinObject soSideBarContents;
@@ -172,6 +177,8 @@ public class SideBar
 
 	private Font fontHeader;
 
+	private Font font;
+
 	private SideBarEntrySWT currentSideBarEntry;
 
 	private static Map mapTitleInfoToEntry = new LightHashMap();
@@ -550,12 +557,17 @@ public class SideBar
 
 		tree.setBackground(bg);
 		tree.setForeground(fg);
+		
+		int fontHeight = 13 + (tree.getItemHeight() > 18 ? tree.getItemHeight() - 18 : 0); 
 
 		FontData[] fontData = tree.getFont().getFontData();
+		Utils.getFontHeightFromPX(tree.getDisplay(), fontData, null, fontHeight - 1);
+		font = new Font(tree.getDisplay(), fontData);
+		tree.setFont(font);
 		//fontData[0].setHeight(fontData[0].getHeight() + 1);
 		fontData[0].setStyle(SWT.BOLD);
 		//fontData[0].setName("Helvetica");
-		Utils.getFontHeightFromPX(tree.getDisplay(), fontData, null, 13);
+		Utils.getFontHeightFromPX(tree.getDisplay(), fontData, null, fontHeight);
 		fontHeader = new Font(tree.getDisplay(), fontData);
 
 		Listener treeListener = new Listener() {
@@ -575,6 +587,10 @@ public class SideBar
 							event.width = size.x + event.x; // tree.getClientArea().width;
 							event.x = 0;
 						}
+						
+						if (Constants.isWindows) {
+							event.width = clientWidth - event.x;
+						}
 						int padding = 4;
 						//String id = (String) treeItem.getData("Plugin.viewID");
 						//SideBarEntrySWT entry = getSideBarInfo(id);
@@ -587,16 +603,53 @@ public class SideBar
 						break;
 					}
 					case SWT.PaintItem: {
-						//paintSideBar(event);
+						if (USE_PAINTITEM) {
+							String id = (String) ((TreeItem) event.item).getData("Plugin.viewID");
+							//System.out.println("PaintItem: " + event.item + ";" + event.index + ";" + event.detail + ";" + id + ";" + event.getBounds() + ";" + event.gc.getClipping());
+							SideBarEntrySWT entry = getEntry(id);
+							paintSideBar(event, entry);
+						}
 						break;
 					}
 
 					case SWT.Paint: {
-						//System.out.println("Paint: " + event.getBounds() + ";" + event.detail + ";" + event.index);
+						if (HIDE_NATIVE_EXPANDER) {
+							boolean selected = (event.detail & SWT.SELECTED) > 0;
+							Rectangle bounds = event.getBounds();
+							int indent = END_INDENT ? tree.getClientArea().width - 1 : 0;
+							int y = event.y + 1;
+							treeItem = tree.getItem(new Point(indent, y));
+
+							while (treeItem != null) {
+								String id = (String) treeItem.getData("Plugin.viewID");
+								SideBarEntrySWT entry = getEntry(id);
+								Rectangle itemBounds = entry.getBounds();
+
+								if (itemBounds != null && entry.disableCollapse) {
+									Rectangle paintArea = treeItem.getBounds();
+									paintArea.x = 0;
+									paintArea.width = 17;
+									selected = tree.getSelectionCount() == 1
+											&& tree.getSelection()[0].equals(treeItem);
+									paintEntryBG(selected, event.gc, paintArea, entry);
+									y = itemBounds.y + itemBounds.height + 1;
+  							} else {
+  								y += tree.getItemHeight();
+  							}
+  
+  							if (y > bounds.y + bounds.height) {
+  								break;
+  							}
+  							treeItem = tree.getItem(new Point(indent, y));
+							}
+						}
+
+						
+						//System.out.println("Paint: " + event.getBounds() + ";" + event.detail + ";" + event.index + ";" + event.gc.getClipping() + "  " + Debug.getCompressedStackTrace());
+						if (!USE_PAINT) {
+							return;
+						}
 						Rectangle bounds = event.getBounds();
-						//if (tree.getItemCount() == 0) {
-						//	return;
-						//}
 						int indent = END_INDENT ? tree.getClientArea().width - 1 : 0;
 						int y = event.y + 1;
 						treeItem = tree.getItem(new Point(indent, y));
@@ -618,7 +671,7 @@ public class SideBar
   							Rectangle newClip = bounds.intersection(itemBounds);
   							//System.out.println("Paint " + id + " @ " + newClip);
   							event.setBounds(newClip);
-  							//event.gc.setClipping(newClip);
+  							event.gc.setClipping(newClip);
   
   							paintSideBar(event, entry);
 
@@ -646,7 +699,7 @@ public class SideBar
 					case SWT.EraseItem: {
 						//event.detail &= ~SWT.FOREGROUND;
 						//event.detail &= ~(SWT.FOREGROUND | SWT.BACKGROUND);
-						event.doit = false;
+						event.doit = true;
 						break;
 					}
 
@@ -709,6 +762,7 @@ public class SideBar
 
 					case SWT.Dispose: {
 						fontHeader.dispose();
+						font.dispose();
 						if (dropTarget != null && !dropTarget.isDisposed()) {
 							dropTarget.dispose();
 						}
@@ -739,8 +793,10 @@ public class SideBar
 		tree.addListener(SWT.MeasureItem, treeListener);
 		tree.addListener(SWT.Resize, treeListener);
 		tree.addListener(SWT.Paint, treeListener);
-		//tree.addListener(SWT.PaintItem, treeListener);
-		//tree.addListener(SWT.EraseItem, treeListener);
+		if (USE_PAINTITEM) {
+			tree.addListener(SWT.PaintItem, treeListener);
+			tree.addListener(SWT.EraseItem, treeListener);
+		}
 
 		tree.addListener(SWT.Selection, treeListener);
 		tree.addListener(SWT.Dispose, treeListener);
@@ -768,29 +824,26 @@ public class SideBar
 
 			// @see org.eclipse.swt.dnd.DropTargetAdapter#dragOver(org.eclipse.swt.dnd.DropTargetEvent)
 			public void dragOver(DropTargetEvent event) {
-				if (!(event.item instanceof TreeItem)) {
-					event.detail = DND.DROP_NONE;
-					return;
-				}
-				TreeItem treeItem = (TreeItem) event.item;
+				TreeItem treeItem = (event.item instanceof TreeItem)
+						? (TreeItem) event.item : null;
 
-				String id = (String) treeItem.getData("Plugin.viewID");
-				SideBarEntrySWT entry = getEntry(id);
-
-				if (entry.hasDropListeners()) {
-					draggingOver = entry;
-					if (Constants.isOSX) {
-						tree.redraw();
-					}
-					if ((event.operations & DND.DROP_LINK) > 0)
-						event.detail = DND.DROP_LINK;
-					else if ((event.operations & DND.DROP_DEFAULT) > 0)
-						event.detail = DND.DROP_DEFAULT;
-					else if ((event.operations & DND.DROP_COPY) > 0)
-						event.detail = DND.DROP_COPY;
+				if (treeItem != null) {
+  				String id = (String) treeItem.getData("Plugin.viewID");
+  				SideBarEntrySWT entry = getEntry(id);
+  
+  				draggingOver = entry;
 				} else {
-					event.detail = DND.DROP_NONE;
+					draggingOver = null;
 				}
+				if (Constants.isOSX) {
+					tree.redraw();
+				}
+				if ((event.operations & DND.DROP_LINK) > 0)
+					event.detail = DND.DROP_LINK;
+				else if ((event.operations & DND.DROP_DEFAULT) > 0)
+					event.detail = DND.DROP_DEFAULT;
+				else if ((event.operations & DND.DROP_COPY) > 0)
+					event.detail = DND.DROP_COPY;
 			}
 			
 			// @see org.eclipse.swt.dnd.DropTargetAdapter#dragLeave(org.eclipse.swt.dnd.DropTargetEvent)
@@ -803,6 +856,7 @@ public class SideBar
 				draggingOver = null;
 				tree.redraw();
 				if (!(event.item instanceof TreeItem)) {
+					defaultDrop(event);
 					return;
 				}
 				TreeItem treeItem = (TreeItem) event.item;
@@ -810,7 +864,10 @@ public class SideBar
 				String id = (String) treeItem.getData("Plugin.viewID");
 				SideBarEntrySWT entry = getEntry(id);
 
-				entry.triggerDropListeners(event.data);
+				boolean handled = entry.triggerDropListeners(event.data);
+				if (!handled) {
+					defaultDrop(event);
+				}
 			}
 		});
 
@@ -939,6 +996,13 @@ public class SideBar
 		}
 	}
 
+	/**
+	 * @param event
+	 */
+	protected void defaultDrop(DropTargetEvent event) {
+		TorrentOpener.openDroppedTorrents(event, false);
+	}
+
 	/**
 	 * @param menuDropDown
 	 *
@@ -1020,32 +1084,12 @@ public class SideBar
 			}
 		}
 	}
-
-	/**
-	 * @param event
-	 * @param sideBarEntry
-	 *
-	 * @since 3.1.0.1
-	 */
-	protected void paintSideBar(Event event, SideBarEntrySWT sideBarEntry) {
-		TreeItem treeItem = (TreeItem) event.item;
-		Rectangle itemBounds = treeItem.getBounds();
-
-		String text = (String) treeItem.getData("text");
-		if (text == null)
-			text = "";
-
-		//Point size = event.gc.textExtent(text);
-		//Rectangle treeBounds = tree.getBounds();
-		GC gc = event.gc;
-
-		gc.setAntialias(SWT.ON);
-		gc.setAdvanced(true);
-		//gc.setClipping((Rectangle) null);
-
-		boolean selected = (event.detail & SWT.SELECTED) > 0;
+	
+	private Color paintEntryBG(boolean selected, GC gc, Rectangle drawBounds, SideBarEntrySWT sideBarEntry) {
 		Color fgText = Colors.black;
 		if (selected) {
+			//System.out.println("gmmm" + drawBounds + ": " + Debug.getCompressedStackTrace());
+			gc.setClipping((Rectangle)null);
 			if (fgSel != null) {
 				fgText = fgSel;
 			}
@@ -1063,12 +1107,13 @@ public class SideBar
 			}
 
 			gc.setBackground(color1);
-			gc.fillRectangle(event.x, itemBounds.y, event.width, 3);
+			gc.fillRectangle(drawBounds.x, drawBounds.y, drawBounds.width, 3);
 
 			gc.setForeground(color1);
 			gc.setBackground(color2);
-			gc.fillGradientRectangle(event.x, itemBounds.y + 3, event.width,
-					itemBounds.height - 3, true);
+			//System.out.println("FOO");
+			//gc.fillGradientRectangle(itemBounds.x, itemBounds.y, itemBounds.width, itemBounds.height, true);
+			gc.fillGradientRectangle(drawBounds.x, drawBounds.y + 3, drawBounds.width,	drawBounds.height - 3, true);
 		} else {
 
 			if (fg != null) {
@@ -1082,8 +1127,39 @@ public class SideBar
 				gc.setBackground(ColorCache.getColor(gc.getDevice(), "#2688aa"));
 			}
 			
-			gc.fillRectangle(event.getBounds());
+			gc.fillRectangle(drawBounds);
 		}
+		return fgText;
+	}
+
+	/**
+	 * @param event
+	 * @param sideBarEntry
+	 *
+	 * @since 3.1.0.1
+	 */
+	protected void paintSideBar(Event event, SideBarEntrySWT sideBarEntry) {
+		TreeItem treeItem = (TreeItem) event.item;
+		Rectangle itemBounds = treeItem.getBounds();
+		Rectangle drawBounds = Utils.isCocoa || Constants.isWindows ? event.gc.getClipping() : event.getBounds();
+		if (drawBounds.isEmpty()) {
+			return;
+		}
+		
+		String text = (String) treeItem.getData("text");
+		if (text == null)
+			text = "";
+
+		//Point size = event.gc.textExtent(text);
+		//Rectangle treeBounds = tree.getBounds();
+		GC gc = event.gc;
+
+		gc.setAntialias(SWT.ON);
+		gc.setAdvanced(true);
+		//gc.setClipping((Rectangle) null);
+
+		boolean selected = (event.detail & SWT.SELECTED) > 0;
+		Color fgText = paintEntryBG(selected, gc, drawBounds, sideBarEntry);
 
 		Rectangle treeArea = tree.getClientArea();
 
@@ -1093,10 +1169,19 @@ public class SideBar
 			String id = (String) treeItem.getData("Plugin.viewID");
 			sideBarEntry = getEntry(id);
 		}
+		if (DO_OUR_OWN_TREE_INDENT) {
+			int indentLevel = 0;
+			TreeItem tempItem = treeItem;
+			while (tempItem != null)  {
+				tempItem =  tempItem.getParentItem();
+				indentLevel++;
+			}
+			itemBounds.x += (18 * indentLevel);
+		}
 		int x1IndicatorOfs = SIDEBAR_SPACING;
 		int x0IndicatorOfs = itemBounds.x;
 
-		//System.out.println(System.currentTimeMillis() + "] refhres " + sideBarInfo.getId());
+		//System.out.println(System.currentTimeMillis() + "] refresh " + sideBarEntry.getId() + "; " + itemBounds + ";clip=" + event.gc.getClipping() + ";eb=" + event.getBounds());
 		if (sideBarEntry.titleInfo != null) {
 			String textIndicator = (String) sideBarEntry.titleInfo.getTitleInfoProperty(ViewTitleInfo.TITLE_INDICATOR_TEXT);
 			if (textIndicator != null) {
@@ -1267,7 +1352,8 @@ public class SideBar
 		Rectangle clipping = new Rectangle(x0IndicatorOfs, itemBounds.y,
 				treeArea.width - x1IndicatorOfs - SIDEBAR_SPACING - x0IndicatorOfs,
 				itemBounds.height);
-		if (event.getBounds().intersects(clipping)) {
+		//System.out.println("itemBounds=" + itemBounds + ";event=" + event.getBounds() + ";" + event.gc.getClipping() + ";" + text);
+		if (drawBounds.intersects(clipping)) {
 			//gc.setClipping(clipping);
 
 			if (text.startsWith(" ")) {
@@ -1276,6 +1362,8 @@ public class SideBar
 				clipping.width -= 30;
 			}
 
+			//System.out.println("draw at " + clipping + " " + text);
+
 			GCStringPrinter sp = new GCStringPrinter(gc, text, clipping, true, false, SWT.NONE);
 			sp.printString();
 			clipping.x += sp.getCalculatedSize().x + 5;
@@ -1307,12 +1395,15 @@ public class SideBar
 
 		// OSX overrides the twisty, and we can't use the default twisty
 		// on Windows because it doesn't have transparency and looks ugly
-		if (treeItem.getItemCount() > 0 && !sideBarEntry.disableCollapse) {
+		if (treeItem.getItemCount() > 0 && !sideBarEntry.disableCollapse && (!Utils.isCocoa || !HIDE_NATIVE_EXPANDER)) {
 			gc.setAntialias(SWT.ON);
 			Color oldBG = gc.getBackground();
 			gc.setBackground(gc.getForeground());
 			if (treeItem.getExpanded()) {
 				int xStart = 15;
+				if (Utils.isCocoa) {
+					xStart -= 5;
+				}
 				int arrowSize = 8;
 				int yStart = itemBounds.height - (itemBounds.height + arrowSize) / 2;
 				gc.fillPolygon(new int[] {
@@ -1325,6 +1416,9 @@ public class SideBar
 				});
 			} else {
 				int xStart = 15;
+				if (Utils.isCocoa) {
+					xStart -= 5;
+				}
 				int arrowSize = 8;
 				int yStart = itemBounds.height - (itemBounds.height + arrowSize) / 2;
 				gc.fillPolygon(new int[] {
@@ -1434,8 +1528,6 @@ public class SideBar
 		entry.setImageLeftID("image.sidebar.library");
 		entry.disableCollapse = true;
 
-		addDropTest(entry);
-
 		createEntryFromSkinRef(SIDEBAR_SECTION_LIBRARY, SIDEBAR_SECTION_LIBRARY_DL,
 				"library", MessageText.getString("sidebar.LibraryDL"), null, null,
 				false, -1);
@@ -1553,11 +1645,6 @@ public class SideBar
 
 		loadCloseables();
 
-		if (System.getProperty("v3.sidebar.advanced", "0").equals("1")) {
-			createEntryFromSkinRef(null, SIDEBAR_SECTION_ADVANCED,
-					"main.area.advancedtab", "Advanced", null, null, false, -1);
-		}
-
 		Composite parent = tree.getParent();
 
 		if (parent.isVisible()) {
@@ -1617,7 +1704,7 @@ public class SideBar
 			return;
 		}
 		entry.addListener(new SideBarDropListener() {
-			public void sideBarEntryDrop(SideBarEntry entry, Object droppedObject) {
+			public boolean sideBarEntryDrop(SideBarEntry entry, Object droppedObject) {
 				String s = "You just dropped " + droppedObject.getClass() + "\n"
 						+ droppedObject + "\n\n";
 				if (droppedObject.getClass().isArray()) {
@@ -1633,7 +1720,8 @@ public class SideBar
 						s += "\n";
 					}
 				}
-				Utils.openMessageBox(null, SWT.OK, "test", s);
+				new MessageBoxShell(SWT.OK, "test", s).open(null);
+				return true;
 			}
 		});
 
@@ -1651,6 +1739,7 @@ public class SideBar
 						"v3.MainWindow.menu.getting_started").replaceAll("&", ""), null,
 				null, true, 0);
 		entry.setImageLeftID("image.sidebar.welcome");
+		addDropTest(entry);
 		return entry;
 	}
 
@@ -1756,12 +1845,19 @@ public class SideBar
 		}
 
 		if (parentTreeItem instanceof Tree) {
+			Tree tree = (Tree) parentTreeItem;
+			if (tree.isDisposed()) {
+				return null;
+			}
 			if (index >= 0) {
-				treeItem = new TreeItem((Tree) parentTreeItem, SWT.NONE, index);
+				treeItem = new TreeItem(tree, SWT.NONE, index);
 			} else {
-				treeItem = new TreeItem((Tree) parentTreeItem, SWT.NONE);
+				treeItem = new TreeItem(tree, SWT.NONE);
 			}
 		} else {
+			if (((TreeItem) parentTreeItem).isDisposed()) {
+				return null;
+			}
 			if (index >= 0) {
 				treeItem = new TreeItem((TreeItem) parentTreeItem, SWT.NONE, index);
 			} else {
@@ -1961,6 +2057,9 @@ public class SideBar
 	}
 
 	private void _itemSelected(TreeItem treeItem) {
+		if (treeItem == null) {
+			return;
+		}
 		TreeItem[] selection = tree.getSelection();
 		if (selection == null || selection.length == 0 || selection[0] != treeItem) {
 			tree.showItem(treeItem);
@@ -2083,6 +2182,14 @@ public class SideBar
 			c.setVisible(true);
 		}
 
+		if (currentSideBarEntry.iview instanceof IViewExtension) {
+			try {
+				((IViewExtension)currentSideBarEntry.iview).viewActivated();
+			} catch (Exception e) {
+				Debug.out(e);
+			}
+		}
+
 		// hide old
 		if (oldEntry != null && oldEntry != newSideBarInfo) {
 			if (lastImage != null && !lastImage.isDisposed()) {
@@ -2109,6 +2216,14 @@ public class SideBar
 					oldComposite.setVisible(false);
 					oldComposite.getShell().update();
 				}
+				
+				if (oldEntry.iview instanceof IViewExtension) {
+					try {
+						((IViewExtension)oldEntry.iview).viewDeactivated();
+					} catch (Exception e) {
+						Debug.out(e);
+					}
+				}
 			}
 		}
 
@@ -2783,22 +2898,10 @@ public class SideBar
 			itemSelected(entry.treeItem);
 			return true;
 		}
-		if (id.equals(SIDEBAR_SECTION_ADVANCED)) {
-			SideBarEntrySWT entryAdv = createEntryFromSkinRef(null,
-					SIDEBAR_SECTION_ADVANCED, "main.area.advancedtab", "Advanced", null,
-					null, false, -1);
-			itemSelected(entryAdv.treeItem);
-			return true;
-		} else if (id.equals(SIDEBAR_SECTION_WELCOME)) {
+		if (id.equals(SIDEBAR_SECTION_WELCOME)) {
 			SideBarEntrySWT entryWelcome = createWelcomeSection();
 			itemSelected(entryWelcome.treeItem);
 			return true;
-		} else if (id.equals(SIDEBAR_SECTION_PUBLISH)) {
-			SideBarEntrySWT entryPublish = createEntryFromSkinRef(
-					SIDEBAR_SECTION_BROWSE, SIDEBAR_SECTION_PUBLISH, "publishtab.area",
-					"Publish", null, null, true, -1);
-			itemSelected(entryPublish.treeItem);
-			return true;
 		} else if (id.startsWith("ContentNetwork.")) {
 			long networkID = Long.parseLong(id.substring(15));
 			handleContentNetworkSwitch(id, networkID);
@@ -2827,8 +2930,6 @@ public class SideBar
 			id = tabID;
 		} else if (tabID.equals("library") || tabID.equals("minilibrary")) {
 			id = SIDEBAR_SECTION_LIBRARY;
-		} else if (tabID.equals("publish")) {
-			id = SIDEBAR_SECTION_PUBLISH;
 		} else if (tabID.equals("activities")) {
 			id = SIDEBAR_SECTION_ACTIVITIES;
 		} else if (tabID.startsWith("ContentNetwork.")) {
