@@ -26,10 +26,11 @@ import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.HashWrapper;
 
 import com.aelitis.azureus.activities.VuzeActivitiesEntry;
-import com.aelitis.azureus.buddy.VuzeShareable;
 import com.aelitis.azureus.core.AzureusCoreFactory;
 import com.aelitis.azureus.core.cnetwork.ContentNetwork;
 import com.aelitis.azureus.core.cnetwork.ContentNetworkManagerFactory;
+import com.aelitis.azureus.core.content.RelatedContent;
+import com.aelitis.azureus.core.devices.DeviceOfflineDownload;
 import com.aelitis.azureus.core.devices.TranscodeFile;
 import com.aelitis.azureus.core.devices.TranscodeJob;
 import com.aelitis.azureus.core.torrent.PlatformTorrentUtils;
@@ -72,8 +73,6 @@ public class DataSourceUtils
 				return gm.getDownloadManager((TOTorrent) ds);
 			} else if (ds instanceof ISelectedContent) {
 				return getDM(((ISelectedContent)ds).getDownloadManager()); 
-			} else if (ds instanceof VuzeShareable) {
-				return getDM(((VuzeShareable)ds).getDownloadManager()); 
 			} else 	if (ds instanceof TranscodeJob) {
 				TranscodeJob tj = (TranscodeJob) ds;
 				try {
@@ -98,6 +97,8 @@ public class DataSourceUtils
 					}
 				} catch (DownloadException e) {
 				}
+			} else if (ds instanceof DeviceOfflineDownload ) {
+				return( PluginCoreUtils.unwrap(((DeviceOfflineDownload)ds).getDownload()));
 			}
 
 		} catch (Exception e) {
@@ -164,7 +165,12 @@ public class DataSourceUtils
 			}
 		}
 		
-		
+		if (ds instanceof DeviceOfflineDownload ){
+			Torrent torrent = ((DeviceOfflineDownload) ds).getDownload().getTorrent();
+			if (torrent != null) {
+				return PluginCoreUtils.unwrap(torrent);
+			}
+		}
 
 		if (ds instanceof ISelectedContent) {
 			return ((ISelectedContent)ds).getTorrent();
@@ -183,10 +189,6 @@ public class DataSourceUtils
 			}
 		}
 
-		if ( ds instanceof VuzeShareable ){
-			return getTorrent(((VuzeShareable)ds).getDownloadManager());
-		}
-		
 		return null;
 	}
 
@@ -214,13 +216,13 @@ public class DataSourceUtils
 				return ((DownloadManager) ds).getTorrent().getHashWrapper().toBase32String();
 			} else if (ds instanceof TOTorrent) {
 				return ((TOTorrent) ds).getHashWrapper().toBase32String();
+			} else if (ds instanceof DeviceOfflineDownload) {
+				return( getHash(PluginCoreUtils.unwrap(((DeviceOfflineDownload)ds).getDownload())));
 			} else if (ds instanceof VuzeActivitiesEntry) {
 				VuzeActivitiesEntry entry = (VuzeActivitiesEntry) ds;
 				return entry.getAssetHash();
 			} else if (ds instanceof ISelectedContent) {
 				return ((ISelectedContent)ds).getHash();
-			} else if (ds instanceof VuzeShareable) {
-				return ((VuzeShareable)ds).getHash();
 			} else if (ds instanceof String) {
 				return (String) ds;
 			}
@@ -237,13 +239,13 @@ public class DataSourceUtils
 				id = PlatformTorrentUtils.getContentNetworkID(((DownloadManager) ds).getTorrent());
 			} else if (ds instanceof TOTorrent) {
 				id = PlatformTorrentUtils.getContentNetworkID((TOTorrent) ds);
+			} else if (ds instanceof DeviceOfflineDownload) {
+				return( getContentNetwork(PluginCoreUtils.unwrap(((DeviceOfflineDownload)ds).getDownload())));
 			} else if (ds instanceof VuzeActivitiesEntry) {
 				VuzeActivitiesEntry entry = (VuzeActivitiesEntry) ds;
 				return entry.getContentNetwork();
 			} else if (ds instanceof ISelectedContent) {
 				return getContentNetwork(((ISelectedContent)ds).getDownloadManager());
-			} else if (ds instanceof VuzeShareable ) {
-				return getContentNetwork(((VuzeShareable)ds).getDownloadManager());
 			} else if ((ds instanceof String) && ((String)ds).length() == 32) {
 				// assume 32 byte string is a hash and that it belongs to the def. network
 				id = ConstantsVuze.getDefaultContentNetwork().getID();
@@ -273,6 +275,8 @@ public class DataSourceUtils
 					}
 				} catch (Throwable e) {
 				}
+			} else if (ds instanceof RelatedContent) {
+				id = ((RelatedContent)ds).getContentNetwork();
 			} else {
 				Debug.out("Tux: UH OH NO CN for " + ds + "\n" + Debug.getCompressedStackTrace());
 			}
@@ -293,9 +297,6 @@ public class DataSourceUtils
 		if (ds instanceof ISelectedContent) {
 			return ((ISelectedContent)ds).getDownloadInfo();
 		}
-		if (ds instanceof VuzeShareable ) {
-			return ((VuzeShareable)ds).getDownloadInfo();
-		}
 		return null;
 	}
 
