@@ -24,6 +24,7 @@ package com.aelitis.net.magneturi;
 
 import java.net.InetSocketAddress;
 import java.net.URL;
+import java.util.Map;
 
 /**
  * @author parg
@@ -40,6 +41,7 @@ MagnetURIHandlerListener
 	download(
 		MagnetURIHandlerProgressListener	progress,
 		byte[]								hash,
+		String								args,
 		InetSocketAddress[]					sources,
 		long								timeout )
 	
@@ -50,4 +52,14 @@ MagnetURIHandlerListener
 		URL			magnet_url )
 	
 		throws MagnetURIHandlerException;
+	
+	public boolean
+	set(
+		String	name,
+		Map values );
+	
+	public int
+	get(
+		String	name,
+		Map 	values );
 }
