@@ -1,7 +1,7 @@
 /*
  * Created on 14-Jun-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -28,18 +28,32 @@ package com.aelitis.net.upnp;
  */
 
 import com.aelitis.net.upnp.impl.*;
+import com.aelitis.net.upnp.impl.ssdp.SSDPCore;
 
-import org.gudy.azureus2.plugins.PluginInterface;
 
 public class 
 UPnPFactory 
 {
 	public static UPnP
 	getSingleton(
-		PluginInterface		plugin_interface )
+		UPnPAdapter		adapter,
+		String[]		selected_interfaces )
 	
 		throws UPnPException
 	{
-		return( UPnPImpl.getSingleton( plugin_interface));
+		return( UPnPImpl.getSingleton( adapter, selected_interfaces ));
+	}
+	
+	public static UPnPSSDP
+	getSSDP(
+		UPnPSSDPAdapter		adapter,
+		String				group_address,
+		int					group_port,
+		int					control_port,
+		String[]			selected_interfaces )
+	
+		throws UPnPException
+	{
+		return( SSDPCore.getSingleton( adapter, group_address, group_port, control_port, selected_interfaces ));
 	}
 }
