@@ -1,7 +1,7 @@
 /*
  * Created on 15-Jun-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,15 +15,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
 
 package com.aelitis.net.upnp;
 
+import java.net.NetworkInterface;
 import java.net.URL;
 import java.net.InetAddress;
+import java.util.Map;
 
 
 /**
@@ -37,15 +39,30 @@ UPnPRootDevice
 	public UPnP
 	getUPnP();
 	
+	public String
+	getUSN();
+	
 	public URL
 	getLocation();
 	
 	public InetAddress
 	getLocalAddress();
 	
+	public NetworkInterface
+	getNetworkInterface();
+	
+	public String
+	getInfo();
+	
 	public UPnPDevice
 	getDevice();
 	
+	public boolean
+	isDestroyed();
+	
+	public Map
+	getDiscoveryCache();
+	
 	public void
 	addListener(
 		UPnPRootDeviceListener	l );
