@@ -40,6 +40,10 @@ SSDPIGD
 	public void
 	searchNow();
 	
+	public void
+	searchNow(
+		String[]	STs );
+	
 	public void
 	addListener(
 		SSDPIGDListener	l );
