@@ -58,12 +58,13 @@ UPnPRootDeviceImpl
 			//true,		// report always	removed, apparently it works OK now according to manufacturer
 		};
 	
-	private UPnPImpl			upnp;
-	private NetworkInterface	network_interface;
-	private InetAddress			local_address;
+	final private UPnPImpl			upnp;
+	final private NetworkInterface	network_interface;
+	final private InetAddress		local_address;
+	
+	final private String		usn;
+	final private URL			location;
 	
-	private String		usn;
-	private URL			location;
 	private URL			url_base_for_relative_urls;
 	private URL			saved_url_base_for_relative_urls;
 	
@@ -93,7 +94,7 @@ UPnPRootDeviceImpl
 		usn					= _usn;
 		location			= _location;
 		
-		SimpleXMLParserDocument	doc = upnp.downloadXML( location );
+		SimpleXMLParserDocument	doc = upnp.downloadXML( this, location );
 			
 		SimpleXMLParserDocumentNode url_base_node = doc.getChild("URLBase");
 		
@@ -140,6 +141,27 @@ UPnPRootDeviceImpl
 		}
 	}
 	
+	public Map 
+	getDiscoveryCache() 
+	{		
+		try{
+			Map	cache = new HashMap();
+
+			cache.put( "ni", network_interface.getName().getBytes( "UTF-8" ));
+			cache.put( "la", local_address.getHostAddress().getBytes( "UTF-8" ));
+			cache.put( "usn", usn.getBytes( "UTF-8" ));
+			cache.put( "loc", location.toExternalForm().getBytes( "UTF-8" ));
+			
+			return( cache );
+		
+		}catch( Throwable e ){
+			
+			Debug.printStackTrace(e);
+			
+			return( null );
+		}
+	}
+	
 	public void
 	portMappingResult(
 		boolean	ok )
@@ -182,12 +204,12 @@ UPnPRootDeviceImpl
 						
 					}else{
 						
-						String	url = root_device.getModeURL();
+						String	url = root_device.getModelURL();
 						
 						upnp.logAlert( 
 								"Device '" + model + "', version '" + version + 
 								"' has known problems with UPnP. Please update to the latest software version (see " + 
-								(url==null?"the manufacturer's web site":url) + ") and refer to http://azureus.aelitis.com/wiki/index.php/UPnP",
+								(url==null?"the manufacturer's web site":url) + ") and refer to http://www.azureuswiki.com/index.php/UPnP",
 								false,
 								UPnPLogListener.TYPE_ONCE_EVER );
 					}
