@@ -43,6 +43,11 @@ public class CategoryImpl implements Category, Comparable {
   private LimitedRateGroup upload_limiter = 
 	  new LimitedRateGroup()
 	  {
+		  public String 
+		  getName() 
+		  {
+			  return( "cat_up: " + sName);
+		  }
 		  public int 
 		  getRateLimitBytesPerSecond()
 		  {
@@ -53,6 +58,11 @@ public class CategoryImpl implements Category, Comparable {
   private LimitedRateGroup download_limiter = 
 	  new LimitedRateGroup()
   {
+	  public String 
+	  getName() 
+	  {
+		  return( "cat_down: " + sName);
+	  }
 	  public int 
 	  getRateLimitBytesPerSecond()
 	  {
@@ -136,6 +146,11 @@ public class CategoryImpl implements Category, Comparable {
     
     DownloadManager	manager = manager_state.getDownloadManager();
     
+    	// can be null if called during downloadmanagerstate construction
+    if ( manager == null ){
+    	return;
+    }
+    
     if (!managers.contains(manager)) {
       managers.add(manager);
       
@@ -154,6 +169,11 @@ public class CategoryImpl implements Category, Comparable {
     }
     DownloadManager	manager = manager_state.getDownloadManager();
 
+   	// can be null if called during downloadmanagerstate construction
+    if ( manager == null ){
+    	return;
+    }
+    
     if (managers.contains(manager) || type != Category.TYPE_USER) {
       managers.remove(manager);
       
