@@ -62,6 +62,8 @@ ConfigurationChecker
   private static boolean new_install			= false;
   
   private static AEMonitor	class_mon	= new AEMonitor( "ConfigChecker");
+
+	private static boolean new_version = false;
   
   
 
@@ -274,6 +276,11 @@ ConfigurationChecker
 	    String	this_version	= Constants.AZUREUS_VERSION;
 	    
 	    if ( !last_version.equals( this_version )){
+	    	if (!Constants.getBaseVersion(last_version).equals(
+						Constants.getBaseVersion())) {
+	    		COConfigurationManager.setParameter("Last Version", last_version);
+					new_version = true;
+				}
 	    	
 	    	if (!COConfigurationManager.hasParameter("First Recorded Version", true)) {
 					COConfigurationManager.setParameter("First Recorded Version",
@@ -561,7 +568,8 @@ ConfigurationChecker
         }
         else {
           System.getProperties().remove( "org.eclipse.swt.internal.carbon.smallFonts" );
-        } 
+        }
+        System.setProperty( "org.eclipse.swt.internal.carbon.noFocusRing", "1" );
       }
       
 	    
@@ -629,6 +637,12 @@ ConfigurationChecker
 	{
 		return( new_install );
 	}
+	
+	public static final boolean
+	isNewVersion()
+	{
+		return( new_version );
+	}
   
   public static void main(String args[]) {
     Integer obj = new Integer(1);
