@@ -141,6 +141,7 @@ public class ConfigurationDefaults {
     def.put("HTTP.Data.Listen.Port.Override", ZERO);
     def.put("HTTP.Data.Listen.Port.Enable", FALSE );
     
+    def.put("IPV6 Enable Support", Constants.isOSX?FALSE:TRUE );
     def.put("IPV6 Prefer Addresses",FALSE);
     	
     def.put("max active torrents", new Long(4));
@@ -248,6 +249,7 @@ public class ConfigurationDefaults {
       for (int j = 0; j <= 3; j++)
         def.put("bLog" + logComponents[i] + "-" + j, TRUE);
     def.put("Logger.DebugFiles.Enabled", TRUE);
+    def.put("Logger.DebugFiles.Enabled.Force", FALSE );
     def.put("Logging Enable UDP Transport", FALSE); 
 
     
@@ -375,6 +377,8 @@ public class ConfigurationDefaults {
     def.put( "Tracker TCP NonBlocking", FALSE);
     def.put( "Tracker TCP NonBlocking Restrict Request Types", TRUE);
     def.put( "Tracker TCP NonBlocking Conc Max", new Long(2048));
+    def.put( "Tracker TCP NonBlocking Immediate Close", FALSE );
+    
     def.put( "Tracker Client Scrape Enable", TRUE);
     def.put( "Tracker Client Scrape Total Disable", FALSE );
     def.put( "Tracker Client Scrape Stopped Enable", TRUE);
@@ -383,10 +387,10 @@ public class ConfigurationDefaults {
     def.put( "Tracker Server Not Found Redirect", "" );
     def.put( "Tracker Server Support Experimental Extensions", FALSE );
     
-    def.put( "Network Selection Prompt", TRUE);
-    def.put( "Network Selection Default.Public", TRUE);
-    def.put( "Network Selection Default.I2P", TRUE);
-    def.put( "Network Selection Default.Tor", TRUE);
+    def.put( "Network Selection Prompt", FALSE );
+    def.put( "Network Selection Default.Public", TRUE );
+    def.put( "Network Selection Default.I2P", FALSE );
+    def.put( "Network Selection Default.Tor", FALSE );
     def.put( "Tracker Network Selection Default.Public", TRUE);
     def.put( "Tracker Network Selection Default.I2P", TRUE);
     def.put( "Tracker Network Selection Default.Tor", TRUE);
@@ -398,6 +402,7 @@ public class ConfigurationDefaults {
     def.put( "Peer Source Selection Default.Incoming", TRUE);
     
     def.put( "config.style.useSIUnits", FALSE );
+    def.put( "config.style.forceSIValues", Constants.isOSX_10_6_OrHigher?FALSE:TRUE );
     def.put( "config.style.useUnitsRateBits", FALSE );
     def.put( "config.style.separateProtDataStats", FALSE );
     def.put( "config.style.dataStatsOnly", FALSE );
