@@ -29,6 +29,21 @@ public interface
 DiskManagerListener 
 {
 	public void
-	stateChanged(int oldState, int	newState );
+	stateChanged(
+		int oldState, 
+		int	newState );
+	
+	public void
+	filePriorityChanged(
+		DiskManagerFileInfo		file );
 
+	public void
+	pieceDoneChanged(
+		DiskManagerPiece		piece );
+	
+	public void
+	fileAccessModeChanged(
+		DiskManagerFileInfo		file,
+		int						old_mode,
+		int						new_mode );
 }
