@@ -79,12 +79,19 @@ DiskManagerHelper
 	setPercentDone(
 		int			num );
 		
+	public void
+	setPieceDone(
+		DiskManagerPieceImpl	piece,
+		boolean					done );
+	
 	public TOTorrent
 	getTorrent();
 	
 	public String[]
 	getStorageTypes();
 	
+	public String getStorageType(int fileIndex);
+	
 	public void
 	accessModeChanged(
 		DiskManagerFileInfoImpl		file,
