@@ -1,7 +1,7 @@
 /*
  * Created on 31-Jul-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -35,15 +35,22 @@ DMAccessFactory
 {
 	public static DMReader
 	createReader(
-		DiskManagerHelper		disk_manager )
+		DiskManagerHelper	adapter )
 	{
-		return( new DMReaderImpl( disk_manager ));
+		return( new DMReaderImpl( adapter ));
 	}
 	
-	public static DMWriterAndChecker
-	createWriterAndChecker(
+	public static DMWriter
+	createWriter(
 		DiskManagerHelper		disk_manager )
 	{
-		return( new DMWriterAndCheckerImpl( disk_manager ));
+		return( new DMWriterImpl( disk_manager ));
+	}
+	
+	public static DMChecker
+	createChecker(
+		DiskManagerHelper		disk_manager )
+	{
+		return( new DMCheckerImpl( disk_manager ));
 	}
 }
