@@ -61,6 +61,9 @@ DMReaderImpl
 	private boolean					started;
 	private boolean					stopped;
 	
+	private long					total_read_ops;
+	private long					total_read_bytes;
+	
 	protected AEMonitor	this_mon	= new AEMonitor( "DMReader" );
 	
 	public
@@ -181,6 +184,12 @@ DMReaderImpl
 		}
 	}
 	
+	public long[]
+	getStats()
+	{
+		return( new long[]{ total_read_ops, total_read_bytes });
+	}
+	
 		// returns null if the read can't be performed
 	
 	public DirectByteBuffer 
@@ -330,7 +339,7 @@ DMReaderImpl
 			List	chunks = new ArrayList();
 			
 			int	buffer_position = 0;
-			
+						
 			while ( buffer_position < length && currentFile < pieceList.size()) {
 	     
 				DMPieceMapEntry map_entry = pieceList.get( currentFile );
@@ -484,6 +493,7 @@ DMReaderImpl
 		private int	buffer_length;
 		
 		private int	chunk_index;
+		private int	chunk_limit;
 		
 		protected
 		requestDispatcher(
@@ -577,6 +587,12 @@ DMReaderImpl
 									public void 
 									requestExecuted(long bytes) 
 									{
+										if ( bytes > 0 ){
+											
+											total_read_bytes 	+= bytes;
+											total_read_ops		++;
+										}
+										
 										listener.requestExecuted( bytes );									
 									}
 								});
@@ -609,10 +625,16 @@ DMReaderImpl
 		doRequest(
 			DiskAccessRequestListener	l )
 		{
-			
 			Object[]	stuff = (Object[])chunks.get( chunk_index++ );
 			
-			buffer.limit( DirectByteBuffer.SS_DR, ((Integer)stuff[2]).intValue());
+			if ( chunk_index > 0 ){
+				
+				buffer.position( DirectByteBuffer.SS_DR, chunk_limit );
+			}
+			
+			chunk_limit = ((Integer)stuff[2]).intValue();
+			
+			buffer.limit( DirectByteBuffer.SS_DR, chunk_limit );
 			
 			short	cache_policy = dm_request.getUseCache()?CacheFile.CP_READ_CACHE:CacheFile.CP_NONE;
 			
@@ -662,6 +684,12 @@ DMReaderImpl
 		public void 
 		requestExecuted(long bytes) 
 		{
+			if ( bytes > 0 ){
+				
+				total_read_bytes 	+= bytes;
+				total_read_ops		++;
+			}
+			
 			listener.requestExecuted( bytes );									
 		}
 		
