@@ -35,12 +35,15 @@ DMPieceMapper
 	
 		throws UnsupportedEncodingException;
 	
-	public DMPieceList[] 
+	public DMPieceMap
 	getPieceMap();
 	
 	public DMPieceMapperFile[]
 	getFiles();
 	
+	public int
+	getPieceLength();
+	
 	public int
 	getLastPieceLength();
 	
