@@ -22,24 +22,28 @@
 
 package org.gudy.azureus2.core3.disk.impl.resume;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
+import java.util.*;
 
-import org.gudy.azureus2.core3.logging.*;
-import org.gudy.azureus2.core3.torrent.TOTorrent;
-import org.gudy.azureus2.core3.util.*;
-
-import org.gudy.azureus2.core3.config.*;
-import org.gudy.azureus2.core3.download.*;
-import org.gudy.azureus2.core3.disk.impl.*;
-import org.gudy.azureus2.core3.disk.impl.access.*;
+import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
+import org.gudy.azureus2.core3.disk.DiskManagerCheckRequest;
+import org.gudy.azureus2.core3.disk.DiskManagerCheckRequestListener;
+import org.gudy.azureus2.core3.disk.DiskManagerFileInfo;
+import org.gudy.azureus2.core3.disk.DiskManagerPiece;
+import org.gudy.azureus2.core3.disk.impl.DiskManagerFileInfoImpl;
+import org.gudy.azureus2.core3.disk.impl.DiskManagerImpl;
+import org.gudy.azureus2.core3.disk.impl.DiskManagerRecheckInstance;
+import org.gudy.azureus2.core3.disk.impl.access.DMChecker;
 import org.gudy.azureus2.core3.disk.impl.piecemapper.DMPieceList;
 import org.gudy.azureus2.core3.disk.impl.piecemapper.DMPieceMapEntry;
-import org.gudy.azureus2.core3.disk.*;
+import org.gudy.azureus2.core3.download.DownloadManager;
+import org.gudy.azureus2.core3.download.DownloadManagerState;
+import org.gudy.azureus2.core3.logging.LogEvent;
+import org.gudy.azureus2.core3.logging.LogIDs;
+import org.gudy.azureus2.core3.logging.Logger;
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+import org.gudy.azureus2.core3.util.AESemaphore;
+import org.gudy.azureus2.core3.util.Debug;
 
 import com.aelitis.azureus.core.diskmanager.cache.CacheFileManagerException;
 
@@ -156,6 +160,22 @@ RDResumeHandler
 	
 				DiskManagerPiece[]	pieces	= disk_manager.getPieces();
 				
+				
+				// calculate the current file sizes up front for performance reasons
+				DiskManagerFileInfo[]	files = disk_manager.getFiles();
+				Map	file_sizes = new HashMap();
+				
+				for (int i=0;i<files.length;i++){
+					try{
+						Long	len = new Long(((DiskManagerFileInfoImpl)files[i]).getCacheFile().getLength());
+						file_sizes.put( files[i], len );
+					}catch( CacheFileManagerException e ){
+						Debug.printStackTrace(e);
+					}
+				}
+
+				
+				
 				if ( resumeEnabled ){
 					
 					boolean resumeValid = false;
@@ -222,25 +242,6 @@ RDResumeHandler
 					
 					check_resume_was_valid = resumeValid;
 					
-						// calculate the current file sizes up front for performance reasons
-					
-					DiskManagerFileInfo[]	files = disk_manager.getFiles();
-					
-					Map	file_sizes = new HashMap();
-					
-					for (int i=0;i<files.length;i++){
-						
-						try{
-							Long	len = new Long(((DiskManagerFileInfoImpl)files[i]).getCacheFile().getLength());
-						
-							file_sizes.put( files[i], len );
-							
-						}catch( CacheFileManagerException e ){
-							
-							Debug.printStackTrace(e);
-						}
-					}
-		
 					boolean	recheck_all	= use_fast_resume_recheck_all;
 					
 					if ( !recheck_all ){
@@ -302,12 +303,14 @@ RDResumeHandler
 						
 						disk_manager.setPercentDone(((i + 1) * 1000) / disk_manager.getNbPieces() );
 						
+						boolean pieceCannotExist = false;
+						
 						byte	piece_state = resume_pieces[i];
 						
 							// valid resume data means that the resume array correctly represents
 							// the state of pieces on disk, be they done or not
 						
-						if ( piece_state == PIECE_DONE ){
+						if ( piece_state == PIECE_DONE || !resumeValid || recheck_all ){
 						
 								// at least check that file sizes are OK for this piece to be valid
 							
@@ -322,6 +325,7 @@ RDResumeHandler
 								if ( file_size == null ){
 									
 									piece_state	= PIECE_NOT_DONE;
+									pieceCannotExist = true;
 									
 									if (Logger.isEnabled())
 										Logger.log(new LogEvent(disk_manager, LOGID,
@@ -336,6 +340,7 @@ RDResumeHandler
 								if ( file_size.longValue() < expected_size ){
 									
 									piece_state	= PIECE_NOT_DONE;
+									pieceCannotExist = true;
 									
 									if (Logger.isEnabled())
 										Logger.log(new LogEvent(disk_manager, LOGID,
@@ -361,8 +366,10 @@ RDResumeHandler
 							
 								// We only need to recheck pieces that are marked as not-ok
 								// if the resume data is invalid or explicit recheck needed
-							
-							if ( piece_state == PIECE_RECHECK_REQUIRED || !resumeValid ){
+							if(pieceCannotExist)
+							{
+								dm_piece.setDone( false );
+							} else if ( piece_state == PIECE_RECHECK_REQUIRED || !resumeValid ){
 										
 								run_sem.reserve();
 								
@@ -466,14 +473,43 @@ RDResumeHandler
 					}
 				}else{
 					
-						// resume not enabled, recheck everything
+					// resume not enabled, recheck everything
 					
 					for (int i = 0; i < pieces.length; i++){
 	
 						check_position	= i;
 						
+						disk_manager.setPercentDone(((i + 1) * 1000) / disk_manager.getNbPieces() );
+
+						boolean pieceCannotExist = false;
+						
+						// check if there is an underlying file for this piece, if not set it to not done
+						DMPieceList list = disk_manager.getPieceList(i);
+						
+						for (int j=0;j<list.size();j++){
+							DMPieceMapEntry	entry = list.get(j);
+							
+							Long	file_size 		= (Long)file_sizes.get(entry.getFile());
+							if ( file_size == null ){
+								pieceCannotExist = true;
+								break;
+							}
+							
+							long	expected_size 	= entry.getOffset() + entry.getLength();
+							if ( file_size.longValue() < expected_size ){
+								pieceCannotExist = true;
+								break;
+							}
+						}
+						
+						if(pieceCannotExist)
+						{
+							disk_manager.getPiece(i).setDone(false);
+							continue;
+						}
+						
 						run_sem.reserve();
-	
+						
 						while( ! stopped ){
 							
 							if ( recheck_inst.getPermission()){
@@ -486,8 +522,7 @@ RDResumeHandler
 														
 							break;
 						}
-											
-						disk_manager.setPercentDone(((i + 1) * 1000) / disk_manager.getNbPieces() );						
+						
 							
 						try{
 							DiskManagerCheckRequest	request = disk_manager.createCheckRequest( i, null );
@@ -828,7 +863,7 @@ RDResumeHandler
 		DownloadManager			download_manager,
 		DiskManagerFileInfo		file,
 		boolean					recheck,
-		boolean					ignore_first_and_last )
+		boolean					onlyClearUnsharedFirstLast )
 	{
 		DownloadManagerState	download_manager_state = download_manager.getDownloadState();
 		
@@ -841,26 +876,45 @@ RDResumeHandler
 
 		int	pieces_cleared	= 0;
 		
-			// TODO: we could be a bit smarter with the first and last pieces regarding
-			// partial blocks where the piece spans the file bounaries.
-		
-			// clear any affected pieces
+		// clear any affected pieces
 		
 		byte[]	resume_pieces = (byte[])resume_data.get("resume data");
 		
-		int	first_piece = file.getFirstPieceNumber();
-		int last_piece	= file.getLastPieceNumber();
+		int firstPiece = file.getFirstPieceNumber();
+		int lastPiece = file.getLastPieceNumber();
 		
-		if ( ignore_first_and_last ){
+		if ( onlyClearUnsharedFirstLast ){
+			DiskManagerFileInfo[] files = download_manager.getDiskManagerFileInfo();
+			boolean firstPieceShared = false;
+			boolean lastPieceShared = false;
 			
-			first_piece++;
+			int firstFile = findFirstFileWithPieceN(firstPiece, files); 
 			
-			last_piece--;
+			for(int i = firstFile;i<files.length;i++)
+			{
+				DiskManagerFileInfo currentFile = files[i];
+				if(currentFile.getLastPieceNumber() < firstPiece)
+					continue;
+				if(currentFile.getIndex() == file.getIndex())
+					continue;
+				if(currentFile.getFirstPieceNumber() > lastPiece)
+					break;
+				if(currentFile.getFirstPieceNumber() <= firstPiece && firstPiece <= currentFile.getLastPieceNumber())
+					firstPieceShared |= !currentFile.isSkipped();
+				if(currentFile.getFirstPieceNumber() <= lastPiece && lastPiece <= currentFile.getLastPieceNumber())
+					lastPieceShared |= !currentFile.isSkipped();
+			}
+			
+			if(firstPieceShared)
+				firstPiece++;
+
+			if(lastPieceShared)
+				lastPiece--;
 		}
 		
 		if ( resume_pieces != null ){
 			
-			for (int i=first_piece;i<=last_piece;i++){
+			for (int i=firstPiece;i<=lastPiece;i++){
 				
 				if ( i >= resume_pieces.length ){
 					
@@ -887,13 +941,13 @@ RDResumeHandler
 			
 				int piece_number = Integer.parseInt((String)iter.next());
 	
-				if ( piece_number >= first_piece && piece_number <= last_piece ){
+				if ( piece_number >= firstPiece && piece_number <= lastPiece ){
 					
 					iter.remove();
 				}
 			}
 		}
-					
+		
 			// either way we're valid as 
 			//    1) clear -> pieces are set as not done
 			//	  2) recheck -> pieces are set as "recheck" and will be checked on restart
@@ -904,6 +958,70 @@ RDResumeHandler
 		
 		return( pieces_cleared );
 	}
+
+	/**
+	 * finds the first affected file via binary search, this is necessary as some methods might be
+	 * invoked for all files, which would result in O(n²) if we'd scan the whole file array every
+	 * time
+	 */	
+	private static int findFirstFileWithPieceN(int firstPiece, DiskManagerFileInfo[] files)
+	{
+		int start = 0;
+		int end = files.length-1;
+		int pivot = 0;
+		
+		while (start <= end) {
+		    pivot = (start + end) >>> 1;
+		    int midVal = files[pivot].getLastPieceNumber();
+
+		    if (midVal < firstPiece)
+		    	start = pivot + 1;
+		    else if (midVal > firstPiece)
+		    	end = pivot - 1;
+		    else {
+		    	// some matching file, now slide leftwards to find the first one, shouldn't be that many
+		    	while(pivot > 0 && files[pivot-1].getLastPieceNumber() == firstPiece)
+		    		pivot--;
+		    	break;
+		    }
+		}
+		
+		return pivot;		
+	}
+	
+	public static boolean fileMustExist(DownloadManager download_manager, DiskManagerFileInfo file) {
+		
+		Map resumeData = getResumeData( download_manager );
+
+		byte[]	resumePieces = resumeData != null ? (byte[])resumeData.get("resume data") : null;
+		
+		boolean sharesAnyNeededPieces = false;
+
+		DiskManagerFileInfo[] files = download_manager.getDiskManagerFileInfo();
+		int firstPiece = file.getFirstPieceNumber();
+		int lastPiece = file.getLastPieceNumber();
+		
+		int firstFile = findFirstFileWithPieceN(firstPiece, files); 
+		
+		// we must sweep over the files, as any number of files could share the first/last piece of the file we're probing
+		for (int i = firstFile; i < files.length && !sharesAnyNeededPieces; i++)
+		{
+			DiskManagerFileInfo currentFile = files[i];
+			if(currentFile.getLastPieceNumber() < firstPiece)
+				continue;
+			if (currentFile.getIndex() == file.getIndex() && resumePieces != null && file.getStorageType() != DiskManagerFileInfo.ST_COMPACT)
+				for (int j = firstPiece; j <= lastPiece && !sharesAnyNeededPieces; j++)
+					sharesAnyNeededPieces |= resumePieces[j] != PIECE_NOT_DONE;
+			if (currentFile.getFirstPieceNumber() > lastPiece)
+				break;
+			if (currentFile.getFirstPieceNumber() <= firstPiece && firstPiece <= currentFile.getLastPieceNumber())
+				sharesAnyNeededPieces |= !currentFile.isSkipped();
+			if (currentFile.getFirstPieceNumber() <= lastPiece && lastPiece <= currentFile.getLastPieceNumber())
+				sharesAnyNeededPieces |= !currentFile.isSkipped();
+		}
+
+		return sharesAnyNeededPieces;
+	}
 	
 	public static int
 	storageTypeChanged(
