@@ -298,16 +298,27 @@ DownloadManager
     public int
     getNbPeers();
 
+    /**
+     * Same as filesExist( true );
+     * @deprecated Use {@link #filesExist(boolean)} - to be removed when EMP dependency removed
+     * @return
+     */
+    
+    public boolean
+    filesExist();
+    
     /**
      * Checks if all the files the user wants to download from this torrent
      * actually exist on their filesystem.
      * <p>
      * If a file does not exist, the download will be set to error state.
-     * 
+     * @param expected_to_be_allocated if this is false and allocation <b>hasn't<b> been attempted then the method will return with false without marking the download as in an error state
      * @return Whether all the non-skipped (non-DND) files exist
      */
+    
     public boolean
-    filesExist();
+    filesExist(
+    	boolean	expected_to_be_allocated );
 
     public String
     getErrorDetails();
@@ -486,41 +497,6 @@ DownloadManager
         File    new_parent_dir )
 
         throws DownloadManagerException;
-
-    /**
-     * Returns an array of size 2 indicating the appropriate locations for this
-     * download's data files and torrent file, based on Azureus's rules regarding
-     * default save paths, and move on completion rules.
-     * 
-     * This method takes one argument - <i>for_moving</i>. This essentially
-     * indicates whether you are getting this information for purposes of just
-     * finding where Azureus would store these files by default, or whether you
-     * are considering moving the files from its current location.
-     * 
-     * If <i>for_moving</i> is <tt>false</tt>, this method will determine locations
-     * for the download and the torrent file where Azureus would store them by
-     * default (it may return the current paths used by this download). 
-     * 
-     * If <i>for_moving</i> is <tt>true</tt>, then this method will consider the
-     * download's current location, and whether it is allowed to move it - you
-     * may not be allowed to move this download (based on Azureus's current rules)
-     * if the download doesn't exist within a default save directory already. If
-     * a download is complete, we consider whether we are allowed to move downloads
-     * on completion, and whether that includes downloads outside the default save
-     * directory.
-     * 
-     * In this case, the array may contain <tt>null</tt> indicating that the Azureus
-     * doesn't believe that the download should be moved (based on the current rules
-     * the user has set out). However, you are not prevented from changing the
-     * location of the torrent file or download.
-     * 
-     * @since 2.5.0.2
-     * @author amc1
-     * @return An array of type <tt>File</tt> of size 2, first element containing the
-     *     calculated location for the download's data files, and the second element
-     *     containing the location for the download's torrent file.
-     */
-    public File[] calculateDefaultPaths();
     
     /**
      * Returns <tt>true</tt> if the download is being saved to one of the default
@@ -549,7 +525,13 @@ DownloadManager
     public void
     setScrapeResult(
         DownloadScrapeResult    result );
+    
+    public boolean
+    isUnauthorisedOnTracker();
 
+    public boolean
+    isTrackerError();
+    
   /**
    * Is extended messaging enabled for this download (meaning AzMP and LTEP support).
    * @return true if enabled, false if disabled
@@ -600,6 +582,18 @@ DownloadManager
 		LimitedRateGroup	group,
 		boolean				upload );
 	
+
+	/**
+	 * @param listener
+	 * @param triggerStateChange
+	 *
+	 * @since 3.1.1.1
+	 */
+	public void
+	addListener(
+		DownloadManagerListener listener,
+		boolean triggerStateChange );
+
     public void
     addListener(
             DownloadManagerListener listener );
@@ -691,6 +685,13 @@ DownloadManager
      */
     public void renameTorrent(String new_name) throws DownloadManagerException;
 
+
+		/**
+		 * Same as renameTorrent, but appends numbers if torrent already exists 
+		 * @since 4.2.0.9
+		 */
+		public void renameTorrentSafe(String name) throws DownloadManagerException;
+    
     /**
      * @since 3.0.5.1
      */
