@@ -31,6 +31,15 @@ import org.gudy.azureus2.core3.peer.*;
 public interface 
 DownloadManagerPeerListener 
 {
+		/**
+		 * Called when a peer manager is created but not yet started
+		 * @param manager
+		 */
+	
+	public void
+	peerManagerWillBeAdded(
+		PEPeerManager	manager );
+
 	public void
 	peerManagerAdded(
 		PEPeerManager	manager );
@@ -46,12 +55,4 @@ DownloadManagerPeerListener
 	public void
 	peerRemoved(
 		PEPeer	peer );
-		
-	public void
-	pieceAdded(
-		PEPiece 	piece );
-		
-	public void
-	pieceRemoved(
-		PEPiece		piece );
 }
