@@ -92,7 +92,8 @@ DownloadManagerStats
   
 	public long getTotalProtocolBytesSent();
 	
-  
+	public long getRemaining();
+	
 	public long
 	getDiscarded();
   	
@@ -101,7 +102,10 @@ DownloadManagerStats
 	
 	public long
 	getHashFailCount();
-	
+
+	/**
+	 * Gives the share ratio of the torrent in 1000ths (i.e. 1000 = share ratio of 1)
+	 */
 	public int
 	getShareRatio();
 	
@@ -182,6 +186,16 @@ DownloadManagerStats
    */
   public void setDownloadRateLimitBytesPerSecond( int max_rate_bps );
   
+	public int getTimeSinceLastDataReceivedInSeconds();
+	public int getTimeSinceLastDataSentInSeconds();
+	
+	public long getAvailWentBadTime();
+	
+	/*
+	public long getEstimatedDownloaded();
+	public long getEstimatedUploaded();
+	*/
+	
 	public void
 	restoreSessionTotals(
 		long		_saved_data_bytes_downloaded,
