@@ -21,6 +21,7 @@
 
 package org.gudy.azureus2.core3.download.impl;
 
+import org.gudy.azureus2.core3.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.core3.download.*;
 
 /** Adapter for DownloadManagerListener 
@@ -30,6 +31,7 @@ public class DownloadManagerAdapter
 {
 	public void stateChanged(DownloadManager manager, int state) {}
 	public void downloadComplete(DownloadManager manager) {}
-  public void completionChanged(DownloadManager manager, boolean bCompleted) {}
+    public void completionChanged(DownloadManager manager, boolean bCompleted) {}
 	public void	positionChanged(DownloadManager download, int oldPosition, int newPosition) {}
+	public void filePriorityChanged( DownloadManager download, DiskManagerFileInfo file ){}
 }
