@@ -414,7 +414,7 @@ DownloadManagerImpl
 										
 										an.cloneFrom( announcer );
 										
-										an.setTrackerUrl( old_url );
+										an.setTrackerURL( old_url );
 										
 										an.stop( false );
 										
@@ -782,7 +782,23 @@ DownloadManagerImpl
 						download_manager_state.setFlag( DownloadManagerState.FLAG_LOW_NOISE, true );
 					}
 							
-				 	download_manager_state.setTrackerResponseCache( new HashMap());
+					Map peer_cache = TorrentUtils.getPeerCache( torrent );
+					
+					if ( peer_cache != null ){
+						
+						try{
+							download_manager_state.setTrackerResponseCache( peer_cache );
+							
+						}catch( Throwable e ){
+						
+							Debug.out( e );
+							
+							download_manager_state.setTrackerResponseCache( new HashMap());
+						}
+					}else{
+					
+						download_manager_state.setTrackerResponseCache( new HashMap());
+					}
 				 	
 				 		// also remove resume data incase someone's published a torrent with resume
 				 		// data in it
@@ -2017,6 +2033,14 @@ DownloadManagerImpl
 			
 			// Need to notify listeners, even if scrape result is not valid, in
 			// case they parse invalid scrapes 
+			
+			if ( response.isValid() && response.getStatus() == TRTrackerScraperResponse.ST_ONLINE ){
+			
+				long cache = ((((long)response.getSeeds())&0x00ffffffL)<<32)|(((long)response.getPeers())&0x00ffffffL);
+				
+				download_manager_state.setLongAttribute( DownloadManagerState.AT_SCRAPE_CACHE, cache );
+			}
+			
 			tracker_listeners.dispatch(LDT_TL_SCRAPERESULT, response);
 		}
 	}
@@ -2974,11 +2998,16 @@ DownloadManagerImpl
 	protected void 
 	deleteDataFiles() 
 	{
-		DiskManagerFactory.deleteDataFiles(torrent, torrent_save_location.getParent(), torrent_save_location.getName());
+		DiskManagerFactory.deleteDataFiles(
+			torrent, 
+			torrent_save_location.getParent(), 
+			torrent_save_location.getName(),
+			getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ));
 		
 		// Attempted fix for bug 1572356 - apparently sometimes when we perform removal of a download's data files,
 		// it still somehow gets processed by the move-on-removal rules. I'm making the assumption that this method
 		// is only called when a download is about to be removed.
+		
 		this.getDownloadState().setFlag(DownloadManagerState.FLAG_DISABLE_AUTO_FILE_MOVE, true);
 	}
   
@@ -2987,7 +3016,7 @@ DownloadManagerImpl
 	{
 		if ( torrentFileName != null ){
   		
-			TorrentUtils.delete( new File(torrentFileName));
+			TorrentUtils.delete( new File(torrentFileName),getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ));
 		}
 	}
   
@@ -3749,7 +3778,7 @@ DownloadManagerImpl
 		this.moveTorrentFile(null, name);
 	}
 
-	private void renameTorrentSafe(String name) throws DownloadManagerException {
+	public void renameTorrentSafe(String name) throws DownloadManagerException {
 		String torrent_parent = new File(this.getTorrentFileName()).getParent();
 		String torrent_name = name;
 		
