@@ -24,7 +24,6 @@ package org.gudy.azureus2.core3.download.impl;
 
 import java.io.*;
 import java.net.URL;
-import java.security.SecureRandom;
 import java.util.*;
 import java.util.zip.GZIPInputStream;
 import java.util.zip.GZIPOutputStream;
@@ -35,11 +34,7 @@ import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.disk.DiskManagerFactory;
 import org.gudy.azureus2.core3.disk.DiskManagerFileInfo;
-import org.gudy.azureus2.core3.download.DownloadManager;
-import org.gudy.azureus2.core3.download.DownloadManagerState;
-import org.gudy.azureus2.core3.download.DownloadManagerStateAttributeListener;
-import org.gudy.azureus2.core3.download.DownloadManagerStateEvent;
-import org.gudy.azureus2.core3.download.DownloadManagerStateListener;
+import org.gudy.azureus2.core3.download.*;
 import org.gudy.azureus2.core3.logging.LogEvent;
 import org.gudy.azureus2.core3.logging.LogIDs;
 import org.gudy.azureus2.core3.logging.LogRelation;
@@ -117,7 +112,7 @@ DownloadManagerStateImpl
 	
 	private static Map					state_map 					= new HashMap();
 	private static Map					global_state_cache			= new HashMap();
-	private static List					global_state_cache_wrappers	= new ArrayList();
+	private static ArrayList			global_state_cache_wrappers	= new ArrayList();
 	
 	private DownloadManagerImpl			download_manager;
 	
@@ -471,6 +466,7 @@ DownloadManagerStateImpl
 		}
 		
 		global_state_cache_wrappers.clear();
+		global_state_cache_wrappers.trimToSize();
 	}
 
 	protected
@@ -885,6 +881,12 @@ DownloadManagerStateImpl
 		return(( value & flag ) != 0 );
 	}
 	
+	public long 
+	getFlags() 
+	{
+		return( getLongAttribute( AT_FLAGS ));
+	}
+	
 	public boolean parameterExists(String name) {
 		return parameters.containsKey(name);
 	}
@@ -1239,10 +1241,14 @@ DownloadManagerStateImpl
 			if (fileInfo.length > 0) {
 				int idxBiggest = -1;
 				long lBiggest = -1;
-				for (int i = 0; i < fileInfo.length && i < 10; i++) {
-					if (!fileInfo[i].isSkipped() && fileInfo[i].getLength() > lBiggest) {
-						lBiggest = fileInfo[i].getLength();
-						idxBiggest = i;
+				int numChecked = 0;
+				for (int i = 0; i < fileInfo.length && numChecked < 10; i++) {
+					if (!fileInfo[i].isSkipped()) {
+						numChecked++;
+						if (fileInfo[i].getLength() > lBiggest) {
+  						lBiggest = fileInfo[i].getLength();
+  						idxBiggest = i;
+						}
 					}
 				}
 				if (idxBiggest >= 0) {
@@ -2393,6 +2399,12 @@ DownloadManagerStateImpl
 			return( false );
 		}
 		
+		public long 
+		getFlags() 
+		{
+			return 0;
+		}
+		
 		public void
 		setParameterDefault(
 			String	name )
@@ -3272,6 +3284,16 @@ DownloadManagerStateImpl
 	   		return( null );
     	}
     	
+       	public void
+    	setCreatedBy(
+    		byte[]		cb )
+       	{
+	   		if ( fixup()){
+				
+				delegate.setCreatedBy( cb );
+			}
+    	}
+       	
     	public boolean
     	isCreated()
        	{
