@@ -42,6 +42,16 @@ HTMLPageFactory
 		return( loadPage( is, true ));
 	}
 	
+	public static HTMLPage
+	loadPage(
+		InputStream		is,
+		String			charset )
+	
+		throws HTMLException
+	{
+		return( loadPage( is, charset, true ));
+	}
+	
 	public static HTMLPage
 	loadPage(
 		InputStream		is,
@@ -49,6 +59,17 @@ HTMLPageFactory
 	
 		throws HTMLException
 	{
-		return( new HTMLPageImpl( is, close_file ));
+		return(loadPage( is, null, close_file ));
+	}
+	
+	public static HTMLPage
+	loadPage(
+		InputStream		is,
+		String			charset,
+		boolean			close_file )
+	
+		throws HTMLException
+	{
+		return( new HTMLPageImpl( is, charset, close_file ));
 	}
 }
