@@ -23,6 +23,7 @@ package org.gudy.azureus2.core3.internat;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
+import java.io.InputStream;
 import java.util.*;
 
 import org.gudy.azureus2.core3.util.AETemporaryFileHandler;
@@ -40,6 +41,8 @@ public class
 IntegratedResourceBundle 
 	extends ResourceBundle 
 {
+	private static final boolean DEBUG = false;
+
 	private static final Object	NULL_OBJECT = new Object();
 	
 	private static final Map	bundle_map = new WeakHashMap();
@@ -72,10 +75,17 @@ IntegratedResourceBundle
 					
 									IntegratedResourceBundle	rb = (IntegratedResourceBundle)it.next();
 					
+									if (DEBUG) {
+										System.out.println("Compact RB " + rb.getString());
+									}
+
 									if ( rb.compact()){
 					
 										did_something	= true;
 									}
+									if (DEBUG) {
+										System.out.println("        to " + rb.getString());
+									}
 								}
 					
 								if ( !did_something ){
@@ -93,27 +103,47 @@ IntegratedResourceBundle
 	
 	private Locale	locale;
 
-	private Map	messages 		= new LightHashMap();
+	private Map	messages;
 	private Map	used_messages;
+	private List null_values;
 	
 	private int		clean_count	= 0;
-	private File	scratch_file;
+	private boolean	one_off_discard_done;
 	
+	private File		scratch_file_name;
+	private InputStream	scratch_file_is;
+
+	private final int initCapacity;
+	
+
 	
 	public 
 	IntegratedResourceBundle(
 		ResourceBundle 		main, 
 		Map 				localizationPaths) 
 	{
-		this( main, localizationPaths, null );
+		this( main, localizationPaths, null, 10 );
 	}
 
 	public 
 	IntegratedResourceBundle(
 		ResourceBundle 		main, 
 		Map 				localizationPaths,
-		Collection 			resource_bundles) 
+		int					initCapacity) 
 	{
+		this( main, localizationPaths, null, initCapacity );
+	}
+
+	public 
+	IntegratedResourceBundle(
+		ResourceBundle 		main, 
+		Map 				localizationPaths,
+		Collection 			resource_bundles,
+		int					initCapacity)  
+	{
+		this.initCapacity = initCapacity;
+		messages = new LightHashMap(initCapacity);
+
 		locale = main.getLocale();
 
 			// use a somewhat decent initial capacity, proper calculation would require java 1.6
@@ -148,6 +178,7 @@ IntegratedResourceBundle
 			
 			resetCompactTimer();
 		}
+		//System.out.println("IRB Size = " + messages.size() + "/cap=" + initCapacity + ";" + Debug.getCompressedStackTrace());
 	}
 
 	public Locale getLocale() 
@@ -178,6 +209,31 @@ IntegratedResourceBundle
 		
 		return( m.keySet().iterator());
 	}
+
+	/**
+	 * Gets a string, using default if key doesn't exist.  Skips
+	 * throwing MissingResourceException when key doesn't exist, which saves
+	 * some CPU cycles
+	 * 
+	 * @param key
+	 * @param def
+	 * @return
+	 *
+	 * @since 3.1.1.1
+	 */
+  public String getString(String key, String def) {
+		String s = (String) handleGetObject(key);
+		if (s == null) {
+			if (parent != null) {
+				s = parent.getString(key);
+			}
+			if (s == null) {
+				return def;
+			}
+		}
+		return s;
+	}
+
 	
 	protected Object 
 	handleGetObject(
@@ -190,6 +246,15 @@ IntegratedResourceBundle
 			res = used_messages.get( key );
 		}
 		
+		Integer keyHash = null;
+		if (null_values != null) {
+			keyHash = new Integer(key.hashCode());
+  		int index = Collections.binarySearch(null_values, keyHash);
+  		if (index >= 0) {
+  			return null;
+  		}
+		}
+		
 		if ( res == NULL_OBJECT ){
 			
 			return( null );
@@ -205,8 +270,24 @@ IntegratedResourceBundle
 					
 					res = messages.get( key );
 				}
-			
-				used_messages.put( key, res==null?NULL_OBJECT:res );
+
+				if (res == null && null_values != null) {
+
+		  		int index = Collections.binarySearch(null_values, keyHash);
+					if (index < 0) {
+						index = -1 * index - 1; // best guess
+					}
+
+					if (index > null_values.size()) {
+						index = null_values.size();
+					}
+					
+					null_values.add(index, keyHash);
+					
+				} else {
+
+					used_messages.put( key, res==null?NULL_OBJECT:res );
+				}
 					
 				clean_count	= 0;
 				
@@ -269,6 +350,7 @@ IntegratedResourceBundle
 				}
 			}			
 		}
+//		System.out.println("after addrb; IRB Size = " + messages.size() + "/cap=" + initCapacity + ";" + Debug.getCompressedStackTrace());
 	}
 	
 	protected boolean
@@ -283,7 +365,7 @@ IntegratedResourceBundle
 			return( true );
 		}
 		
-		if ( scratch_file == null ){
+		if ( scratch_file_is == null ){
 			
 			File temp_file = null;
 			
@@ -304,7 +386,8 @@ IntegratedResourceBundle
 				
 				fos = null;
 				
-				scratch_file = temp_file;
+				scratch_file_name	= temp_file;
+				scratch_file_is 	= new FileInputStream( temp_file );
 				
 			}catch( Throwable e ){
 				
@@ -325,12 +408,28 @@ IntegratedResourceBundle
 			}
 		}
 		
-		if ( scratch_file != null && clean_count >= 2 ){
+		if ( scratch_file_is != null ){
 			
-			messages = null;
+			if ( clean_count >= 2 ){
+		
+			
+					// throw away full message map after 2 ticks
+			
+				messages = null;
+			}
+		
+			if ( clean_count == 5 && !one_off_discard_done){
+
+				one_off_discard_done = true;
+				
+					// one off discard of used_messages to clear out any that were
+					// accessed once and never again
+			
+				used_messages.clear();
+			}
 		}
 		
-		if ( clean_count >= 5 ){
+		if ( clean_count > 5 ){
 		
 			Map	compact_um = new LightHashMap( used_messages.size() + 16 );
 			
@@ -356,23 +455,23 @@ IntegratedResourceBundle
 				return( messages );
 			}
 			
-			if ( scratch_file == null ){
+			if ( scratch_file_is == null ){
 				
 				return( new LightHashMap());
 			}
 			
 			Properties p = new Properties();
 			
-			FileInputStream	fis = null;
+			InputStream	fis = scratch_file_is;
 			
 			try{
-				
-				fis = new FileInputStream( scratch_file );
-				
+								
 				p.load( fis );
 				
 				fis.close();
 				
+				scratch_file_is = new FileInputStream( scratch_file_name );
+				
 				messages = new LightHashMap();
 				
 				messages.putAll( p );
@@ -392,9 +491,9 @@ IntegratedResourceBundle
 				
 				Debug.out( "Failed to load message bundle scratch file", e );
 				
-				scratch_file.delete();
+				scratch_file_name.delete();
 				
-				scratch_file = null;
+				scratch_file_is = null;
 				
 				return( new LightHashMap());
 			}
@@ -404,6 +503,31 @@ IntegratedResourceBundle
 	protected String
 	getString()
 	{
-		return( locale + ": use=" + used_messages.size() + ",map=" + (messages==null?"":String.valueOf(messages.size())));
+		return( locale + ": use=" + used_messages.size() + ",map=" + (messages==null?"":String.valueOf(messages.size())) 
+				+ (null_values == null ? "" : ",null=" + null_values.size()));
+	}
+	
+	public void
+	addString(String key, String value) {
+		messages.put(key, value);
+	}
+
+	public boolean getUseNullList() {
+		return null_values != null;
+	}
+
+	public void setUseNullList(boolean useNullList) {
+		if (useNullList && null_values == null) {
+			null_values = new ArrayList(0);
+		} else if (!useNullList && null_values != null) {
+			null_values = null;
+		}
+	}
+	
+	public void clearUsedMessagesMap(int initialCapacity) {
+		used_messages = new LightHashMap(initialCapacity);
+		if (null_values != null) {
+			null_values = new ArrayList(0);
+		}
 	}
 }
