@@ -63,19 +63,22 @@ IpFilter
   
 	public boolean 
 	isInRange(
-		String ipAddress, 
-		String torrent_name);
+		String 	ipAddress, 
+		String 	torrent_name,
+		byte[]	torrent_hash );
 	
 	public boolean 
 	isInRange(
-		String ipAddress, 
-		String torrent_name,
+		String 	ipAddress, 
+		String 	torrent_name,
+		byte[]	torrent_hash,
 		boolean	loggable );
 	
 	public boolean 
 	isInRange(
 		InetAddress 	ipAddress, 
 		String 			torrent_name,
+		byte[]			torrent_hash,
 		boolean			loggable );
 	
 	public IpRange
@@ -108,8 +111,15 @@ IpFilter
 	public boolean 
 	ban(
 		String 	ipAddress,
-		String	torrent_name );
+		String	torrent_name,
+		boolean	manual );
 	
+	public void
+	unban(String ipAddress);
+	
+	public void
+	unban(String ipAddress, boolean block);
+
 	public int
 	getNbBannedIps();
 	
@@ -149,4 +159,12 @@ IpFilter
 	public void
 	removeListener(
 		IPFilterListener	l );
+	
+	public void
+	addExternalHandler(
+		IpFilterExternalHandler	handler );
+	
+	public void
+	removeExternalHandler(
+		IpFilterExternalHandler	handler );
 }
