@@ -119,4 +119,11 @@ IpRange
 	 * @param e2
 	 */
 	public void addMergedEntry(IpRange e2);
+
+	/**
+	 * @return
+	 *
+	 * @since 3.0.1.5
+	 */
+	public boolean getAddedToRangeList();
 }
