@@ -37,10 +37,16 @@ public class IpRangeImpl implements IpRange
 	private final static byte FLAG_SESSION_ONLY = 0x1;
 
 	private final static byte FLAG_ADDED_TO_RANGE_LIST = 0x2;
+	
+	private final static byte FLAG_INVALID_START = 0x8;
 
-	private Object startIp; // Integer if value, String/null otherwise
+	private final static byte FLAG_INVALID_END = 0x10;
 
-	private Object endIp; // Integer if value, String/null otherwise
+	private final static byte FLAG_INVALID = FLAG_INVALID_START | FLAG_INVALID_END;
+
+	private int ipStart;
+
+	private int ipEnd;
 
 	private byte flags;
 
@@ -64,17 +70,16 @@ public class IpRangeImpl implements IpRange
 			throw (new RuntimeException(
 					"Invalid start/end values - null not supported"));
 		}
-
-		if (_startIp == "") {
-			startIp = "";
-		} else {
-			startIp = _startIp.trim();
+		
+		try {
+			ipStart = PRHelpers.addressToInt(_startIp);
+		} catch (UnknownHostException e) {
+			flags |= FLAG_INVALID_START;
 		}
-
-		if (_endIp == "") {
-			endIp = "";
-		} else {
-			endIp = _endIp.trim();
+		try {
+			ipEnd = PRHelpers.addressToInt(_endIp);
+		} catch (UnknownHostException e) {
+			flags |= FLAG_INVALID_END;
 		}
 
 		if (_description != "") {
@@ -84,53 +89,44 @@ public class IpRangeImpl implements IpRange
 		checkValid();
 	}
 
-	public void checkValid() {
-		if (startIp != null && endIp != null) {
-
-			if (startIp instanceof String) {
-
-				try {
-					startIp = new Integer(PRHelpers.addressToInt((String) startIp));
-
-				} catch (UnknownHostException e) {
-
-				}
-			}
-
-			if (endIp instanceof String) {
-
-				try {
-					endIp = new Integer(PRHelpers.addressToInt((String) endIp));
-
-				} catch (UnknownHostException e) {
-
-				}
-			}
+	public IpRangeImpl(String _description, int _startIp, int _endIp,
+			boolean _sessionOnly) {
+		if (_sessionOnly) {
+			flags = FLAG_SESSION_ONLY;
 		}
 
-		((IpFilterImpl) IpFilterImpl.getInstance()).setValidOrNot(this, isValid());
+		ipStart = _startIp;
+		ipEnd = _endIp;
 
+		if (_description != "") {
+			setDescription(_description);
+		}
+
+		checkValid();
+	}
+
+	public void checkValid() {
+		((IpFilterImpl) IpFilterImpl.getInstance()).setValidOrNot(this, isValid());
 	}
 
 	public boolean isValid() {
-		if (startIp instanceof Integer && endIp instanceof Integer) {
-
-			long start_address = ((Integer) startIp).intValue();
-			long end_address = ((Integer) endIp).intValue();
-
-			if (start_address < 0) {
-
-				start_address += 0x100000000L;
-			}
-			if (end_address < 0) {
-
-				end_address += 0x100000000L;
-			}
-
-			return (end_address >= start_address);
+		if ((flags & FLAG_INVALID) > 0) {
+			return false;
 		}
 
-		return (false);
+		long start_address = ipStart;
+		long end_address = ipEnd;			
+
+		if (start_address < 0) {
+
+			start_address += 0x100000000L;
+		}
+		if (end_address < 0) {
+
+			end_address += 0x100000000L;
+		}
+
+		return (end_address >= start_address);
 	}
 
 	public boolean isInRange(String ipAddress) {
@@ -146,8 +142,8 @@ public class IpRangeImpl implements IpRange
 				int_address += 0x100000000L;
 			}
 
-			long start_address = ((Integer) startIp).intValue();
-			long end_address = ((Integer) endIp).intValue();
+  		long start_address = ipStart;
+  		long end_address = ipEnd;			
 
 			if (start_address < 0) {
 
@@ -172,30 +168,28 @@ public class IpRangeImpl implements IpRange
 	}
 
 	public void setDescription(String str) {
-		descRef = IpFilterManagerFactory.getSingleton().addDecription(this,
+		descRef = IpFilterManagerFactory.getSingleton().addDescription(this,
 				str.getBytes());
 	}
 
 	public String getStartIp() {
-		return (startIp instanceof Integer
-				? PRHelpers.intToAddress(((Integer) startIp).intValue())
-				: (String) startIp);
+		return (flags & FLAG_INVALID_START) > 0 ? ""
+				: PRHelpers.intToAddress(ipStart);
 	}
 
 	public long getStartIpLong() {
-		if (startIp instanceof Integer) {
-
-			long val = ((Integer) startIp).intValue();
-
-			if (val < 0) {
-
-				val += 0x100000000L;
-			}
-
-			return (val);
+		if ((flags & FLAG_INVALID_START) > 0) {
+			return -1;
 		}
 
-		return (-1);
+		long val = ipStart;
+
+		if (val < 0) {
+
+			val += 0x100000000L;
+		}
+
+		return (val);
 	}
 
 	public void setStartIp(String str) {
@@ -207,31 +201,34 @@ public class IpRangeImpl implements IpRange
 			return;
 		}
 
-		startIp = str;
+		flags &= ~FLAG_INVALID_START;
+		try {
+			ipStart = PRHelpers.addressToInt(str);
+		} catch (UnknownHostException e) {
+			flags |= FLAG_INVALID_START;
+		}
 
-		if (endIp != "") {
+		if ((flags & FLAG_INVALID) == 0) {
 			checkValid();
 		}
 	}
 
 	public String getEndIp() {
-		return (endIp instanceof Integer)
-				? PRHelpers.intToAddress(((Integer) endIp).intValue()) : (String) endIp;
+		return (flags & FLAG_INVALID_END) > 0 ? "" : PRHelpers.intToAddress(ipEnd);
 	}
 
 	public long getEndIpLong() {
-		if (endIp instanceof Integer) {
-
-			long val = ((Integer) endIp).intValue();
-
-			if (val < 0) {
-				val += 0x100000000L;
-			}
-
-			return (val);
+		if ((flags & FLAG_INVALID_END) > 0) {
+			return -1;
 		}
 
-		return (-1);
+		long val = ipEnd;
+
+		if (val < 0) {
+			val += 0x100000000L;
+		}
+
+		return (val);
 	}
 
 	public void setEndIp(String str)
@@ -245,9 +242,14 @@ public class IpRangeImpl implements IpRange
 			return;
 		}
 
-		endIp = str;
+		flags &= ~FLAG_INVALID_END;
+		try {
+			ipEnd = PRHelpers.addressToInt(str);
+		} catch (UnknownHostException e) {
+			flags |= FLAG_INVALID_END;
+		}
 
-		if (startIp != "") {
+		if ((flags & FLAG_INVALID) == 0) {
 			checkValid();
 		}
 	}
@@ -299,7 +301,7 @@ public class IpRangeImpl implements IpRange
 		}
 	}
 
-	protected boolean getAddedToRangeList() {
+	public boolean getAddedToRangeList() {
 		return (flags & FLAG_ADDED_TO_RANGE_LIST) != 0;
 	}
 
@@ -326,8 +328,8 @@ public class IpRangeImpl implements IpRange
 	public void resetMergeInfo() {
 		flags &= ~FLAG_MERGED;
 
-		if (endIp instanceof Integer) {
-			merged_end = ((Integer) endIp).intValue();
+		if ((flags & FLAG_INVALID_END) == 0) {
+			merged_end = ipEnd;
 		}
 	}
 
