@@ -53,6 +53,7 @@ public class FileLogging implements ILogEventListener {
 	private static final String CFG_ENABLELOGTOFILE = "Logging Enable";
 
 	private boolean bLogToFile = false;
+	private boolean bLogToFileErrorPrinted = false;
 
 	private String sLogDir = "";
 
@@ -94,13 +95,21 @@ public class FileLogging implements ILogEventListener {
 	 */
 	protected void reloadLogToFileParam() {
 		final ConfigurationManager config = ConfigurationManager.getInstance();
-		boolean bNewLogToFile = config.getBooleanParameter(CFG_ENABLELOGTOFILE);
+		boolean bNewLogToFile = System.getProperty("azureus.overridelog") != null || config.getBooleanParameter(CFG_ENABLELOGTOFILE);
 		if (bNewLogToFile != bLogToFile) {
 			bLogToFile = bNewLogToFile;
 			if (bLogToFile)
 				Logger.addListener(this);
-			else
+			else{
 				Logger.removeListener(this);
+				
+				synchronized( Logger.class ){
+					
+						// close existing file
+					
+					checkAndSwapLog();
+				}
+			}
 		}
 	}
 
@@ -113,14 +122,18 @@ public class FileLogging implements ILogEventListener {
 
 			boolean overrideLog = System.getProperty("azureus.overridelog") != null;
 			if (overrideLog) {
-				bLogToFile = true;
-				sLogDir = ".";
+				
+				// Don't set this - reloadLogToFileParam will do it.
+				//bLogToFile = true;
+				sLogDir = System.getProperty("azureus.overridelogdir", ".");
 				iLogFileMaxMB = 2;
 				timeStampFormat = "HH:mm:ss.SSS ";
 
 				for (int i = 0; i < ignoredComponents.length; i++) {
 					ignoredComponents[i].clear();
 				}
+				
+				reloadLogToFileParam();
 			} else {
 				reloadLogToFileParam();
 
@@ -142,8 +155,10 @@ public class FileLogging implements ILogEventListener {
 			}
 			
 			synchronized (Logger.class) {
-				checkAndSwapLog();
+				// Create the date format first *before* we do checkAndSwapLog,
+				// just in case we end up invoking logToFile...
 				format = new SimpleDateFormat(timeStampFormat);
+				checkAndSwapLog();
 			}
 			
 			
@@ -156,13 +171,14 @@ public class FileLogging implements ILogEventListener {
 		if (!bLogToFile)
 			return;
 
-		str = format.format(new Date()) + str;
+		String dateStr = format.format(new Date()); 
 		
 		synchronized (Logger.class) {
 
 			// exception handling is done by FileWriter
 			if(logFilePrinter != null)
 			{
+				logFilePrinter.print(dateStr);
 				logFilePrinter.print(str);
 				logFilePrinter.flush();
 			}
@@ -210,7 +226,20 @@ public class FileLogging implements ILogEventListener {
 				logFilePrinter = new PrintWriter(new FileWriter(logFile, true));
 			} catch (IOException e)
 			{
-				// don't log, would cause infinite recursion
+				if (!bLogToFileErrorPrinted) {
+					
+					// don't just log errors, as it would cause infinite recursion
+					bLogToFileErrorPrinted = true;
+					Debug.out("Unable to write to log file: " + logFile);
+					Debug.printStackTrace(e);
+
+					/*
+					java.io.PrintStream stderr = Logger.getOldStdErr();
+					stderr.println("Unable to write to log file: " + logFile);
+					e.printStackTrace(stderr);
+					*/
+				}
+				
 			}
 		}
 	}
@@ -252,7 +281,7 @@ public class FileLogging implements ILogEventListener {
 				.contains(event.logID))
 			return;
 
-		StringBuffer text = new StringBuffer();
+		StringBuffer text = new StringBuffer(event.text.length());
 		
 		text.append(event.entryType).append(" ");
 
