@@ -29,8 +29,6 @@ import org.gudy.azureus2.core3.config.impl.ConfigurationManager;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.logging.ILogAlertListener;
 import org.gudy.azureus2.core3.logging.ILogEventListener;
-import org.gudy.azureus2.core3.logging.ILoggerListener;
-import org.gudy.azureus2.core3.logging.LGAlertListener;
 import org.gudy.azureus2.core3.logging.LogAlert;
 import org.gudy.azureus2.core3.logging.LogEvent;
 import org.gudy.azureus2.core3.logging.LogIDs;
@@ -68,6 +66,8 @@ public class LoggerImpl {
 	private List alertListeners = new ArrayList();
 
 	private List alertHistory = new ArrayList();
+	
+	private boolean logToStdErrAllowed = true;
 
 	/**
 	 * Initializes the Logger and sets up a file logger.
@@ -101,8 +101,6 @@ public class LoggerImpl {
 				}
 			});
 		}
-
-		alertLogger = AEDiagnostics.getLogger("alerts");
 	}
 
 	/**
@@ -191,6 +189,15 @@ public class LoggerImpl {
 	 *            event to log
 	 */
 	public void log(LogEvent event) {
+		
+		/**
+		 * This highlights bits of code which log, but don't bother
+		 * to check whether logging is enabled or not.
+		 */ 
+		//if (!bEventLoggingEnabled) {
+		//	new Exception("No logging check done!").printStackTrace(psOldErr);
+		//}
+		
 		if (bLogToStdOut && psOldOut != null)
 			psOldOut.println(event.text);
 
@@ -199,7 +206,7 @@ public class LoggerImpl {
 					// more recursive horrors here if we try and log too early
 				Debug.outDiagLoggerOnly("[" + event.logID + "] " + event.text);
 			}
-			if (psOldErr != null && event.logID != LogIDs.STDERR) {
+			if (logToStdErrAllowed && psOldErr != null && event.logID != LogIDs.STDERR) {
 				psOldErr.println("[" + event.logID + "] " + event.text);
 			}
 		}
@@ -209,12 +216,8 @@ public class LoggerImpl {
 					Object listener = logListeners.get(i);
 					if (listener instanceof ILogEventListener)
 						((ILogEventListener) listener).log(event);
-					else
-						// XXX ComponentID
-						((ILoggerListener) listener).log(0, event.entryType, event.entryType,
-								event.text);
 				} catch (Throwable e) {
-					if (psOldErr != null) {
+					if (logToStdErrAllowed && psOldErr != null) {
 						psOldErr.println("Error while logging: " + e.getMessage());
 						e.printStackTrace(psOldErr);
 					}
@@ -237,24 +240,6 @@ public class LoggerImpl {
 		log(event);
 	}
 
-	/**
-	 * 
-	 * @param aListener
-	 * @deprecated
-	 */
-	public void addListener(ILoggerListener aListener) {
-		logListeners.add(aListener);
-	}
-
-	/**
-	 * 
-	 * @param aListener
-	 * @deprecated
-	 */
-	public void removeListener(ILoggerListener aListener) {
-		logListeners.remove(aListener);
-	}
-
 	public void addListener(ILogEventListener aListener) {
 		logListeners.add(aListener);
 	}
@@ -275,8 +260,12 @@ public class LoggerImpl {
 		alertEvent.err = alert.err;
 		Logger.log(alertEvent);
 
-		if (alertLogger != null)
-			alertLogger.log(logText);
+		synchronized (this) {
+			if (alertLogger == null) {
+				alertLogger = AEDiagnostics.getLogger("alerts");
+			}
+		}
+		alertLogger.log(logText);
 
 		alertHistory.add(alert);
 
@@ -288,14 +277,6 @@ public class LoggerImpl {
 				Object listener = alertListeners.get(i);
 				if (listener instanceof ILogAlertListener)
 					((ILogAlertListener) listener).alertRaised(alert);
-				else if (listener instanceof LGAlertListener) {
-					if (alert.err == null)
-						((LGAlertListener) listener).alertRaised(alert.entryType,
-								alert.text, alert.repeatable);
-					else
-						((LGAlertListener) listener).alertRaised(alert.text, alert.err,
-								alert.repeatable);
-				}
 			} catch (Throwable f) {
 				if (psOldErr != null) {
 					psOldErr.println("Error while alerting: " + f.getMessage());
@@ -315,23 +296,6 @@ public class LoggerImpl {
 		log(alert);
 	}
 
-	public void addListener(LGAlertListener l) {
-		alertListeners.add(l);
-
-		for (int i = 0; i < alertHistory.size(); i++) {
-			LogAlert alert = (LogAlert) alertHistory.get(i);
-
-			if (alert.err == null)
-				l.alertRaised(alert.entryType, alert.text, alert.repeatable);
-			else
-				l.alertRaised(alert.text, alert.err, alert.repeatable);
-		}
-	}
-
-	public void removeListener(LGAlertListener l) {
-		alertListeners.remove(l);
-	}
-
 	public void addListener(ILogAlertListener l) {
 		alertListeners.add(l);
 
@@ -348,4 +312,8 @@ public class LoggerImpl {
 	public PrintStream getOldStdErr() {
 		return psOldErr;
 	}
+	
+	public void allowLoggingToStdErr(boolean allowed) {
+		this.logToStdErrAllowed = allowed;
+	}
 }
