@@ -26,10 +26,8 @@ package org.gudy.azureus2.core3.peer.impl;
  *
  */
 
-import org.gudy.azureus2.core3.tracker.client.*;
 import org.gudy.azureus2.core3.disk.*;
-import org.gudy.azureus2.core3.download.*;
-import org.gudy.azureus2.core3.peer.*;
+import org.gudy.azureus2.core3.peer.PEPeerManagerAdapter;
 import org.gudy.azureus2.core3.peer.impl.control.*;
 
 public class 
@@ -37,11 +35,20 @@ PEPeerControlFactory {
 	
 	public static PEPeerControl
 	create(
-		DownloadManager 	manager,
-		PEPeerServer 		server,
-		TRTrackerClient 	tracker,
-		DiskManager 		diskManager )
+		byte[]					peer_id,
+		PEPeerManagerAdapter 	adapter,
+		DiskManager 			diskManager )
 	{
-		return( new PEPeerControlImpl( manager, (PEPeerServerHelper)server, tracker, diskManager ));
+		return( create( peer_id, adapter, diskManager, 0 ));
+	}
+	
+	public static PEPeerControl
+	create(
+		byte[]					peer_id,
+		PEPeerManagerAdapter 	adapter,
+		DiskManager 			diskManager,
+		int						id )
+	{
+		return( new PEPeerControlImpl( peer_id, adapter, diskManager, id ));
 	}
 }
