@@ -35,6 +35,8 @@ import org.gudy.azureus2.core3.logging.*;
 import org.gudy.azureus2.core3.peer.*;
 import org.gudy.azureus2.core3.util.*;
 
+import com.aelitis.azureus.core.peermanager.piecepicker.PiecePicker;
+
 
 public class PEPieceImpl
     implements PEPiece
@@ -287,6 +289,64 @@ public class PEPieceImpl
 		return cleared;
 	}
 	*/
+	
+		/*
+		 * Parg: replaced above commented out checking with one that verifies that the 
+		 * requests still exist. As piece-picker activity and peer disconnect logic is multi-threaded
+		 * and full of holes, this is a stop-gap measure to prevent a piece from being left with 
+		 * requests that no longer exist
+		 */
+	
+	public void 
+	checkRequests()
+	{
+        if ( getTimeSinceLastActivity() < 30*1000 ){
+        	
+            return;
+        }
+        
+		int cleared = 0;
+				
+		for (int i=0; i<nbBlocks; i++){
+		
+			if (!downloaded[i] &&!dmPiece.isWritten(i)){
+			
+				final String			requester = requested[i];
+				
+				if ( requester != null ){
+				
+					if ( !manager.requestExists( 
+							requester, 
+							getPieceNumber(),
+							i *DiskManager.BLOCK_SIZE, 
+							getBlockSize( i ))){
+
+                        clearRequested(i);
+                        
+						cleared++;
+					}
+				}
+			}
+		}
+		
+		if ( cleared > 0 ){
+					
+            if (Logger.isEnabled())
+                Logger.log(new LogEvent(dmPiece.getManager().getTorrent(), LOGID, LogEvent.LT_WARNING,
+                        "checkRequests(): piece #" +getPieceNumber()+" cleared " +cleared +" requests" ));
+		}else{
+			
+			if ( fully_requested && getNbUnrequested() > 0 ){
+
+		          if (Logger.isEnabled())
+		                Logger.log(new LogEvent(dmPiece.getManager().getTorrent(), LOGID, LogEvent.LT_WARNING,
+		                        "checkRequests(): piece #" +getPieceNumber()+" reset fully requested" ));
+
+				fully_requested = false;
+			}
+		}
+	}
+	
     
 	/** @return true if the piece has any blocks that are not;
 	 *  Downloaded, Requested, or Written
@@ -310,11 +370,39 @@ public class PEPieceImpl
 	 * TODO: this should return the largest span equal or smaller than nbWanted
 	 * OR, probably a different method should do that, so this one can support 'more sequential' picking
 	 */
-	public int[] getAndMarkBlocks(PEPeer peer, int nbWanted )
+	public int[] getAndMarkBlocks(PEPeer peer, int nbWanted, boolean enable_request_hints )
 	{
 		final String ip =peer.getIp();
         final boolean[] written =dmPiece.getWritten();
 		int blocksFound =0;
+		
+		if ( enable_request_hints ){
+			
+			int[]	request_hint = peer.getRequestHint();
+			
+			if ( request_hint != null && request_hint[0] == dmPiece.getPieceNumber()){
+				
+					// try to honour the hint first
+				
+				int	hint_block_start 	= request_hint[1] / DiskManager.BLOCK_SIZE;
+				int hint_block_count	=  ( request_hint[2] + DiskManager.BLOCK_SIZE-1 ) / DiskManager.BLOCK_SIZE;
+				
+				for (int i =hint_block_start; i < nbBlocks && i <hint_block_start + hint_block_count; i++)
+				{
+					while (blocksFound <nbWanted &&(i +blocksFound) <nbBlocks &&!downloaded[i +blocksFound]
+					    &&requested[i +blocksFound] ==null &&(written ==null ||!written[i]))
+					{
+						requested[i +blocksFound] =ip;
+						blocksFound++;
+					}
+					if (blocksFound >0){
+												
+						return new int[] {i, blocksFound};
+					}
+				}
+			}
+		}
+		
 		// scan piece to find first free block
 		for (int i =0; i <nbBlocks; i++)
 		{
@@ -678,24 +766,21 @@ public class PEPieceImpl
 		
 		dmPiece.setDownloadable();
 	}
-	
-	public boolean isChecking()
-	{
-		return dmPiece.isChecking();
-	}
 
 	public String
 	getString()
 	{
 		String	text  = "";
 		
+		PiecePicker pp = manager.getPiecePicker();
+
 		text	+= ( isRequestable()?"reqable,":"" );
 		text	+= "req=" + getNbRequests() + ",";
 		text	+= ( isRequested()?"reqstd,":"" );
 		text	+= ( isDownloaded()?"downed,":"" );
 		text	+= ( getReservedBy()!=null?"resrv,":"" );
 		text	+= "speed=" + getSpeed() + ",";
-		text	+= "pri=" + getResumePriority();
+		text	+= ( pp==null?("pri=" + getResumePriority()):pp.getPieceString(dmPiece.getPieceNumber()));
 		
 		if ( text.endsWith(",")){
 			text = text.substring(0,text.length()-1);
