@@ -26,19 +26,33 @@ package org.gudy.azureus2.core3.security.impl;
  *
  */
 
-import java.util.*;
-import java.net.*;
 import java.io.*;
+import java.net.Authenticator;
+import java.net.MalformedURLException;
+import java.net.PasswordAuthentication;
+import java.net.URL;
+import java.security.Key;
+import java.security.KeyStore;
+import java.security.Permission;
+import java.security.cert.Certificate;
+import java.security.cert.X509Certificate;
+import java.util.*;
+
 import javax.net.ssl.*;
 
-import java.security.*;
-import java.security.cert.*;
-import java.security.cert.Certificate;
-
 import org.gudy.azureus2.core3.config.COConfigurationManager;
-import org.gudy.azureus2.core3.logging.*;
-import org.gudy.azureus2.core3.security.*;
-import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.core3.logging.LogAlert;
+import org.gudy.azureus2.core3.logging.LogEvent;
+import org.gudy.azureus2.core3.logging.LogIDs;
+import org.gudy.azureus2.core3.logging.Logger;
+import org.gudy.azureus2.core3.security.SECertificateListener;
+import org.gudy.azureus2.core3.security.SEKeyDetails;
+import org.gudy.azureus2.core3.security.SEPasswordListener;
+import org.gudy.azureus2.core3.security.SESecurityManager;
+import org.gudy.azureus2.core3.util.AEMonitor;
+import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.FileUtil;
+import org.gudy.azureus2.core3.util.RandomUtils;
 
 import com.aelitis.azureus.core.util.CopyOnWriteList;
 
@@ -83,7 +97,19 @@ SESecurityManagerImpl
 	protected List				certificate_listeners 	= new ArrayList();
 	protected CopyOnWriteList	password_listeners 		= new CopyOnWriteList();
 	
+	
+	private static ThreadLocal		tls	= 
+		new ThreadLocal()
+		{
+			public Object
+			initialValue()
+			{
+				return( null );
+			}
+		};
+		
 	protected Map	password_handlers		= new HashMap();
+	protected Map	certificate_handlers	= new HashMap();
 	
 	protected boolean	 exit_vm_permitted	= false;
 	
@@ -96,9 +122,20 @@ SESecurityManagerImpl
 		return( singleton );
 	}
 	
+	private boolean initialized = false;
+	
+	private List	stoppable_threads = new ArrayList();
+	
 	public void
 	initialise()
 	{
+		synchronized (this)
+		{
+			if(initialized)
+				return;
+			initialized = true;
+		}
+		
 		// 	keytool -genkey -keystore %home%\.keystore -keypass changeit -storepass changeit -keyalg rsa -alias azureus
 
 		// 	keytool -export -keystore %home%\.keystore -keypass changeit -storepass changeit -alias azureus -file azureus.cer
@@ -212,6 +249,18 @@ SESecurityManagerImpl
 			System.setSecurityManager(
 				new SecurityManager()
 				{
+					public void checkAccept(String host, int port) {
+						// do nothing
+					}
+					
+					public void checkRead(String file) {
+						// do nothing
+					}
+					
+					public void checkWrite(String file) {
+						// do nothing
+					}
+					
 					public void 
 					checkExit(int status) 
 					{
@@ -231,6 +280,14 @@ SESecurityManagerImpl
 					{						
 						if ( perm instanceof RuntimePermission && perm.getName().equals( "stopThread")){
 							
+							synchronized( stoppable_threads ){
+								
+								if ( stoppable_threads.contains( Thread.currentThread())){
+									
+									return;
+								}
+							}
+							
 							throw( new SecurityException( "Thread.stop operation prohibited"));
 						}
 						
@@ -264,20 +321,44 @@ SESecurityManagerImpl
 		}
 	}
 	
+	public void
+	stopThread(
+		Thread	t )
+	{
+		synchronized( stoppable_threads ){
+			
+			stoppable_threads.add( Thread.currentThread());	
+		}
+		
+		try{
+			
+			t.stop();
+			
+		}finally{
+		
+			synchronized( stoppable_threads ){
+				
+				stoppable_threads.remove( Thread.currentThread());	
+			}
+		}
+	}
+	
 	public void
 	exitVM(
 		int		status )
 	{
 		try{
 			exit_vm_permitted	= true;
-			
+
 			try{
-      	System.exit( status );
-      }
-      catch( Throwable t ){}
-			
+				System.exit( status );
+				
+			}catch( Throwable t ){
+				
+			}
+
 		}finally{
-			
+
 			exit_vm_permitted	= false;
 		}
 	}
@@ -562,7 +643,7 @@ SESecurityManagerImpl
 		context.init(  	
 				keyManagerFactory.getKeyManagers(), 
 				null,
-				new java.security.SecureRandom());
+				RandomUtils.SECURE_RANDOM);
 		
 		SSLServerSocketFactory factory = context.getServerSocketFactory();
 		
@@ -627,6 +708,38 @@ SESecurityManagerImpl
 		return( SESecurityManagerBC.createSelfSignedCertificate( this, alias, cert_dn, strength ));
 	}
 	
+	public SSLSocketFactory
+	getSSLSocketFactory()
+	{
+		try{
+			this_mon.enter();
+		
+			KeyStore keystore = getTrustStore();
+						
+			TrustManagerFactory tmf = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
+			
+			tmf.init(keystore);
+			
+			SSLContext ctx = SSLContext.getInstance("SSL");
+			
+			ctx.init(null, tmf.getTrustManagers(), null);
+						
+			SSLSocketFactory	factory = ctx.getSocketFactory();
+	
+			return( factory );
+			
+		}catch( Throwable e ){
+				
+			Debug.printStackTrace( e );
+			
+			return((SSLSocketFactory)SSLSocketFactory.getDefault());
+			
+		}finally{
+			
+			this_mon.exit();
+		}		
+	}
+	
 	public SSLSocketFactory
 	installServerCertificates(
 		URL		https_url )
@@ -663,7 +776,7 @@ SESecurityManagerImpl
 				
 				SSLContext sc = SSLContext.getInstance("SSL");
 				
-				sc.init(null, trustAllCerts, new java.security.SecureRandom());
+				sc.init(null, trustAllCerts, RandomUtils.SECURE_RANDOM);
 				
 				SSLSocketFactory factory = sc.getSocketFactory();
 						
@@ -701,14 +814,60 @@ SESecurityManagerImpl
 					
 					resource = resource.substring(0,param_pos);
 				}
+			
+					// recalc - don't use port above as it may have been changed
+				
+				String url_s	= https_url.getProtocol() + "://" + https_url.getHost() + ":" + https_url.getPort() + "/";
+				
+				Object[]	handler = (Object[])certificate_handlers.get( url_s );
+				
+				String	alias = host.concat(":").concat(String.valueOf(port));
+				
+				KeyStore keystore = getTrustStore();
+
+				byte[]	new_encoded = x509_cert.getEncoded();
+				
+				int	count = 0;
+				
+				while( count < 256 ){
+					
+					String	test_alias = count==0?alias:(alias + "." + count );
+					
+					Certificate existing = keystore.getCertificate( test_alias );
+				
+					if ( existing != null ){
+					
+						if ( Arrays.equals( new_encoded, existing.getEncoded())){
+						
+							alias = test_alias;
+							
+							break;
+						}
+					}else{
+						
+						alias = test_alias;
+						
+						break;
+					}
+					
+					count++;
+				}
+
+				if ( handler != null ){
+					
+					if (((SECertificateListener)handler[0]).trustCertificate( resource, x509_cert )){
+						
+				
+						return( addCertToTrustStore( alias, cert, true ));
+					}
+				}
 				
 				for (int i=0;i<certificate_listeners.size();i++){
 					
 					if (((SECertificateListener)certificate_listeners.get(i)).trustCertificate( resource, x509_cert )){
 						
-						String	alias = host.concat(":").concat(String.valueOf(port));
 				
-						return( addCertToTrustStore( alias, cert ));
+						return( addCertToTrustStore( alias, cert, true ));
 					}
 				}
 				
@@ -739,6 +898,94 @@ SESecurityManagerImpl
 		}
 	}
 	
+	public SSLSocketFactory
+	installServerCertificates(
+		String		alias,
+		String		host,
+		int			port )
+	{
+		try{
+			this_mon.enter();
+					
+			SSLSocket	socket = null;
+			
+			try{
+		
+					// to get the server certs we have to use an "all trusting" trust manager
+				
+				TrustManager[] trustAllCerts = new TrustManager[]{
+							new X509TrustManager() {
+								public java.security.cert.X509Certificate[] getAcceptedIssuers() {
+									return null;
+								}
+								public void checkClientTrusted(
+										java.security.cert.X509Certificate[] certs, String authType) {
+								}
+								public void checkServerTrusted(
+										java.security.cert.X509Certificate[] certs, String authType) {
+								}
+							}
+						};
+				
+				SSLContext sc = SSLContext.getInstance("SSL");
+				
+				sc.init(null, trustAllCerts, RandomUtils.SECURE_RANDOM);
+				
+				SSLSocketFactory factory = sc.getSocketFactory();
+						
+				socket = (SSLSocket)factory.createSocket(host, port);
+			
+				socket.startHandshake();
+				
+				java.security.cert.Certificate[] serverCerts = socket.getSession().getPeerCertificates();
+				
+				if ( serverCerts.length == 0 ){
+									
+					return( null );
+				}
+				
+				java.security.cert.Certificate	cert = serverCerts[0];
+							
+				java.security.cert.X509Certificate x509_cert;
+				
+				if ( cert instanceof java.security.cert.X509Certificate ){
+					
+					x509_cert = (java.security.cert.X509Certificate)cert;
+					
+				}else{
+					
+					java.security.cert.CertificateFactory cf = java.security.cert.CertificateFactory.getInstance("X.509");
+					
+					x509_cert = (java.security.cert.X509Certificate)cf.generateCertificate(new ByteArrayInputStream(cert.getEncoded()));
+				}
+					
+				return( addCertToTrustStore( alias, cert, false ));
+								
+			}catch( Throwable e ){
+				
+				Debug.printStackTrace( e );
+				
+				return( null );
+				
+			}finally{
+				
+				if ( socket != null ){
+					
+					try{
+						socket.close();
+						
+					}catch( Throwable e ){
+						
+						Debug.printStackTrace( e );
+					}
+				}
+			}
+		}finally{
+			
+			this_mon.exit();
+		}
+	}
+	
 	protected void
 	addCertToKeyStore(
 		String								alias,
@@ -786,7 +1033,8 @@ SESecurityManagerImpl
 	protected SSLSocketFactory
 	addCertToTrustStore(
 		String							alias,
-		java.security.cert.Certificate	cert )
+		java.security.cert.Certificate	cert,
+		boolean							update_https_factory )
 	
 		throws Exception
 	{
@@ -832,7 +1080,10 @@ SESecurityManagerImpl
 						
 			SSLSocketFactory	factory = ctx.getSocketFactory();
 			
-			HttpsURLConnection.setDefaultSSLSocketFactory( factory );
+			if ( update_https_factory ){
+				
+				HttpsURLConnection.setDefaultSSLSocketFactory( factory );
+			}
 			
 			return( factory );
 		}finally{
@@ -846,6 +1097,13 @@ SESecurityManagerImpl
 		String		realm,
 		URL			tracker )
 	{
+		SEPasswordListener	thread_listener = (SEPasswordListener)tls.get();
+		
+		if ( thread_listener != null ){
+			
+			return( thread_listener.getAuthentication( realm, tracker));
+		}
+		
 		Object[]	handler = (Object[])password_handlers.get(tracker.toString());
 		
 		if ( handler != null ){
@@ -885,6 +1143,13 @@ SESecurityManagerImpl
 		URL			tracker,
 		boolean		success )
 	{
+		SEPasswordListener	thread_listener = (SEPasswordListener)tls.get();
+		
+		if ( thread_listener != null ){
+			
+			thread_listener.setAuthenticationOutcome(realm, tracker, success);
+		}
+		
 		Iterator	it = password_listeners.iterator();
 		
 		while( it.hasNext()){
@@ -926,6 +1191,13 @@ SESecurityManagerImpl
 	public void
 	clearPasswords()
 	{
+		SEPasswordListener	thread_listener = (SEPasswordListener)tls.get();
+		
+		if ( thread_listener != null ){
+			
+			thread_listener.clearPasswords();
+		}
+		
 		Iterator	it = password_listeners.iterator();
 		
 		while( it.hasNext()){
@@ -941,25 +1213,33 @@ SESecurityManagerImpl
 	}
 	
 	public void
-	addPasswordHandler(
-		URL						url,
+	setThreadPasswordHandler(
 		SEPasswordListener		l )
 	{
-		String url_s	= url.getProtocol() + "://" + url.getHost() + ":" + url.getPort() + "/";
-		
-		password_handlers.put( url_s, new Object[]{ l, url });
+		tls.set( l );
 	}
 	
 	public void
-	removePasswordHandler(
+	unsetThreadPasswordHandler()
+	{
+		tls.set( null );
+	}
+		
+	public void
+	setPasswordHandler(
 		URL						url,
 		SEPasswordListener		l )
 	{
-		Ignore.ignore( l );
-		
 		String url_s	= url.getProtocol() + "://" + url.getHost() + ":" + url.getPort() + "/";
 		
-		password_handlers.remove( url_s );
+		if ( l == null ){
+			
+			password_handlers.remove( url_s );
+			
+		}else{
+			
+			password_handlers.put( url_s, new Object[]{ l, url });
+		}
 	}
 	
 	public void
@@ -977,6 +1257,23 @@ SESecurityManagerImpl
 		}
 	}	
 	
+	public void
+	setCertificateHandler(
+		URL						url,
+		SECertificateListener	l )
+	{
+		String url_s	= url.getProtocol() + "://" + url.getHost() + ":" + url.getPort() + "/";
+		
+		if ( l == null ){
+		
+			certificate_handlers.remove( url_s );
+			
+		}else{
+			
+			certificate_handlers.put( url_s, new Object[]{ l, url });
+		}
+	}
+	
 	public void
 	removeCertificateListener(
 		SECertificateListener	l )
