@@ -44,7 +44,9 @@ TOTorrent
 		 */
 	
 	public static final String	AZUREUS_PRIVATE_PROPERTIES		= "azureus_private_properties";
-	
+
+	public static final String ENCODING_ACTUALLY_UTF8_KEYS = "utf8 keys";
+
 	/**
 	 * Get the name of the torrent
 	 * @return
@@ -89,6 +91,10 @@ TOTorrent
 	public byte[]
 	getCreatedBy();
 	
+	public void
+	setCreatedBy(
+		byte[]		cb );
+	
 	public boolean
 	isCreated();
 	
