@@ -85,4 +85,32 @@ public interface TorrentDownloader {
      * Returns the URL downloaded from.
      */
     public String getURL();
+		/**
+		 * @return
+		 */
+		int getLastReadCount();
+		/**
+		 * @return
+		 */
+		byte[] getLastReadBytes();
+		/**
+		 * @return
+		 */
+		boolean getDeleteFileOnCancel();
+		/**
+		 * @param deleteFileOnCancel
+		 */
+		void setDeleteFileOnCancel(boolean deleteFileOnCancel);
+		/**
+		 * @return
+		 *
+		 * @since 4.0.0.5
+		 */
+		boolean isIgnoreReponseCode();
+		/**
+		 * @param ignoreReponseCode
+		 *
+		 * @since 4.0.0.5
+		 */
+		void setIgnoreReponseCode(boolean ignoreReponseCode);
 }
