@@ -21,39 +21,42 @@
 
 package org.gudy.azureus2.core3.tracker.client.impl.bt;
 
-import java.io.*;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.UnsupportedEncodingException;
 import java.net.*;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Map;
-import java.util.HashMap;
-import java.util.Random;
-import java.util.Properties;
-import java.util.StringTokenizer;
+import java.util.*;
+import java.util.zip.GZIPInputStream;
 
-import javax.net.ssl.*;
+import javax.net.ssl.HostnameVerifier;
+import javax.net.ssl.HttpsURLConnection;
+import javax.net.ssl.SSLException;
+import javax.net.ssl.SSLSession;
 
-import java.util.zip.*;
-
-import org.gudy.azureus2.core3.logging.*;
-import org.gudy.azureus2.core3.config.*;
-import org.gudy.azureus2.core3.torrent.*;
-import org.gudy.azureus2.core3.security.*;
+import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
+import org.gudy.azureus2.core3.internat.MessageText;
+import org.gudy.azureus2.core3.logging.LogAlert;
+import org.gudy.azureus2.core3.logging.LogEvent;
+import org.gudy.azureus2.core3.logging.LogIDs;
+import org.gudy.azureus2.core3.logging.Logger;
+import org.gudy.azureus2.core3.peer.PEPeerSource;
+import org.gudy.azureus2.core3.security.SESecurityManager;
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+import org.gudy.azureus2.core3.torrent.TOTorrentAnnounceURLSet;
+import org.gudy.azureus2.core3.torrent.TOTorrentException;
 import org.gudy.azureus2.core3.tracker.client.*;
 import org.gudy.azureus2.core3.tracker.client.impl.*;
-import org.gudy.azureus2.core3.util.*;
-import org.gudy.azureus2.core3.internat.*;
-//import org.gudy.azureus2.core3.peer.util.*;
-import org.gudy.azureus2.core3.peer.*;
-
-import org.gudy.azureus2.core3.tracker.protocol.*;
+import org.gudy.azureus2.core3.tracker.protocol.PRHelpers;
 import org.gudy.azureus2.core3.tracker.protocol.udp.*;
 import org.gudy.azureus2.core3.tracker.util.TRTrackerUtils;
-
-import org.gudy.azureus2.plugins.clientid.*;
-import org.gudy.azureus2.plugins.download.*;
+import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.core3.util.Timer;
+import org.gudy.azureus2.plugins.clientid.ClientIDException;
+import org.gudy.azureus2.plugins.clientid.ClientIDGenerator;
+import org.gudy.azureus2.plugins.download.DownloadAnnounceResult;
+import org.gudy.azureus2.plugins.download.DownloadAnnounceResultPeer;
 import org.gudy.azureus2.pluginsimpl.local.clientid.ClientIDManagerImpl;
 
 import com.aelitis.azureus.core.dht.netcoords.DHTNetworkPosition;
@@ -62,11 +65,7 @@ import com.aelitis.azureus.core.networkmanager.NetworkManager;
 import com.aelitis.azureus.core.networkmanager.admin.NetworkAdmin;
 import com.aelitis.azureus.core.networkmanager.impl.udp.UDPNetworkManager;
 import com.aelitis.azureus.core.peermanager.utils.PeerClassifier;
-import com.aelitis.net.udp.uc.PRUDPPacket;
-import com.aelitis.net.udp.uc.PRUDPPacketHandler;
-import com.aelitis.net.udp.uc.PRUDPPacketHandlerException;
-import com.aelitis.net.udp.uc.PRUDPPacketHandlerFactory;
-import com.aelitis.net.udp.uc.PRUDPPacketRequest;
+import com.aelitis.net.udp.uc.*;
 
 
 /**
@@ -78,9 +77,9 @@ import com.aelitis.net.udp.uc.PRUDPPacketRequest;
  */
 public class 
 TRTrackerBTAnnouncerImpl
-	extends TRTrackerAnnouncerImpl
+	implements TRTrackerAnnouncer
 {
-	
+	public final static LogIDs LOGID = LogIDs.TRACKER;
 		
 	private static final int OVERRIDE_PERIOD			= 10*1000;
 	 
@@ -115,12 +114,15 @@ TRTrackerBTAnnouncerImpl
 	private static Map			tracker_report_map	= new HashMap();
 	
     
-	private TOTorrent				torrent;
+	private TOTorrent					torrent;
+	private TOTorrentAnnounceURLSet[]	announce_urls;
+	
+	private TRTrackerAnnouncerImpl.Helper	helper;
 	
 	private TimerEvent				current_timer_event;
 	private TimerEventPerformer		timer_event_action;
 	
-	protected int				tracker_state 			= TS_INITIALISED;
+	protected int				tracker_state 			= TRTrackerAnnouncer.TS_INITIALISED;
 	private String				tracker_status_str		= "";
 	private TRTrackerAnnouncerResponseImpl	last_response			= null;
 	private long				last_update_time_secs;
@@ -204,17 +206,19 @@ TRTrackerBTAnnouncerImpl
 	
   public 
   TRTrackerBTAnnouncerImpl(
-   	TOTorrent		_torrent,
-	String[]		_peer_networks,
-	boolean			_manual ) 
+   	TOTorrent						_torrent,
+   	TOTorrentAnnounceURLSet[]		_announce_urls,
+	String[]						_peer_networks,
+	boolean							_manual,
+	TRTrackerAnnouncerImpl.Helper	_helper )
   	
   	throws TRTrackerAnnouncerException
   {
-	super( _torrent );
-	 
 	torrent			= _torrent;
+	announce_urls	= _announce_urls;
   	peer_networks	= _peer_networks;
   	manual_control	= _manual;
+  	helper			= _helper;
   	
 		//Get the Tracker url
 		
@@ -292,7 +296,7 @@ TRTrackerBTAnnouncerImpl
 						
 					current_time_to_wait_secs	= secs_to_wait;
 							
-					if ( tracker_state == TS_STOPPED ){
+					if ( tracker_state == TRTrackerAnnouncer.TS_STOPPED ){
 						
 						// System.out.println( "\tperform: stopped so no more events");
 						
@@ -417,7 +421,7 @@ TRTrackerBTAnnouncerImpl
 				if (Logger.isEnabled())
 					Logger.log(new LogEvent(torrent, LOGID,
 							"MIN INTERVAL CALC: override, perc = 0"));
-      	return REFRESH_MINIMUM_SECS;
+      	return TRTrackerAnnouncer.REFRESH_MINIMUM_SECS;
       }
 
       if (rd_override_percentage != 100) {
@@ -428,9 +432,9 @@ TRTrackerBTAnnouncerImpl
     		}
       }
 									
-      if ( secs_to_wait < REFRESH_MINIMUM_SECS ){
+      if ( secs_to_wait < TRTrackerAnnouncer.REFRESH_MINIMUM_SECS ){
 	  			
-        secs_to_wait = REFRESH_MINIMUM_SECS;
+        secs_to_wait = TRTrackerAnnouncer.REFRESH_MINIMUM_SECS;
       }
       
       //use 'min interval' for calculation
@@ -566,7 +570,7 @@ TRTrackerBTAnnouncerImpl
         
         if ( now < last_update_time_secs )  force = true;  //time went backwards
 
-        long	effective_min = min_interval_override>0?min_interval_override:REFRESH_MINIMUM_SECS;
+        long	effective_min = min_interval_override>0?min_interval_override:TRTrackerAnnouncer.REFRESH_MINIMUM_SECS;
         
 		if ( manual_control || force || ( now - last_update_time_secs >= effective_min )){
 			
@@ -664,29 +668,29 @@ TRTrackerBTAnnouncerImpl
 					// if manual control then we assume that a stop request is required, even if we
 					// are in an init state. needed for explicit stop based on URL
 				
-				if ( tracker_state == TS_INITIALISED && !manual_control ){
+				if ( tracker_state == TRTrackerAnnouncer.TS_INITIALISED && !manual_control ){
 					
 						// never started
 					
-					tracker_state = TS_STOPPED;
+					tracker_state = TRTrackerAnnouncer.TS_STOPPED;
 					
-				}else if ( tracker_state != TS_STOPPED ){
+				}else if ( tracker_state != TRTrackerAnnouncer.TS_STOPPED ){
 			
 					response = stopSupport();
 					
 					if ( response.getStatus() == TRTrackerAnnouncerResponse.ST_ONLINE ){
 												
-						tracker_state = TS_STOPPED;
+						tracker_state = TRTrackerAnnouncer.TS_STOPPED;
 						
 					}else{
 						
 							// just have one go at sending a stop event as we don't want to sit here
 							// forever trying to send stop to a stuffed tracker
 							
-						tracker_state = TS_STOPPED;
+						tracker_state = TRTrackerAnnouncer.TS_STOPPED;
 					}
 				}	
-			}else if ( tracker_state == TS_INITIALISED ){
+			}else if ( tracker_state == TRTrackerAnnouncer.TS_INITIALISED ){
 							
 					// always go through the "start" phase, even if we're already complete
 					// as some trackers insist on the initial "start"
@@ -695,7 +699,7 @@ TRTrackerBTAnnouncerImpl
 					
 				if ( response.getStatus() == TRTrackerAnnouncerResponse.ST_ONLINE ){
 						
-					tracker_state = TS_DOWNLOADING;
+					tracker_state = TRTrackerAnnouncer.TS_DOWNLOADING;
 				}
 			}else if ( completed ){
 				
@@ -712,10 +716,10 @@ TRTrackerBTAnnouncerImpl
 						
 						complete_reported	= true;
 				
-						tracker_state = TS_COMPLETED;
+						tracker_state = TRTrackerAnnouncer.TS_COMPLETED;
 					}
 				}else{
-					tracker_state = TS_COMPLETED;
+					tracker_state = TRTrackerAnnouncer.TS_COMPLETED;
 					
 					response = updateSupport();
 				}
@@ -742,7 +746,7 @@ TRTrackerBTAnnouncerImpl
 						// will fail peers that don't start with a "started" event after a 
 						// tracker restart
 					
-					tracker_state	= TS_INITIALISED;
+					tracker_state	= TRTrackerAnnouncer.TS_INITIALISED;
 					
 				}else{
 	    	       	    
@@ -766,7 +770,7 @@ TRTrackerBTAnnouncerImpl
 				
 				last_response = response;
 				
-				listeners.dispatch( LDT_TRACKER_RESPONSE, response );
+				helper.informResponse( response );
 				
 				return( response.getTimeToWait());
 			}
@@ -1054,7 +1058,7 @@ TRTrackerBTAnnouncerImpl
 	  int	num_want = calculateNumWant() * 4;
 
 
-      TRTrackerAnnouncerResponsePeer[]	cached_peers = getPeersFromCache(num_want);      
+      TRTrackerAnnouncerResponsePeer[]	cached_peers = helper.getPeersFromCache(num_want);      
       
       if ( cached_peers.length > 0 ){
 
@@ -1074,6 +1078,8 @@ TRTrackerBTAnnouncerImpl
   		throws Exception
 	{
    			// set context in case authentication dialog is required
+ 		
+ 		boolean errorLevel = true;
     	
  		try{
 	    	TorrentUtils.setTLSTorrentHash( torrent_hash );
@@ -1209,6 +1215,9 @@ TRTrackerBTAnnouncerImpl
 					}
 				}catch( IOException e ){
 					
+					if(e instanceof UnknownHostException)
+						errorLevel = false;
+					
 		     		if ( i == 0 && protocol.toLowerCase().startsWith( "http" )){
 		      			
 		      			URL retry_url = UrlUtils.getIPV4Fallback( reqUrl );
@@ -1233,10 +1242,11 @@ TRTrackerBTAnnouncerImpl
 				if ( failure_reason != null && failure_reason.indexOf("401" ) != -1 ){
 						
 					failure_reason = "Tracker authentication failed";
+					errorLevel = false;
 				}
 			
 				if (Logger.isEnabled())
-					Logger.log(new LogEvent(torrent, LOGID, LogEvent.LT_ERROR,
+					Logger.log(new LogEvent(torrent, LOGID, errorLevel ? LogEvent.LT_ERROR : LogEvent.LT_WARNING,
 							"Exception while processing the Tracker Request for " + reqUrl + ": "
 									+ failure_reason));
 				
@@ -2083,13 +2093,13 @@ TRTrackerBTAnnouncerImpl
 	}
 	
 	public URL 
-	getTrackerUrl() 
+	getTrackerURL() 
 	{
 		return( lastUsedUrl );
 	} 
   
 	public void 
-	setTrackerUrl(
+	setTrackerURL(
 		URL new_url ) 
 	{
 		try{
@@ -2111,6 +2121,13 @@ TRTrackerBTAnnouncerImpl
 		}
 	}
   
+	public void
+	setTrackerURLs(
+		TOTorrentAnnounceURLSet[]		_set )
+	{
+		announce_urls = _set;
+	}
+	
 	public void
 	resetTrackerUrl(
 		boolean		shuffle )
@@ -2159,10 +2176,8 @@ TRTrackerBTAnnouncerImpl
 			trackerUrlLists = new ArrayList(1);
 	  
 				//This entry is present on multi-tracker torrents
-	  
-			TOTorrentAnnounceURLSet[]	announce_sets = torrent.getAnnounceURLGroup().getAnnounceURLSets();
-	       
-			if ( announce_sets.length == 0 ){
+	  	       
+			if ( announce_urls.length == 0 ){
 	  	
 					//If not present, we use the default specification
 					
@@ -2180,11 +2195,11 @@ TRTrackerBTAnnouncerImpl
 	  			
 					//Ok we have a multi-tracker torrent
 				
-				for(int i = 0 ; i < announce_sets.length ; i++){
+				for(int i = 0 ; i < announce_urls.length ; i++){
 					
 				  	//Each list contains a list of urls
 				  
-					URL[]	urls = announce_sets[i].getAnnounceURLs();
+					URL[]	urls = announce_urls[i].getAnnounceURLs();
 					
 				 	List random_urls = new ArrayList();
 				 	
@@ -2382,6 +2397,12 @@ TRTrackerBTAnnouncerImpl
 								}
 								min_interval = 0;
 							}
+						} else {
+							// tracker owners complain we announce too much but then never
+							// implement "min interval".  So take it into our own hands
+							// and enforce a min_interval of interval when there is no
+							// "min interval"
+							min_interval = time_to_wait > 30 ? time_to_wait - 10 : time_to_wait;
 						}
 						
 						if(userMinInterval != 0)
@@ -2675,7 +2696,7 @@ TRTrackerBTAnnouncerImpl
 					    		
 					    		int		tcp_port 	= ((tcp_bytes[0]&0xff) << 8 ) + (tcp_bytes[1]&0xff );
 	                
-					    		byte[]	peer_peer_id = getAnonymousPeerId( ip, tcp_port );
+					    		byte[]	peer_peer_id = TRTrackerAnnouncerImpl.getAnonymousPeerId( ip, tcp_port );
 	
 					    		int		udp_port 	= 0;
 					    		
@@ -2835,7 +2856,7 @@ TRTrackerBTAnnouncerImpl
 	                
 									// Debug.out(ip + ": tracker did not give peerID in reply");
 
-									peer_peer_id = getAnonymousPeerId( ip, peer_port );
+									peer_peer_id = TRTrackerAnnouncerImpl.getAnonymousPeerId( ip, peer_port );
 									
 									// System.out.println("generated peer id" + new String(peerId) + "/" + ByteFormatter.nicePrint( peerId, true ));
 								}else{
@@ -2926,7 +2947,7 @@ TRTrackerBTAnnouncerImpl
 				    			continue;
 				    		}
                 
-				    		byte[]	peer_peer_id = getAnonymousPeerId( ip, tcp_port );
+				    		byte[]	peer_peer_id = TRTrackerAnnouncerImpl.getAnonymousPeerId( ip, tcp_port );
 							
 				    		short 	protocol;
 				    		int		udp_port;
@@ -3023,7 +3044,7 @@ TRTrackerBTAnnouncerImpl
 								continue;
 							}
 							
-							byte[] peer_peer_id = getAnonymousPeerId( ip, tcp_port );
+							byte[] peer_peer_id = TRTrackerAnnouncerImpl.getAnonymousPeerId( ip, tcp_port );
 							
 							short protocol = DownloadAnnounceResultPeer.PROTOCOL_NORMAL;
 							
@@ -3043,7 +3064,7 @@ TRTrackerBTAnnouncerImpl
 					
 					valid_meta_peers.toArray(peers);
 					
-					addToTrackerCache( peers);
+					helper.addToTrackerCache( peers);
 					
 					TRTrackerAnnouncerResponseImpl resp = new TRTrackerAnnouncerResponseImpl( url, torrent_hash, TRTrackerAnnouncerResponse.ST_ONLINE, time_to_wait, peers );
           
@@ -3103,7 +3124,7 @@ TRTrackerBTAnnouncerImpl
 							TRTrackerScraper scraper = TRTrackerScraperFactory.getSingleton();
 
 							if (scraper != null) {
-								TRTrackerScraperResponse scrapeResponse = scraper.scrape(this);
+								TRTrackerScraperResponse scrapeResponse = scraper.scrape( torrent, getTrackerURL());
 								if (scrapeResponse != null) {
 									long lNextScrapeTime = scrapeResponse.getNextScrapeStartTime();
 									long lNewNextScrapeTime = TRTrackerScraperResponseImpl.calcScrapeIntervalSecs(
@@ -3165,14 +3186,13 @@ TRTrackerBTAnnouncerImpl
 		URL		new_url,
 		boolean	explicit  )
 	{
-		listeners.dispatch(	LDT_URL_CHANGED,
-							new Object[]{old_url, new_url, new Boolean(explicit)});
+		helper.informURLChange( old_url, new_url, explicit );
 	}
 	
 	protected void
 	informURLRefresh()
 	{
-		listeners.dispatch( LDT_URL_REFRESH, null );		
+		helper.informURLRefresh();	
 	}
 	
 	public TRTrackerAnnouncerResponse
@@ -3196,9 +3216,7 @@ TRTrackerBTAnnouncerImpl
 	destroy()
 	{       
 		destroyed	= true;
-		
-		TRTrackerAnnouncerFactoryImpl.destroy( this );
-		
+				
 		try{
 			this_mon.enter();
 			
@@ -3357,7 +3375,7 @@ TRTrackerBTAnnouncerImpl
 
 			l_peers.toArray( peers );
 			
-			addToTrackerCache( peers);
+			helper.addToTrackerCache( peers);
 		
 			if ( ps_enabled || peers.length > 0 || ext_peers.length == 0 ){
 				
@@ -3388,7 +3406,41 @@ TRTrackerBTAnnouncerImpl
 			tracker_status_str	= status + " (" + result.getURL() + ")";
 		}
 		
-		listeners.dispatch( LDT_TRACKER_RESPONSE, response );
+		helper.informResponse( response );
+	}
+	
+	public void 
+	addListener(
+		TRTrackerAnnouncerListener l )
+	{
+		helper.addListener( l );
+	}
+	
+	public void 
+	removeListener(
+		TRTrackerAnnouncerListener l )
+	{
+		helper.removeListener( l );
+	}
+	
+	public void 
+	setTrackerResponseCache(
+		Map map	)
+	{
+		helper.setTrackerResponseCache( map );
+	}
+	
+	public void 
+	removeFromTrackerResponseCache(
+		String ip, int tcpPort) 
+	{
+		helper.removeFromTrackerResponseCache( ip, tcpPort );
+	}
+	
+	public Map 
+	getTrackerResponseCache() 
+	{
+		return( helper.getTrackerResponseCache());
 	}
 	
 	public void 
