@@ -21,24 +21,23 @@
 package org.gudy.azureus2.core3.tracker.client.impl.bt;
 
 import java.io.ByteArrayOutputStream;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.FileNotFoundException;
 import java.net.*;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
+import java.util.*;
 import java.util.zip.GZIPInputStream;
 
-import javax.net.ssl.*;
+import javax.net.ssl.HostnameVerifier;
+import javax.net.ssl.HttpsURLConnection;
+import javax.net.ssl.SSLSession;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.internat.MessageText;
-import org.gudy.azureus2.core3.logging.*;
+import org.gudy.azureus2.core3.logging.LogEvent;
+import org.gudy.azureus2.core3.logging.LogIDs;
+import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.security.SESecurityManager;
 import org.gudy.azureus2.core3.tracker.client.TRTrackerAnnouncer;
 import org.gudy.azureus2.core3.tracker.client.TRTrackerScraperClientResolver;
@@ -458,9 +457,6 @@ public class TrackerStatus {
 				if (one_of_the_hashes == null)
 					return;
 
-				// set context in case authentication dialog is required
-				TorrentUtils.setTLSTorrentHash(one_of_the_hashes);
-
 				String	request = scrapeURL + info_hash;
 				
 				if ( az_tracker ){
@@ -488,38 +484,51 @@ public class TrackerStatus {
 				
 		  		URL udpScrapeURL = null;
 		  		
+		  		boolean auto_probe = false;
+		  		
 		  		if(protocol.equalsIgnoreCase("udp") && udpScrapeEnabled)
 		  			udpScrapeURL = reqUrl;
-		  		else if(protocol.equalsIgnoreCase("http") && !az_tracker && scrapeCount % autoUDPscrapeEvery == 0 && udpScrapeEnabled)
+		  		else if(protocol.equalsIgnoreCase("http") && !az_tracker && scrapeCount % autoUDPscrapeEvery == 0 && udpScrapeEnabled) {
 		  			udpScrapeURL = new URL(reqUrl.toString().replaceFirst("^http", "udp"));
-		  			
-		  		
-		  		if ( udpScrapeURL != null){
-		  			
-		  			boolean success = scrapeUDP( reqUrl, message, hashesForUDP );
-		  			
-		  			if((!success || message.size() == 0) && !protocol.equalsIgnoreCase("udp"))
-		  			{ // automatic UDP probe failed, use HTTP again
-		  				udpScrapeURL = null;
-		  				message.reset();
-		  				if(autoUDPscrapeEvery < 16)
-		  					autoUDPscrapeEvery <<= 1;
-						if (Logger.isEnabled())
-							Logger.log(new LogEvent(LOGID, LogEvent.LT_INFORMATION, "redirection of http scrape ["+scrapeURL+"] to udp failed, will retry in "+autoUDPscrapeEvery+" scrapes"));
-		  			} else if(success && !protocol.equalsIgnoreCase("udp"))
-		  			{
-						if (Logger.isEnabled())
-							Logger.log(new LogEvent(LOGID, LogEvent.LT_INFORMATION, "redirection of http scrape ["+scrapeURL+"] to udp successful"));
-		  				autoUDPscrapeEvery = 1;
-		  				TRTrackerUtils.setUDPProbeResult( reqUrl, true );
-		  			}
-		  				
+		  			auto_probe = true;
 		  		}
+		  			
 		  		
-		  		scrapeCount++;
-		  		
-		  		if(udpScrapeURL == null)
-		  			redirect_url = scrapeHTTP(reqUrl, message);
+		  		try{
+		  				// set context in case authentication dialog is required
+		  			
+					TorrentUtils.setTLSTorrentHash(one_of_the_hashes);
+
+			  		if ( udpScrapeURL != null){
+			  			
+			  			boolean success = scrapeUDP( reqUrl, message, hashesForUDP, !auto_probe );
+			  			
+			  			if((!success || message.size() == 0) && !protocol.equalsIgnoreCase("udp"))
+			  			{ // automatic UDP probe failed, use HTTP again
+			  				udpScrapeURL = null;
+			  				message.reset();
+			  				if(autoUDPscrapeEvery < 16)
+			  					autoUDPscrapeEvery <<= 1;
+							if (Logger.isEnabled())
+								Logger.log(new LogEvent(LOGID, LogEvent.LT_INFORMATION, "redirection of http scrape ["+scrapeURL+"] to udp failed, will retry in "+autoUDPscrapeEvery+" scrapes"));
+			  			} else if(success && !protocol.equalsIgnoreCase("udp"))
+			  			{
+							if (Logger.isEnabled())
+								Logger.log(new LogEvent(LOGID, LogEvent.LT_INFORMATION, "redirection of http scrape ["+scrapeURL+"] to udp successful"));
+			  				autoUDPscrapeEvery = 1;
+			  				TRTrackerUtils.setUDPProbeResult( reqUrl, true );
+			  			}
+			  				
+			  		}
+			  		
+			  		scrapeCount++;
+			  		
+			  		if(udpScrapeURL == null)
+			  			redirect_url = scrapeHTTP(reqUrl, message);
+				}finally{
+					
+					TorrentUtils.setTLSTorrentHash( null );
+				}
 				
 				scrape_reply = message.toByteArray();
 				
@@ -853,6 +862,8 @@ public class TrackerStatus {
 				setAllError(e);
 			} catch (UnknownHostException e) {
 				setAllError(e);
+			} catch (PRUDPPacketHandlerException e) {
+				setAllError(e);
 			} catch (BEncodingException e) {
 				setAllError(e);
 			} catch (Exception e) {
@@ -936,8 +947,10 @@ public class TrackerStatus {
 		// Error will apply to ALL hashes, so set all
 		Object[] values;
 		try {
-			values = hashes.values().toArray();
 			hashes_mon.enter();
+			
+			values = hashes.values().toArray();
+
 		} finally {
 			hashes_mon.exit();
 		}
@@ -1134,7 +1147,7 @@ public class TrackerStatus {
 	  return( redirect_url );
   }
   
-  protected boolean scrapeUDP(URL reqUrl, ByteArrayOutputStream message, List hashes) throws Exception {
+  protected boolean scrapeUDP(URL reqUrl, ByteArrayOutputStream message, List hashes, boolean do_auth_test) throws Exception {
 		Map rootMap = new HashMap();
 		Map files = new ByteEncodedKeyHashMap();
 		rootMap.put("files", files);
@@ -1178,8 +1191,7 @@ public class TrackerStatus {
 	boolean					auth_ok	= false;
 	
 	try{
-		if ( reqUrl.getQuery().toLowerCase().indexOf("auth") != -1 ){
-					
+		if (do_auth_test && UrlUtils.queryHasParameter(reqUrl.getQuery(), "auth", false)) {
 			auth = SESecurityManager.getPasswordAuthentication( "UDP Tracker", reqUrl );
 		}		
 	
