@@ -27,6 +27,10 @@ package org.gudy.azureus2.core3.tracker.host;
  */
 
 import java.io.*;
+import java.net.InetSocketAddress;
+import java.net.URL;
+
+import org.gudy.azureus2.core3.util.AsyncController;
 
 public interface 
 TRHostListener 
@@ -45,11 +49,14 @@ TRHostListener
 	
 	public boolean
 	handleExternalRequest(
-		String			client_address,
-		String			url,
-		String			header,
-		InputStream		is,
-		OutputStream	os )
+		InetSocketAddress	client_address,
+		String				user,
+		String				url,
+		URL					absolute_url,
+		String				header,
+		InputStream			is,
+		OutputStream		os,
+		AsyncController		async )
 	
 		throws IOException;
 }
