@@ -50,7 +50,10 @@ TRHostConfigImpl
 	private volatile boolean		loading	= false;
 	private volatile boolean		save_outstanding	= false;
 	
-	private Map			saved_stats		= new HashMap();
+	private Map			saved_stats				= new HashMap();
+	private List		saved_stats_to_delete	= new ArrayList();
+	
+	private boolean		config_exists = true;
 	
 	private AEMonitor this_mon 	= new AEMonitor( "TRHostConfig" );
 
@@ -124,8 +127,8 @@ TRHostConfigImpl
 								torrent = TorrentUtils.readFromFile( file, true, true );
 								
 							}catch( Throwable e ){
-								
-								Debug.printStackTrace( e );
+								// torrent might have been deleted, don't barf out errors
+								// Debug.printStackTrace( e );
 							}
 						}
 					}
@@ -143,7 +146,7 @@ TRHostConfigImpl
 				 	
 				 	}else{
 						
-						if ( COConfigurationManager.getBooleanParameter( "Tracker Public Enable", false )){
+						if ( COConfigurationManager.getBooleanParameter( "Tracker Public Enable")){
 			 		
 				 			host.addExternalTorrent( hash, state, date_added );
 						}
@@ -159,6 +162,7 @@ TRHostConfigImpl
 	   	}catch (Exception e) {
 		 
 	   		Debug.printStackTrace( e );
+	   		
 	   	}finally{
 		 	
 	   		loading	= false;
@@ -177,10 +181,15 @@ TRHostConfigImpl
 			Map	t_map = (Map)saved_stats.get( hash );
 			
 			if ( t_map != null ){
-				
-				saved_stats.remove( hash );
-				
+								
 				recoverStats( host_torrent, t_map );
+				
+					// can't delete here due to sync problems - tag for later
+				
+				synchronized( saved_stats_to_delete ){
+					
+					saved_stats_to_delete.add( hash );
+				}
 			}
 			
 		}catch( Throwable e ){
@@ -241,6 +250,23 @@ TRHostConfigImpl
 			return;
 		}
 			
+		if ( saved_stats_to_delete.size() > 0 ){
+			
+			synchronized( saved_stats_to_delete ){
+		
+				Map	saved_stats_copy = new HashMap( saved_stats );
+				
+				for (int i=0;i<saved_stats_to_delete.size();i++){
+					
+					saved_stats_copy.remove( saved_stats_to_delete.get(i));
+				}
+								
+				saved_stats_to_delete.clear();
+				
+				saved_stats = saved_stats_copy;
+			}
+		}
+		
 		if ( immediate || save_outstanding ){
 						
 			save_outstanding	= false;
@@ -403,9 +429,22 @@ TRHostConfigImpl
 			   	try{
 			   		save_lock_mon.enter();
 			   		
-			   		FileUtil.writeResilientConfigFile( "tracker.config", map );
-				   	
-					if ( 	COConfigurationManager.getBooleanParameter( "Tracker Log Enable", false ) &&
+			   		if ( torrents.length == 0 ){
+			   			
+			   			if ( config_exists ){
+			   		
+			   				FileUtil.deleteResilientConfigFile( "tracker.config" );
+			   				
+			   				config_exists = false;
+			   			}
+			   		}else{
+			   		
+			   			config_exists = true;
+			   			
+			   			FileUtil.writeResilientConfigFile( "tracker.config", map );
+			   		}
+			   		
+					if ( 	COConfigurationManager.getBooleanParameter( "Tracker Log Enable") &&
 							stats_entries.size() > 0 ){
 				   		
 					   	try{
