@@ -29,6 +29,7 @@ package org.gudy.azureus2.core3.tracker.host.impl;
 import java.util.*;
 
 import org.gudy.azureus2.core3.tracker.host.*;
+import org.gudy.azureus2.core3.tracker.server.TRTrackerServerTorrent;
 import org.gudy.azureus2.core3.tracker.client.*;
 import org.gudy.azureus2.core3.torrent.*;
 import org.gudy.azureus2.core3.util.AEMonitor;
@@ -151,6 +152,12 @@ TRHostTorrentPublishImpl
 		return( torrent );
 	}
 
+	public TRTrackerServerTorrent 
+	getTrackerTorrent() 
+	{
+		return( null );
+	}
+	
 	public int
 	getPort()
 	{
