@@ -21,12 +21,15 @@
  
 package org.gudy.azureus2.core3.tracker.server;
 
+import java.util.Map;
+
 /**
  * @author parg
  */
 
 public interface 
 TRTrackerServerPeer 
+	extends TRTrackerServerPeerBase
 {
 	public static final byte	NAT_CHECK_UNKNOWN				= 0;
 	public static final byte	NAT_CHECK_DISABLED				= 1;
@@ -49,15 +52,9 @@ TRTrackerServerPeer
 	public long
 	getAmountLeft();
 	
-	public String
-	getIP();
-	
 	public String
 	getIPRaw();
 	
-	public int
-	getTCPPort();
-	
 	public byte[]
 	getPeerID();
 	
@@ -68,4 +65,23 @@ TRTrackerServerPeer
 	
 	public byte
 	getNATStatus();
+	
+	public boolean
+	isBiased();
+	
+	public void
+	setBiased(
+		boolean	bias );
+	
+	public void
+	setUserData(
+		Object		key,
+		Object		data );
+	
+	public Object
+	getUserData(
+		Object		key );
+	
+	public Map
+	export();
 }
