@@ -31,9 +31,11 @@ import java.util.Map;
 public interface 
 TRTrackerServerRequest
 {	
+	public static final int		RT_UNKNOWN		= -1;
 	public static final int		RT_ANNOUNCE		= 1;
 	public static final int		RT_SCRAPE		= 2;
 	public static final int		RT_FULL_SCRAPE	= 3;
+	public static final int		RT_QUERY		= 4;
 	
 	public int
 	getType();
@@ -44,6 +46,9 @@ TRTrackerServerRequest
 	public TRTrackerServerTorrent
 	getTorrent();
 	
+	public String
+	getRequest();
+	
 	public Map
 	getResponse();
 }
