@@ -37,4 +37,16 @@ TRTrackerServerStats
 	
 	public long
 	getBytesOut();
+	
+	public long
+	getAnnounceCount();
+	
+	public long
+	getScrapeCount();
+	
+	public long
+	getAnnounceTime();
+	
+	public long
+	getScrapeTime();
 }
