@@ -28,6 +28,7 @@ package org.gudy.azureus2.core3.tracker.server.impl;
 
 import java.util.*;
 import java.io.*;
+import java.net.InetAddress;
 import java.net.URL;
 import java.net.UnknownHostException;
 
@@ -68,10 +69,12 @@ TRTrackerServerTorrentImpl
 	private TRTrackerServerImpl	server;
 	private HashWrapper			hash;
 
-	private Map				peer_map 		= new HashMap();
-	private Map				peer_reuse_map	= new HashMap();
+	private Map<HashWrapper,TRTrackerServerPeerImpl>		peer_map 		= new HashMap<HashWrapper,TRTrackerServerPeerImpl>();
+	
+	private Map<String,TRTrackerServerPeerImpl>				peer_reuse_map	= new HashMap<String,TRTrackerServerPeerImpl>();
+	
+	private List<TRTrackerServerPeerImpl>					peer_list		= new ArrayList<TRTrackerServerPeerImpl>();
 	
-	private List			peer_list		= new ArrayList();
 	private int				peer_list_hole_count;
 	private boolean			peer_list_compaction_suspended;
 	
@@ -115,19 +118,10 @@ TRTrackerServerTorrentImpl
 	
 	protected AEMonitor this_mon 	= new AEMonitor( "TRTrackerServerTorrent" );
 
-	private static String[]	EXPLICIT_PEERS = {
-		 "209.34.83.140",
-	};
-
-	private static final int		EXPLICIT_PORT	= 20001;
-	
-	private static final int	EXPLICIT_PEERS_TO_ADD	= 1;
-	private static final byte[]	EXPLICIT_HASH	= ByteFormatter.decodeString( "07A4750F3CAA588E6963EB66B1E3713B4F3ED172" );
-	
-	private static int explicit_next_peer;
-	
-	private final boolean	add_explicit_peers;
-	
+	private List	explicit_manual_biased_peers;
+		
+	private int 	explicit_next_peer;
+		
 	public
 	TRTrackerServerTorrentImpl(
 		TRTrackerServerImpl		_server,
@@ -139,13 +133,6 @@ TRTrackerServerTorrentImpl
 		enabled		= _enabled;
 		
 		stats		= new TRTrackerServerTorrentStatsImpl( this );
-		
-		add_explicit_peers = Arrays.equals( hash.getBytes(), EXPLICIT_HASH );
-		
-		if ( add_explicit_peers ){
-			
-			System.out.println( "Adding explicit peers for " + ByteFormatter.encodeString( EXPLICIT_HASH ));
-		}
 	}
 	
 	public void
@@ -337,7 +324,7 @@ TRTrackerServerTorrentImpl
 					
 					if ( ip_override && !old_peer.isIPOverride()){
 						
-						throw( new TRTrackerServerException( "IP Override denied" ));
+						throw( new TRTrackerServerException( "IP Override denied (existing '" + reuse_key + "' is not override)" ));
 					}
 					
 					last_contact_time	= old_peer.getLastContactTime();
@@ -419,7 +406,7 @@ TRTrackerServerTorrentImpl
 							
 							if ( !biased_peer_set.contains( original_address )){
 								
-								throw( new TRTrackerServerException( "IP Override denied" ));
+								throw( new TRTrackerServerException( "IP Override denied (you are " + original_address + ")" ));
 							}
 						}
 						
@@ -494,7 +481,7 @@ TRTrackerServerTorrentImpl
 
 						if ( biased_peer_set == null || !biased_peer_set.contains( original_address )){
 
-							throw( new TRTrackerServerException( "IP Override denied" ));
+							throw( new TRTrackerServerException( "IP Override denied (you are " + original_address + ")"));
 						}
 					}
 					
@@ -502,7 +489,7 @@ TRTrackerServerTorrentImpl
 				
 					if ( !peer.isIPOverride()){
 					
-						throw( new TRTrackerServerException( "IP Override denied" ));
+						throw( new TRTrackerServerException( "IP Override denied (existing entry not override)" ));
 					}
 				}
 
@@ -1142,8 +1129,9 @@ TRTrackerServerTorrentImpl
 				// if set this list contains the only peers that are to be returned. It allows a manual
 				// external peer selection algorithm
 			
-			List	explicit_limited_peers 	= null;
-			List	explicit_biased_peers 	= null;
+			List<TRTrackerServerSimplePeer> 	explicit_limited_peers 	= null;
+			List<TRTrackerServerSimplePeer>		explicit_biased_peers	= null;
+			
 			Set		remove_ips				= null;
 			
 			if ( requesting_peer != null ){
@@ -1163,7 +1151,7 @@ TRTrackerServerTorrentImpl
 									
 									if ( explicit_limited_peers == null ){
 										
-										explicit_limited_peers = new ArrayList();
+										explicit_limited_peers = new ArrayList<TRTrackerServerSimplePeer>();
 									}
 									
 									for (int j=0;j<limited_peers.size();j++){
@@ -1190,7 +1178,7 @@ TRTrackerServerTorrentImpl
 									
 									if ( explicit_biased_peers == null ){
 										
-										explicit_biased_peers = new ArrayList();
+										explicit_biased_peers = new ArrayList<TRTrackerServerSimplePeer>();
 									}
 									
 									for (int j=0;j<biased_peers.size();j++){
@@ -1202,9 +1190,14 @@ TRTrackerServerTorrentImpl
 										
 										String	reuse_key = ip + ":" + port;
 
-										TRTrackerServerPeerImpl peer	= (TRTrackerServerPeerImpl)peer_reuse_map.get( reuse_key );
+										TRTrackerServerSimplePeer peer	= peer_reuse_map.get( reuse_key );
 
-										if ( peer != null && !explicit_biased_peers.contains( peer )){
+										if ( peer == null ){
+											
+											peer = new temporaryBiasedSeed( ip, port );
+										}
+										
+										if ( !explicit_biased_peers.contains( peer )){
 											
 											explicit_biased_peers.add( peer );
 										}
@@ -1338,9 +1331,10 @@ TRTrackerServerTorrentImpl
 							
 							// don't return "crypto required" peers to those that can't correctly connect to them
 							
+							/* change this to make the explicit ones additional, not replacing
 						}else if ( 	explicit_biased_peers != null &&
 									peer.isBiased()){
-							
+							*/
 								// if we have an explicit biased peer list and this peer is biased 
 								// skip here as we add them later
 							
@@ -1484,7 +1478,7 @@ TRTrackerServerTorrentImpl
 							
 							int	biased_peers_count = 0;
 							
-							if ( biased_peers != null && explicit_biased_peers == null ){
+							if ( biased_peers != null ){ // explicit are additional && explicit_biased_peers == null ){
 								
 								if ( biased_peers.size() > 1 ){
 													
@@ -1834,7 +1828,7 @@ TRTrackerServerTorrentImpl
 					
 					num_want--;
 					
-					TRTrackerServerPeerImpl peer = (TRTrackerServerPeerImpl)explicit_limited_peers.get(i);
+					TRTrackerServerSimplePeer  peer = explicit_limited_peers.get(i);
 					
 					exportPeer(rep_peers, peer, send_peer_ids, compact_mode, crypto_level, network_position);
 				}
@@ -1846,71 +1840,63 @@ TRTrackerServerTorrentImpl
 					
 					num_want--;
 					
-					TRTrackerServerPeerImpl peer = (TRTrackerServerPeerImpl)explicit_biased_peers.get(i);
+					TRTrackerServerSimplePeer peer = explicit_biased_peers.get(i);
 					
 					exportPeer(rep_peers, peer, send_peer_ids, compact_mode, crypto_level, network_position);
 				}
 			}
 		
-			if ( add_explicit_peers && num_want > 0 ){
+			if ( explicit_manual_biased_peers != null ){
 								
 				if ( requesting_peer != null && !requesting_peer.isSeed()){
+											
+					Object[]	explicit_peer = (Object[])explicit_manual_biased_peers.get( explicit_next_peer++ );
 					
-					for (int i=0;i<EXPLICIT_PEERS_TO_ADD;i++){
+					if ( explicit_next_peer == explicit_manual_biased_peers.size()){
 						
-						String	cl_peer = EXPLICIT_PEERS[explicit_next_peer++];
-						
-						if ( explicit_next_peer == EXPLICIT_PEERS.length ){
-							
-							explicit_next_peer = 0;
-						}
-						
-						Map rep_peer = new HashMap(3);
-						
-						if ( send_peer_ids ){
-							
-							byte[]	peer_id = new byte[20];
-							
-							random.nextBytes( peer_id );
-							
-							rep_peer.put( "peer id", peer_id );
-						}
-						
-						if ( compact_mode != COMPACT_MODE_NONE ){
-							
-							byte[]	peer_bytes = HostNameToIPResolver.hostAddressToBytes( cl_peer );
-							
-							if ( peer_bytes == null ){
-																	
-								continue;
-							}
-							
-							rep_peer.put( "ip", peer_bytes );
-							
-							if ( compact_mode >= COMPACT_MODE_AZ ){
-								
-								rep_peer.put( "azver", new Long( 0 ));	// non-az
-								
-								rep_peer.put( "azudp", new Long( 0 ));
-								
-								rep_peer.put( "azup", new Long( 0 ));
-																
-								rep_peer.put( "azbiased", "" );
-							}
-						}else{
-							
-							rep_peer.put( "ip", cl_peer.getBytes());
-						}
-						
-						rep_peer.put( "port", new Long( EXPLICIT_PORT ));	
-						
-						if ( crypto_level != TRTrackerServerPeer.CRYPTO_NONE ){
-							
-							rep_peer.put( "crypto_flag", new Long( 0 ));
-						}
-	
-						rep_peers.addFirst( rep_peer );
+						explicit_next_peer = 0;
 					}
+					
+					Map rep_peer = new HashMap(3);
+					
+					if ( send_peer_ids ){
+						
+						byte[]	peer_id = new byte[20];
+						
+						random.nextBytes( peer_id );
+						
+						rep_peer.put( "peer id", peer_id );
+					}
+					
+					if ( compact_mode != COMPACT_MODE_NONE ){
+						
+						byte[]	peer_bytes = (byte[])explicit_peer[1];
+													
+						rep_peer.put( "ip", peer_bytes );
+						
+						if ( compact_mode >= COMPACT_MODE_AZ ){
+							
+							rep_peer.put( "azver", new Long( 0 ));	// non-az
+							
+							rep_peer.put( "azudp", new Long( 0 ));
+							
+							rep_peer.put( "azup", new Long( 0 ));
+															
+							rep_peer.put( "azbiased", "" );
+						}
+					}else{
+						
+						rep_peer.put( "ip", ((String)explicit_peer[0]).getBytes());
+					}
+					
+					rep_peer.put( "port", new Long( ((Integer)explicit_peer[2]).intValue()));	
+					
+					if ( crypto_level != TRTrackerServerPeer.CRYPTO_NONE ){
+						
+						rep_peer.put( "crypto_flag", new Long( 0 ));
+					}
+
+					rep_peers.addFirst( rep_peer );
 				}
 			}
 			
@@ -2091,21 +2077,39 @@ TRTrackerServerTorrentImpl
 						
 					int	index = 0;
 					
+					int	num_ipv4 = 0;
+					int num_ipv6 = 0;
+					
 					while( it.hasNext()){
 						
 						Map	rep_peer = (Map)it.next();
 						
 						byte[] 	ip 		= (byte[])rep_peer.get( "ip" );
-						int		port	= ((Long)rep_peer.get( "port" )).intValue();
 						
-						int	pos = index*6;
-						
-						System.arraycopy( ip, 0, compact_peers, pos, 4 );
-						
-						pos += 4;
-						
-						compact_peers[pos++] = (byte)(port>>8);
-						compact_peers[pos++] = (byte)(port&0xff);
+						if ( ip.length > 4 ){
+							
+							num_ipv6++;
+							
+								// continue and fill in crypto return
+
+						}else{
+
+							num_ipv4++;
+							
+							if ( num_ipv6 == 0 ){
+								
+								int		port	= ((Long)rep_peer.get( "port" )).intValue();
+								
+								int	pos = index*6;
+								
+								System.arraycopy( ip, 0, compact_peers, pos, 4 );
+								
+								pos += 4;
+								
+								compact_peers[pos++] = (byte)(port>>8);
+								compact_peers[pos++] = (byte)(port&0xff);
+							}
+						}
 						
 						if ( crypto_flags != null ){
 							
@@ -2116,9 +2120,68 @@ TRTrackerServerTorrentImpl
 						
 						index++;
 					}
-										
-					root.put( "peers", compact_peers );
 					
+						// inefficient hack to support ipv6 compact for the moment
+					
+					if ( num_ipv6 > 0 ){
+						
+						byte[]	compact_peers_v4 = new byte[num_ipv4*6];
+						byte[]	compact_peers_v6 = new byte[num_ipv6*18];
+
+						it	= rep_peers.iterator();
+
+						int	v4_index	= 0;
+						int v6_index	= 0;
+						
+						while( it.hasNext()){
+							
+							Map	rep_peer = (Map)it.next();
+							
+							byte[] 	ip 		= (byte[])rep_peer.get( "ip" );
+							
+							int		port	= ((Long)rep_peer.get( "port" )).intValue();
+
+							if ( ip.length > 4 ){
+													
+								int	pos = v6_index*18;
+								
+								System.arraycopy( ip, 0, compact_peers_v6, pos, 16 );
+								
+								pos += 16;
+								
+								compact_peers_v6[pos++] = (byte)(port>>8);
+								compact_peers_v6[pos++] = (byte)(port&0xff);
+								
+								v6_index++;
+								
+							}else{
+								
+								int	pos = v4_index*6;
+								
+								System.arraycopy( ip, 0, compact_peers_v4, pos, 4 );
+								
+								pos += 4;
+								
+								compact_peers_v4[pos++] = (byte)(port>>8);
+								compact_peers_v4[pos++] = (byte)(port&0xff);
+
+								v4_index++;
+							}
+						}
+					
+						if ( compact_peers_v4.length > 0 ){
+							
+							root.put( "peers", compact_peers_v4 );
+						}
+						
+						if ( compact_peers_v6.length > 0 ){
+							
+							root.put( "peers6", compact_peers_v6 );
+						}
+					}else{
+					
+						root.put( "peers", compact_peers );
+					}
 				}else{
 					
 					int	index = 0;
@@ -2182,12 +2245,12 @@ TRTrackerServerTorrentImpl
 	
 	private void
 	exportPeer(
-		LinkedList				rep_peers,
-		TRTrackerServerPeerImpl	peer,
-		boolean					send_peer_ids,
-		byte					compact_mode,
-		byte					crypto_level,
-		DHTNetworkPosition		network_position )
+		LinkedList					rep_peers,
+		TRTrackerServerSimplePeer	peer,
+		boolean						send_peer_ids,
+		byte						compact_mode,
+		byte						crypto_level,
+		DHTNetworkPosition			network_position )
 	{
 		Map rep_peer = new HashMap(3);
 		
@@ -2590,7 +2653,32 @@ TRTrackerServerTorrentImpl
 	{
 		return( hash );
 	}
+	
+	public void
+	addExplicitBiasedPeer(
+		String		ip,
+		int			port )
+	{
+		byte[]	bytes = HostNameToIPResolver.hostAddressToBytes( ip );
 		
+		if ( bytes != null ){
+			
+			try{
+				this_mon.enter();
+
+				if ( explicit_manual_biased_peers == null  ){
+					
+					explicit_manual_biased_peers = new ArrayList();
+				}
+				
+				explicit_manual_biased_peers.add( new Object[]{ ip, bytes, new Integer( port )});
+				
+			}finally{
+				
+				this_mon.exit();
+			}
+		}
+	}
 	public void
 	setRedirects(
 		URL[]		urls )
@@ -3012,13 +3100,13 @@ TRTrackerServerTorrentImpl
 			return( tcp_port & 0xffff );
 		}
 		
-		protected int
+		public int
 		getUDPPort()
 		{
 			return( udp_port & 0xffff );
 		}
 		
-		protected int
+		public int
 		getHTTPPort()
 		{
 			return( http_port & 0xffff );
@@ -3076,6 +3164,111 @@ TRTrackerServerTorrentImpl
 		}
 	}
 	
+	protected class
+	temporaryBiasedSeed
+		implements TRTrackerServerSimplePeer
+	{
+		private String			ip;
+		private int				tcp_port;
+		private HashWrapper		peer_id;
+		
+		protected
+		temporaryBiasedSeed(
+			String			_ip,
+			int				_tcp_port )
+		{
+			ip			= _ip;
+			tcp_port	= _tcp_port;
+			
+			peer_id = new HashWrapper( RandomUtils.nextHash());
+		}
+		
+		public byte[]
+    	getIPAsRead()
+		{
+			try{
+			
+				return( ip.getBytes( Constants.BYTE_ENCODING ));
+				
+			}catch( Throwable e ){
+    			
+    			return( ip.getBytes());
+    		}
+		}
+    	
+    	public byte[]
+    	getIPAddressBytes()
+    	{
+    		try{
+    			return( InetAddress.getByName( ip ).getAddress());
+    			
+    		}catch( Throwable e ){
+    			
+    			return( null );
+    		}
+    	}
+
+    	public HashWrapper
+       	getPeerId()
+    	{
+    		return( peer_id );
+    	}
+
+    	public int
+    	getTCPPort()
+    	{
+    		return( tcp_port );
+    	}
+    	
+    	public int
+    	getUDPPort()
+    	{
+    		return( 0 );
+    	}
+    	
+    	public int
+    	getHTTPPort()
+    	{
+    		return( 0 );
+    	}
+    	
+    	public boolean
+    	isSeed()
+    	{
+    		return( true );
+    	}
+    	
+    	public boolean
+    	isBiased()
+    	{
+    		return( true );
+    	}
+    	
+    	public byte
+    	getCryptoLevel()
+    	{
+    		return( TRTrackerServerPeer.CRYPTO_NONE );
+    	}
+    	
+    	public byte
+    	getAZVer()
+    	{
+    		return( 0 );
+    	}
+    	
+    	public int
+    	getUpSpeed()
+    	{
+    		return( 0 );
+    	}
+    	
+    	public DHTNetworkPosition
+    	getNetworkPosition()
+    	{
+    		return( null );
+    	}
+	}
+	
 	public String
 	getString()
 	{
