@@ -31,7 +31,7 @@ public class
 TRTrackerServerTorrentStatsImpl
 	implements TRTrackerServerTorrentStats 
 {
-	private TRTrackerServerTorrentImpl	torrent;
+	private TRTrackerServerTorrentImpl		torrent;
 	private long							announce_count;
 	private long							scrape_count;
 	private long							completed_count;
@@ -183,6 +183,12 @@ TRTrackerServerTorrentStatsImpl
 		return( torrent.getLeecherCount());
 	}
 	
+	public int
+	getQueuedCount()
+	{
+		return( torrent.getQueuedCount());
+	}
+	
 	public int
 	getBadNATPeerCount()
 	{
@@ -192,6 +198,6 @@ TRTrackerServerTorrentStatsImpl
 	public String
 	getString()
 	{
-		return( "an=" + announce_count + ",sc=" + scrape_count + ",co=" + completed_count +",le=" + getLeecherCount() + ",se=" + getSeedCount() + ",bi=" + bytes_in + ",bo=" + bytes_out );
+		return( "an=" + announce_count + ",sc=" + scrape_count + ",co=" + completed_count +",le=" + getLeecherCount() + ",se=" + getSeedCount() + ",q=" + getQueuedCount() + ",bi=" + bytes_in + ",bo=" + bytes_out );
 	}
 }
