@@ -100,15 +100,18 @@ TRTrackerServerProcessorTCP
 		return( server );
 	}
 	
-	protected void
+	protected boolean
 	processRequest(
 		String				input_header,
 		String				lowercase_input_header,
 		String				url_path,
-		InetSocketAddress	client_address,
+		InetSocketAddress	local_address,
+		InetSocketAddress	remote_address,
 		boolean				announce_and_scrape_only,
+		boolean				keep_alive,
 		InputStream			is,
-		OutputStream		os )
+		OutputStream		os,
+		AsyncController		async )
 		
 		throws IOException
 	{
@@ -173,12 +176,14 @@ TRTrackerServerProcessorTCP
 						
 						if ( user == null ){
 							
-							return;
+							return( false );
 						}
 						
-						if ( handleExternalRequest( client_address, user, str, input_header, is, os )){
+						boolean[] ka = new boolean[]{ keep_alive };
 						
-							return;
+						if ( handleExternalRequest( local_address, remote_address, user, str, input_header, is, os, async, ka )){
+						
+							return( ka[0] );
 						}
 					}
 					
@@ -193,7 +198,7 @@ TRTrackerServerProcessorTCP
 					
 					os.flush();
 
-					return; // throw( new Exception( "Unsupported Request Type"));
+					return( false ); // throw( new Exception( "Unsupported Request Type"));
 				}
 				
 					// OK, here its an announce, scrape or full scrape
@@ -202,7 +207,7 @@ TRTrackerServerProcessorTCP
 					
 				if ( doAuthentication( url_path, input_header, os, true ) == null ){
 					
-					return;
+					return ( false );
 				}
 				
 				
@@ -266,7 +271,7 @@ TRTrackerServerProcessorTCP
 				
 				DHTNetworkPosition	network_position = null;
 				
-				String		real_ip_address		= client_address.getAddress().getHostAddress();
+				String		real_ip_address		= remote_address.getAddress().getHostAddress();
 				String		client_ip_address	= real_ip_address;
 				
 				while(pos < str.length()){
@@ -452,7 +457,7 @@ TRTrackerServerProcessorTCP
 						if ( lhs.equals( "aznp" )){
 
 							try{
-								network_position = DHTNetworkPositionManager.deserialisePosition( Base32.decode( rhs ));
+								network_position = DHTNetworkPositionManager.deserialisePosition( remote_address.getAddress(), Base32.decode( rhs ));
 																
 							}catch( Throwable e ){
 								
@@ -614,7 +619,7 @@ TRTrackerServerProcessorTCP
 						
 						os.flush();
 
-						return;
+						return( false );
 					}
 					
 					if ( tr_excep.isUserMessage()){
@@ -774,6 +779,8 @@ TRTrackerServerProcessorTCP
 
 			os.flush();
 		}
+		
+		return( false );
 	}
 	
 	protected String
@@ -922,17 +929,20 @@ TRTrackerServerProcessorTCP
 		
 	protected boolean
 	handleExternalRequest(
-		InetSocketAddress	client_address,
+		InetSocketAddress	local_address,
+		InetSocketAddress	remote_address,
 		String				user,
 		String				url,
 		String				header,
 		InputStream			is,
-		OutputStream		os )
+		OutputStream		os,
+		AsyncController		async,
+		boolean[]			keep_alive )
 		
 		throws IOException
 	{
 		URL	absolute_url = new URL( server_url + (url.startsWith("/")?url:("/"+url)));
 			
-		return( server.handleExternalRequest(client_address,user,url,absolute_url,header, is, os));
+		return( server.handleExternalRequest( local_address, remote_address, user,url,absolute_url,header, is, os, async, keep_alive ));
 	}
 }
