@@ -82,6 +82,8 @@ TRNonBlockingServer
 
 	private VirtualServerChannelSelector accept_server;
 	
+	private boolean immediate_close = COConfigurationManager.getBooleanParameter( "Tracker TCP NonBlocking Immediate Close" );
+	
 	private volatile boolean	closed;
 	
 	public
@@ -211,6 +213,13 @@ TRNonBlockingServer
 		}
 	}
 	
+	public void
+	setImmediateClose(
+		boolean	immediate )
+	{
+		immediate_close = immediate;
+	}
+	
 	protected void
 	selectLoop(
       VirtualChannelSelector	selector )
@@ -426,7 +435,20 @@ TRNonBlockingServer
         		read_selector.cancel( processor.getSocketChannel() );
         		write_selector.cancel( processor.getSocketChannel() );
         	
-        		connections_to_close.add( processor );
+        		if ( immediate_close ){
+
+        			try{
+        				processor.closed();
+
+        				processor.getSocketChannel().close();
+        				
+        			}catch( Throwable e ){
+        				
+        			}
+        		}else{
+        			
+        			connections_to_close.add( processor );
+        		}
         	}
         	
         }finally{
