@@ -33,6 +33,8 @@ import java.nio.channels.SocketChannel;
 import org.gudy.azureus2.core3.tracker.server.impl.TRTrackerServerImpl;
 import org.gudy.azureus2.core3.tracker.server.impl.tcp.TRTrackerServerProcessorTCP;
 import org.gudy.azureus2.core3.tracker.server.impl.tcp.TRTrackerServerTCP;
+import org.gudy.azureus2.core3.util.AESemaphore;
+import org.gudy.azureus2.core3.util.AsyncController;
 import org.gudy.azureus2.core3.util.SystemTime;
 
 /**
@@ -46,7 +48,7 @@ TRNonBlockingServerProcessor
 {
 	private static final int			READ_BUFFER_INITIAL		= 1024;
 	private static final int			READ_BUFFER_INCREMENT	= 1024;
-	private static final int			READ_BUFFER_LIMIT		= 8192;
+	private static final int			READ_BUFFER_LIMIT		= 32*1024;	// needs to be reasonable size to handle scrapes with plugin generated per-hash content
 		
 	private SocketChannel				socket_channel;
 	
@@ -196,21 +198,61 @@ TRNonBlockingServerProcessor
 									
 			url = url.substring(0,pos);
 				
-			ByteArrayOutputStream	response = 
-				process( 	request_header,
-							request_header.toLowerCase(),
-							url, 
-							(InetSocketAddress)socket_channel.socket().getRemoteSocketAddress(),
-							TRTrackerServerImpl.restrict_non_blocking_requests,
-							new ByteArrayInputStream(new byte[0]));
+			final AESemaphore[]				went_async 		= { null };
+			final ByteArrayOutputStream[]	async_stream	= { null };
 			
-			if ( response == null ){
+			AsyncController	async_control = 
+				new AsyncController()
+				{
+					public void
+					setAsyncStart()
+					{
+						went_async[0] = new AESemaphore( "async" );
+					}
+					
+					public void
+					setAsyncComplete()
+					{
+						went_async[0].reserve();
+						
+						asyncProcessComplete( async_stream[0] );
+					}
+				};
+			
+			try{
+				ByteArrayOutputStream	response = 
+					process( 	request_header,
+								request_header.toLowerCase(),
+								url, 
+								(InetSocketAddress)socket_channel.socket().getRemoteSocketAddress(),
+								TRTrackerServerImpl.restrict_non_blocking_requests,
+								new ByteArrayInputStream(new byte[0]),
+								async_control );
 				
-				async = true;
+					// two ways of going async
+					//	1) return is null and something else will call asyncProcessComplete later
+					//	2) return is 'not-yet-filled' os and async controller is managing things
 				
-			}else{
+				if ( response == null ){
+					
+					async = true;
+					
+				}else if ( went_async[0] != null ){
+					
+					async_stream[0] = response;
+					
+					async = true;
+					
+				}else{
+					
+					write_buffer = ByteBuffer.wrap( response.toByteArray());
+				}
+			}finally{
 				
-				write_buffer = ByteBuffer.wrap( response.toByteArray());
+				if ( went_async[0] != null ){
+				
+					went_async[0].release();
+				}
 			}
 		}catch( Throwable e ){
 			
@@ -231,7 +273,8 @@ TRNonBlockingServerProcessor
 		String				url_path,
 		InetSocketAddress	client_address,
 		boolean				announce_and_scrape_only,
-		InputStream			is )
+		InputStream			is,
+		AsyncController		async )
 	
 		throws IOException;
 	
