@@ -56,7 +56,7 @@ TRTrackerServerProcessorUDP
 	private DatagramPacket			request_dg;
 	
 	private static Map				connection_id_map 	= new LinkedHashMap();
-	private static SecureRandom		random				= new SecureRandom();
+	private static SecureRandom		random				= RandomUtils.SECURE_RANDOM;
 	private static AEMonitor		random_mon 			= new AEMonitor( "TRTrackerServerUDP:rand" );
 
 	static{
@@ -252,11 +252,8 @@ TRTrackerServerProcessorUDP
 				}else{
 										
 					System.out.println( "UDP Tracker: replying 'disabled' to " + client_ip_address );
-					
-					//if ( client_ip_address.equals( "64.79.127.118" )){
-								
-						reply = new PRUDPPacketReplyError( request.getTransactionId(), "UDP Tracker disabled" );
-					//}
+													
+					reply = new PRUDPPacketReplyError( request.getTransactionId(), "UDP Tracker disabled" );
 				}
 			}
 			
