@@ -23,14 +23,17 @@
 package org.gudy.azureus2.core3.util;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
+import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.logging.*;
 import org.gudy.azureus2.platform.PlatformManager;
 import org.gudy.azureus2.platform.PlatformManagerCapabilities;
 import org.gudy.azureus2.platform.PlatformManagerFactory;
 
+import com.aelitis.azureus.core.util.AEThreadMonitor;
 import com.aelitis.azureus.core.util.Java15Utils;
 
+
 /**
  * @author parg
  *
@@ -116,12 +119,11 @@ AEDiagnostics
 	
 	private static Map<String,AEDiagnosticsLogger>		loggers	= new HashMap<String, AEDiagnosticsLogger>();
 	
+	protected static boolean	logging_enabled;
 	protected static boolean	loggers_enabled;
 	
 	private static List		evidence_generators	= new ArrayList();
-	
-	private static boolean load_15_tried;
-	
+		
 	public static synchronized void
 	startup(
 		boolean	_enable_pending )
@@ -136,14 +138,18 @@ AEDiagnostics
 		enable_pending_writes = _enable_pending;
 		
 		try{
-			// Minimize risk of loading to much when in transitory startup mode
+				// Minimize risk of loading to much when in transitory startup mode
+			
 			boolean transitoryStartup = System.getProperty("transitory.startup", "0").equals("1");
-			if (transitoryStartup) {
-				// no vivaldi and Thread monitor for you!
-				load_15_tried = true;
-				// no xxx_?.log logging for you!
+			
+			if ( transitoryStartup ){
+				
+					// no xxx_?.log logging for you!
+				
 				loggers_enabled = false;
-				// skip tidy check and more!
+				
+					// skip tidy check and more!
+				
 				return;
 			}
 
@@ -151,8 +157,28 @@ AEDiagnostics
 			
 			debug_save_dir	= new File( debug_dir, "save" );
 			
-			loggers_enabled = COConfigurationManager.getBooleanParameter( "Logger.DebugFiles.Enabled");
-
+			COConfigurationManager.addAndFireParameterListeners(
+				new String[]{
+					"Logger.Enabled",
+					"Logger.DebugFiles.Enabled",	
+				},
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						String parameterName) 
+					{			
+						logging_enabled = COConfigurationManager.getBooleanParameter( "Logger.Enabled" );
+						
+						loggers_enabled = logging_enabled && COConfigurationManager.getBooleanParameter( "Logger.DebugFiles.Enabled");
+						
+						if ( !loggers_enabled ){
+							
+							loggers_enabled = Constants.IS_CVS_VERSION || COConfigurationManager.getBooleanParameter( "Logger.DebugFiles.Enabled.Force" );
+						}
+					}
+				});
+			
 			boolean	was_tidy	= COConfigurationManager.getBooleanParameter( CONFIG_KEY );
 			
 			new AEThread2( "asyncify", true )
@@ -172,9 +198,7 @@ AEDiagnostics
 			if ( debug_dir.exists()){
 				
 				long	now = SystemTime.getCurrentTime();
-				
-				debug_save_dir.mkdir();
-				
+								
 				File[] files = debug_dir.listFiles();
 				
 				if ( files != null ){
@@ -192,6 +216,11 @@ AEDiagnostics
 						
 						if ( !was_tidy ){
 				
+							if ( !file_copied ){
+								
+								debug_save_dir.mkdir();
+							}
+							
 							file_copied	= true;
 							
 							FileUtil.copyFile( file, new File( debug_save_dir, now + "_" + file.getName()));
@@ -209,6 +238,9 @@ AEDiagnostics
 				
 				debug_dir.mkdir();
 			}
+			
+			AEThreadMonitor.initialise();
+			
 		}catch( Throwable e ){
 			
 				// with webui we don't have the file stuff so this fails with class not found
@@ -220,43 +252,9 @@ AEDiagnostics
 		}finally{
 			
 			startup_complete	= true;
-			
-			load15Stuff();
 		}
 	}
-	
-	protected static void
-	load15Stuff()
-	{
-		if ( load_15_tried ){
-			
-			return;
-		}
 		
-		load_15_tried = true;
-		
-		// pull in the JDK1.5 monitoring stuff if present
-			
-		try{
-			Class c = Class.forName( "com.aelitis.azureus.jdk15.Java15Initialiser" );
-					
-			if ( c != null ){
-				
-				Method m = c.getDeclaredMethod( "getUtilsProvider", new Class[0] );
-				
-				Java15Utils.Java15UtilsProvider provider = (Java15Utils.Java15UtilsProvider)m.invoke( null, new Object[0] );
-				
-				if ( provider != null ){
-					
-					 Java15Utils.setProvider( provider );
-				}
-			}
-			// System.out.println( "**** AEThread debug on ****" );
-
-		}catch( Throwable e ){
-		}
-	}
-	
 	public static void
 	dumpThreads()
 	{
