@@ -124,6 +124,8 @@ AEMonSem
 		
 		synchronized( AEMonSem.class ){
 
+			// dumpTrace();
+			
 			diag_logger.log( 
 					"AEMonSem: mid = " + monitor_id_next +
 					", sid = " + semaphore_id_next +
@@ -356,8 +358,6 @@ AEMonSem
 	protected String		name;
 	protected boolean		is_monitor;
 	protected int			waiting		= 0;
-
-	// protected boolean	trace;
 	
 	protected
 	AEMonSem(
@@ -424,9 +424,12 @@ AEMonSem
 	protected void
 	debugEntry()
 	{
-		//if ( trace ){
-		//	System.out.println( Debug.getStackTrace( true, false ));
-		//}
+		/*
+		if ( trace ){
+			traceEntry();
+		}
+		*/
+		
 		try{
 				// bad things are:
 				// A->B and somewhere else B->A
@@ -720,12 +723,66 @@ AEMonSem
 	}
 	
 	/*
+	protected boolean			trace;
+	protected static Map		trace_map = new HashMap();
+	
 	public void
 	trace(
 		boolean	_on )
 	{
 		trace	= _on;
 	}
+	
+	protected void
+	traceEntry()
+	{
+		String str = Debug.getCompressedStackTrace();
+		
+		synchronized( trace_map ){
+			Map map = (Map)trace_map.get( name );
+			if ( map == null ){
+				map = new HashMap();
+				trace_map.put( name, map );
+			}
+			Long l = (Long)map.get(str);
+			
+			if ( l == null ){
+				l = new Long(1);
+			}else{
+				l = new Long(l.longValue()+1);
+			}
+			map.put(str,l);
+		}
+	}
+	
+	protected static void 
+	dumpTrace()
+	{		
+		synchronized( trace_map ){
+						
+			Iterator it = trace_map.entrySet().iterator();
+			
+			while( it.hasNext()){
+				
+				Map.Entry entry = (Map.Entry)it.next();
+				
+				System.out.println( entry.getKey());
+				
+				Map map = (Map)entry.getValue();
+				
+				Iterator it2 = map.entrySet().iterator();
+				
+				while( it2.hasNext()){
+					
+					Map.Entry entry2 = (Map.Entry)it2.next();
+				
+					System.out.println( "    " + entry2.getValue() + " -> " + entry2.getKey());
+				}
+			}
+			
+			trace_map.clear();
+		}
+	}
 	*/
 	
 	public String
