@@ -35,23 +35,24 @@ Constants
 {
   public static final String EMPTY_STRING = "";
   public static final String SF_WEB_SITE			= "http://azureus.sourceforge.net/";
-  //public static final String AELITIS_WEB_SITE   	= "http://azureus.aelitis.com/";  
-  //public static final String GETAZUREUS_WEB_SITE	= "http://www.getazureus.com/";
-  
-  public static final String AELITIS_TORRENTS		= "http://torrents.aelitis.com:88/torrents/";
-  public static final String AELITIS_FILES			= "http://torrents.aelitis.com:88/files/";
+ 
+  public static final String AELITIS_TORRENTS		= "http://torrent.vuze.com:88/torrents/";
+  public static final String AELITIS_FILES			= "http://torrent.vuze.com:88/files/";
   public static final String AZUREUS_WIKI 			= "http://wiki.vuze.com/index.php/";
   
-  public static final String  VERSION_SERVER_V4 	= "version.azureusplatform.com";
-  public static final String  VERSION_SERVER_V6 	= "version6.azureusplatform.com";
+  public static final String  VERSION_SERVER_V4 	= "version.vuze.com";
+  public static final String  VERSION_SERVER_V6 	= "version6.vuze.com";
 
-  public static final String DHT_SEED_ADDRESS_V4	= "dht.aelitis.com";
-  public static final String DHT_SEED_ADDRESS_V6	= "dht6.azureusplatform.com";
+  public static final String DHT_SEED_ADDRESS_V4	= "dht.vuze.com";
+  public static final String DHT_SEED_ADDRESS_V6	= "dht6.vuze.com";
   
-  public static final String NAT_TEST_SERVER		= "nettest.azureusplatform.com";
-  public static final String NAT_TEST_SERVER_HTTP	= "http://nettest.azureusplatform.com/";
+  public static final String NAT_TEST_SERVER		= "nettest.vuze.com";
+  public static final String NAT_TEST_SERVER_HTTP	= "http://nettest.vuze.com/";
    
-  public static final String SPEED_TEST_SERVER		= "speed.azureusplatform.com";
+  public static final String SPEED_TEST_SERVER		= "speedtest.vuze.com";
+  
+  public static final String PAIRING_URL			= "http://pair.vuze.com/pairing";
+
   
   public static final String[] AZUREUS_DOMAINS = { "azureusplatform.com", "azureus.com", "aelitis.com", "vuze.com" };
   
@@ -84,9 +85,12 @@ Constants
   
   public static String APP_NAME = "Vuze";
   public static final String AZUREUS_NAME	  = "Azureus";
-  public static final String AZUREUS_VERSION  = "4.2.0.8";  //4.2.0.9_CVS
-  public static final byte[] VERSION_ID       = ("-" + "AZ" + "4208" + "-").getBytes();  //MUST be 8 chars long!
+  public static final String AZUREUS_VERSION  = "4.3.0.6";  //4.3.0.7_CVS
+  public static final byte[] VERSION_ID       = ("-" + "AZ" + "4306" + "-").getBytes();  //MUST be 8 chars long!
+
+  private static final boolean FORCE_NON_CVS = System.getProperty( "az.force.noncvs", "0" ).equals( "1" );
   
+  public static final boolean IS_CVS_VERSION = isCVSVersion( AZUREUS_VERSION ) && !FORCE_NON_CVS;
   
   public static final String  OSName = System.getProperty("os.name");
   
@@ -130,6 +134,39 @@ Constants
 	  }
   }
   
+  public static final boolean isOSX_10_5_OrHigher;
+  public static final boolean isOSX_10_6_OrHigher;
+  
+  static{
+	  if ( isOSX ){
+		 
+		  int	first_digit 	= 0;
+		  int	second_digit	= 0;
+		  
+		  try{
+			  String os_version = System.getProperty( "os.version" );
+
+			  String[] bits = os_version.split( "\\." );
+			
+			  first_digit = Integer.parseInt( bits[0] );
+			  
+			  if ( bits.length > 1 ){
+			  
+				  second_digit = Integer.parseInt( bits[1] );
+			  }
+		  }catch( Throwable e ){
+			  
+		  }
+		  
+		  isOSX_10_5_OrHigher = first_digit > 10 || ( first_digit == 10 && second_digit >= 5 );
+		  isOSX_10_6_OrHigher = first_digit > 10 || ( first_digit == 10 && second_digit >= 6 );
+		  
+	  }else{
+		  
+		  isOSX_10_5_OrHigher = false;
+		  isOSX_10_6_OrHigher = false;
+	  }
+  }
   
   public static final String	JAVA_VERSION = System.getProperty("java.version");
   
@@ -168,7 +205,7 @@ Constants
   public static boolean
   isCVSVersion()
   {
-  	return( isCVSVersion( AZUREUS_VERSION )); 
+  	return IS_CVS_VERSION; 
   }
   
   public static boolean
