@@ -28,12 +28,13 @@ package org.gudy.azureus2.core3.util;
  */
 
 import java.net.InetAddress;
+import java.net.UnknownHostException;
 import java.util.*;
 
 public class 
 IPToHostNameResolver 
 {
-	static protected Thread			resolver_thread;
+	static protected AEThread2		resolver_thread;
 	static protected List			request_queue		= new ArrayList();
 	static protected AEMonitor		request_mon			= new AEMonitor( "IPToHostNameResolver" );
 
@@ -56,21 +57,28 @@ IPToHostNameResolver
 			if ( resolver_thread == null ){
 				
 				resolver_thread = 
-					new AEThread("IPToHostNameResolver")
+					new AEThread2("IPToHostNameResolver", true )
 					{
 						public void
-						runSupport()
+						run()
 						{
 							while(true){
 								
 								try{
-									request_semaphore.reserve();
+									request_semaphore.reserve(30000);
 									
 									IPToHostNameResolverRequest	req;
 									
 									try{
 										request_mon.enter();
 										
+										if ( request_queue.isEmpty()){
+											
+											resolver_thread = null;
+											
+											break;
+										}
+										
 										req	= (IPToHostNameResolverRequest)request_queue.remove(0);
 										
 									}finally{
@@ -102,9 +110,7 @@ IPToHostNameResolver
 							}
 						}
 					};
-					
-				resolver_thread.setDaemon( true );	
-					
+										
 				resolver_thread.start();
 			}
 			
@@ -115,4 +121,55 @@ IPToHostNameResolver
 			request_mon.exit();
 		}
 	}
+	
+	public static String
+	syncResolve(
+		String			ip,
+		int				timeout )
+	
+		throws Exception
+	{
+		final AESemaphore	sem = new AESemaphore( "IPToHostNameREsolver:sync" );
+		
+		final Object[]	result = {null};
+				
+		addResolverRequest(
+			ip, 
+			new IPToHostNameResolverListener()
+			{
+				public void
+				IPResolutionComplete(
+					String		resolved_ip,
+					boolean		succeeded )
+				{
+					try{
+						synchronized( result ){
+
+							if ( succeeded ){
+									
+								result[0] = resolved_ip;
+							}
+						}
+					}finally{
+						
+						sem.release();
+					}
+				}
+			});
+			
+		if ( !sem.reserve( timeout )){
+			
+			throw( new Exception( "Timeout" ));
+		}
+				
+		synchronized( result ){
+
+			if ( result[0] != null ){
+				
+				return((String)result[0]);
+			}
+			
+			throw( new UnknownHostException( ip ));
+		}
+	}
 }
