@@ -18,7 +18,10 @@
  */
 package org.gudy.azureus2.core3.util;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.concurrent.atomic.AtomicLong;
 
 /**
  * Utility class to retrieve current system time, and catch clock backward time
@@ -27,6 +30,12 @@ import java.util.*;
 public class SystemTime {
 	public static final long			TIME_GRANULARITY_MILLIS	= 25;	//internal update time ms
 	private static SystemTimeProvider	instance;
+	
+	// can't do that without some safeguarding code.
+	// monotime does guarantee that time neither goes backwards nor performs leaps into the future.
+	// the HPC doesn't jump backward but can jump forward in time
+	private static final boolean		SOD_IT_LETS_USE_HPC = false;//	= Constants.isCVSVersion();
+	
 	static
 	{
 		try
@@ -73,10 +82,13 @@ public class SystemTime {
 
 	protected static class SteppedProvider implements SystemTimeProvider {
 		private static final int	STEPS_PER_SECOND	= (int) (1000 / TIME_GRANULARITY_MILLIS);
+		private static final long	HPC_START = getHighPrecisionCounter()/1000000L;
+		
 		private final Thread		updater;
 		private volatile long		stepped_time;
 		private volatile long		currentTimeOffset = System.currentTimeMillis();
-		private volatile long		last_approximate_time;
+		private AtomicLong 			last_approximate_time = new AtomicLong(); 
+		//private volatile long		last_approximate_time;
 		private volatile int		access_count;
 		private volatile int		slice_access_count;
 		private volatile int		access_average_per_slice;
@@ -213,30 +225,47 @@ public class SystemTime {
 		}
 
 		public long getMonoTime() {
-			long adjusted_time = stepped_time;
-			long averageSliceStep = access_average_per_slice;
-			if (averageSliceStep > 0)
-			{
-				long sliceStep = (drift_adjusted_granularity * slice_access_count) / averageSliceStep;
-				if (sliceStep >= drift_adjusted_granularity)
+			if ( SOD_IT_LETS_USE_HPC ){
+				
+				return( ( getHighPrecisionCounter()/1000000) - HPC_START );
+				
+			}else{
+				long adjusted_time;
+				long averageSliceStep = access_average_per_slice;
+				if (averageSliceStep > 0)
 				{
-					sliceStep = drift_adjusted_granularity - 1;
-				}
-				adjusted_time += sliceStep;
+					long sliceStep = (drift_adjusted_granularity * slice_access_count) / averageSliceStep;
+					if (sliceStep >= drift_adjusted_granularity)
+					{
+						sliceStep = drift_adjusted_granularity - 1;
+					}
+					adjusted_time = sliceStep + stepped_time;
+				} else
+					adjusted_time = stepped_time;
+				access_count++;
+				slice_access_count++;
+	
+				// make sure we don't go backwards and our reference value for going backwards doesn't go backwards either
+				long approxBuffered = last_approximate_time.get(); 
+				if (adjusted_time < approxBuffered)
+					adjusted_time = approxBuffered;				
+				else
+					last_approximate_time.compareAndSet(approxBuffered, adjusted_time);
+	
+				return adjusted_time;
 			}
-			access_count++;
-			slice_access_count++;
-			// make sure we don't go backwards
-			if (adjusted_time < last_approximate_time)
-				adjusted_time = last_approximate_time;
-			else
-				last_approximate_time = adjusted_time;
-			return adjusted_time;
 		}
 		
 		public long getSteppedMonoTime() {
 
-			return( stepped_mono_time );
+			if ( SOD_IT_LETS_USE_HPC ){
+				
+				return( getHighPrecisionCounter()/1000000 );
+				
+			}else{
+				
+				return( stepped_mono_time );
+			}
 		}
 	}
 	
@@ -349,9 +378,6 @@ public class SystemTime {
 	 * 
 	 * <b>Do not mix times retrieved by this method with normal time!</b>
 	 * 
-	 * TODO once we move to java 1.5 use atomic stuff to harden the guarantee
-	 * (multithreaded access can weaken it at the moment)
-	 * 
 	 * @return the amount of real time passed since the program start in
 	 *         milliseconds
 	 */
@@ -360,7 +386,7 @@ public class SystemTime {
 	}
 
 		/**
-		 * Like getMonotonousTime but only updated at TIME_GRANULARITY_MILLIS intervals (not interopolated)
+		 * Like getMonotonousTime but only updated at TIME_GRANULARITY_MILLIS intervals (not interpolated)
 		 * As such it is likely to be cheaper to obtain
 		 * @return
 		 */
