@@ -33,6 +33,19 @@ public class TimeFormatter {
   // XXX should be i18n'd
 	static final String[] TIME_SUFFIXES = { "s", "m", "h", "d", "y" };
 
+	public static final String[] DATEFORMATS_DESC = new String[] {
+		"EEEE, MMMM d, yyyy GG",
+		"EEEE, MMMM d, yyyy",
+		"EEE, MMMM d, yyyy",
+		"MMMM d, ''yy",
+		"EEE, MMM d, ''yy",
+		"MMM d, yyyy",
+		"MMM d, ''yy",
+		"yyyy/MM/dd",
+		"''yy/MM/dd",
+		"MMM dd",
+		"MM/dd",
+	};
 	
 	private static final SimpleDateFormat http_date_format = 
 		new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss zzz", Locale.US );
@@ -52,7 +65,7 @@ public class TimeFormatter {
 	 * @return Formatted time string
 	 */
 	public static String format(long time_secs) {
-		if (time_secs == Constants.INFINITY_AS_INT || time_secs >= Constants.INFINITE_AS_LONG)
+		if (time_secs == Constants.CRAPPY_INFINITY_AS_INT || time_secs >= Constants.CRAPPY_INFINITE_AS_LONG)
 			return Constants.INFINITY_STRING;
 
 		if (time_secs < 0)
@@ -74,10 +87,14 @@ public class TimeFormatter {
 		
 		String result = vals[end] + TIME_SUFFIXES[end];
 
+		/* old logic removed to prefer showing consecutive units
 		// skip until we have a non-zero time section
 		do {
 			end--;
 		} while (end >= 0 && vals[end] == 0);
+		*/
+		
+		end--;
 		
 		if (end >= 0)
 			result += " " + twoDigits(vals[end]) + TIME_SUFFIXES[end];
@@ -108,7 +125,7 @@ public class TimeFormatter {
 	 */
     public static String formatColon(long time)
     {
-      if (time == Constants.INFINITY_AS_INT || time >= Constants.INFINITE_AS_LONG) return Constants.INFINITY_STRING;
+      if (time == Constants.CRAPPY_INFINITY_AS_INT || time >= Constants.CRAPPY_INFINITE_AS_LONG) return Constants.INFINITY_STRING;
       if (time < 0) return "";
 
       int secs = (int) time % 60;
@@ -179,6 +196,21 @@ public class TimeFormatter {
 		}
     }
     
+    public static long
+    parseHTTPDate(
+    	String		date )
+    {
+    	try{
+    		return( http_date_format.parse( date ).getTime());
+    		
+    	}catch( Throwable e ){
+    		
+    		Debug.out("Failed to parse HTTP date '" + date + "'" );
+    		
+    		return( 0 );
+    	}
+    }
+    
     public static String
     milliStamp()
     {
