@@ -53,9 +53,12 @@ TorrentUtils
 	private static final String		TORRENT_AZ_PROP_PLUGINS					= "plugins";
 	
 	public static final String		TORRENT_AZ_PROP_OBTAINED_FROM			= "obtained_from";
+	public static final String		TORRENT_AZ_PROP_PEER_CACHE				= "peer_cache";
+	public static final String		TORRENT_AZ_PROP_PEER_CACHE_VALID		= "peer_cache_valid";
 	
 	private static final String		MEM_ONLY_TORRENT_PATH		= "?/\\!:mem_only:!\\/?";
 	
+	private static final long		PC_MARKER = RandomUtils.nextLong();
 	
 	private static final List	created_torrents;
 	private static final Set	created_torrents_set;
@@ -399,9 +402,10 @@ TorrentUtils
 	
 	public static void
 	delete(
-		File 		torrent_file )
+		File 		torrent_file,
+		boolean		force_no_recycle )
 	{
-		if ( !FileUtil.deleteWithRecycle( torrent_file )){
+		if ( !FileUtil.deleteWithRecycle( torrent_file, force_no_recycle )){
 			
     		Debug.out( "TorrentUtils::delete: failed to delete '" + torrent_file + "'" );
     	}
@@ -1105,6 +1109,61 @@ TorrentUtils
 		return( null );
 	}
 	
+	public static void
+	setPeerCache(
+		TOTorrent		torrent,
+		Map				pc )
+	{
+		Map	m = getAzureusPrivateProperties( torrent );
+			
+		try{
+			m.put( TORRENT_AZ_PROP_PEER_CACHE, pc );
+						
+		}catch( Throwable e ){
+			
+			Debug.printStackTrace(e);
+		}
+	}
+	
+	public static void
+	setPeerCacheValid(
+		TOTorrent		torrent )
+	{
+		Map	m = getAzureusPrivateProperties( torrent );
+			
+		try{
+			m.put( TORRENT_AZ_PROP_PEER_CACHE_VALID, new Long( PC_MARKER ));
+						
+		}catch( Throwable e ){
+			
+			Debug.printStackTrace(e);
+		}
+	}
+	
+	public static Map
+	getPeerCache(
+		TOTorrent		torrent )
+	{
+		try{
+			Map	m = getAzureusPrivateProperties( torrent );
+	
+			Long value = (Long)m.get( TORRENT_AZ_PROP_PEER_CACHE_VALID );
+			
+			if ( value != null && value == PC_MARKER ){
+			
+				Map	pc = (Map)m.get( TORRENT_AZ_PROP_PEER_CACHE );
+	
+				return( pc );
+			}
+			
+		}catch( Throwable e ){
+			
+			Debug.out( e );
+		}
+		
+		return( null );
+	}
+	
 	public static void
 	setFlag(
 		TOTorrent		torrent,
@@ -1601,6 +1660,13 @@ TorrentUtils
 			return( delegate.getCreatedBy());
 		}
 		
+	 	public void
+		setCreatedBy(
+			byte[]		cb )
+	   	{
+	  		delegate.setCreatedBy( cb );
+	   	}
+	 	
 		public boolean
 		isCreated()
 		{
@@ -2465,14 +2531,7 @@ TorrentUtils
 			}
 		}
 	}
-	
-	public static String
-	getMagnetURI(
-		byte[]		hash )
-	{
-		return( "magnet:?xt=urn:btih:" + Base32.encode( hash ));
-	}
-	
+		
 	private static void
 	fireAttributeListener(
 		TOTorrent		torrent,	
