@@ -68,6 +68,69 @@ public class UrlUtils
 		new String[] { "'", "&apos;" },
 	};
 
+	public static String
+	getMagnetURI(
+		byte[]		hash )
+	{
+		return( "magnet:?xt=urn:btih:" + Base32.encode( hash ));
+	}
+
+		/**
+		 * returns magnet uri if input is base 32 or base 16 encoded sha1 hash, null otherwise
+		 * @param base_hash
+		 * @return
+		 */
+	
+	public static String
+	normaliseMagnetURI(
+		String		base_hash )
+	{
+		byte[]	hash = decodeSHA1Hash( base_hash );
+		
+		if ( hash != null ){
+			
+			return( getMagnetURI( hash ));
+		}
+		
+		return( null );
+	}
+	
+	public static byte[]
+	decodeSHA1Hash(
+		String	str )
+	{
+		if ( str == null ){
+			
+			return( null );
+		}
+		
+		str = str.trim();
+		
+		byte[] hash = null;
+		
+		try{
+			if ( str.length() == 40 ){
+				
+				hash = ByteFormatter.decodeString( str );
+				
+			}else if ( str.length() == 32 ){
+				
+				hash = Base32.decode( str );
+			}
+		}catch( Throwable e ){
+		}
+		
+		if ( hash != null ){
+			
+			if ( hash.length != 20 ){
+								
+				hash = null;
+			}
+		}
+		
+		return( hash );
+	}
+	
 	/**
 	 * test string for possibility that it's an URL.  Considers 40 byte hex 
 	 * strings as URLs
@@ -335,81 +398,17 @@ public class UrlUtils
 	
 		throws IOException
 	{
-		if ( Java15Utils.isAvailable()){
-			
-			if ( connect_timeout != -1 ){
+		if ( connect_timeout != -1 ){
 				
-				Java15Utils.setConnectTimeout( connection, (int)connect_timeout );	
-			}
-			
-			if ( read_timeout != -1 ){
-				
-				Java15Utils.setReadTimeout( connection, (int)read_timeout );	
-			}
-			
-			connection.connect();
-			
-		}else{
-			
-				// TODO: No read timeout support here yet...
-			
-			final AESemaphore sem = new AESemaphore( "URLUtils:cwt" );
-			
-			final Throwable[] res = { null };
-			
-			//long	start = SystemTime.getMonotonousTime();
-			
-			if ( connect_pool.isFull()){
-				
-				Debug.out( "Connect pool is full, forcing timeout" );
-				
-				throw( new IOException( "Timeout" ));
-			}
-			
-			connect_pool.run(
-				new AERunnable()
-				{
-					public void
-					runSupport()
-					{
-						try{
-							connection.connect();
-							
-						}catch( Throwable e ){
-							
-							res[0] = e;
-							
-						}finally{
-							
-							sem.release();
-						}
-					}
-				});
-			
-			boolean ok = sem.reserve( connect_timeout );
-			
-			//long	duration = SystemTime.getMonotonousTime() - start;
-			
-			//System.out.println( connection.getURL() + ": time=" + duration + ", ok=" + ok );
-			
-			if ( ok ){
-	
-				Throwable error = res[0];
-				
-				if ( error != null ){
-					
-					if ( error instanceof IOException ){
-						
-						throw((IOException)error);
-					}
-					
-					throw( new IOException( Debug.getNestedExceptionMessage( error )));
-				}
-			}else{
-				
-				throw( new IOException( "Timeout" ));
-			}
+			Java15Utils.setConnectTimeout( connection, (int)connect_timeout );	
 		}
+			
+		if ( read_timeout != -1 ){
+				
+			Java15Utils.setReadTimeout( connection, (int)read_timeout );	
+		}
+			
+		connection.connect();
 	}
 	
 	private static String	last_headers = COConfigurationManager.getStringParameter( "metasearch.web.last.headers", null );
