@@ -506,7 +506,13 @@ public class PlatformManagerImpl implements PlatformManager, AEDiagnosticsEviden
      */
     public void dispose()
     {
-        NativeInvocationBridge.sharedInstance().dispose();
+    	try {
+    		if (NativeInvocationBridge.hasSharedInstance()) {
+    			NativeInvocationBridge.sharedInstance().dispose();
+    		}
+    	} catch (Throwable t) {
+    		Debug.out("Problem disposing NativeInvocationBridge", t);
+    	}
     }
 
     /**
@@ -577,9 +583,12 @@ public class PlatformManagerImpl implements PlatformManager, AEDiagnosticsEviden
             StringBuffer sb = new StringBuffer();
             sb.append("tell application \"");
             sb.append(getFileBrowserName());
-            sb.append("\" to reveal (posix file \"");
+            sb.append("\"\n");
+            sb.append("reveal (posix file \"");
             sb.append(path);
-            sb.append("\" as alias)");
+            sb.append("\" as alias)\n");
+            sb.append("activate\n");
+            sb.append("end tell\n");
 
             try
             {
