@@ -30,7 +30,8 @@ public class
 AEWin32AccessException
 	extends Exception
 {
-	protected
+	
+	public
 	AEWin32AccessException(
 		String	str )
 	{
