@@ -27,10 +27,13 @@ package org.gudy.azureus2.platform.win32.access.impl;
  *
  */
 
-import java.io.*;
+import java.io.File;
+import java.net.InetAddress;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 
-import org.gudy.azureus2.core3.util.Debug;
-import org.gudy.azureus2.platform.win32.access.*;
+import org.gudy.azureus2.platform.PlatformManagerPingCallback;
 
 public class 
 Test 
@@ -40,6 +43,24 @@ Test
 		String[]	args )
 	{
 		try{
+			
+			List availableDrives = AEWin32AccessInterface.getAvailableDrives();
+			
+			for (Object object : availableDrives) {
+				File f = (File) object;
+				System.out.println(f.getAbsolutePath());
+
+				Map driveInfo = AEWin32AccessInterface.getDriveInfo(f.getPath().charAt(0));
+				for (Iterator iter = driveInfo.keySet().iterator(); iter.hasNext();) {
+					Object key = (Object) iter.next();
+					Object val = driveInfo.get(key);
+					System.out.println(key + ": " + val);
+				}
+				
+			}
+			
+			if (true)
+				return;
 			/*
 			AEWin32Access access = AEWin32Manager.getAccessor();
 			
@@ -114,7 +135,34 @@ Test
 			}
 		*/
 			
-			AEWin32AccessInterface.copyPermission( "C:\\temp\\fred", "C:\\temp\\bill" );
+			//AEWin32AccessInterface.copyPermission( "C:\\temp\\fred", "C:\\temp\\bill" );
+			
+			/*
+			AEWin32AccessImpl.getSingleton( false ).traceRoute(
+					InetAddress.getByName( "192.168.1.143" ),
+					InetAddress.getByName( "www.google.com"),
+					new PlatformManagerPingCallback()
+					{
+						public boolean
+						reportNode(
+							int				distance,
+							InetAddress		address,
+							int				millis )
+						{
+							System.out.println( distance + ": " + address + " - " + millis );
+							
+							return( true );
+						}
+					});
+			*/
+			
+			// AEWin32AccessInterface.ping( "www.google.com" );
+			
+			int res = AEWin32AccessImpl.getSingleton( false ).shellExecuteAndWait(
+				"c:\\temp\\3110\\Vuze_3.1.1.0_windows.exe",
+				"-VFORCE_LAUNCH=1" );
+			
+			System.out.println( "res=" + res );
 			
 		}catch( Throwable e ){
 			
