@@ -29,7 +29,13 @@ package org.gudy.azureus2.plugins;
 public interface 
 PluginEvent 
 {
+	/**
+	 * Not guaranteed to trigger.  Used to be triggered at startup
+	 */
 	public static final int	PEV_CONFIGURATION_WIZARD_STARTS			= 1;
+	/**
+	 * Not guaranteed to trigger.  Used to be triggered at startup
+	 */
 	public static final int	PEV_CONFIGURATION_WIZARD_COMPLETES		= 2;
 	public static final int	PEV_INITIALISATION_PROGRESS_TASK		= 3;
 	public static final int	PEV_INITIALISATION_PROGRESS_PERCENT		= 4;
@@ -56,6 +62,14 @@ PluginEvent
 	
 	public static final int	PEV_ALL_PLUGINS_INITIALISED			= 7;
 
+		/**
+		 * Data is the PluginInterface of installed plugin
+		 * @since 4.1.0.1
+		 */
+	public static final int	PEV_PLUGIN_OPERATIONAL				= 8;
+
+	public static final int	PEV_PLUGIN_NOT_OPERATIONAL			= 9;
+
 		/**
 		 * Plugin specific events can be raised by a plugin to communicate with
 		 * other components. The event type must start from the number below
