@@ -35,17 +35,15 @@ import org.gudy.azureus2.plugins.ipfilter.IPFilter;
 import org.gudy.azureus2.plugins.ddb.DistributedDatabase;
 import org.gudy.azureus2.plugins.download.DownloadManager;
 import org.gudy.azureus2.plugins.torrent.TorrentManager;
-import org.gudy.azureus2.plugins.peers.protocol.PeerProtocolManager;
 import org.gudy.azureus2.plugins.platform.PlatformManager;
 import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.ui.config.Parameter;
 import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 import org.gudy.azureus2.plugins.ui.config.PluginConfigUIFactory;
-import org.gudy.azureus2.plugins.ui.tables.peers.PluginPeerItemFactory;
-import org.gudy.azureus2.plugins.ui.tables.mytorrents.PluginMyTorrentsItemFactory;
 import org.gudy.azureus2.plugins.update.UpdateManager;
 import org.gudy.azureus2.plugins.utils.ShortCuts;
 import org.gudy.azureus2.plugins.clientid.*;
+import org.gudy.azureus2.plugins.dht.mainline.MainlineDHTManager;
 
 
 /**
@@ -54,14 +52,22 @@ import org.gudy.azureus2.plugins.clientid.*;
  */
 public interface PluginInterface {  
 	
-	/** Retrieve the Application's name
-   *
-   * @return the Application's name
-   *
-   * @since 2.1.0.0
-   */
-	public String
-	getAzureusName();
+	/**
+	 * Retrieve the name of the application.
+     *
+     * @return the Application's name
+     *
+     * @since 2.1.0.0
+     */
+	public String getAzureusName();
+	
+	/**
+	 * Returns the name of the application that the user sees - if you need to
+	 * display the name of the program, you should use this method.
+	 * 
+	 * @return 3.0.5.3
+	 */
+	public String getApplicationName();
 	
 	/** Retrieve the Application's version as a string.
 	 *
@@ -98,34 +104,11 @@ public interface PluginInterface {
    * in order to find the localized displayName. (see i18n)
    *
    * @since 2.0.6.0
+   * @deprecated Use of this is discouraged - use {@link UIManager#getBasicPluginViewModel(String)}
+   *     to get a <tt>BasicPluginViewModel</tt> instance, and then use the methods on that to add
+   *     parameters.
    */
   public void addConfigUIParameters(Parameter[] parameters, String displayName);
-  
-  /** (DEPRECATED) Adds a column to the peers table.
-   *
-   * @param columnName the key name of the column
-   * @param factory the factory responsible of creating items.
-   * Azureus will look-up for PeersView.<i>columnName</i> into the lang files
-   * in order to find the localized displayName. (see i18n)
-   *
-   * @since 2.0.6.0
-   *
-   * @deprecated use {@link org.gudy.azureus2.plugins.ui.tables.TableManager}
-   */
-  public void addColumnToPeersTable(String columnName,PluginPeerItemFactory factory);
-  
-  /** (DEPRECATED) Adds a column to the My Torrents table.
-   *
-   * @param columnName the key name of the column
-   * @param factory the factory responsible of creating items.
-   * Azureus will look-up for MyTorrentsView.<i>columnName</i> into the lang files
-   * in order to find the localized displayName. (see i18n)
-   *
-   * @since 2.0.8.0
-   *
-   * @deprecated use {@link org.gudy.azureus2.plugins.ui.tables.TableManager}
-   */
-  public void addColumnToMyTorrentsTable(String columnName, PluginMyTorrentsItemFactory factory);
 
   /**
    * adds a ConfigSection to the config view.<p>
@@ -135,6 +118,7 @@ public interface PluginInterface {
    * @param section ConfigSection to be added to the Config view
    *
    * @since 2.0.8.0
+   * @deprecated Use {@link UIManager#createBasicPluginConfigModel(String)} instead.
    */
 	public void addConfigSection(ConfigSection section);
 
@@ -188,16 +172,6 @@ public interface PluginInterface {
   public DownloadManager
   getDownloadManager();
   
-  /**
-   * Gives access to the peer protocol manager
-   * @return An object that allows management of Peer Protocols
-   * @decprecated 2307 If you want to handle extensions plugin into the announce protocol itself
-   * @since 2.0.7.0
-   */
-  
-  public PeerProtocolManager
-  getPeerProtocolManager();
-  
   /**
    * Gives access to the sharing functionality
    * @return
@@ -285,7 +259,9 @@ public interface PluginInterface {
   public Properties getPluginProperties();
   
   /**
-   * gives access to the plugin installation path
+   * Gives access to the plugin installation path - note, if you want to use this
+   * path to store data files in, it would be better for you to use
+   * {@link PluginConfig#getPluginUserFile(String)} instead.
    * @return the full path the plugin is installed in
    *
    * @since 2.0.4.0
@@ -293,9 +269,7 @@ public interface PluginInterface {
   public String getPluginDirectoryName();
   
   /**
-   * Returns the value of plugin.name if it exists in the properties file, dirctory name otherwise
-   * @return
-   *
+   * Returns the value of "plugin.name" if it exists in the properties file, otherwise the directory name is returned.
    * @since 2.1.0.0
    */
   public String getPluginName();
@@ -323,6 +297,8 @@ public interface PluginInterface {
   	/**
   	 * Whether or not this is a mandatory plugin. Mandatory plugins take priority over update checks, for example,
   	 * over optional ones.
+  	 * 
+  	 * @deprecated Use {@link PluginState#isMandatory()}.
   	 */
   
   public boolean
@@ -330,9 +306,8 @@ public interface PluginInterface {
   
   	/**
   	 * Built-in plugins are those used internally by Azureus, for example the UPnP plugin
-  	 * @return
-  	 */
-  
+  	 * @deprecated Use {@link PluginState#isBuiltIn()}.
+  	 */ 
   public boolean
   isBuiltIn();
   
@@ -344,8 +319,12 @@ public interface PluginInterface {
   
   
   /**
-   * gives acess to the plugin Config UI Factory
+   * gives access to the plugin Config UI Factory
    * @return the PluginConfigUIFactory associated with this plugin
+   * 
+   * @deprecated Use of this is discouraged - use {@link UIManager#getBasicPluginViewModel(String)}
+   *     to get a <tt>BasicPluginViewModel</tt> instance, and then use the methods on that to add
+   *     parameters.
    */
   public PluginConfigUIFactory getPluginConfigUIFactory();
   
@@ -393,44 +372,56 @@ public interface PluginInterface {
   getPlugin();
   
   /**
-   * If a plugin fails to load properly (i.e. the construction of the plugin object
-   * fails) it is marked as non-operational (rather than not being present at all) 
-   * @return whether or not the plugin is operational or not
+   * Returns <tt>true</tt> if the plugin is running, returns <tt>false</tt> if the
+   * plugin isn't running for some reason.
    *
    * @since 2.1.0.0
+   * @deprecated Use {@link PluginState#isOperational()}.
    */
   public boolean
   isOperational();
+  
+  /**
+   * Returns <tt>true</tt> if the plugin has been marked as disabled, and prevented
+   * from initialising.
+   * 
+   * @deprecated Use {@link PluginState#isDisabled}.
+   */
+  public boolean
+  isDisabled();
+  
+  /**
+   * Sets whether the plugin can be loaded or not. If you are trying to affect if the plugin
+   * can be loaded at startup - use {@link #setLoadedAtStartup(boolean)} instead. This needs
+   * to be called prior to a plugin's initialisation to take effect.
+   * 
+   * @since 2.3.0.1
+   * @param disabled
+   * @deprecated Use {@link PluginState#setDisabled(boolean)}.
+   */
+  public void setDisabled(boolean disabled);
+
 
   /**
-   *
+   * @deprecated Use {@link PluginState#isUnloadable()}.
    * @since 2.1.0.0
    */
   public boolean
   isUnloadable();
 
-  /**
-   * @since 2.3.0.1
-   * @param disabled
-   */
   
-  public void
-  setDisabled(
-	boolean	disabled );
-  
-  public boolean
-  isDisabled();
+
   
   /**
    * @since 2503/3005
-   * @return
+   * @deprecated Use {@link PluginState#isShared()}.
    */
   
   public boolean
   isShared();
   
   /**
-   *
+   * @deprecated Use {@link PluginState#unload()}.
    * @since 2.1.0.0
    */  
   public void
@@ -439,7 +430,7 @@ public interface PluginInterface {
   	throws PluginException;
 
   /**
-   *
+   * @deprecated Use {@link PluginState#reload()}.
    * @since 2.1.0.0
    */
   public void
@@ -449,7 +440,8 @@ public interface PluginInterface {
   
   	/**
   	 * Uninstall this plugin if it has been loaded from a plugin directory. Deletes the
-  	 * plugin directory 
+  	 * plugin directory
+     * @deprecated Use {@link PluginState#uninstall()}. 
   	 * @throws PluginException
   	 */
   
@@ -458,6 +450,15 @@ public interface PluginInterface {
   
   	throws PluginException;
   
+  	/**
+  	 * Indicates whether or not the current thread is the one responsible for running
+  	 * plugin initialisation
+  	 * @return
+  	 */
+  
+  public boolean
+  isInitialisationThread();
+  
   /**
    * gives access to the plugin manager
    * @return
@@ -550,4 +551,21 @@ public interface PluginInterface {
   public void
   removeEventListener(
   	PluginEventListener	l );
+  
+  /**
+   * Returns the manager object for registering plugins that connect to the
+   * Mainline DHT.
+   *
+   * @since 3.0.4.3
+   */
+  public MainlineDHTManager getMainlineDHTManager();
+  
+  /**
+   * Returns an object that provides information the current state of the plugin,
+   * and provides various mechanisms to query and control plugins and their
+   * integration with Azureus at a low-level.
+   * 
+   * @since 3.1.1.1
+   */
+  public PluginState getPluginState();
 }
