@@ -42,6 +42,10 @@ TrackerWebContext
 	public URL[]
 	getURLs();
 	
+	public void
+	setEnableKeepAlive(
+		boolean		enable );
+	
 	public void
 	addPageGenerator(
 		TrackerWebPageGenerator	generator );
