@@ -2,7 +2,7 @@
  * Created on 2004/May/23
  * Created by TuxPaper
  * 
- * Copyright (C) 2004 Aelitis SARL, All rights Reserved
+ * Copyright (C) 2004, 2005, 2006 Aelitis SAS, All rights Reserved
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
- * AELITIS, SARL au capital de 30,000 euros,
+ * AELITIS, SAS au capital de 46,603.30 euros,
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  */
 
@@ -25,5 +25,8 @@ package org.gudy.azureus2.plugins.ui;
 
 /** An image to be used in Azureus
  */
-public interface Graphic {
+
+public interface 
+Graphic 
+{
 }
