@@ -1,7 +1,7 @@
 /*
  * Created on 27-Apr-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
@@ -31,6 +31,8 @@ UITextArea
 	extends UIComponent
 
 {
+	public static final int	DEFAULT_MAX_SIZE	= 60000;
+	
 	/**
 	 * Setting values results in a PT_VALUE property change with a String value
 	 * @param precentage
@@ -51,4 +53,14 @@ UITextArea
 	
 	public String
 	getText();
+	
+	/**
+	 * Limits the maximum size of text held by the area. When then size is exceeded the text
+	 * will be truncated (text at the start of the string is removed, NOT the end)
+	 * All areas have a default max size as defined by the constant above
+	 */
+	
+	public void
+	setMaximumSize(
+		int	max_size );
 }
