@@ -32,9 +32,13 @@ public interface
 Parameter
 	extends ConfigParameter
 {
+	public static final int MODE_BEGINNER		= 0;
+	public static final int MODE_INTERMEDIATE	= 1;
+	public static final int MODE_ADVANCED		= 2;
+	
 	/**
 	 * Sets whether the UI object for this parameter is enabled (changeable) or
-	 * disabled (not changeable, and usualy grayed out)
+	 * disabled (not changeable, and usually grayed out)
 	 * 
 	 * @param enabled The new enabled state
 	 * 
@@ -54,9 +58,28 @@ Parameter
 	public boolean
 	isEnabled();
 
+	/** 
+	 * Gets the lowest user mode required for this parameter to be displayed.
+	 * 
+	 * @return MODE_ constants above
+	 * @since 3.0.5.3
+	 */
+	public int
+	getMinimumRequiredUserMode();
 	
 	/**
-	 * Sets whether the UI object for this parameter is visble to the user
+	 * Sets the lowest user mode required for this parameter to be displayed.
+	 * 
+	 * @param mode see MODE_ constants defined above 
+	 * @since 3.0.5.3
+	 */
+	
+	public void
+	setMinimumRequiredUserMode(
+		int		mode );
+	
+	/**
+	 * Sets whether the UI object for this parameter is visible to the user
 	 * 
 	 * @param visible The new visibility state
 	 * 
@@ -76,6 +99,27 @@ Parameter
 	public boolean
 	isVisible();
 	
+	/**
+	 * Controls whether or not 'parameter change' events are fired for each incremental value change
+	 * @param b
+	 * 
+	 * @since 3.0.5.1
+	 */
+	
+	public void
+	setGenerateIntermediateEvents(
+		boolean	b );
+	
+	/**
+	 * 
+	 * @return
+	 * 
+	 * @since 3.0.5.1
+	 */
+	
+	public boolean
+	getGenerateIntermediateEvents();
+	
 	/**
 	 * Adds a listener triggered when the parameter is changed by the user
 	 * 
