@@ -22,18 +22,27 @@
 
 package org.gudy.azureus2.plugins.ui.model;
 
-/**
- * @author parg
- *
- */
-
 import org.gudy.azureus2.plugins.ui.config.*;
 import org.gudy.azureus2.plugins.ui.config.FileParameter;
 
+/**
+ * This object represents a configuration section.
+ *
+ * <p>
+ * 
+ * If you specify "_blank" as a resource name (the label for the parameter),
+ * (or use the {@link #BLANK_RESOURCE} constant defined here), then this will
+ * be a blank label (available since 3.0.5.3).
+ */
 public interface 
 BasicPluginConfigModel 
-	extends PluginConfigModel
-{
+	extends PluginConfigModel {
+	
+	/**
+	 * @since 3.0.5.3
+	 */
+	public String BLANK_RESOURCE = "_blank";
+	
 	/**
 	 * @deprecated use addBooleanParameter2
 	 * @param key
@@ -117,7 +126,7 @@ BasicPluginConfigModel
 	 * @param key
 	 * @param resource_name
 	 * @param values
-	 * @param labels
+	 * @param labels A list of localised message strings corresponding to each value.
 	 * @param defaultValue
 	 * @return
 	 * @since 2.3.0.6
@@ -160,6 +169,24 @@ BasicPluginConfigModel
 		String 		resource_name,
 		int	 		defaultValue );
 
+	/**
+	 * 
+	 * @param key
+	 * @param resource_name
+	 * @param defaultValue
+	 * @param min_value Minimum allowed value
+	 * @param max_value Maximum allowed value
+	 * @return
+	 * @since 3.0.3.5
+	 */
+	public IntParameter
+	addIntParameter2(
+		String 		key,
+		String 		resource_name,
+		int	 		defaultValue,
+		int         min_value,
+		int         max_value);
+	
 	/**
 	 * 
 	 * @param resource_name
@@ -170,6 +197,18 @@ BasicPluginConfigModel
 	addLabelParameter2(
 		String 		resource_name );
 	
+	/**
+	 * @since 4005
+	 * @param resource_name
+	 * @param value
+	 * @return
+	 */
+	
+	public InfoParameter
+	addInfoParameter2(
+		String 		resource_name,
+		String		value );
+
 	/**
 	 * @since 2.5.0.2
 	 */
@@ -231,6 +270,24 @@ BasicPluginConfigModel
 		String 		label_resource_name,
 		String		action_resource_name );
 	
+	/**
+	 * @since 3.0.3.5
+	 * @param key
+	 * @param resource_name
+	 * @param r
+	 * @param g
+	 * @param b
+	 * @return
+	 */
+	public ColorParameter addColorParameter2(String key, String resource_name, int r, int g, int b);
+	
+	/**
+	 * Creates a {@link UIParameter} object to add to this config model object.
+	 * 
+	 * @since 3.0.5.3
+	 */
+	public UIParameter addUIParameter2(UIParameterContext context, String name);
+	
 	/**
 	 * 
 	 * @param resource_name
@@ -267,4 +324,13 @@ BasicPluginConfigModel
 	 */
 	public Parameter[]
 	getParameters();
+	
+	/**
+	 * Sets the name of the configuration model - this is useful in
+	 * situations where the configuration section is being dynamically
+	 * created (perhaps with user input).
+	 * 
+	 * @since 3.0.5.3
+	 */
+	public void setLocalizedName(String name);
 }
