@@ -1,7 +1,7 @@
 /*
  * Created on 28-Apr-2004
  * Created by Paul Gardner
- * Copyright (C) 2004 Aelitis, All Rights Reserved.
+ * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,13 +15,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * 
- * AELITIS, SARL au capital de 30,000 euros
+ * AELITIS, SAS au capital de 46,603.30 euros
  * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
  *
  */
 
 package org.gudy.azureus2.plugins.ui.model;
 
+import org.gudy.azureus2.plugins.PluginInterface;
+
 /**
  * @author parg
  *
@@ -29,4 +31,9 @@ package org.gudy.azureus2.plugins.ui.model;
 public interface 
 PluginConfigModel 
 {
+	public PluginInterface
+	getPluginInterface();
+	
+	public void
+	destroy();
 }
