@@ -44,6 +44,31 @@ Update
 	public String[]
 	getDescription();
 	
+	public String
+	getRelativeURLBase();
+	
+	public void
+	setRelativeURLBase(
+		String	base );
+
+	/**
+	 * 
+	 * @param url URL to load instead of showing the description text)
+	 *
+	 * @since 3.0.1.7
+	 */
+	public void
+	setDescriptionURL(
+		String url);
+	
+	/**
+	 * @return null if no description url
+	 *
+	 * @since 3.0.1.7
+	 */
+	public String 
+	getDesciptionURL();
+
 	public String
 	getNewVersion();
 	
@@ -81,6 +106,12 @@ Update
 	public void
 	cancel();
 	
+	public boolean
+	isCancelled();
+	
+	public boolean
+	isComplete();
+	
 	public UpdateCheckInstance
 	getCheckInstance();
 	
