@@ -40,6 +40,13 @@ ResourceDownloaderAdapter
 	{
 	}
 	
+	public void
+	reportAmountComplete(
+		ResourceDownloader	downloader,
+		long				amount )
+	{	
+	}
+	
 	public void
 	reportActivity(
 		ResourceDownloader	downloader,
