@@ -30,6 +30,14 @@ package org.gudy.azureus2.plugins.utils.xml.rss;
 public interface 
 RSSFeed 
 {
+		/**
+		 * True if this is an Atom feed http://www.w3.org/2005/Atom, RSS otherwise
+		 * @return
+		 */
+	
+	public boolean
+	isAtomFeed();
+	
 		/**
 		 * A feed is composed of one (or more?) channels
 		 * @return
