@@ -30,6 +30,12 @@ SimpleXMLParserDocumentNode
 	public String
 	getName();
 	
+	public String
+	getFullName();
+	
+	public String
+	getNameSpaceURI();
+	
 	public String
 	getValue();
 	
