@@ -169,6 +169,12 @@ PluginInitializer
 					"azbuddy",
 					"true",
 					"false"},
+			{	 PluginManagerDefaults.PID_RSS, 
+					"com.aelitis.azureus.core.rssgen.RSSGeneratorPlugin", 
+					"azintrss", 
+					"azintrss",
+					"true",
+					"false"},
 			/* disable until we can get some tracker admins to work on this
 	   		{	 PluginManagerDefaults.PID_TRACKER_PEER_AUTH, 
 					"com.aelitis.azureus.plugins.tracker.peerauth.TrackerPeerAuthPlugin", 
@@ -1076,6 +1082,33 @@ PluginInitializer
 	      
 	      String pid = plugin_id[0]==null?directory.getName():plugin_id[0];
 	      
+	      if ( pid.endsWith( "_v" )){
+	    	  
+	    	  	// re-verify jar files
+	    	  
+	    	  log( "Re-verifying " + pid );
+	    	  
+	    	  for( int i = 0 ; i < pluginContents.length ; i++){
+	    	    	
+	    	    	File	jar_file = pluginContents[i];
+	    	    	
+	    	    	if ( jar_file.getName().endsWith( ".jar" )){
+	    	    		
+	    	    		try{
+	    	    			log( "    verifying " + jar_file );
+	    	    			
+	    	    			AEVerifier.verifyData( jar_file );
+	    	    			
+	    	    			log( "    OK" );
+	    	    		}catch( Throwable e ){
+	    	    			
+	    	    			log( "    Failed" );
+	    	    			
+	    	    			throw( e );
+	    	    		}
+	    	    	}
+	    	   }
+	      }
 	      Plugin plugin = PluginLauncherImpl.getPreloadedPlugin( plugin_class );
 	      
 	      if ( plugin == null ){
@@ -1190,6 +1223,15 @@ PluginInitializer
     }
   }
   
+  private void
+  log(
+	String	str )
+  {
+	if (Logger.isEnabled()){
+		Logger.log(new LogEvent(LOGID, str ));
+	}
+  }
+  
   public void 
   initialisePlugins() 
   {
