@@ -31,6 +31,7 @@ import org.gudy.azureus2.plugins.dht.mainline.*;
 import org.gudy.azureus2.plugins.logging.Logger;
 import org.gudy.azureus2.plugins.messaging.MessageManager;
 import org.gudy.azureus2.plugins.network.ConnectionManager;
+import org.gudy.azureus2.pluginsimpl.local.deprecate.PluginDeprecation;
 import org.gudy.azureus2.pluginsimpl.local.dht.mainline.*;
 import org.gudy.azureus2.pluginsimpl.local.clientid.ClientIDManagerImpl;
 import org.gudy.azureus2.pluginsimpl.local.ddb.DDBaseImpl;
@@ -41,7 +42,6 @@ import org.gudy.azureus2.pluginsimpl.local.ipfilter.IPFilterImpl;
 import org.gudy.azureus2.pluginsimpl.local.logging.LoggerImpl;
 import org.gudy.azureus2.pluginsimpl.local.messaging.MessageManagerImpl;
 import org.gudy.azureus2.pluginsimpl.local.network.ConnectionManagerImpl;
-import org.gudy.azureus2.pluginsimpl.local.peers.protocol.*;
 import org.gudy.azureus2.pluginsimpl.local.sharing.ShareManagerImpl;
 import org.gudy.azureus2.pluginsimpl.local.torrent.TorrentManagerImpl;
 import org.gudy.azureus2.pluginsimpl.local.tracker.*;
@@ -56,9 +56,6 @@ import org.gudy.azureus2.plugins.ipfilter.IPFilter;
 import org.gudy.azureus2.plugins.tracker.Tracker;
 import org.gudy.azureus2.plugins.ui.config.Parameter;
 import org.gudy.azureus2.plugins.ui.config.PluginConfigUIFactory;
-import org.gudy.azureus2.plugins.ui.tables.peers.PluginPeerItemFactory;
-import org.gudy.azureus2.plugins.ui.tables.mytorrents.PluginMyTorrentsItemFactory;
-import org.gudy.azureus2.plugins.peers.protocol.*;
 import org.gudy.azureus2.plugins.platform.PlatformManager;
 import org.gudy.azureus2.plugins.sharing.*;
 import org.gudy.azureus2.plugins.clientid.ClientIDManager;
@@ -91,21 +88,23 @@ PluginInterfaceImpl
   private Plugin				plugin;
   private PluginInitializer		initialiser;
   private Object				initialiser_key;
-  private ClassLoader			class_loader;
-  private CopyOnWriteList		listeners 		= new CopyOnWriteList();
-  private CopyOnWriteList		event_listeners	= new CopyOnWriteList();
+  protected ClassLoader			class_loader;
+  
+  private CopyOnWriteList<PluginListener>		listeners 				= new CopyOnWriteList<PluginListener>();
+  private Set<PluginListener>					init_complete_fired_set	= new HashSet<PluginListener>();
+  
+  private CopyOnWriteList<PluginEventListener>		event_listeners	= new CopyOnWriteList<PluginEventListener>();
   private String				key;
   private String 				pluginConfigKey;
   private Properties 			props;
   private String 				pluginDir;
   private PluginConfigImpl		config;
   private String				plugin_version;
-  private boolean				operational;
-  private boolean				disabled;
   private Logger				logger;
   private IPCInterfaceImpl		ipc_interface;
-  private List					children		= new ArrayList();
-  private List configSections = new ArrayList();
+  protected List				children		= new ArrayList();
+  private List 					configSections 	= new ArrayList();
+  private PluginStateImpl       state;
   
   /**
    * This is the plugin ID value we were given when we were created.
@@ -145,6 +144,7 @@ PluginInterfaceImpl
     given_plugin_id     = _plugin_id;
     plugin_version		= _plugin_version;
     ipc_interface		= new IPCInterfaceImpl( initialiser, plugin );
+    state               = new PluginStateImpl(this, initialiser);
   }
   
   	public Plugin
@@ -152,18 +152,10 @@ PluginInterfaceImpl
 	{
   		return( plugin );
 	}
-  
-  	protected void
-	setOperational(
-		boolean	b )
-	{
-  		operational	= b;
-  	}
   	
-    public boolean
-    isOperational()
-	{
-    	return( operational );
+    public boolean isOperational() {
+    	PluginDeprecation.call("isOperational", this.given_plugin_id);
+    	return getPluginState().isOperational();
     }
 
   	public Object
@@ -205,6 +197,7 @@ PluginInterfaceImpl
   
   public void addConfigSection(ConfigSection section)
   {
+	// Method is used by autocat.
   	ConfigSectionRepository.getInstance().addConfigSection(section);
   	configSections.add(section);
   }
@@ -223,6 +216,7 @@ PluginInterfaceImpl
    * @deprecated
    */
   public void openTorrentFile(String fileName) {
+	  PluginDeprecation.call("openTorrentFile", this.getPluginID());
 	  try{
 		  getDownloadManager().addDownload( new File(fileName));
 	  }catch( DownloadException e ){
@@ -234,6 +228,7 @@ PluginInterfaceImpl
    * @deprecated
    */
   public void openTorrentURL(String url) {
+	  PluginDeprecation.call("openTorrentURL", this.getPluginID());
 	  try{
 		  getDownloadManager().addDownload( new URL( url ));
 	  }catch( Throwable e ){
@@ -321,40 +316,16 @@ PluginInterfaceImpl
   	return plugin_id_to_use;
   }
 
-  public boolean
-  isMandatory()
-  {
-	String	mand = getPluginProperties().getProperty( "plugin.mandatory");
-	
-	return( mand != null && mand.trim().toLowerCase().equals("true"));
+  public boolean isMandatory() {
+	  PluginDeprecation.call("isMandatory", this.given_plugin_id);
+	  return getPluginState().isMandatory();
   }
   
-  public boolean
-  isBuiltIn()
-  {
-	  String	dir = getPluginDirectoryName();
-	  
-	  if ( dir == null ){
-		  
-		  return( PluginInitializer.isLoadingBuiltin());
-	  }
-	  
-  		return( dir.length() == 0 || getPluginID().equals( "azupdater" ));
-  }
-  
-	public void
-	setDisabled(
-		boolean	_disabled )
-	{
-		disabled	= _disabled;
-	}
-	  
-	public boolean
-	isDisabled()
-	{
-		return( disabled );
-	}
-	
+  public boolean isBuiltIn() {
+	  PluginDeprecation.call("isBuiltIn", this.given_plugin_id);
+	  return getPluginState().isBuiltIn();
+  }  
+
   public Properties getPluginProperties() 
   {
     return(props);
@@ -393,16 +364,6 @@ PluginInterfaceImpl
   	return( pluginConfigKey );
   }
   
-  /** @deprecated Use getUIManager().getTableManager().createColumn */
-  public void addColumnToPeersTable(String columnName, PluginPeerItemFactory item) {
-    Debug.out( "Method PluginInterface::addColumnToPeersTable deprecated. Use getUIManager().getTableManager().createColumn" );
-  }
-  
-  /** @deprecated Use getUIManager().getTableManager().createColumn */
-  public void addColumnToMyTorrentsTable(String columnName, PluginMyTorrentsItemFactory item) {
-	   Debug.out( "Method PluginInterface::addColumnToMyTorrentsTable deprecated. Use getUIManager().getTableManager().createColumn" );
- }
-
   public Tracker getTracker() {
   	return( TrackerImpl.getSingleton());
   }
@@ -471,152 +432,34 @@ PluginInterfaceImpl
   	return( UpdateManagerImpl.getSingleton( initialiser.getAzureusCore()));
   }
 
-  public PeerProtocolManager
-  getPeerProtocolManager()
-  {
-  	return( PeerProtocolManagerImpl.getSingleton());
-  }
-  
-  public boolean
-  isUnloadable()
-  {
-  	String dir = getPluginDirectoryName();
-  	
-  		// mechanism to override unloadability 
-  	
-   	boolean	disable_unload = getPluginProperties().getProperty( "plugin.unload.disabled", "" ).equalsIgnoreCase( "true" );
-  	
-  	if ( disable_unload ){
-  		
-  		return( false );
-  	}
-  	
-		// if not dir based then just test this one
-  	
-  	if ( dir == null || dir.length() == 0 ){
-  		
-  		return(getPlugin() instanceof UnloadablePlugin );
-  	}
-  	
- 	List	pis = PluginInitializer.getPluginInterfaces();
-  	
-  	for (int i=0;i<pis.size();i++){
-  		
-  		PluginInterface	pi = (PluginInterface)pis.get(i);
-  		
-  		String other_dir = pi.getPluginDirectoryName();
-  		
-  		if ( other_dir == null || other_dir.length() == 0 ){
-  			
-  			continue;
-  		}
-  		
-  		if ( dir.equals( other_dir )){
-  			
-  			if ( !(pi.getPlugin() instanceof UnloadablePlugin )){
-  		
-  				return( false );
-  			}  
-  		}
-  	}
-  	
-  	for (int i=0;i<children.size();i++){
-  		
-  		if ( !((PluginInterface)children.get(i)).isUnloadable()){
-  			
-  			return( false );
-  		}
-  	}
-  	
-  	return( true );
-  }
-  
-  public void
-  unload()
-  
-  	throws PluginException
-  {
-  	if ( !isUnloadable()){
-  		
-  		throw( new PluginException( "Plugin isn't unloadable" ));
-  	}
-  	
- 	String dir = getPluginDirectoryName();
-  	
-  		// if not dir based then just test this one
-  	
-  	if ( dir == null || dir.length() == 0 ){
-  		
-		((UnloadablePlugin)getPlugin()).unload();
-			
-		initialiser.unloadPlugin( this );
-		
-  	}else{
-  		
-  			// we must copy the list here as when we unload interfaces they will be
-  			// removed from the original list
-  		
-		List	pis = new ArrayList(PluginInitializer.getPluginInterfaces());
-		 
-		for (int i=0;i<pis.size();i++){
-	  		
-	  		PluginInterfaceImpl	pi = (PluginInterfaceImpl)pis.get(i);
-	  		
-			String other_dir = pi.getPluginDirectoryName();
-	  		
-	  		if ( other_dir == null || other_dir.length() == 0 ){
-	  			
-	  			continue;
-	  		}
-	  		
-	  		if ( dir.equals( other_dir )){
-		  			
-	  			((UnloadablePlugin)pi.getPlugin()).unload();
-	  			
-	  			initialiser.unloadPlugin( pi );
-	  		}
-		}
-  	}
-  	
-  	for (int i=0;i<children.size();i++){
-  		
-  		((PluginInterface)children.get(i)).unload();
-  	}
-  	
-  	setOperational(false);
-
-  	class_loader = null;
-  }
   
   protected void
   unloadSupport()
   {
 	  ipc_interface.unload();
+	  
+	  UIManagerImpl.unload( this );
   }
   
-  public void
-  reload()
-  
-  	throws PluginException
-  {
-	  	// we use the "reload" method to load disabled plugins regardless of whether they are
-	  	// unloadable. If currently disabled then no unloading to do anyway
-	  
-	if ( isUnloadable() || isOperational()){
-		
-	  unload();
-	}
-	  
-  	initialiser.reloadPlugin( this );
+  public boolean isUnloadable() {
+	  PluginDeprecation.call("unloadable", this.given_plugin_id);
+	  return getPluginState().isUnloadable();
+  }
+
+  public void reload() throws PluginException {
+	  PluginDeprecation.call("reload", this.given_plugin_id);
+	  getPluginState().reload();
   }
   
-	public void
-	uninstall()
-	
-		throws PluginException
-	{
-		PluginInstallerImpl.getSingleton(getPluginManager()).uninstall( this );
-	}
+  public void unload() throws PluginException {
+	  PluginDeprecation.call("unload", this.given_plugin_id);
+	  getPluginState().unload();
+  }
+  
+  public void uninstall() throws PluginException {
+	  PluginDeprecation.call("uninstall", this.given_plugin_id);
+	  getPluginState().uninstall();
+  }
 	
 	public boolean
 	isInitialisationThread()
@@ -655,13 +498,13 @@ PluginInterfaceImpl
   protected void
   initialisationComplete()
   {
-	  Iterator it = listeners.iterator();
+	  Iterator<PluginListener> it = listeners.iterator();
 	  
 	  while( it.hasNext()){
 
 		  try{
-			  ((PluginListener)it.next()).initializationComplete();
-
+			  fireInitComplete( it.next());
+			  
 		  }catch( Throwable e ){
 
 			  Debug.printStackTrace( e );
@@ -674,6 +517,27 @@ PluginInterfaceImpl
 	  }
   }
   
+  protected void
+  fireInitComplete(
+	PluginListener		listener )
+  {
+	  synchronized( init_complete_fired_set ){
+		  
+		  if ( init_complete_fired_set.contains( listener )){
+			  
+			  return;
+		  }
+		  
+		  init_complete_fired_set.add( listener );
+	  }
+	  
+	  try {
+	  	listener.initializationComplete();
+	  } catch (Exception e) {
+	  	Debug.out(e);
+	  }
+  }
+  
   protected void
   closedownInitiated()
   {
@@ -800,14 +664,16 @@ PluginInterfaceImpl
 		 return( ipc_interface );
 	 }
 	 
-	public boolean
-	isShared()
-	{
-		String shared_dir 	= FileUtil.getApplicationFile( "plugins" ).toString(); 
-		   
-		String	plugin_dir = getPluginDirectoryName();
-				
-		return( plugin_dir.startsWith( shared_dir ));
+	public boolean isShared() {
+		PluginDeprecation.call("isShared", this.given_plugin_id);
+		return getPluginState().isShared();
+	}
+	
+	
+	// Not exposed in the interface.
+	void setAsFailed() {
+		getPluginState().setDisabled(true);
+		state.failed = true;
 	}
 	
   public void
@@ -818,15 +684,32 @@ PluginInterfaceImpl
   	
   	if ( initialiser.isInitialisationComplete()){
   		
-  		l.initializationComplete();
+  		fireInitComplete( l );
   	}
   }
   
   public void
   removeListener(
-  	PluginListener	l )
+  	final PluginListener	l )
   {
   	listeners.remove(l);
+  	
+  		// we want to remove this ref, but there is a *small* chance that there's a parallel thread firing the complete so
+  		// decrease chance of hanging onto unwanted ref 
+  	
+  	new DelayedEvent( 
+  		"PIL:clear", 10000,
+  		new AERunnable()
+  		{
+  			public void 
+  			runSupport() 
+  			{
+  				synchronized( init_complete_fired_set ){
+  		
+  					init_complete_fired_set.remove(l);
+  				}
+  			}
+  		});
   }
   
   public void
@@ -874,14 +757,31 @@ PluginInterfaceImpl
 				type = "built-in";
 			}
 			
-			writer.println( "type:" + type + ",enabled:" + !isDisabled() + ",operational:" + isOperational());
+			writer.println( "type:" + type + ",enabled:" + !getPluginState().isDisabled() + ",operational:" + getPluginState().isOperational());
 			
 		}finally{
 			
 			writer.exdent();
 		}
 	}
+	
+	public boolean isDisabled() {
+		PluginDeprecation.call("isDisabled", this.given_plugin_id);
+		return getPluginState().isDisabled();
+	}
+	
+	public void setDisabled(boolean disabled) {
+		PluginDeprecation.call("setDisabled", this.given_plugin_id);
+		getPluginState().setDisabled(disabled);
+	}
+	
+	public PluginState getPluginState() {
+		return this.state;
+	}
   
+	PluginStateImpl getPluginStateImpl() {
+		return this.state;
+	}
   
   
   	// unfortunately we need to protect ourselves against the plugin itself trying to set
