@@ -81,7 +81,7 @@ DiskManagerChannelImpl
 	
 	private static final int COMPACT_DELAY	= 32;
 	
-	private static final int MAX_READ_CHUNK	= 64*1024;
+	private static final int MAX_READ_CHUNK_DEFAULT	= 64*1024;
 	
 	private static final Comparator comparator = new
 		Comparator()
@@ -530,6 +530,8 @@ DiskManagerChannelImpl
 		
 		private String	user_agent;
 		
+		private int		max_read_chunk = MAX_READ_CHUNK_DEFAULT;
+		
 		private volatile boolean	cancelled;
 		
 		AESemaphore	wait_sem = new AESemaphore( "DiskManagerChannelImpl:wait" );
@@ -559,9 +561,21 @@ DiskManagerChannelImpl
 		setLength(
 			long		_length )
 		{
+			if ( _length < 0 ){
+				
+				throw( new RuntimeException( "Illegal argument" ));
+			}
+			
 			request_length	= _length;
 		}
 		
+		public void
+		setMaximumReadChunkSize(
+			int 	size )
+		{
+			max_read_chunk = size;
+		}
+		
 		public long
 		getRemaining()
 		{
@@ -689,7 +703,7 @@ DiskManagerChannelImpl
 							
 							if ( available > 0 ){
 								
-								len = (int)( available<MAX_READ_CHUNK?available:MAX_READ_CHUNK);
+								len = (int)available;
 								
 								break;
 							}
@@ -698,6 +712,16 @@ DiskManagerChannelImpl
 					
 					if ( len > 0 ){
 						
+						if ( len > rem ){
+							
+							len = (int)rem;
+						}
+						
+						if ( len > max_read_chunk ){
+						
+							len = max_read_chunk;
+						}
+						
 						DirectByteBuffer buffer = core_file.read( pos, len );
 	
 						inform( new event( new PooledByteBufferImpl( buffer ), pos, len ));
