@@ -24,6 +24,7 @@ package org.gudy.azureus2.pluginsimpl.local.disk;
 
 import java.io.File;
 
+import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.plugins.disk.DiskManagerChannel;
 import org.gudy.azureus2.plugins.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.plugins.download.Download;
@@ -112,6 +113,16 @@ public class DiskManagerFileInfoImpl
 	  return core.getFirstPieceNumber();
 	}
 	
+	public long getPieceSize(){
+		try{
+			return getDownload().getTorrent().getPieceSize();
+		}catch( Throwable e ){
+			
+			Debug.printStackTrace(e);
+			
+			return(0);
+		}
+	}
 	public int getNumPieces() {
 	  return core.getNbPieces();
 	}
@@ -130,9 +141,22 @@ public class DiskManagerFileInfoImpl
 		return( core.getIndex());
 	}
 	
+	public byte[] getDownloadHash() 
+		throws DownloadException 
+	{
+		return( getDownload().getTorrent().getHash());
+	}
+	
 	public Download getDownload()
          throws DownloadException
     {
+		if ( download != null ){
+			
+			return( download );
+		}
+		
+			// not sure why this code is here as we already have the download - leaving in for the moment just in case...
+		
 		return DownloadManagerImpl.getDownloadStatic( core.getDownloadManager());
     }
 	
@@ -148,7 +172,8 @@ public class DiskManagerFileInfoImpl
 		return( new DiskManagerChannelImpl( download, this ));
 	}
 	
-	protected org.gudy.azureus2.core3.disk.DiskManagerFileInfo
+	// not visible to plugin interface
+	public org.gudy.azureus2.core3.disk.DiskManagerFileInfo
 	getCore()
 	{
 		return( core );
