@@ -42,6 +42,7 @@ import org.gudy.azureus2.plugins.torrent.Torrent;
 import org.gudy.azureus2.plugins.torrent.TorrentAttribute;
 
 import org.gudy.azureus2.plugins.peers.*;
+import org.gudy.azureus2.pluginsimpl.local.deprecate.PluginDeprecation;
 import org.gudy.azureus2.pluginsimpl.local.disk.DiskManagerFileInfoImpl;
 import org.gudy.azureus2.pluginsimpl.local.peers.*;
 import org.gudy.azureus2.pluginsimpl.local.torrent.TorrentImpl;
@@ -64,7 +65,6 @@ import org.gudy.azureus2.plugins.download.DownloadStats;
 import org.gudy.azureus2.plugins.download.DownloadException;
 import org.gudy.azureus2.plugins.download.DownloadRemovalVetoException;
 import org.gudy.azureus2.plugins.download.DownloadWillBeRemovedListener;
-import org.gudy.azureus2.plugins.download.session.SessionAuthenticator;
 import org.gudy.azureus2.plugins.download.savelocation.SaveLocationChange;
 
 import org.gudy.azureus2.core3.internat.MessageText;
@@ -109,6 +109,8 @@ DownloadImpl
 	private CopyOnWriteList	activation_listeners = new CopyOnWriteList();
 	private DownloadActivationEvent	activation_state;
 	
+	private HashMap property_to_attribute_map = null;
+	
 	protected
 	DownloadImpl(
 		DownloadManager		_dm )
@@ -265,6 +267,12 @@ DownloadImpl
 		return( download_manager.getErrorDetails());
 	}
 	
+	public long
+	getFlags()
+	{
+		return( download_manager.getDownloadState().getFlags());
+	}
+	
 	public boolean
 	getFlag(
 		long		flag )
@@ -1143,6 +1151,22 @@ DownloadImpl
 	addPropertyListener(
 		DownloadPropertyListener	l )
 	{
+		
+		// Compatibility for the autostop plugin.
+		if ("com.aimedia.stopseeding.core.RatioWatcher".equals(l.getClass().getName())) {
+			
+			// Looking at the source code, this method doesn't actually appear to do anything,
+			// so we can avoid doing anything for now.
+			return;
+			/*
+			if (property_to_attribute_map == null) {property_to_attribute_map = new HashMap(1);}
+			DownloadAttributeListener dal = new PropertyListenerBridge(l);
+			property_to_attribute_map.put(l, dal);
+			this.addAttributeListener(dal, attr, event_type);
+			*/
+		}
+		
+		PluginDeprecation.call("property listener", l);
 		try{
 			tracker_listeners_mon.enter();
 	
@@ -1166,6 +1190,15 @@ DownloadImpl
 	removePropertyListener(
 		DownloadPropertyListener	l )
 	{
+		
+		// Compatibility for the autostop plugin.
+		if ("com.aimedia.stopseeding.core.RatioWatcher".equals(l.getClass().getName())) {
+			
+			// Looking at the source code, this method doesn't actually appear to do anything,
+			// so we can avoid doing anything for now.
+			return;
+		}
+		
 		try{
 			tracker_listeners_mon.enter();
 			
@@ -1672,11 +1705,6 @@ DownloadImpl
   }
   
   
-  public void setSessionAuthenticator( SessionAuthenticator auth ) {
-    //TODO
-  }
-  
-  
  	// Deprecated methods
 
   public int getPriority() {
@@ -1796,4 +1824,15 @@ DownloadImpl
 			 
 	 }
 	 
+	 private static class PropertyListenerBridge implements DownloadAttributeListener {
+		 private DownloadPropertyListener l;
+		 public PropertyListenerBridge(DownloadPropertyListener l) {this.l = l;}
+		 public void attributeEventOccurred(Download d, final TorrentAttribute attr, final int event_type) {
+			 l.propertyChanged(d, new DownloadPropertyEvent() {
+				 public int getType() {return event_type;}
+				 public Object getData() {return attr;}
+			 });
+		 }
+	 }
+	 
 }
\ No newline at end of file
