@@ -157,6 +157,12 @@ DownloadStatsImpl
 		return(DisplayFormatters.formatETA(dm_stats.getETA()));
 	}
 	
+	public long
+	getETASecs()
+	{
+		return( dm_stats.getETA());
+	}
+	
 	public long
 	getHashFails()
 	{		
