@@ -35,6 +35,7 @@ import org.gudy.azureus2.plugins.messaging.MessageException;
 import org.gudy.azureus2.plugins.messaging.generic.GenericMessageConnection;
 import org.gudy.azureus2.plugins.messaging.generic.GenericMessageConnectionListener;
 import org.gudy.azureus2.plugins.messaging.generic.GenericMessageEndpoint;
+import org.gudy.azureus2.plugins.network.RateLimiter;
 import org.gudy.azureus2.plugins.utils.PooledByteBuffer;
 import org.gudy.azureus2.pluginsimpl.local.utils.PooledByteBufferImpl;
 
@@ -68,12 +69,17 @@ GenericMessageConnectionImpl
 	private boolean								incoming;
 	
 	private volatile GenericMessageConnectionAdapter		delegate;
+	private volatile boolean								closing;
 	private volatile boolean								closed;
 	private volatile boolean								connecting;
 	
 	private List	listeners	= new ArrayList();
 
+	private int	connect_method_count;
 	
+	private List				inbound_rls;
+	private List				outbound_rls;
+
 	protected
 	GenericMessageConnectionImpl(
 		MessageManagerImpl				_message_manager,
@@ -84,6 +90,8 @@ GenericMessageConnectionImpl
 		
 		incoming	= true;
 		
+		connect_method_count = 1;
+		
 		delegate.setOwner( this );
 	}
 	
@@ -103,6 +111,8 @@ GenericMessageConnectionImpl
 		stream_crypto	= _stream_crypto;
 		shared_secrets	= _shared_secrets;
 		
+		connect_method_count = endpoint.getConnectionEndpoint().getProtocols().length;
+		
 		incoming	= false;
 	}
 	
@@ -118,12 +128,127 @@ GenericMessageConnectionImpl
 		return( delegate==null?GenericMessageConnectionIndirect.MAX_MESSAGE_SIZE:delegate.getMaximumMessageSize());
 	}
 	
+	public String
+	getType()
+	{
+		if ( delegate == null ){
+			
+			return( "" );
+			
+		}else{
+	
+			return( delegate.getType());
+		}
+	}
+	
+	public int
+	getTransportType()
+	{
+		if ( delegate == null ){
+			
+			return( TT_NONE );
+		}else{
+			
+			return( delegate.getTransportType());
+		}
+	}
+	
+
+	public void
+	addInboundRateLimiter(
+		RateLimiter		limiter )
+	{
+		synchronized( this ){
+			
+			if ( delegate != null ){
+				
+				delegate.addInboundRateLimiter( limiter );
+
+			}else{
+				
+				if ( inbound_rls == null ){
+					
+					inbound_rls = new ArrayList();
+				}
+				
+				inbound_rls.add( limiter );
+			}
+		}
+	}
+	
+	public void
+	removeInboundRateLimiter(
+		RateLimiter		limiter )
+	{
+		synchronized( this ){
+			
+			if ( delegate != null ){
+				
+				delegate.removeInboundRateLimiter( limiter );
+
+			}else{
+				
+				if ( inbound_rls != null ){
+										
+					inbound_rls.remove( limiter );
+				}
+			}
+		}
+	}
+	
+	public void
+	addOutboundRateLimiter(
+		RateLimiter		limiter )
+	{
+		synchronized( this ){
+			
+			if ( delegate != null ){
+				
+				delegate.addOutboundRateLimiter( limiter );
+
+			}else{
+				
+				if ( outbound_rls == null ){
+					
+					outbound_rls = new ArrayList();
+				}
+				
+				outbound_rls.add( limiter );
+			}
+		}
+	}
+	
+	public void
+	removeOutboundRateLimiter(
+		RateLimiter		limiter )
+	{
+		synchronized( this ){
+			
+			if ( delegate != null ){
+				
+				delegate.removeOutboundRateLimiter( limiter );
+
+			}else{
+				
+				if ( outbound_rls != null ){
+										
+					outbound_rls.remove( limiter );
+				}
+			}
+		}
+	}
+	
 	public boolean
 	isIncoming()
 	{
 		return( incoming );
 	}
 	
+	public int
+	getConnectMethodCount()
+	{
+		return( connect_method_count );
+	}
 	
 	public void
 	connect()
@@ -133,6 +258,36 @@ GenericMessageConnectionImpl
 		connect( null );
 	}
 	
+	protected void
+	setDelegate(
+		GenericMessageConnectionAdapter		_delegate )
+	{
+	    synchronized( this ){
+	    	
+			delegate 	= _delegate;
+			
+	    	if ( inbound_rls != null ){
+	    		
+	    		for (int i=0;i<inbound_rls.size();i++){
+	    			
+	    			delegate.addInboundRateLimiter((RateLimiter)inbound_rls.get(i));
+	    		}
+	    		
+	    		inbound_rls = null;
+	    	}
+	    	
+	    	if ( outbound_rls != null ){
+	    		
+	    		for (int i=0;i<outbound_rls.size();i++){
+	    			
+	    			delegate.addOutboundRateLimiter((RateLimiter)outbound_rls.get(i));
+	    		}
+	    		
+	    		inbound_rls = null;
+	    	}
+	    }
+	}
+	
 		/**
 		 * Outgoing connection
 		 * @param initial_data
@@ -204,10 +359,14 @@ GenericMessageConnectionImpl
 				initial_data,
 				new GenericMessageConnectionAdapter.ConnectionListener()
 				{
+					private boolean	connected;
+					
 					public void
 					connectSuccess()
 					{
-						delegate = tcp_delegate;
+						connected	= true;
+						
+						setDelegate( tcp_delegate );
 						
 						if ( closed ){
 							
@@ -231,7 +390,7 @@ GenericMessageConnectionImpl
 					{
 						InetSocketAddress	udp_ep = endpoint.getUDP();
 
-						if ( udp_ep != null ){
+						if ( udp_ep != null && !connected ){
 							
 							initial_data.rewind();
 							
@@ -268,7 +427,7 @@ GenericMessageConnectionImpl
 			final NATTraverser	nat_traverser = message_manager.getNATTraverser();
 			
 			Map	request = new HashMap();
-					
+								
 			nat_traverser.attemptTraversal(
 					message_manager,
 					udp_ep,
@@ -288,6 +447,8 @@ GenericMessageConnectionImpl
 
 							}else{
 								
+								connect_method_count++;
+
 								if ( TEST_TUNNEL ){
 									
 									initial_data.rewind();
@@ -300,10 +461,14 @@ GenericMessageConnectionImpl
 											initial_data,
 											new GenericMessageConnectionAdapter.ConnectionListener()
 											{
+												private boolean	connected;
+												
 												public void
 												connectSuccess()
 												{
-													delegate = udp_delegate;
+													connected	= true;
+													
+													setDelegate( udp_delegate );
 													
 													if ( closed ){
 														
@@ -325,9 +490,16 @@ GenericMessageConnectionImpl
 												connectFailure( 
 													Throwable failure_msg )
 												{
-													initial_data.rewind();
+													if ( connected ){
+														
+														reportFailed( failure_msg );
+														
+													}else{
+														
+														initial_data.rewind();
 	
-													connectTunnel( initial_data, gen_udp, rendezvous, target );
+														connectTunnel( initial_data, gen_udp, rendezvous, target );
+													}
 												}
 											});
 								}
@@ -338,7 +510,7 @@ GenericMessageConnectionImpl
 						failed(
 							int			failure_type )
 						{
-							reportFailed( new Throwable( "UDP connection attempt failed - NAT traversal failed, type=" + failure_type ));
+							reportFailed( new MessageException( "UDP connection attempt failed - NAT traversal failed (" + NATTraversalObserver.FT_STRINGS[ failure_type ] + ")"));
 						}
 						
 						public void
@@ -351,7 +523,7 @@ GenericMessageConnectionImpl
 						public void
 						disabled()
 						{
-							reportFailed( new Throwable( "UDP connection attempt failed as DDB is disabled" ));
+							reportFailed( new MessageException( "UDP connection attempt failed as DDB is disabled" ));
 						}
 					});
 		}else{
@@ -360,10 +532,14 @@ GenericMessageConnectionImpl
 					initial_data,
 					new GenericMessageConnectionAdapter.ConnectionListener()
 					{
+						private boolean	connected;
+						
 						public void
 						connectSuccess()
 						{
-							delegate = udp_delegate;
+							connected	= true;
+							
+							setDelegate( udp_delegate );
 							
 							if ( closed ){
 								
@@ -385,9 +561,16 @@ GenericMessageConnectionImpl
 						connectFailure( 
 							Throwable failure_msg )
 						{
-							initial_data.rewind();
+							if ( connected ){
 								
-							connectUDP( initial_data, udp_ep, true );
+								reportFailed( failure_msg );
+
+							}else{
+								
+								initial_data.rewind();
+									
+								connectUDP( initial_data, udp_ep, true );
+							}
 						}
 					});
 		}
@@ -416,7 +599,7 @@ GenericMessageConnectionImpl
 					public void
 					connectSuccess()
 					{
-						delegate = tunnel_delegate;
+						setDelegate( tunnel_delegate );
 						
 						if ( closed ){
 							
@@ -490,16 +673,25 @@ GenericMessageConnectionImpl
 				
 				buffer.returnToPool();
 				
-				Debug.printStackTrace(f);
+				if ( !( f instanceof MessageException )){
+				
+					Debug.printStackTrace(f);
+				}
 			}
 		}
 		
-		if ( !handled ){
+		if ( !handled && !( closed || closing )){
 			
 			Debug.out( "GenericMessage: incoming message not handled" );
 		}
 	}
 	
+	public void
+	closing()
+	{
+		closing = true;
+	}
+	
 	public void
 	close()
 	
