@@ -91,8 +91,6 @@ public class MessageManagerImpl implements MessageManager, NATTraversalHandler {
                 }
                 
                 public void sentBadChunk( int piece_num, int total_bad_chunks ) { /*nothing*/ }
-                public void addAvailability(boolean[] peerHavePieces) { /*nothing*/ }
-                public void removeAvailability(boolean[] peerHavePieces) { /*nothing*/ }
               });
             }
 
