@@ -280,6 +280,16 @@ ShareResourceImpl
 	delete(
 		boolean	force )
 	
+		throws ShareException, ShareResourceDeletionVetoException
+	{
+		delete( force, true );
+	}
+	
+	public void
+	delete(
+		boolean	force,
+		boolean	fire_listeners )
+	
 		throws ShareException, ShareResourceDeletionVetoException
 	{
 		if ( !force ){
@@ -287,7 +297,7 @@ ShareResourceImpl
 			canBeDeleted();
 		}
 		
-		manager.delete(this);
+		manager.delete( this, fire_listeners );
 	}
 	
 	public abstract boolean
