@@ -57,6 +57,8 @@ TorrentImpl
 	private TOTorrent				torrent;
 	private LocaleUtilDecoder		decoder;
 	
+	private boolean					complete;
+	
 	public
 	TorrentImpl(
 		TOTorrent		_torrent )
@@ -78,7 +80,7 @@ TorrentImpl
 	{
 		String	name = decode( torrent.getName());
 		
-		name = FileUtil.convertOSSpecificChars( name );
+		name = FileUtil.convertOSSpecificChars( name, false );
 
 		return( name );
 	}
@@ -274,7 +276,7 @@ TorrentImpl
 				
 				String	comp = decode(comps[j]);
 			
-				comp = FileUtil.convertOSSpecificChars( comp );
+				comp = FileUtil.convertOSSpecificChars( comp, j != comps.length-1 );
 				
 				name += (j==0?"":File.separator)+comp;
 			}
@@ -532,12 +534,23 @@ TorrentImpl
 
 			download_manager_state.save();
 			
+			complete	= true;
+			
 		}catch( Throwable e ){
 			
 			throw( new TorrentException("encoding selection fails", e ));
 		}
 	}
 	
+	public boolean
+	isComplete()
+	{
+			// TODO: could check the download state too I guess...
+		
+		return( complete );
+	}
+	
+	
   // Pass LogRelation off to core objects
 
 	/* (non-Javadoc)
@@ -553,4 +566,6 @@ TorrentImpl
 	public Object[] getQueryableInterfaces() {
 		return new Object[] { torrent };
 	}
+	
+	public boolean isSimpleTorrent() {return torrent.isSimpleTorrent();}
 }
\ No newline at end of file
