@@ -42,7 +42,7 @@ import org.gudy.azureus2.core3.util.Debug;
 public class 
 TrackerImpl
 	extends		TrackerWCHelper
-	implements 	Tracker, TRHostListener, TRHostAuthenticationListener
+	implements 	Tracker, TRHostListener2, TRHostAuthenticationListener
 {
 	private static TrackerImpl	singleton;
 	private static AEMonitor 		class_mon 	= new AEMonitor( "Tracker" );
@@ -81,7 +81,7 @@ TrackerImpl
 		
 		host		= _host;
 				
-		host.addListener( this );
+		host.addListener2( this );
 	}
 	
 	public String
@@ -90,6 +90,13 @@ TrackerImpl
 		return( host.getName());
 	}
 	
+	public void
+	setEnableKeepAlive(
+		boolean		enable )
+	{
+		Debug.out( "Keep alive setting ignored for tracker" );
+	}
+	
 	public URL[]
 	getURLs()
 	{
@@ -138,7 +145,7 @@ TrackerImpl
 	publish(
 			Torrent _torrent)
 	
-	throws TrackerException
+		throws TrackerException
 	{
 		TorrentImpl	torrent = (TorrentImpl)_torrent;
 		
@@ -379,4 +386,18 @@ TrackerImpl
 			this_mon.exit();
 		}
 	}
+	
+	public void
+	destroy()
+	{
+		super.destroy();
+		
+		auth_listeners.clear();
+
+		host.removeAuthenticationListener( this );
+		
+		listeners.clear();
+		
+		host.close();
+	}
 }
