@@ -27,8 +27,9 @@ package org.gudy.azureus2.pluginsimpl.local.ui.config;
  *
  */
 
-import org.gudy.azureus2.plugins.PluginConfig;
 import org.gudy.azureus2.plugins.ui.config.LabelParameter;
+import org.gudy.azureus2.pluginsimpl.local.PluginConfigImpl;
+
 
 public class 
 LabelParameterImpl 
@@ -37,7 +38,7 @@ LabelParameterImpl
 {
 	public 
 	LabelParameterImpl(
-		PluginConfig 	config,
+		PluginConfigImpl 	config,
 		String 			key, 
 		String 			label)
 	{ 
