@@ -99,6 +99,12 @@ ParameterImpl
 	public void
 	parameterChanged(
 		String		key )
+	{
+		fireParameterChanged();
+	}
+	
+	protected void
+	fireParameterChanged()
 	{
 		// toArray() since listener trigger may remove listeners
 		Object[] listenerArray = listeners.toArray();
