@@ -268,7 +268,7 @@ BasicPluginConfigModelImpl
 		String		resource_name,
 		String		value )
 	{
-		InfoParameterImpl res = new InfoParameterImpl(configobj, key_prefix, resource_name, value );
+		InfoParameterImpl res = new InfoParameterImpl(configobj, resolveKey(resource_name), resource_name, value );
 		
 		parameters.add( res );
 		
@@ -317,7 +317,12 @@ BasicPluginConfigModelImpl
 		
 		for (int i=0;i<_parameters.length;i++){
 			
-			((ParameterImpl)_parameters[i]).setGroup( pg );
+			ParameterImpl parameter = (ParameterImpl)_parameters[i];
+			
+			if ( parameter != null ){
+			
+				parameter.setGroup( pg );
+			}
 		}
 		
 		return( pg );
