@@ -38,6 +38,11 @@ public class
 FormattersImpl
 	implements Formatters
 {
+	public
+	FormattersImpl()
+	{
+	}
+	
 	public String
 	formatByteCountToKiBEtc(
 		long		bytes )
@@ -81,12 +86,22 @@ FormattersImpl
 		return( ByteFormatter.decodeString( str ));
 	}
 	
-	public String
-	formatDate(
-		long		millis )
-	{
-		return( DisplayFormatters.formatDate( millis ));
+	public String formatDate(long millis) {
+		return DisplayFormatters.formatCustomDateTime(millis);
 	}
+
+	public String formatTimeOnly(long millis) {
+		return DisplayFormatters.formatCustomTimeOnly(millis);
+	}
+	
+	public String formatTimeOnly(long millis, boolean with_secs) {
+		return DisplayFormatters.formatCustomTimeOnly(millis, with_secs);
+	}
+
+	public String formatDateOnly(long millis) {
+		return DisplayFormatters.formatCustomDateOnly(millis);
+	}
+
 	
 	public String
 	formatTimeFromSeconds(
@@ -151,16 +166,6 @@ FormattersImpl
 						String	s1 = (String)o1;
 						String	s2 = (String)o2;
 						
-						if ( s1 == null ){
-							
-							return( -1 );
-						}
-						
-						if ( s2 == null ){
-							
-							return( -1 );
-						}
-						
 						int	l1 = s1.length();
 						int	l2 = s2.length();
 								
