@@ -29,6 +29,7 @@ package org.gudy.azureus2.pluginsimpl.local.utils;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.File;
+import java.lang.reflect.Method;
 import java.net.InetAddress;
 import java.net.URL;
 import java.nio.ByteBuffer;
@@ -40,6 +41,7 @@ import org.gudy.azureus2.platform.PlatformManager;
 import org.gudy.azureus2.platform.PlatformManagerFactory;
 import org.gudy.azureus2.plugins.*;
 import org.gudy.azureus2.plugins.utils.*;
+import org.gudy.azureus2.plugins.utils.Utilities.FeatureEnabler;
 import org.gudy.azureus2.plugins.utils.resourcedownloader.*;
 import org.gudy.azureus2.plugins.utils.resourceuploader.ResourceUploaderFactory;
 import org.gudy.azureus2.plugins.utils.search.Search;
@@ -48,6 +50,10 @@ import org.gudy.azureus2.plugins.utils.search.SearchInitiator;
 import org.gudy.azureus2.plugins.utils.search.SearchListener;
 import org.gudy.azureus2.plugins.utils.search.SearchProvider;
 import org.gudy.azureus2.plugins.utils.security.SESecurityManager;
+import org.gudy.azureus2.plugins.utils.subscriptions.Subscription;
+import org.gudy.azureus2.plugins.utils.subscriptions.SubscriptionException;
+import org.gudy.azureus2.plugins.utils.subscriptions.SubscriptionManager;
+import org.gudy.azureus2.plugins.utils.subscriptions.SubscriptionResult;
 import org.gudy.azureus2.plugins.utils.xml.rss.RSSFeed;
 import org.gudy.azureus2.plugins.utils.xml.simpleparser.SimpleXMLParserDocumentException;
 import org.gudy.azureus2.plugins.utils.xml.simpleparser.SimpleXMLParserDocumentFactory;
@@ -86,6 +92,7 @@ import org.gudy.azureus2.core3.util.TimerEvent;
 import org.gudy.azureus2.core3.util.TimerEventPerformer;
 
 import com.aelitis.azureus.core.AzureusCore;
+import com.aelitis.azureus.core.util.CopyOnWriteList;
 import com.aelitis.azureus.core.versioncheck.VersionCheckClient;
 
 public class 
@@ -112,6 +119,8 @@ UtilitiesImpl
 	private static List<searchManager>		search_managers 	= new ArrayList<searchManager>();
 	private static List<Object[]>			search_providers	= new ArrayList<Object[]>();
 	
+	private static CopyOnWriteList<FeatureEnabler>	feature_enablers = new CopyOnWriteList<FeatureEnabler>();
+	
 	public
 	UtilitiesImpl(
 		AzureusCore			_core,
@@ -890,6 +899,15 @@ UtilitiesImpl
 		FileUtil.writeResilientFile( parent_dir, file_name, data, use_backup );
 	}
 
+	public void
+ 	deleteResilientBEncodedFile(
+ 		File	parent_dir,
+ 		String	file_name,
+ 		boolean	use_backup )
+	{
+		FileUtil.deleteResilientFile( new File( parent_dir, file_name ));
+	}
+	
 	public int compareVersions(String v1, String v2) {
 		return Constants.compareVersions( v1, v2 );
 	}
@@ -1037,6 +1055,48 @@ UtilitiesImpl
 		}
 	}
 	
+	public boolean 
+	isFeatureEnabled(
+		String 					feature_id,
+		Map<String, Object> 	feature_properties) 
+	{
+		String pid = pi.getPluginID();
+		
+		if ( !pid.endsWith( "_v" )){
+			
+			return( false );
+		}
+		
+		for ( FeatureEnabler fe: feature_enablers ){
+			
+			if ( fe.isFeatureEnabled( pid, feature_id, feature_properties)){
+				
+				return( true );
+			}
+		}
+		
+		return false;
+	}
+	
+	public void
+	registerFeatureEnabler(
+		FeatureEnabler	enabler )
+	{
+		if ( !pi.getPluginID().endsWith( "_v" )){
+						
+			return;
+		}
+		
+		feature_enablers.add( enabler );
+	}
+	
+	public void
+	unregisterFeatureEnabler(
+		FeatureEnabler	enabler )
+	{
+		feature_enablers.remove( enabler );
+	}
+	
 	public interface
 	searchManager
 		extends SearchInitiator
@@ -1048,6 +1108,134 @@ UtilitiesImpl
 	}
 		
 	
+	public SubscriptionManager 
+	getSubscriptionManager() 
+	
+		throws SubscriptionException
+	{
+		try{
+			Method m = Class.forName( "com.aelitis.azureus.core.subs.SubscriptionManagerFactory" ).getMethod( "getSingleton" );
+			
+			final PluginSubscriptionManager sm = (PluginSubscriptionManager)m.invoke( null );
+			
+			return( 
+				new SubscriptionManager()
+				{
+					public Subscription[] 
+					getSubscriptions() 
+					{
+						PluginSubscription[] p_subs = sm.getSubscriptions( true );
+						
+						Subscription[]	subs = new Subscription[ p_subs.length ];
+						
+						for ( int i=0;i<subs.length;i++ ){
+							
+							final PluginSubscription p_sub = p_subs[i];
+							
+							subs[i] = 
+								new Subscription()
+								{
+									public String 
+									getID() 
+									{
+										return( p_sub.getID());
+									}
+									
+									public String 
+									getName() 
+									{
+										return( p_sub.getName());
+									}
+									
+									public SubscriptionResult[] 
+									getResults() 
+									{
+										PluginSubscriptionResult[] p_results = p_sub.getResults( false );
+										
+										SubscriptionResult[] results = new SubscriptionResult[p_results.length];
+										
+										for (int i=0;i<results.length;i++){
+											
+											final PluginSubscriptionResult p_res = p_results[i];
+											
+											results[i] = 
+												new SubscriptionResult()
+												{
+													private Map<Integer,Object> map = p_res.toPropertyMap();
+													
+													public Object
+													getProperty(
+														int		property_name )
+													{
+														return( map.get( property_name ));
+													}
+													
+													public boolean
+													isRead()
+													{
+														return( p_res.getRead());
+													}
+													
+													public void
+													setRead(
+														boolean	read )
+													{
+														p_res.setRead( read );
+													}
+												};
+										}
+										
+										return( results );
+									}
+								};
+						}
+					
+						return( subs );
+					}
+				});
+			
+		}catch( Throwable e ){
+			
+			throw( new SubscriptionException( "Subscriptions unavailable", e ));
+		}
+	}
+	
+	public interface
+	PluginSubscriptionManager
+	{
+		public PluginSubscription[]
+		getSubscriptions(
+			boolean	subscribed_only );
+	}
+	
+	public interface
+	PluginSubscription
+	{
+		public String
+		getID();
+		
+		public String
+		getName();
+		
+		public PluginSubscriptionResult[]
+		getResults(
+			boolean		include_deleted );
+	}
+	
+	public interface
+	PluginSubscriptionResult
+	{
+		public Map<Integer,Object>
+		toPropertyMap();
+		
+		public void
+		setRead(
+			boolean		read );
+		
+		public boolean
+		getRead();
+	}
+	
 	public interface
 	runnableWithReturn<T>
 	{
