@@ -28,6 +28,8 @@ package org.gudy.azureus2.pluginsimpl.local.utils.resourcedownloader;
  */
 
 import java.io.File;
+import java.net.MalformedURLException;
+import java.net.URI;
 import java.net.URL;
 import java.util.*;
 
@@ -39,8 +41,16 @@ public class
 ResourceDownloaderFactoryImpl
 	implements ResourceDownloaderFactory
 {
+
 	private static final LogIDs LOGID = LogIDs.CORE;
 	protected static ResourceDownloaderFactoryImpl	singleton = new ResourceDownloaderFactoryImpl();
+
+	// A list of SourceForge mirrors.
+	private static final String[] SF_MIRRORS = new String[] {
+		"jaist", "nchc", "keihanna", "optusnet", "peterhost", "ovh", "puzzle",
+		"switch", "mesh", "kent", "surfnet", "heanet", "citkit", "internap",
+		"cogent", "umn", "easynews", "ufpr"
+	};
 	
 	public static ResourceDownloaderFactory
 	getSingleton()
@@ -60,7 +70,27 @@ ResourceDownloaderFactoryImpl
 	create(
 		URL		url )
 	{
-		return( new ResourceDownloaderURLImpl( null, url ));
+		if ( url.getProtocol().equalsIgnoreCase("file")){
+			
+			try{
+				return( new ResourceDownloaderFileImpl( null, new File( new URI( url.toString()))));
+			
+			}catch( Throwable e ){
+				
+				return( new ResourceDownloaderURLImpl( null, url ));
+			}
+		}else{
+			
+			return( new ResourceDownloaderURLImpl( null, url ));
+		}
+	}
+	
+	public ResourceDownloader create(URL url, boolean force_no_proxy) {
+		ResourceDownloader rd = create(url);
+		if (force_no_proxy && rd instanceof ResourceDownloaderURLImpl) {
+			((ResourceDownloaderURLImpl)rd).setForceNoProxy(force_no_proxy);
+		}
+		return rd;
 	}
 	
 	public ResourceDownloader
@@ -214,4 +244,20 @@ ResourceDownloaderFactoryImpl
 			return( _downloader );
 		}
 	}
+	
+	public ResourceDownloader[] getSourceforgeDownloaders(String project_name, String filename) {
+		String template = "http://%s.dl.sourceforge.net/sourceforge/" + project_name + "/" + filename;
+		ResourceDownloader[] result = new ResourceDownloader[SF_MIRRORS.length];
+		
+		for (int i=0; i<result.length; i++) {
+			String url = template.replaceFirst("%s", SF_MIRRORS[i]);
+			try {result[i] = create(new URL(url));}
+			catch (MalformedURLException me) {throw new RuntimeException(me);}
+		}
+		return result;
+	}
+	
+	public ResourceDownloader getSourceforgeDownloader(String project_name, String filename) {
+		return getRandomDownloader(getSourceforgeDownloaders(project_name, filename));
+	}
 }
