@@ -108,10 +108,12 @@ ResourceDownloaderMetaRefreshImpl
 		}
 	}
 	
-	protected void
+	public void
 	setProperty(
 		String	name,
 		Object	value )
+	
+		throws ResourceDownloaderException
 	{
 		setPropertySupport( name, value );
 		
@@ -230,7 +232,7 @@ ResourceDownloaderMetaRefreshImpl
 		try{
 			this_mon.enter();
 		
-			result	= new ResourceDownloaderException( "Download cancelled");
+			result	= new ResourceDownloaderCancelledException();
 			
 			cancelled	= true;
 			
@@ -262,7 +264,7 @@ ResourceDownloaderMetaRefreshImpl
 				
 				boolean	marked = false;
 				
-				if ( data instanceof ByteArrayInputStream){
+				if ( data.markSupported()){
 				
 					data.mark(data.available());
 					
