@@ -126,10 +126,12 @@ ResourceDownloaderRetryImpl
 		}
 	}
 	
-	protected void
+	public void
 	setProperty(
 		String	name,
 		Object	value )
+	
+		throws ResourceDownloaderException
 	{
 		setPropertySupport( name, value );
 		
@@ -207,7 +209,7 @@ ResourceDownloaderRetryImpl
 		try{
 			this_mon.enter();
 		
-			result	= new ResourceDownloaderException( "Download cancelled");
+			result	= new ResourceDownloaderCancelledException();
 			
 			cancelled	= true;
 			
