@@ -37,9 +37,10 @@ import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.plugins.utils.resourcedownloader.*;
 import org.gudy.azureus2.plugins.download.*;
 import org.gudy.azureus2.pluginsimpl.local.torrent.*;
-import org.gudy.azureus2.pluginsimpl.local.tracker.TrackerWebPageResponseImpl;
 import org.gudy.azureus2.pluginsimpl.local.*;
 
+import com.aelitis.azureus.core.util.HTTPUtils;
+
 public class 
 ResourceDownloaderTorrentImpl 	
 	extends 	ResourceDownloaderBaseImpl
@@ -126,10 +127,12 @@ ResourceDownloaderTorrentImpl
 		}
 	}
 	
-	protected void
+	public void
 	setProperty(
 		String	name,
 		Object	value )
+	
+		throws ResourceDownloaderException
 	{
 		setPropertySupport( name, value );
 		
@@ -185,7 +188,7 @@ ResourceDownloaderTorrentImpl
 				}
 				
 				setProperty( 	ResourceDownloader.PR_STRING_CONTENT_TYPE,
-								TrackerWebPageResponseImpl.guessContentTypeFromFileType( file_type ));
+								HTTPUtils.guessContentTypeFromFileType( file_type ));
 				
 			}catch( Throwable e ){
 				
@@ -293,15 +296,19 @@ ResourceDownloaderTorrentImpl
 			
 			final File	data_dir		= download_dir==null?torrent_file.getParentFile():download_dir;
 			
-			torrent_holder[0].serialiseToBEncodedFile( torrent_file );
-						
+			final TOTorrent	torrent = torrent_holder[0];
+			
+			TorrentUtils.setFlag( torrent, TorrentUtils.TORRENT_FLAG_LOW_NOISE, true );
+
+			torrent.serialiseToBEncodedFile( torrent_file );
+				
 			if ( persistent ){
 				
-				download = download_manager.addDownload( new TorrentImpl(torrent_holder[0]), torrent_file, data_dir );
+				download = download_manager.addDownload( new TorrentImpl(torrent), torrent_file, data_dir );
 				
 			}else{
 				
-				download = download_manager.addNonPersistentDownload( new TorrentImpl(torrent_holder[0]), torrent_file, data_dir );
+				download = download_manager.addNonPersistentDownload( new TorrentImpl(torrent), torrent_file, data_dir );
 			}
 			
 			download.moveTo(1);		
@@ -336,7 +343,7 @@ ResourceDownloaderTorrentImpl
 				{
 					public void
 					stateChanged(
-						Download		download,
+						final Download		download,
 						int				old_state,
 						int				new_state )
 					{		
@@ -346,7 +353,12 @@ ResourceDownloaderTorrentImpl
 							
 							download.removeListener( this );
 							
-							downloadSucceeded( download, torrent_file, data_dir );
+							PluginInitializer.getDefaultInterface().getUtilities().createThread("resource complete event dispatcher", new Runnable() {
+								public void run() {
+									downloadSucceeded( download, torrent_file, data_dir );
+								}
+							});
+							
 						}
 					}
 
@@ -371,7 +383,7 @@ ResourceDownloaderTorrentImpl
 														
 							int	this_percentage = download.getStats().getCompleted()/10;
 							
-							long	total	= torrent_holder[0].getSize();
+							long	total	= torrent.getSize();
 														
 							if ( this_percentage != last_percentage ){
 								
@@ -480,7 +492,7 @@ ResourceDownloaderTorrentImpl
 		try{
 			this_mon.enter();
 		
-			result	= new ResourceDownloaderException( "Download cancelled");
+			result	= new ResourceDownloaderCancelledException();
 			
 			cancelled	= true;
 			
