@@ -21,6 +21,8 @@
 
 package org.gudy.azureus2.pluginsimpl.remote;
 
+import org.gudy.azureus2.plugins.config.PluginConfigSource;
+
 /**
  * @author parg
  *
@@ -532,4 +534,68 @@ RPPluginConfig
 		public boolean hasParameter(String x) {notSupported(); return false;}
 		public boolean hasPluginParameter(String x) {notSupported(); return false;}
 		public boolean removePluginParameter(String x) {notSupported(); return false;}
+		public boolean removePluginColorParameter(String x) {notSupported(); return false;}
+		
+		  public byte[] getByteParameter(String key) {notSupported(); return null;}
+		  public float getFloatParameter(String key, float default_value) {notSupported(); return 0;}
+		  public long getLongParameter(String key) {notSupported(); return 0;}
+		  public long getLongParameter(String key, long default_value) {notSupported(); return 0;}
+		  public void setByteParameter(String key, byte[] value) {notSupported();}
+		  public void setFloatParameter(String key, float value) {notSupported();}
+		  public void setLongParameter(String key, long value) {notSupported();}
+		  public void setStringParameter(String key, String value) {notSupported();}
+		  public byte[] getPluginByteParameter(String key) {notSupported(); return null;}
+		  public float getPluginFloatParameter(String key) {notSupported(); return 0;}
+		  public float getPluginFloatParameter(String key, float default_value) {notSupported(); return 0;}
+		  public long getPluginLongParameter(String key) {notSupported(); return 0;}
+		  public long getPluginLongParameter(String key, long default_value) {notSupported(); return 0;}
+		  public void setPluginParameter(String key, float value) {notSupported();}
+		  public void setPluginParameter(String key, long value) {notSupported();}
+		  public boolean getUnsafeBooleanParameter(String key) {notSupported(); return false;}
+		  public byte[] getUnsafeByteParameter(String key) {notSupported(); return null;}
+		  public byte[] getUnsafeByteParameter(String key, byte[] default_value) {notSupported(); return null;}
+		  public float getUnsafeFloatParameter(String key) {notSupported(); return 0;}
+		  public int getUnsafeIntParameter(String key) {notSupported(); return 0;}
+		  public long getUnsafeLongParameter(String key) {notSupported(); return 0;}
+		  public String getUnsafeStringParameter(String key) {notSupported(); return null;}
+		  public void setUnsafeByteParameter(String key, byte[] value) {notSupported();}
+
+		  public boolean getCoreBooleanParameter(String key) {notSupported(); return false;}
+		  public boolean getCoreBooleanParameter(String key, boolean default_value) {notSupported(); return false;}
+		  public byte[] getCoreByteParameter(String key, byte[] default_value) {notSupported(); return null;}
+		  public byte[] getCoreByteParameter(String key) {notSupported(); return null;}
+		  public float getCoreFloatParameter(String key) {notSupported(); return 0;}
+		  public float getCoreFloatParameter(String key, float default_value) {notSupported(); return 0;}
+		  public int getCoreIntParameter(String key) {notSupported(); return 0;}
+		  public int getCoreIntParameter(String key, int default_value) {notSupported(); return 0;}
+		  public String getCoreStringParameter(String key) {notSupported(); return null;}
+		  public String getCoreStringParameter(String key, String default_value) {notSupported(); return null;}
+		  public long getCoreLongParameter(String key) {notSupported(); return 0;}
+		  public long getCoreLongParameter(String key, long default_value) {notSupported(); return 0;}
+		  public void setCoreBooleanParameter(String key, boolean value) {notSupported();}
+		  public void setCoreByteParameter(String key, byte[] value) {notSupported();}
+		  public void setCoreFloatParameter(String key, float value) {notSupported();}
+		  public void setCoreIntParameter(String key, int value) {notSupported();}
+		  public void setCoreLongParameter(String key, long value) {notSupported();}
+		  public void setCoreStringParameter(String key, String value) {notSupported();}
+		  
+		  public int[] getCoreColorParameter(String key) {notSupported(); return null;}
+		  public int[] getCoreColorParameter(String key, int[] default_value) {notSupported(); return null;}
+		  public void setCoreColorParameter(String key, int[] value) {notSupported();}
+		  public void setCoreColorParameter(String key, int[] value, boolean override) {notSupported();}
+		  public int[] getPluginColorParameter(String key) {notSupported(); return null;}
+		  public int[] getPluginColorParameter(String key, int[] default_value) {notSupported(); return null;}
+		  public int[] getPluginColorParameter(String key, int[] default_value, boolean override) {notSupported(); return null;}
+		  public void setPluginColorParameter(String key, int[] value) {notSupported();}
+		  public void setPluginColorParameter(String key, int[] value, boolean override) {notSupported();}
+		  public int[] getUnsafeColorParameter(String key) {notSupported(); return null;}
+		  public int[] getUnsafeColorParameter(String key, int[] default_value) {notSupported(); return null;}
+		  public void setUnsafeColorParameter(String key, int[] default_value) {notSupported();}
+		  public void setUnsafeColorParameter(String key, int[] default_value, boolean override) {notSupported();}
+		  public PluginConfigSource getPluginConfigSource() {notSupported(); return null;}
+		  public void setPluginConfigSource(PluginConfigSource source) {notSupported();}
+		  public PluginConfigSource enableExternalConfigSource() {notSupported(); return null;}
+		  
+		  public void setPluginStringListParameter(String key, String[] value)  {notSupported();}
+		  public String[] getPluginStringListParameter(String key)  {notSupported(); return null;}
 }
