@@ -43,15 +43,12 @@ import org.gudy.azureus2.plugins.clientid.ClientIDManager;
 import org.gudy.azureus2.plugins.ddb.DistributedDatabase;
 import org.gudy.azureus2.plugins.dht.mainline.MainlineDHTManager;
 import org.gudy.azureus2.plugins.download.DownloadManager;
-import org.gudy.azureus2.plugins.peers.protocol.PeerProtocolManager;
 import org.gudy.azureus2.plugins.platform.PlatformManager;
 import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.update.*;
 import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 import org.gudy.azureus2.plugins.ui.config.Parameter;
 import org.gudy.azureus2.plugins.ui.config.PluginConfigUIFactory;
-import org.gudy.azureus2.plugins.ui.tables.peers.PluginPeerItemFactory;
-import org.gudy.azureus2.plugins.ui.tables.mytorrents.PluginMyTorrentsItemFactory;
 
 import org.gudy.azureus2.core3.util.Constants;
 
@@ -241,16 +238,6 @@ RPPluginInterface
 	{
 		notSupported();
 	}
-	
-	public void addColumnToPeersTable(String columnName,PluginPeerItemFactory factory)
-	{
-		notSupported();
-	}
-
-    public void addColumnToMyTorrentsTable(String columnName, PluginMyTorrentsItemFactory factory)
-    {
-    	notSupported();
-    }
 
 	public void addConfigSection(ConfigSection tab)
 	{
@@ -300,14 +287,6 @@ RPPluginInterface
 	}
 	
 	
-	public PeerProtocolManager
-	getPeerProtocolManager()
-	{
-		notSupported();
-		
-		return( null );
-	}
-	
 	public ShareManager
 	getShareManager()
 	
@@ -623,4 +602,6 @@ RPPluginInterface
 	}
 	
 	public MainlineDHTManager getMainlineDHTManager() {notSupported(); return null;}
+	public PluginState getPluginState() {notSupported(); return null;}
+	
 }
