@@ -31,7 +31,6 @@ import java.util.*;
 import org.gudy.azureus2.plugins.*;
 import org.gudy.azureus2.plugins.logging.*;
 import org.gudy.azureus2.plugins.ipfilter.*;
-import org.gudy.azureus2.pluginsimpl.remote.download.*;
 import org.gudy.azureus2.pluginsimpl.remote.rpexceptions.*;
 
 public class
@@ -40,19 +39,9 @@ RPRequestHandler
     protected PluginInterface   plugin_interface;
 
     protected Map   reply_cache = new HashMap();
-    protected boolean generic_classes;
     
     public RPRequestHandler(PluginInterface _pi) {
-    	this(_pi, false);
-    }
-
-    public
-    RPRequestHandler(
-        PluginInterface     _pi,
-        boolean use_generic_classes)
-    {
-        plugin_interface    = _pi;
-        generic_classes = use_generic_classes;
+    	this.plugin_interface = _pi;
     }
 
     public RPReply
@@ -62,6 +51,10 @@ RPRequestHandler
         return( processRequest( request, null));
     }
 
+    /**
+     * We no longer allow null to be returned, you will have to return a new RPReply instance
+     * which contains null instead.
+     */
     public RPReply
     processRequest(
         RPRequest                   request,
@@ -80,6 +73,7 @@ RPRequestHandler
         }
 
         RPReply reply = processRequestSupport( request, access_controller );
+        if (reply == null) {reply = new RPReply(null);}
         reply_cache.put( connection_id, new replyCache( request.getRequestId(), reply ));
 
         return( reply );
@@ -95,25 +89,13 @@ RPRequestHandler
             String          method  = request.getMethod();
 
             if ( object == null && method.equals("getSingleton")){
-                RPObject pi = null;
-                if (this.generic_classes) {
-                    pi = GenericRPPluginInterface.create(plugin_interface);
-                }
-                else {
-                    pi = RPPluginInterface.create(plugin_interface);
-                }
+                RPObject pi = request.createRemotePluginInterface(plugin_interface);
                 RPReply reply = new RPReply(pi);
                 return( reply );
 
             }else if ( object == null && method.equals( "getDownloads")){
 
-                RPPluginInterface pi = null;
-                if (this.generic_classes) {
-                    pi = GenericRPPluginInterface.create(plugin_interface);
-                }
-                else {
-                    pi = RPPluginInterface.create(plugin_interface);
-                }
+                RPPluginInterface pi = request.createRemotePluginInterface(plugin_interface);
 
                     // short cut method for quick access to downloads
                     // used by GTS
