@@ -28,8 +28,10 @@ package org.gudy.azureus2.pluginsimpl.remote.download;
 
 import java.io.*;
 import java.net.*;
+import java.util.Map;
 
 import org.gudy.azureus2.plugins.download.*;
+import org.gudy.azureus2.plugins.download.savelocation.*;
 import org.gudy.azureus2.plugins.torrent.*;
 
 import org.gudy.azureus2.pluginsimpl.remote.*;
@@ -223,6 +225,14 @@ RPDownloadManager
 		notSupported();
 	}
 	
+	public void 
+	addDownload(
+		URL 		url, 
+		Map 		request_properties) 
+	{
+		notSupported();
+	}
+	
 	public Download
 	addDownload(
 		Torrent		torrent )
@@ -280,6 +290,19 @@ RPDownloadManager
 		}	
 	}
 	
+	public Download
+	addDownloadStopped(
+		Torrent		torrent,
+		File		torrent_location,
+		File		data_location )
+	
+		throws DownloadException
+	{
+		notSupported();
+		
+		return( null );
+	}
+	
 	public Download
 	addNonPersistentDownload(
 		Torrent		torrent,
@@ -401,6 +424,9 @@ RPDownloadManager
 		notSupported();
 	}
 	
+	public void addListener(DownloadManagerListener	l, boolean notify) {
+		notSupported();
+	}
 	
 	public void
 	removeListener(
@@ -408,6 +434,10 @@ RPDownloadManager
 	{
 		notSupported();
 	}	
+
+	public void removeListener(DownloadManagerListener	l, boolean notify) {
+		notSupported();
+	}
 	
 	public void
 	addDownloadWillBeAddedListener(
@@ -422,4 +452,24 @@ RPDownloadManager
 	{
 		notSupported();
 	}
+	
+	public DownloadEventNotifier getGlobalDownloadEventNotifier() {
+		notSupported();
+		return null;
+	}
+	
+	public void setSaveLocationManager(SaveLocationManager manager) {
+		notSupported();
+	}
+	
+	public SaveLocationManager getSaveLocationManager() {
+		notSupported();
+		return null;
+	}	
+
+	public DefaultSaveLocationManager getDefaultSaveLocationManager() {
+		notSupported();
+		return null;
+	}
+	
 }
\ No newline at end of file
