@@ -388,4 +388,13 @@ RPTorrent
 	{
 		notSupported();
 	}
+	
+	public boolean
+	isComplete()
+	{
+		notSupported();
+		
+		return( false );
+	}
+	public boolean isSimpleTorrent() {notSupported(); return false;} 
 }
