@@ -56,14 +56,16 @@ PluginUpdatePlugin
 	implements Plugin
 {
 	private static final String PLUGIN_CONFIGSECTION_ID = "plugins.update";
+	private static final String PLUGIN_RESOURCE_ID		= "ConfigView.section.plugins.update";
 
 	public static final int	RD_SIZE_RETRIES	= 3;
 	public static final int	RD_SIZE_TIMEOUT	= 10000;
 		
-	protected PluginInterface		plugin_interface;
-	protected SFPluginDetailsLoader	loader;
-	protected LoggerChannel 		log;
+	private PluginInterface		plugin_interface;
+	private LoggerChannel 		log;
 		
+	private boolean	loader_listener_added;
+	
 	private String	last_id_info	= "";
 		
 	public void
@@ -80,8 +82,7 @@ PluginUpdatePlugin
 		UIManager	ui_manager = plugin_interface.getUIManager();
 		
 		final BasicPluginViewModel model = 
-			ui_manager.createBasicPluginViewModel( 
-					"Plugin Update");
+			ui_manager.createBasicPluginViewModel( PLUGIN_RESOURCE_ID );
 		
 		final PluginConfig	plugin_config = plugin_interface.getPluginconfig();
 		
@@ -112,24 +113,31 @@ PluginUpdatePlugin
 				}
 			});
 		
-		loader = SFPluginDetailsLoaderFactory.getSingleton();
-		
-		loader.addListener( 
-			new SFPluginDetailsLoaderListener()
-			{
-				public void
-				log(
-					String	str )
-				{
-					log.log( LoggerChannel.LT_INFORMATION, "[" + str + "]" );
-					
-				}
-			});
-				
 		BasicPluginConfigModel config = ui_manager.createBasicPluginConfigModel(ConfigSection.SECTION_PLUGINS, PLUGIN_CONFIGSECTION_ID);
 		
 		config.addBooleanParameter2( "enable.update", "Plugin.pluginupdate.enablecheck", true );
 				
+		plugin_interface.addEventListener(
+			new PluginEventListener()
+			{
+				public void 
+				handleEvent(
+					PluginEvent 	ev ) 
+				{
+					if ( ev.getType() == PluginEvent.PEV_ALL_PLUGINS_INITIALISED ){
+						
+						plugin_interface.removeEventListener( this );
+						
+						initComplete( plugin_config );
+					}
+				}
+			});
+	}
+	
+	protected void
+	initComplete(
+		final PluginConfig		plugin_config )
+	{
 		UpdateManager	update_manager = plugin_interface.getUpdateManager();
 		
 		update_manager.addListener(
@@ -155,7 +163,7 @@ PluginUpdatePlugin
 			
 			PluginInterface	pi = plugins[i];
 						
-			boolean	pi_mandatory = pi.isMandatory();
+			boolean	pi_mandatory = pi.getPluginState().isMandatory();
 						
 			if ( pi_mandatory ){
 					
@@ -199,7 +207,7 @@ PluginUpdatePlugin
 							
 							String	rp_id = rps[i];
 							
-							if ( plugin_manager.getPluginInterfaceByID( rp_id ) != null ){
+							if ( plugin_manager.getPluginInterfaceByID( rp_id, false ) != null ){
 								
 									// already installed
 								
@@ -362,16 +370,21 @@ PluginUpdatePlugin
 				
 			List	plugins_to_check 			= new ArrayList();
 			List	plugins_to_check_ids		= new ArrayList();
-			Map		plugins_to_check_unloadable = new HashMap();
 			Map		plugins_to_check_names		= new HashMap();
 			
 			for (int i=0;i<plugins.length;i++){
 				
 				PluginInterface	pi = plugins[i];
 				
-				if ( pi.isDisabled()){
+				if ( pi.getPluginState().isDisabled()){
 					
-					continue;
+						// if it is disabled because it failed to load, carry on and check for updates as the newer version
+						// may be there to fix the load failure!
+					
+					if ( !pi.getPluginState().hasFailed()){
+						
+						continue;
+					}
 				}
 				
 				String	mand = pi.getPluginProperties().getProperty( "plugin.mandatory");
@@ -416,20 +429,13 @@ PluginUpdatePlugin
 						if ( !name.equals( id )){
 							
 							plugins_to_check_names.put( id, s+","+name);
-						}
-						
-						Boolean	old_unloadable = (Boolean)plugins_to_check_unloadable.get(id);
-						
-						plugins_to_check_unloadable.put(id,new Boolean(pi.isUnloadable() && old_unloadable.booleanValue()));
-						
+						}						
 					}else{
 						plugins_to_check_ids.add( id );
 						
 						plugins_to_check.add( pi );
 						
 						plugins_to_check_names.put( id, name.equals(id)?"":name);
-						
-						plugins_to_check_unloadable.put( id, new Boolean( pi.isUnloadable()));
 					}
 				}
 				
@@ -438,6 +444,25 @@ PluginUpdatePlugin
 				log.log( LoggerChannel.LT_INFORMATION, (mandatory?"*":"-") + pi.getPluginName() + ", id = " + id + (version==null?"":(", version = " + pi.getPluginVersion())) + (location==null?"":( ", loc = " + location)));
 			}
 			
+			SFPluginDetailsLoader loader = SFPluginDetailsLoaderFactory.getSingleton();
+			
+			if ( !loader_listener_added ){
+			
+				loader_listener_added = true;
+				
+				loader.addListener( 
+					new SFPluginDetailsLoaderListener()
+					{
+						public void
+						log(
+							String	str )
+						{
+							log.log( LoggerChannel.LT_INFORMATION, "[" + str + "]" );
+							
+						}
+					});
+			}
+			
 			String[]	ids = loader.getPluginIDs();
 			
 			String	id_info = "";
@@ -462,14 +487,12 @@ PluginUpdatePlugin
 				
 				if ( checker.getCheckInstance().isCancelled()){
 					
-					throw( new Exception( "Update check cancelled" ));
+					throw( new Exception( "Update check cancelled" )); // XXX: Uh?
 				}
 				
 				final PluginInterface	pi_being_checked 	= (PluginInterface)plugins_to_check.get(i);
 				final String			plugin_id 			= pi_being_checked.getPluginID();
 					
-				checker.reportProgress( "Loading details for " + plugin_id + "/" + pi_being_checked.getPluginName());
-
 				boolean	found	= false;
 				
 				for (int j=0;j<ids.length;j++){
@@ -484,7 +507,7 @@ PluginUpdatePlugin
 				
 				if ( !found ){
 					
-					if ( !pi_being_checked.isBuiltIn()){
+					if ( !pi_being_checked.getPluginState().isBuiltIn()){
 						
 						log.log( LoggerChannel.LT_INFORMATION, "Skipping " + plugin_id + " as not listed on web site");
 					}
@@ -493,12 +516,13 @@ PluginUpdatePlugin
 				}
 				
 				String			plugin_names		= (String)plugins_to_check_names.get( plugin_id );
-				final boolean	plugin_unloadable 	= ((Boolean)plugins_to_check_unloadable.get( plugin_id )).booleanValue();
+				//final boolean	plugin_unloadable 	= ((Boolean)plugins_to_check_unloadable.get( plugin_id )).booleanValue();
 				
 				log.log( LoggerChannel.LT_INFORMATION, "Checking " + plugin_id);
 				
 				try{
-					
+					checker.reportProgress( "Loading details for " + plugin_id + "/" + pi_being_checked.getPluginName());
+
 					SFPluginDetails	details = loader.getPluginDetails( plugin_id );
 	
 					if ( plugin_names.length() == 0 ){
@@ -550,6 +574,8 @@ PluginUpdatePlugin
 								(comp==0&&sf_plugin_version.endsWith( "_CVS")?"_CVS":"")+
 								", Latest: " + sf_plugin_version + (pi_version_info==null?"":" [" + pi_version_info + "]"));
 					
+					checker.reportProgress( "    current=" + az_plugin_version + (comp==0&&sf_plugin_version.endsWith( "_CVS")?"_CVS":"") + ", latest=" + sf_plugin_version );
+					
 					if ( comp < 0 && ! ( pi_being_checked.getPlugin() instanceof UpdatableComponent)){
 													
 							// only update if newer verison + plugin itself doesn't handle
@@ -636,7 +662,27 @@ PluginUpdatePlugin
 							
 						num_updates_found++;
 						
-						addUpdate( 
+							// see if unloadable
+						
+						boolean	plugin_unloadable 	= true;
+						
+						for (int j=0;j<plugins.length;j++){
+							
+							PluginInterface pi = plugins[j];
+							
+							if ( pi.getPluginID().equals( plugin_id )){
+								
+								plugin_unloadable &= pi.getPluginState().isUnloadable();
+							}
+						}
+						
+						if ( plugin_unloadable ){
+							
+							checker.reportProgress( "Plugin is unloadable" );
+						}
+						
+						Update update = 
+							addUpdate( 
 								pi_being_checked,
 								checker,
 								plugin_id + "/" + plugin_names,
@@ -647,16 +693,23 @@ PluginUpdatePlugin
 								plugin_unloadable?Update.RESTART_REQUIRED_NO:Update.RESTART_REQUIRED_YES,
 								true );
 			
-						}
+						update.setRelativeURLBase( details.getRelativeURLBase());
+						update.setDescriptionURL(details.getInfoURL());
+					}
 				}catch( Throwable e ){
+
+					checker.reportProgress( "Failed to load details for plugin '" + plugin_id + "': " + Debug.getNestedExceptionMessage(e));
 					
 					log.log("    Plugin check failed", e ); 
 				}
 			}
 						
 		}catch( Throwable e ){
+			if (!"Update check cancelled".equals(e.getMessage())) {
+				log.log("Failed to load plugin details", e );
+			}
 			
-			log.log("Failed to load plugin details", e );
+			checker.reportProgress( "Failed to load plugin details: " + Debug.getNestedExceptionMessage(e));
 			
 			checker.failed();
 			
@@ -670,7 +723,7 @@ PluginUpdatePlugin
 		return( num_updates_found );
 	}
 	
-	public void
+	public Update
 	addUpdate(
 		final PluginInterface			pi_for_update,
 		final UpdateChecker				checker,
@@ -743,6 +796,8 @@ PluginUpdatePlugin
 					}
 				}
 			});	
+		
+		return( update );
 	}
 	
 	
@@ -758,12 +813,10 @@ PluginUpdatePlugin
 		boolean				verify )
 	{
 		log.log( LoggerChannel.LT_INFORMATION,
-				 "Installing plugin " + plugin.getPluginID() + ", version " + version );
+				 "Installing plugin '" + update.getName() + "', version " + version );
 
 		String	target_version = version.endsWith("_CVS")?version.substring(0,version.length()-4):version;
 
-		final String	plugin_dir	= plugin.getPluginDirectoryName();
-		
 		UpdateInstaller	installer	= null;
 		
 		try{
@@ -774,7 +827,9 @@ PluginUpdatePlugin
 			
 			boolean update_txt_found	= false;
 
-			if ( plugin_dir == null || plugin_dir.length() == 0 ){
+			String plugin_dir_name = plugin.getPluginDirectoryName();
+			
+			if ( plugin_dir_name == null || plugin_dir_name.length() == 0 ){
 				
 					// update to a built-in plugin
 				
@@ -787,8 +842,10 @@ PluginUpdatePlugin
 				update.setRestartRequired( Update.RESTART_REQUIRED_YES );
 				
 			}else{
-				
-			
+
+				final File	plugin_dir	= new File( plugin_dir_name );
+				final File	user_dir	= new File( plugin_interface.getUtilities().getAzureusUserDir());
+				final File	prog_dir	= new File( plugin_interface.getUtilities().getAzureusProgramDir());
 	
 					// .jar files get copied straight in with the right version number
 					// .zip files need to be unzipped. There are various possibilities for
@@ -796,17 +853,80 @@ PluginUpdatePlugin
 					// need to remove any zip paths to ensure it ends up in the right place
 					// There's also the issue of overwriting stuff like "plugin.properties"
 					// and any other config files....
-								
-				String	target = plugin_dir + File.separator + 
-									plugin.getPluginID() + "_" + target_version + (is_jar?".jar":".zip");
+					
+				boolean	force_indirect_install = false;
 				
-				FileUtil.copyFile( data, new FileOutputStream(target));
+					// for windows Vista we may not have write access to the plugin directory and have
+					// to use an installer + restart to copy the files (as the restart can elevate
+					// permissions)
+				
+				if ( Constants.isWindowsVistaOrHigher ){
+					
+						// test with .dll as this will fail write to virtual-store as required
+					
+					File	test_file = new File( plugin_dir, "_aztest45.dll" );
+					
+					boolean	ok = false;
+					
+					try{
+						if ( test_file.exists()){
+							
+							test_file.delete();
+						}
+
+						FileOutputStream os = new FileOutputStream(test_file);
+						os.write(32);
+						os.close();
+
+						ok = test_file.delete();
+					}catch( Throwable e ){					
+					}
+					
+					if ( !ok ){
+						
+						log.log( "Can't write directly to the plugin directroy, installing indirectly" );
+						
+						force_indirect_install = true;				
+					}
+				}
+				
+				File	target_plugin_dir;
+				File	target_prog_dir;
+				File	target_user_dir;
+				
+				if ( force_indirect_install ){
+					
+					File temp_dir = AETemporaryFileHandler.createTempDir();
+					
+					target_plugin_dir	= new File( temp_dir, "plugin" );
+					target_user_dir		= new File( temp_dir, "user" );
+					target_prog_dir		= new File( temp_dir, "prog" );
+					
+					target_plugin_dir.mkdirs();
+					target_user_dir.mkdirs();
+					target_prog_dir.mkdirs();
+					
+					installer = update.getCheckInstance().createInstaller();
+
+					update.setRestartRequired( Update.RESTART_REQUIRED_YES );
+
+				}else{
+					
+					target_plugin_dir	= plugin_dir;
+					target_user_dir		= user_dir;
+					target_prog_dir		= prog_dir;
+				}
+				
+				File	target_jar_zip = new File( target_plugin_dir, plugin.getPluginID() + "_" + target_version + (is_jar?".jar":".zip"));
+				
+
+				FileUtil.copyFile( data, new FileOutputStream(target_jar_zip));
 			
 				if ( !is_jar ){
 					
 					ZipInputStream	zis = 
 						new ZipInputStream( 
-								new BufferedInputStream( new FileInputStream( target ) ));
+								new BufferedInputStream( new FileInputStream( target_jar_zip ) ));
 					
 					
 						// first look for a common dir prefix and platform-specific stuff
@@ -945,7 +1065,6 @@ PluginUpdatePlugin
 								
 								log.log( LoggerChannel.LT_INFORMATION,
 										"platform is '" + selected_platform +"'" );
-
 							}
 						}
 					}
@@ -961,10 +1080,9 @@ PluginUpdatePlugin
 							
 							common_prefix = common_prefix.substring(0,pos+1);
 						}
-					
-						
+									
 						zis = new ZipInputStream( 
-									new BufferedInputStream( new FileInputStream( target ) ));
+									new BufferedInputStream( new FileInputStream( target_jar_zip ) ));
 											
 						try{
 							while( true ){
@@ -980,6 +1098,7 @@ PluginUpdatePlugin
 								
 								OutputStream	entry_os = null;
 								
+								File			origin					= null;
 								File			initial_target			= null;
 								File			final_target			= null;
 								boolean			is_plugin_properties 	= false;
@@ -1013,39 +1132,57 @@ PluginUpdatePlugin
 											}
 										}
 										
-										String	install_root;
+										File	install_root;
+										File	origin_root;
 										
 										if ( file_name.startsWith( "shared/lib" )){
 											
-											if ( plugin.isShared()){
+												// updating shared resources, force restart
+											
+											update.setRestartRequired( Update.RESTART_REQUIRED_YES );
+
+												// indicate that we can't go ahead and load the plugin
+												// later in the code
+											
+											unloadable	= false;
+											
+											if ( plugin.getPluginState().isShared()){
 												
-												install_root 	= plugin_interface.getUtilities().getAzureusProgramDir();
+												origin_root		= prog_dir;
+												install_root 	= target_prog_dir;
 											
 											}else{
 												
-												install_root 	= plugin_interface.getUtilities().getAzureusUserDir();
+												origin_root		= user_dir;
+												install_root 	= target_user_dir;
 											}
 										}else{
 											
-											install_root 	= plugin_dir;
+											origin_root		= plugin_dir;
+											install_root 	= target_plugin_dir;
 										}
 										
-										initial_target 	= new File( install_root + File.separator + file_name );
+										origin 			= new File( origin_root, file_name );
+										initial_target 	= new File( install_root, file_name );
 										
 										final_target	= initial_target;
 														
-										if ( initial_target.exists()){
+										if ( origin.exists()){
 											
-											if ( 	file_name.toLowerCase().endsWith(".properties") ||
-													file_name.toLowerCase().endsWith(".config" )){
+											if ( 	file_name.indexOf( '/' ) == -1 &&
+													(	file_name.toLowerCase(MessageText.LOCALE_ENGLISH).endsWith(".properties") ||
+														file_name.toLowerCase(MessageText.LOCALE_ENGLISH).endsWith(".config" ))){
 												
-												is_plugin_properties	= file_name.toLowerCase().equals("plugin.properties");
+													// don't trash properties and config files in root as users may well
+													// have modified them
+												
+												is_plugin_properties	= file_name.toLowerCase(MessageText.LOCALE_ENGLISH).equals("plugin.properties");
 												
 												String	old_file_name = file_name;
 												
 												file_name = file_name + "_" + target_version;
 												
-												final_target = new File( install_root + File.separator + file_name );
+												final_target = new File( install_root, file_name );
 												
 												log.log( LoggerChannel.LT_INFORMATION,
 															"saving new file '" + old_file_name + "'as '" + file_name +"'" );
@@ -1066,43 +1203,55 @@ PluginUpdatePlugin
 													log.log( LoggerChannel.LT_INFORMATION,
 															"overwriting '" + file_name +"'" );
 													
+													File	backup = new File( origin.getParentFile(), origin.getName() + ".bak" );
+
 														// back up just in case
-													
-													File	backup = new File( initial_target.getParentFile(), initial_target.getName() + ".bak" );
-													
-													if ( backup.exists()){
+
+													if ( force_indirect_install ){
 														
-														backup.delete();
-													}
-													
-													if ( !initial_target.renameTo( backup )){
+														if ( backup.exists()){
 														
-														log.log( LoggerChannel.LT_INFORMATION,
-																"    failed to backup '" + file_name +"', deferring until restart" );
-	
-														if ( installer == null ){
-															
-															update.setRestartRequired( Update.RESTART_REQUIRED_YES );
-															
-															installer = update.getCheckInstance().createInstaller();
+															installer.addRemoveAction( backup.getAbsolutePath());
 														}
 														
-														File	tmp = new File( initial_target.getParentFile(), initial_target.getName() + ".tmp" );
-	
-														tmp.delete();
+														installer.addMoveAction( origin.getAbsolutePath(), backup.getAbsolutePath());
 														
-														installer.addMoveAction( tmp.getAbsolutePath(), initial_target.getAbsolutePath());
+													}else{
 														
-														final_target = tmp;
+														if ( backup.exists()){
+															
+															backup.delete();
+														}
+														
+														if ( !initial_target.renameTo( backup )){
+															
+															log.log( LoggerChannel.LT_INFORMATION,
+																	"    failed to backup '" + file_name +"', deferring until restart" );
+		
+															if ( installer == null ){
+																
+																update.setRestartRequired( Update.RESTART_REQUIRED_YES );
+																
+																installer = update.getCheckInstance().createInstaller();
+															}
+															
+															File	tmp = new File( initial_target.getParentFile(), initial_target.getName() + ".tmp" );
+		
+															tmp.delete();
+															
+															installer.addMoveAction( tmp.getAbsolutePath(), initial_target.getAbsolutePath());
+															
+															final_target = tmp;
+														}
 													}
 												}
 											}
 										}
 										
 										if ( !skip_file ){
-											
+																						
 											FileUtil.mkdirs(final_target.getParentFile());
-										
+											
 											entry_os = new FileOutputStream( final_target );
 										}
 									}
@@ -1155,7 +1304,7 @@ PluginUpdatePlugin
 									Map		props_to_insert		= new HashMap();
 									
 									try{
-										FileInputStream fis = new FileInputStream( initial_target );
+										FileInputStream fis = new FileInputStream( origin );
 										
 										old_props.load( fis );
 										
@@ -1219,15 +1368,26 @@ PluginUpdatePlugin
 										}
 									}
 									
-									File	tmp_file 	= new File(initial_target.toString() + ".tmp");
-									File	bak_file	= new File(initial_target.toString() + ".bak");
+									File	tmp_file;
+									
+									if ( force_indirect_install ){
+										
+											// install into temp dir so we don't need to create a temp file and then rename
+											// later as this installer will do this
+										
+										tmp_file = initial_target;
+										
+									}else{
+										
+										tmp_file = new File( initial_target.getParentFile(), initial_target.getName() + ".tmp" );
+									}
 									
 									LineNumberReader	lnr = null;
 									
 									PrintWriter			tmp = null;
 									
 									try{
-										lnr = new LineNumberReader(new FileReader(initial_target));
+										lnr = new LineNumberReader(new FileReader( origin ));
 									
 										tmp = new PrintWriter(new FileWriter( tmp_file ));			
 									
@@ -1293,25 +1453,39 @@ PluginUpdatePlugin
 										}
 									}
 									
-									if ( bak_file.exists()){
+									File	bak_file	= new File( origin.getParentFile(), origin.getName() + ".bak" );
+
+									if ( force_indirect_install ){
+										
+										if ( bak_file.exists()){
+
+											installer.addRemoveAction( bak_file.getAbsolutePath());
+										}
+										
+										installer.addMoveAction( origin.getAbsolutePath(), bak_file.getAbsolutePath());
+										
+									}else{
+										
+										if ( bak_file.exists()){
+											
+											bak_file.delete();
+										}
+										
+										if ( !initial_target.renameTo( bak_file)){
+											
+											throw( new IOException( "Failed to rename '" + initial_target.toString() + "' to '" + bak_file.toString() + "'" ));
+										}
+										
+										if ( !tmp_file.renameTo( initial_target )){
+											
+											bak_file.renameTo( initial_target );
+											
+											throw( new IOException( "Failed to rename '" + tmp_file.toString() + "' to '" + initial_target.toString() + "'" ));
+										}
 										
 										bak_file.delete();
 									}
 									
-									if ( !initial_target.renameTo( bak_file)){
-										
-										throw( new IOException( "Failed to rename '" + initial_target.toString() + "' to '" + bak_file.toString() + "'" ));
-									}
-									
-									if ( !tmp_file.renameTo( initial_target )){
-										
-										bak_file.renameTo( initial_target );
-										
-										throw( new IOException( "Failed to rename '" + tmp_file.toString() + "' to '" + initial_target.toString() + "'" ));
-									}
-									
-									bak_file.delete();
-									
 								}else if ( final_target != null && final_target.getName().equalsIgnoreCase( "update.txt" )){
 									
 									update_txt_found	= true;
@@ -1353,33 +1527,75 @@ PluginUpdatePlugin
 					}
 				}
 				
-				
 				if ( unloadable ){
 					
+						// 	check unloadability AGAIN in case changed during activities
+					
+					String	plugin_id = plugin.getPluginID();
+					
+					PluginInterface[]	plugins = plugin.getPluginManager().getPlugins();
+					
+					boolean	plugin_unloadable 	= true;
+					
+					for (int j=0;j<plugins.length;j++){
+						
+						PluginInterface pi = plugins[j];
+						
+						if ( pi.getPluginID().equals( plugin_id )){
+							
+							plugin_unloadable &= pi.getPluginState().isUnloadable();
+						}
+					}
+					
+					if ( !plugin_unloadable ){
+						
+						log.log( "Switching unloadability for " + plugin_id + " as changed during update" );
+						
+						update.setRestartRequired( Update.RESTART_REQUIRED_YES );
+						
+						unloadable = false;
+					}
+				}
+				
+				if ( force_indirect_install ){
+					
+						// create installation move actions for the files that have been installed
+						// into temp location
+					
+					addInstallationActions( installer, target_plugin_dir, plugin_dir );
+					addInstallationActions( installer, target_prog_dir, prog_dir );
+					addInstallationActions( installer, target_user_dir, user_dir );					
+				
+						// don't delete temp store, it'll get deleted on restart
+					
+				}else if ( unloadable ){
+					
 					log.log( "Plugin initialising, please wait... " );
 					
-					plugin.reload();	// this will reload all if > 1 defined
+					plugin.getPluginState().reload();	// this will reload all if > 1 defined
 					
 					log.log( "... initialisation complete." );
 	
 				}	
 			}
 			
-			String msg =   "Version " + version + " of plugin '" + 
-							plugin.getPluginID() + "' " +
-							"installed successfully";
-
-			if ( update_txt_found ){
-				
-				msg += " - See update log for details";
-			}
+			Boolean b_disable = (Boolean)update.getCheckInstance().getProperty( UpdateCheckInstance.PT_UI_DISABLE_ON_SUCCESS_SLIDEY );
 			
-			log.logAlertRepeatable( update_txt_found?LoggerChannel.LT_WARNING:LoggerChannel.LT_INFORMATION, msg );			
-
+			if ( update_txt_found || b_disable == null || !b_disable ){
+				
+				String msg =   "Version " + version + " of plugin '" + update.getName() + "' " +
+								"installed successfully";
+	
+				if ( update_txt_found ){
+					
+					msg += " - See update log for details";
+				}
+				
+				log.logAlertRepeatable( update_txt_found?LoggerChannel.LT_WARNING:LoggerChannel.LT_INFORMATION, msg );			
+			}
 		}catch( Throwable e ){
 					
-			String msg =   "Version " + version + " of plugin '" + 
-							plugin.getPluginID() + "' " +
+			String msg =   "Version " + version + " of plugin '" + 	update.getName() + "' " +
 							"failed to install - " + (e.getMessage());
 		
 			log.logAlertRepeatable( LoggerChannel.LT_ERROR, msg );
@@ -1390,6 +1606,31 @@ PluginUpdatePlugin
 		}
 	}
 	
+	protected void
+	addInstallationActions(
+		UpdateInstaller		installer,
+		File				from_file,
+		File				to_file )
+	
+		throws UpdateException
+	{
+		if ( from_file.isDirectory()){
+			
+			File[]	files = from_file.listFiles();
+			
+			if ( files != null ){
+				
+				for (int i=0;i<files.length;i++){
+					
+					addInstallationActions( installer, files[i], new File( to_file, files[i].getName()));
+				}
+			}
+		}else{
+			
+			installer.addMoveAction( from_file.getAbsolutePath(), to_file.getAbsolutePath());
+		}
+	}
+	
 	protected boolean
 	isVersioned(
 		String	name )
