@@ -19,9 +19,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.PrintStream;
-import java.io.PrintWriter;
 import java.io.Reader;
-import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
@@ -46,7 +44,9 @@ import org.gudy.azureus2.core3.torrentdownloader.TorrentDownloader;
 import org.gudy.azureus2.core3.torrentdownloader.TorrentDownloaderCallBackInterface;
 import org.gudy.azureus2.core3.torrentdownloader.TorrentDownloaderFactory;
 import org.gudy.azureus2.core3.torrentdownloader.impl.TorrentDownloaderManager;
+import org.gudy.azureus2.core3.util.Constants;
 import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.SystemProperties;
 import org.gudy.azureus2.plugins.PluginException;
 import org.gudy.azureus2.plugins.PluginInterface;
 import org.gudy.azureus2.plugins.PluginManager;
@@ -58,10 +58,12 @@ import org.gudy.azureus2.plugins.update.UpdateCheckInstanceListener;
 import org.gudy.azureus2.plugins.update.UpdateManager;
 import org.gudy.azureus2.ui.common.UIConst;
 import org.gudy.azureus2.ui.console.commands.*;
+import org.gudy.azureus2.ui.console.util.TextWrap;
 import org.gudy.azureus2.update.CorePatchChecker;
 import org.gudy.azureus2.update.UpdaterUpdateChecker;
 
 import com.aelitis.azureus.core.AzureusCore;
+import com.aelitis.azureus.core.AzureusCoreLifecycleAdapter;
 
 /**
  * @author Tobias Minich
@@ -165,7 +167,19 @@ public class ConsoleInput extends Thread {
 		registerAlertHandler();
 		registerCommands();
 		registerPluginCommands();
-		registerUpdateChecker();
+		
+		azureus_core.addLifecycleListener(
+			new AzureusCoreLifecycleAdapter()
+			{
+				public void
+				started(
+					AzureusCore		core )
+				{
+					registerUpdateChecker();
+				}
+			});
+		
+	
 		try {
 			loadAliases();
 		} catch (IOException e) {
@@ -296,6 +310,7 @@ public class ConsoleInput extends Thread {
 		registerCommand(new CommandHelp());
 		registerCommand(new Alias());
 		registerCommand(new Priority());
+		registerCommand(new Plugin());
 	}
 
 	/**
@@ -351,7 +366,7 @@ public class ConsoleInput extends Thread {
 	{
 		public CommandHelp()
 		{
-			super(new String[] { "help", "?"});
+			super("help", "?");
 		}
 		public String getCommandDescriptions() {
 			return("help [torrents]\t\t\t?\tShow this help. 'torrents' shows info about the show torrents display.");
@@ -368,6 +383,7 @@ public class ConsoleInput extends Thread {
 					List newargs = new ArrayList(args);
 					newargs.remove(0);
 					cmd.printHelp(ci.out, newargs);
+					//if (cmd.getHelpExtra())
 				}
 				else if (subcommand.equalsIgnoreCase("torrents") || subcommand.equalsIgnoreCase("t")) {
 					ci.out.println("> -----");
@@ -393,32 +409,37 @@ public class ConsoleInput extends Thread {
 		
 	}
 	
+	public void printwelcome()
+	{
+		out.println("Running " + Constants.APP_NAME + " " + Constants.AZUREUS_VERSION + "...");
+		out.println("Using configuration settings from:");
+		out.println("  " + SystemProperties.getUserPath());
+	}
+	
 	public void printconsolehelp()
 	{
 		printconsolehelp(out);
 	}
 	private void printconsolehelp(PrintStream os) {
 		os.println("> -----");
-		os.println("Available console commands:");
-		os.println("Command\t\t\t\tShort\tDescription");
-		os.println(".\t\t\t\t\tRepeats last command (Initially 'show torrents').");
+		os.println("Available console commands (use help <command> for more details):");
+		os.println();
 		
-		StringWriter sw = new StringWriter();
-		PrintWriter pw = new PrintWriter(sw);
-		
-		for (Iterator iter = helpItems.iterator(); iter.hasNext();) {
-			IConsoleCommand cmd = (IConsoleCommand) iter.next();
-			String cmddesc = cmd.getCommandDescriptions();
-			if( cmddesc != null )
-				os.println(cmddesc);
-			String extraHelp = cmd.getHelpExtra();
-			if( extraHelp != null )
-			{
-				pw.println();
-				pw.println(extraHelp);
+		ArrayList cmd_lines = new ArrayList();
+		Iterator itr = helpItems.iterator();
+		while (itr.hasNext()) {
+			StringBuffer line_so_far = new StringBuffer("[");
+			IConsoleCommand cmd = (IConsoleCommand)itr.next();
+			String short_name = cmd.getShortCommandName();
+			if (short_name != null) {
+				line_so_far.append(short_name);
 			}
+			line_so_far.append("] ");
+			line_so_far.append(cmd.getCommandName());
+			cmd_lines.add(line_so_far.toString());
 		}
-		os.println(sw.toString());
+		
+		TextWrap.printList(cmd_lines.iterator(), os, "   ");
 		os.println("> -----");
 	}
 	
@@ -426,7 +447,7 @@ public class ConsoleInput extends Thread {
 	{
 		public CommandQuit()
 		{
-			super(new String[] {"quit"});
+			super("quit");
 		}
 		public String getCommandDescriptions() {
 			return("quit\t\t\t\t\tShutdown Azureus");
@@ -455,7 +476,7 @@ public class ConsoleInput extends Thread {
 	{
 		public CommandLogout()
 		{
-			super(new String[] {"logout"});
+			super("logout");
 		}
 		public String getCommandDescriptions() {
 			return "logout\t\t\t\t\tLog out of the CLI";
@@ -489,7 +510,7 @@ public class ConsoleInput extends Thread {
 	{
 		public CommandUI()
 		{
-			super( new String[] { "ui", "u" });
+			super("ui", "u");
 		}
 		public String getCommandDescriptions() {
 			return("ui <interface>\t\t\tu\tStart additional user interface.");
@@ -682,14 +703,14 @@ public class ConsoleInput extends Thread {
 		
 		if ( pi != null ){
 			
-			pi.setDisabled( true );
+			pi.getPluginState().setDisabled( true );
 		}
 		
 		pi = pm.getPluginInterfaceByClass( UpdaterUpdateChecker.class );
 		
 		if ( pi != null ){
 			
-			pi.setDisabled( true );
+			pi.getPluginState().setDisabled( true );
 		}
 		
 		UpdateManager update_manager = azureus_core.getPluginManager().getDefaultPluginInterface().getUpdateManager();
