@@ -35,12 +35,11 @@ public class TorrentRemove extends TorrentCommand {
 
 	public TorrentRemove()
 	{
-		super(new String[] {"remove", "r"}, "Removing");
+		super("remove", "r", "Removing");
 	}
 
 	protected boolean performCommand(ConsoleInput ci, DownloadManager dm, List args) {
 		try {
-			dm.stopIt( DownloadManager.STATE_STOPPED, false, false );
 			ci.getGlobalManager().removeDownloadManager(dm);
 		} catch (GlobalManagerDownloadRemovalVetoException e) {
 			ci.out.println("> Veto when removing torrent (" + e.getMessage() + ")");
