@@ -23,9 +23,12 @@ package org.gudy.azureus2.ui.swt;
 import java.io.File;
 
 import com.aelitis.azureus.core.*;
+import com.aelitis.azureus.launcher.Launcher;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.logging.*;
+import org.gudy.azureus2.core3.util.Base32;
+import org.gudy.azureus2.core3.util.ByteFormatter;
 import org.gudy.azureus2.ui.swt.mainwindow.Initializer;
 
 /**
@@ -40,11 +43,16 @@ Main
 	
   StartServer startServer;
   
-  public 
-  Main(
-  	String args[]) 
-  {
+	public static long startTime = System.currentTimeMillis();
+  
+  // This method is called by other Main classes via reflection - must be kept public.
+  public Main(String args[])
+	{
   	try{
+  		// this should not be necessary, but since it's public let's play safe
+		if(Launcher.checkAndLaunch(Main.class, args))
+			return;
+  		
   			// This *has* to be done first as it sets system properties that are read and cached by Java
   		
   		COConfigurationManager.preInitialise();
@@ -82,6 +90,7 @@ Main
 	    }
 	    
   	}catch( AzureusCoreException e ){
+  		
   		Logger.log(new LogEvent(LOGID, "Start failed", e));
   	}
   }
@@ -95,6 +104,18 @@ Main
 	public static boolean processParams(String[] args, StartServer startServer) {
     boolean	closedown	= false;
     
+    boolean another_instance = startServer.getState() != StartServer.STATE_LISTENING;
+    
+    /*  if another instance is running then set the property which is checked during
+     *	class instantiation by various stuff to to avoid pulling in too much state
+     *	from the already running instance  
+     */
+    if(another_instance)
+    	System.setProperty("transitory.startup", "1");
+    
+    	// WATCH OUT FOR LOGGING HERE - we don't want to use Logger if this is a secondary instance as
+    	// it initialised TOO MUCH of AZ core
+    
     for (int i=0;i<args.length;i++){
 
     	String	arg = args[i];
@@ -111,41 +132,90 @@ Main
 	    	
         String filename = arg;
           
-          if( filename.toUpperCase().startsWith( "HTTP:" ) || 
-          		filename.toUpperCase().startsWith( "HTTPS:" ) || 
-          		filename.toUpperCase().startsWith( "MAGNET:" ) ) {
+        if ( filename.length() == 40 ){
+	        
+        	byte[]	hash = null;
+        	
+        	try{
+        		hash = ByteFormatter.decodeString( filename );
+        		
+        	}catch( Throwable e ){
+        	}
+        	
+        	if ( hash != null && hash.length == 20 ){
+        		
+        		filename = "magnet:?xt=urn:btih:" + Base32.encode( hash );
+        	}
+        }
+        
+        	// handle base32 info hash
+       
+        if ( filename.length() == 32 ){
+            
+        	byte[]	hash = null;
+        	
+        	try{
+        		hash = Base32.decode( filename );
+        		
+        	}catch( Throwable e ){
+        	}
+        	
+        	if ( hash != null && hash.length == 20 ){
+        		
+        		filename = "magnet:?xt=urn:btih:" +filename;
+        	}
+        }
+        
+        if( 	filename.toUpperCase().startsWith( "HTTP:" ) || 
+        		filename.toUpperCase().startsWith( "HTTPS:" ) || 
+        		filename.toUpperCase().startsWith( "MAGNET:" ) ||
+        		filename.toUpperCase().startsWith( "DHT:" ) ) {
+
+        	if ( !another_instance ){
+
         		Logger.log(new LogEvent(LOGID, "Main::main: args[" + i
         				+ "] handling as a URI: " + filename));
-            continue;  //URIs cannot be checked as a .torrent file
-          }            
+        	}
+
+        	continue;  //URIs cannot be checked as a .torrent file
+        }            
         
         try{
         	File	file = new File(filename);
         	
         	if ( !file.exists()){
         		
-        		throw( new Exception("File not found" ));
+        		throw( new Exception("File '" + file + "' not found" ));
         	}
         	
         	args[i] = file.getCanonicalPath();
           	
-        	if (Logger.isEnabled())
+        		// don't use logger if we're not the main instance as we don't want all
+        		// the associated core initialisation + debug file moving...
+        	
+        	if ( (!another_instance) && Logger.isEnabled()){
+        		
         		Logger.log(new LogEvent(LOGID, "Main::main: args[" + i
         				+ "] exists = " + new File(filename).exists()));
-          
+        	}
         }catch( Throwable e ){
-        	Logger.log(new LogAlert(LogAlert.REPEATABLE, LogAlert.AT_ERROR,
-						"Failed to access torrent file '" + filename
-								+ "'. Ensure sufficient temporary "
-								+ "file space available (check browser cache usage)."));
+        	
+        	if ( another_instance ){
+        		
+        		e.printStackTrace();
+        		
+        	}else{
+        		
+	        	Logger.log(new LogAlert(LogAlert.REPEATABLE, LogAlert.AT_ERROR,
+							"Failed to access torrent file '" + filename
+									+ "'. Ensure sufficient temporary "
+									+ "file space available (check browser cache usage)."));
+        	}
         }
-
     }
     
     
-    boolean another_instance = startServer.getState() != StartServer.STATE_LISTENING;
-    
-    if( another_instance ) {  //looks like there's already a process listening on 127.0.0.1:6880
+     if( another_instance ) {  //looks like there's already a process listening on 127.0.0.1:6880
     	//attempt to pass args to existing instance
     	StartSocket ss = new StartSocket(args);
     	
@@ -170,13 +240,18 @@ Main
 	}
 
 
-
 	public static void main(String args[]) 
-  { 	
+  {
+		if(Launcher.checkAndLaunch(Main.class, args))
+			return;
   	//Debug.dumpThreads("Entry threads");
  
   	//Debug.dumpSystemProperties();
   	
-    new Main(args);
+		if (System.getProperty("ui.temp") == null) {
+			System.setProperty("ui.temp", "az2");
+		}
+
+		new Main(args);
   }
 }
