@@ -35,9 +35,7 @@ import org.eclipse.swt.custom.TableEditor;
 import org.eclipse.swt.dnd.Clipboard;
 import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.events.*;
-import org.eclipse.swt.graphics.Font;
-import org.eclipse.swt.graphics.FontData;
-import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.layout.RowLayout;
@@ -62,11 +60,11 @@ import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.ui.swt.components.shell.ShellFactory;
 import org.gudy.azureus2.ui.swt.mainwindow.Colors;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.shells.MessageSlideShell;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
-import com.aelitis.azureus.ui.UIFunctionsManager;
 import com.aelitis.azureus.ui.common.updater.UIUpdatable;
 import com.aelitis.azureus.ui.swt.imageloader.ImageLoader;
 import com.aelitis.azureus.ui.swt.uiupdater.UIUpdaterSWT;
@@ -100,7 +98,7 @@ public class OpenTorrentWindow
 	 */
 	//private final static int MIN_NODOWNLOAD_SIZE = 64 * 1024;
 	//private final static int MAX_NODOWNLOAD_COUNT = 3;
-	private final static int MIN_BUTTON_HEIGHT = Constants.isWindows ? 24 : -1;
+	private final static int MIN_BUTTON_HEIGHT = -1;
 
 	private final static String PARAM_DEFSAVEPATH = "Default save path";
 
@@ -172,7 +170,7 @@ public class OpenTorrentWindow
 	/** List of torrents being downloaded.  Stored so we don't close window
 	 * until they are done/aborted.
 	 */
-	private ArrayList downloaders = new ArrayList();
+	private ArrayList<TorrentDownloader> downloaders = new ArrayList<TorrentDownloader>();
 
 	private boolean bOverrideStartModeToStopped = false;
 
@@ -237,7 +235,7 @@ public class OpenTorrentWindow
 			OpenTorrentWindow openTorrentWindow = stOpenTorrentWindow;
 			openTorrentWindow.bOverrideStartModeToStopped = bDefaultStopped;
 			openTorrentWindow.bDefaultForSeeding = bForSeeding;
-			if (sFilesToOpen != null) {
+			if (sFilesToOpen != null || sPathOfFilesToOpen != null) {
 				// If none of the files sent to us were valid files, don't open the 
 				// window
 				if (!bPopupOpenURL
@@ -500,38 +498,16 @@ public class OpenTorrentWindow
 
 		cmbDataDir.addModifyListener(new ModifyListener() {
 			public void modifyText(ModifyEvent e) {
-				if (bSkipDataDirModify) {
-					return;
-				}
-				sDestDir = cmbDataDir.getText();
-
-				int[] indexes = torrentTable.getSelectionIndices();
-				for (int i = 0; i < indexes.length; i++) {
-					TorrentInfo info = (TorrentInfo) torrentList.get(indexes[i]);
-					//if (!info.allFilesMoving())
-					info.sDestDir = sDestDir;
-				}
-
-				torrentTable.clearAll();
-
-				checkSeedingMode();
-
-				File file = new File(sDestDir);
-				if (!file.isDirectory()) {
-					cmbDataDir.setBackground(Colors.colorErrorBG);
-				} else {
-					cmbDataDir.setBackground(null);
-				}
-				cmbDataDir.redraw();
-				cmbDataDir.update();
-				diskFreeInfoRefreshPending = true;
+				cmbDataDirChanged();
+			}
+		});
+		cmbDataDir.addListener(SWT.Selection, new Listener() {
+			public void handleEvent(Event event) {
+				cmbDataDirChanged();
 			}
 		});
 
 		updateDataDirCombo();
-		if (sDestDir != null && sDestDir.length() > 0) {
-			cmbDataDir.add(sDestDir);
-		}
 		dirList = COConfigurationManager.getStringListParameter("saveTo_list");
 		StringIterator iter = dirList.iterator();
 		while (iter.hasNext()) {
@@ -681,6 +657,36 @@ public class OpenTorrentWindow
 		}
 	}
 
+	protected void cmbDataDirChanged() {
+		if (bSkipDataDirModify) {
+			return;
+		}
+		sDestDir = cmbDataDir.getText();
+
+		int[] indexes = torrentTable.getSelectionIndices();
+		for (int i = 0; i < indexes.length; i++) {
+			TorrentInfo info = (TorrentInfo) torrentList.get(indexes[i]);
+			//if (!info.allFilesMoving())
+			info.sDestDir = sDestDir;
+		}
+
+		torrentTable.clearAll();
+
+		checkSeedingMode();
+
+		if (!Utils.isCocoa || SWT.getVersion() > 3600) { // See Eclipse Bug 292449
+  		File file = new File(sDestDir);
+  		if (!file.isDirectory()) {
+  			cmbDataDir.setBackground(Colors.colorErrorBG);
+  		} else {
+  			cmbDataDir.setBackground(null);
+  		}
+  		cmbDataDir.redraw();
+  		cmbDataDir.update();
+		}
+		diskFreeInfoRefreshPending = true;
+	}
+
 	protected void okPressed() {
 		if (bClosed) {
 			return;
@@ -702,11 +708,13 @@ public class OpenTorrentWindow
 
 		boolean isPathInvalid = cmbDataDir.getText().length() == 0 || file.isFile();
 		if (!isPathInvalid && !file.isDirectory()) {
-			int doCreate = Utils.openMessageBox(shellForChildren, SWT.YES | SWT.NO
+			MessageBoxShell mb = new MessageBoxShell(SWT.YES | SWT.NO
 					| SWT.ICON_QUESTION, "OpenTorrentWindow.mb.askCreateDir",
 					new String[] {
 						file.toString()
 					});
+			mb.open(null);
+			int doCreate = mb.waitUntilClosed();
 
 			if (doCreate == SWT.YES)
 				isPathInvalid = !FileUtil.mkdirs(file);
@@ -717,10 +725,11 @@ public class OpenTorrentWindow
 		}
 
 		if (isPathInvalid) {
-			Utils.openMessageBox(shellForChildren, SWT.OK | SWT.ICON_ERROR,
+			MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.ICON_ERROR,
 					"OpenTorrentWindow.mb.noGlobalDestDir", new String[] {
 						file.toString()
 					});
+			mb.open(null);
 			cmbDataDir.setFocus();
 			return;
 		}
@@ -740,19 +749,21 @@ public class OpenTorrentWindow
 			// 4) change the global def directory to a real one
 			// 5) click ok.  "hi.exe" will be written as moo in c:\test			
 			if (!file.isDirectory() && !FileUtil.mkdirs(file)) {
-				Utils.openMessageBox(shellForChildren, SWT.OK | SWT.ICON_ERROR,
+				MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.ICON_ERROR,
 						"OpenTorrentWindow.mb.noDestDir", new String[] {
 							file.toString(),
 							info.getTorrentName()
 						});
+				mb.open(null);
 				return;
 			}
 
 			if (!info.isValid) {
-				Utils.openMessageBox(shellForChildren, SWT.OK | SWT.ICON_ERROR,
+				MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.ICON_ERROR,
 						"OpenTorrentWindow.mb.notValid", new String[] {
 							info.getTorrentName()
 						});
+				mb.open(null);
 				return;
 			}
 
@@ -781,11 +792,13 @@ public class OpenTorrentWindow
 						+ "\n";
 			}
 
-			if (Utils.openMessageBox(shellForChildren, SWT.OK | SWT.CANCEL
+			MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.CANCEL
 					| SWT.ICON_WARNING, "OpenTorrentWindow.mb.existingFiles",
 					new String[] {
 						sExistingFiles
-					}) != SWT.OK) {
+					});
+			mb.open(null);
+			if (mb.waitUntilClosed() != SWT.OK) {
 				return;
 			}
 		}
@@ -885,6 +898,9 @@ public class OpenTorrentWindow
 			int[] indexes = torrentTable.getSelectionIndices();
 
 			if (indexes.length == 0) {
+				if (cmbDataDir.getItemCount() == 0) {
+					cmbDataDir.add(sDestDir);
+				}
 				cmbDataDir.setText(sDestDir);
 				return;
 			}
@@ -1024,15 +1040,24 @@ public class OpenTorrentWindow
 
 		Utils.disposeSWTObjects(disposeList);
 
-		if (downloaders.size() > 0) {
-			for (Iterator iter = downloaders.iterator(); iter.hasNext();) {
-				TorrentDownloader element = (TorrentDownloader) iter.next();
-				element.cancel();
-			}
-			downloaders.clear();
-		}
-
 		if (bCancel) {
+			
+			List<TorrentDownloader> to_cancel;
+			
+			synchronized( downloaders ){
+				
+				to_cancel = new ArrayList<TorrentDownloader>( downloaders );
+				
+				downloaders.clear(); 
+			}
+			
+			if (to_cancel.size() > 0){
+				for (Iterator iter = to_cancel.iterator(); iter.hasNext();) {
+					TorrentDownloader element = (TorrentDownloader) iter.next();
+					element.cancel();
+				}
+			}
+
 			for (Iterator iter = torrentList.iterator(); iter.hasNext();) {
 				TorrentInfo info = (TorrentInfo) iter.next();
 				if (info.bDeleteFileOnCancel) {
@@ -1150,7 +1175,7 @@ public class OpenTorrentWindow
 		// Menu for tableTorrents
 
 		String sTitle;
-		Menu menu = new Menu(torrentTable);
+		Menu menu = new Menu(torrentTable.getShell());
 		MenuItem item;
 		sTitle = MessageText.getString("OpenTorrentWindow.startMode");
 
@@ -1221,7 +1246,7 @@ public class OpenTorrentWindow
 					TorrentInfo info = (TorrentInfo) torrentList.get(indexes[i]);
 
 					TorrentFileInfo[] files = info.getFiles();
-					if (files.length == 1) {
+					if (files.length == 1 && info.torrent.isSimpleTorrent()) {
 						changeFileDestination(new int[] {
 							0
 						});
@@ -1779,12 +1804,14 @@ public class OpenTorrentWindow
 				File file = new File(sNewName);
 				if (file.length() == fileInfo.lSize)
 					fileInfo.setFullDestName(sNewName);
-				else
-					Utils.openMessageBox(shellForChildren, SWT.OK,
+				else {
+					MessageBoxShell mb = new MessageBoxShell(SWT.OK,
 							"OpenTorrentWindow.mb.badSize", new String[] {
 								file.getName(),
 								fileInfo.orgFullName
 							});
+					mb.open(null);
+				}
 			} else
 				fileInfo.setFullDestName(sNewName);
 
@@ -1977,23 +2004,25 @@ public class OpenTorrentWindow
 				sFileName = UrlUtils.decode(sFileName.substring(16));
 			}
 
-			File fOriginal = new File(sFileName);
+			final File fOriginal = new File(sFileName);
 
 			if (!fOriginal.isFile() || !fOriginal.exists()) {
 				Utils.execSWTThread(new AERunnable() {
 					public void runSupport() {
 						if (shell == null)
 							new MessageSlideShell(Display.getCurrent(), SWT.ICON_ERROR,
-									"OpenTorrentWindow.mb.openError", "", new String[] {
-										sOriginatingLocation,
+									"OpenTorrentWindow.mb.openError", fOriginal.toString(), new String[] {
+										UrlUtils.decode(sOriginatingLocation),
 										"Not a File"
 									}, -1 );
-						else
-							Utils.openMessageBox(shell, SWT.OK,
+						else {
+							MessageBoxShell mb = new MessageBoxShell(SWT.OK,
 									"OpenTorrentWindow.mb.openError", new String[] {
 										sOriginatingLocation,
 										"Not a File"
 									});
+							mb.open(null);
+						}
 					}
 				});
 				return null;
@@ -2033,12 +2062,14 @@ public class OpenTorrentWindow
 									sOriginatingLocation,
 									e.getMessage()
 								}, -1 );
-					else
-						Utils.openMessageBox(shell, SWT.OK,
+					else {
+						MessageBoxShell mb = new MessageBoxShell(SWT.OK,
 								"OpenTorrentWindow.mb.openError", new String[] {
 									sOriginatingLocation,
 									e.getMessage()
 								});
+						mb.open(null);
+					}
 				}
 			});
 
@@ -2101,13 +2132,15 @@ public class OpenTorrentWindow
 								}, new Object[] {
 									fExistingDownload
 								}, -1 );
-					else
-						Utils.openMessageBox(shell, SWT.OK, MSG_ALREADY_EXISTS,
+					else {
+						MessageBoxShell mb = new MessageBoxShell(SWT.OK, MSG_ALREADY_EXISTS,
 								new String[] {
 									":" + sOriginatingLocation,
 									sfExistingName,
 									MessageText.getString(MSG_ALREADY_EXISTS_NAME),
 								});
+						mb.open(null);
+					}
 				}
 			});
 
@@ -2180,6 +2213,14 @@ public class OpenTorrentWindow
 	 * @param sDataDir 
 	 */
 	private void openTorrents() {
+		Utils.getOffOfSWTThread(new AERunnable() {
+			public void runSupport() {
+				_openTorrents();
+			}
+		});
+	}
+
+	private void _openTorrents() {
 		ArrayList addedTorrentsTop = new ArrayList();
 
 		for (int i = 0; i < torrentList.size(); i++) {
@@ -2215,12 +2256,17 @@ public class OpenTorrentWindow
 								DiskManagerFileInfo fileInfo = fileInfos[iIndex];
 								if (iIndex >= 0 && iIndex < files.length && files[iIndex].lSize == fileInfo.getLength())
 								{
-									File fDest = files[iIndex].getDestFileFullName();
+									// Always pull destination file from fileInfo and not from
+									// TorrentFileInfo because the destination may have changed
+									// by magic code elsewhere
+									File fDest = fileInfo.getFile(true);
 									if (files[iIndex].isLinked())
 									{
+										fDest = files[iIndex].getDestFileFullName();
 										// Can't use fileInfo.setLink(fDest) as it renames
 										// the existing file if there is one
-										dm.getDownloadState().setFileLink(fileInfo.getFile(false), fDest);
+										dm.getDownloadState().setFileLink(
+														fileInfo.getFile(false), fDest);
 									}
 									if (!files[iIndex].bDownload)
 									{
@@ -2262,12 +2308,14 @@ public class OpenTorrentWindow
 								info.sOriginatingLocation,
 								e.getMessage()
 							}, -1 );
-				else
-					Utils.openMessageBox(shell, SWT.OK, "OpenTorrentWindow.mb.openError",
+				else {
+					MessageBoxShell mb = new MessageBoxShell(SWT.OK, "OpenTorrentWindow.mb.openError",
 							new String[] {
 								info.sOriginatingLocation,
 								e.getMessage()
 							});
+					mb.open(null);
+				}
 			}
 		}
 
@@ -2299,10 +2347,16 @@ public class OpenTorrentWindow
 
 			activeTorrentCount--;
 			enableControl(ok, activeTorrentCount < 1);
-			if (!downloaders.contains(inf))
-				return;
-			downloaders.remove(inf);
-
+			
+				// PARG - yes, this code sucks, added some sync here to prvent some errors but obviously
+				// it needs a complete rewrite
+			
+			synchronized( downloaders ){
+				if (!downloaders.contains(inf))
+					return;
+				downloaders.remove(inf);
+			}
+			
 			File file = inf.getFile();
 			// we already know it isn't a torrent.. we are just using the call
 			// to popup the message
@@ -2316,16 +2370,20 @@ public class OpenTorrentWindow
 		if (state == TorrentDownloader.STATE_INIT) {
 			activeTorrentCount++;
 			enableControl(ok, activeTorrentCount < 1);
-			downloaders.add(inf);
+			synchronized( downloaders ){
+				downloaders.add(inf);
+			}
 		} else if (state == TorrentDownloader.STATE_FINISHED) {
 			activeTorrentCount--;
 			enableControl(ok, activeTorrentCount < 1);
 
 			// This can be called more than once for each inf..
-			if (!downloaders.contains(inf))
-				return;
-			downloaders.remove(inf);
-
+			synchronized( downloaders ){
+				if (!downloaders.contains(inf))
+					return;
+				downloaders.remove(inf);
+			}
+			
 			File file = inf.getFile();
 			if (addTorrent(file.getAbsolutePath(), inf.getURL()) == null) {
 				// addTorrent may not delete it on error if the downloader saved it
@@ -2369,7 +2427,9 @@ public class OpenTorrentWindow
 				|| state == TorrentDownloader.STATE_DUPLICATE) {
 			activeTorrentCount--;
 			enableControl(ok, activeTorrentCount < 1);
-			downloaders.remove(inf);
+			synchronized( downloaders ){
+				downloaders.remove(inf);
+			}
 		} else if (state == TorrentDownloader.STATE_DOWNLOADING) {
 			int count = inf.getLastReadCount();
 			int numRead = inf.getTotalRead();
