@@ -30,6 +30,9 @@ package org.gudy.azureus2.ui.swt;
 import java.io.ByteArrayOutputStream;
 import java.io.PrintStream;
 import java.util.ArrayList;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.Map;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.*;
@@ -63,6 +66,8 @@ public class Sleak
 
 	Error[] errors = new Error[0];
 	
+	Map all = new HashMap();
+	
 	ArrayList oldNonResources = new ArrayList();
 
 	public void open() {
@@ -253,12 +258,18 @@ public class Sleak
 	}
 
 	String objectName(Object object) {
-		String string = object.toString();
+		Date timeAdded = (Date)all.get(object);
+		if (timeAdded == null) {
+			timeAdded = new Date();
+			all.put(object, timeAdded);
+		}
+
+		String string = timeAdded + "] " + object.toString();
 		if (object instanceof Resource) {
 			return string;
 		}
 
-		int index = string.indexOf(' ');
+		int index = string.indexOf(" {");
 		if (index == -1) {
 			return string;
 		}
@@ -420,11 +431,12 @@ public class Sleak
     data.tracking = true;
     Display display = new Display (data);
 		Sleak sleak = new Sleak();
-    new Main(args);
+    Main.main(args);
 		sleak.open();
 		while (!sleak.shell.isDisposed()) {
-			if (!display.readAndDispatch())
+			if (!display.readAndDispatch()) {
 				display.sleep();
+			}
 		}
 		try {
 			if (!display.isDisposed()) {
