@@ -35,7 +35,6 @@ import org.eclipse.swt.widgets.*;
 import org.gudy.azureus2.core3.category.Category;
 import org.gudy.azureus2.core3.category.CategoryManager;
 import org.gudy.azureus2.core3.config.COConfigurationManager;
-import org.gudy.azureus2.core3.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.download.DownloadManagerState;
 import org.gudy.azureus2.core3.internat.MessageText;
@@ -43,22 +42,31 @@ import org.gudy.azureus2.core3.logging.LogAlert;
 import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.peer.PEPeerManager;
 import org.gudy.azureus2.core3.peer.PEPeerSource;
-import org.gudy.azureus2.core3.torrent.*;
+import org.gudy.azureus2.core3.torrent.TOTorrent;
+import org.gudy.azureus2.core3.torrent.TOTorrentFactory;
 import org.gudy.azureus2.core3.tracker.client.TRTrackerAnnouncer;
 import org.gudy.azureus2.core3.tracker.util.TRTrackerUtils;
 import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.plugins.PluginInterface;
+import org.gudy.azureus2.pluginsimpl.local.PluginCoreUtils;
+import org.gudy.azureus2.plugins.ui.UIInputReceiver;
+import org.gudy.azureus2.plugins.ui.UIInputReceiverListener;
 import org.gudy.azureus2.ui.swt.exporttorrent.wizard.ExportTorrentWizard;
 import org.gudy.azureus2.ui.swt.mainwindow.ClipboardCopy;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
 import org.gudy.azureus2.ui.swt.maketorrent.MultiTrackerEditor;
 import org.gudy.azureus2.ui.swt.maketorrent.TrackerEditorListener;
+import org.gudy.azureus2.ui.swt.maketorrent.WebSeedsEditor;
+import org.gudy.azureus2.ui.swt.maketorrent.WebSeedsEditorListener;
 import org.gudy.azureus2.ui.swt.minibar.DownloadBar;
+import org.gudy.azureus2.ui.swt.shells.AdvRenameWindow;
 import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.views.ViewUtils;
 import org.gudy.azureus2.ui.swt.views.utils.ManagerUtils;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
+import com.aelitis.azureus.plugins.extseed.ExternalSeedPlugin;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
 import com.aelitis.azureus.ui.common.table.TableColumnCore;
@@ -475,6 +483,118 @@ public class TorrentUtil {
 		
 		itemEditTracker.setEnabled(hasSelection);
 
+			// edit webseeds
+		
+		final MenuItem itemEditWebSeeds = new MenuItem(menuTracker, SWT.PUSH);
+		Messages.setLanguageText(itemEditWebSeeds, "MyTorrentsView.menu.editWebSeeds");
+		itemEditWebSeeds.addListener(SWT.Selection, new DMTask(dms) {
+			public void 
+			run(
+				final DownloadManager[] dms ) 
+			{
+				final TOTorrent torrent = dms[0].getTorrent();
+				
+				if ( torrent == null ){
+					
+					return;
+				}
+				
+				List getright = getURLList( torrent, "url-list" );
+				List webseeds = getURLList( torrent, "httpseeds" );
+				
+				Map ws = new HashMap();
+								
+				ws.put( "getright", getright );								
+				ws.put( "webseeds", webseeds );
+				
+				ws = BDecoder.decodeStrings( ws );
+				
+				new WebSeedsEditor(
+						null, ws,
+						new WebSeedsEditorListener()
+						{
+							public void 
+							webSeedsChanged(
+								String 	oldName,
+								String 	newName, 
+								Map 	ws ) 
+							{
+								try{
+										// String -> byte[] 
+									
+									ws = BDecoder.decode( BEncoder.encode( ws ));
+									
+									List	getright =  (List)ws.get( "getright" );
+									
+									if ( getright == null || getright.size() == 0 ){
+										
+										torrent.removeAdditionalProperty( "url-list" );
+										
+									}else{
+										
+										torrent.setAdditionalListProperty( "url-list", getright );
+									}
+									
+									List	webseeds =  (List)ws.get( "webseeds" );
+									
+									if ( webseeds == null || webseeds.size() == 0 ){
+										
+										torrent.removeAdditionalProperty( "httpseeds" );
+										
+									}else{
+										
+										torrent.setAdditionalListProperty( "httpseeds", webseeds );
+									}
+			
+									PluginInterface pi = AzureusCoreFactory.getSingleton().getPluginManager().getPluginInterfaceByClass(ExternalSeedPlugin.class);
+									
+									if ( pi != null ){
+										
+										ExternalSeedPlugin ext_seed_plugin = (ExternalSeedPlugin)pi.getPlugin();
+										
+										ext_seed_plugin.downloadChanged( PluginCoreUtils.wrap( dms[0] ));
+									}
+						
+								}catch (Throwable e){
+						
+									Debug.printStackTrace( e );
+								}
+							}
+						},
+						true );
+
+			}
+			
+			protected List
+			getURLList(
+				TOTorrent	torrent,
+				String		key )
+			{
+				Object obj = torrent.getAdditionalProperty( key );
+				
+				if ( obj instanceof byte[] ){
+					
+	                List l = new ArrayList();
+	                
+			        l.add(obj);
+			        
+			        return( l );
+			        
+				}else if ( obj instanceof List ){
+					
+					return((List)obj);
+					
+				}else{
+					
+					return( new ArrayList());
+				}
+			}
+		});
+		
+		itemEditWebSeeds.setEnabled(dms.length==1);
+
+			// manual update
+		
 		final MenuItem itemManualUpdate = new MenuItem(menuTracker, SWT.PUSH);
 		Messages.setLanguageText(itemManualUpdate, "GeneralView.label.trackerurlupdate"); //$NON-NLS-1$
 		//itemManualUpdate.setImage(ImageRepository.getImage("edit_trackers"));
@@ -635,101 +755,16 @@ public class TorrentUtil {
 		itemFileClearResume.setEnabled(allStopped);
 
 		// Advanced - > Rename
-		final MenuItem itemRename = new MenuItem(menuAdvanced, SWT.CASCADE);
+		final MenuItem itemRename = new MenuItem(menuAdvanced, SWT.DROP_DOWN);
 		Messages.setLanguageText(itemRename, "MyTorrentsView.menu.rename");
-		itemRename.setEnabled(hasSelection);
-
-		final Menu menuRename = new Menu(composite.getShell(), SWT.DROP_DOWN);
-		itemRename.setMenu(menuRename);
-		
-		DownloadManager first_selected = (dms.length == 0) ? null : dms[0];
-		
-		// Advanced - > Rename -> Displayed Name
-		final MenuItem itemRenameDisplayed = new MenuItem(menuRename, SWT.CASCADE);
-		Messages.setLanguageText(itemRenameDisplayed, "MyTorrentsView.menu.rename.displayed");
-		itemRenameDisplayed.setEnabled(hasSelection);
-		if (itemRenameDisplayed.isEnabled()) {
-			itemRenameDisplayed.setData("suggested_text", first_selected.getDisplayName());
-			itemRenameDisplayed.setData("display_name", Boolean.TRUE);
-			itemRenameDisplayed.setData("save_name", Boolean.FALSE);
-			itemRenameDisplayed.setData("rename_all", Boolean.FALSE);
-			itemRenameDisplayed.setData("msg_key", "displayed");
-		}
-
-		// Rename -> Save Name
-		final MenuItem itemRenameSavePath = new MenuItem(menuRename, SWT.CASCADE);
-		Messages.setLanguageText(itemRenameSavePath, "MyTorrentsView.menu.rename.save_path");
-		itemRenameSavePath.setEnabled(fileMove && dms.length == 1);
-		if (itemRenameSavePath.isEnabled()) {
-			itemRenameSavePath.setData("suggested_text", first_selected.getAbsoluteSaveLocation().getName());
-			itemRenameSavePath.setData("display_name", Boolean.FALSE);
-			itemRenameSavePath.setData("save_name", Boolean.TRUE);
-			itemRenameSavePath.setData("rename_all", Boolean.FALSE);
-			itemRenameSavePath.setData("msg_key", "save_path");
-		}
-
-		// Rename -> Both
-		final MenuItem itemRenameBoth = new MenuItem(menuRename, SWT.CASCADE);
-		Messages.setLanguageText(itemRenameBoth, "MyTorrentsView.menu.rename.displayed_and_save_path");
-		itemRenameBoth.setEnabled(fileMove && dms.length == 1);
-		if (itemRenameBoth.isEnabled()) {
-			itemRenameBoth.setData("suggested_text", first_selected.getAbsoluteSaveLocation().getName());
-			itemRenameBoth.setData("display_name", Boolean.TRUE);
-			itemRenameBoth.setData("save_name", Boolean.TRUE);
-			itemRenameBoth.setData("msg_key", "displayed_and_save_path");
-			itemRenameBoth.setData("rename_all", Boolean.FALSE);
-		}
-
-		Listener rename_listener = new Listener() {
+		itemRename.setEnabled(hasSelection && dms.length == 1);
+		itemRename.addListener(SWT.Selection, new Listener() {
 			public void handleEvent(Event event) {
-				MenuItem mi = (MenuItem) event.widget;
-				String suggested = (String) mi.getData("suggested_text");
-				final boolean rename_all = ((Boolean) mi.getData("rename_all")).booleanValue();
-				final boolean change_displayed_name = ((Boolean) mi.getData("display_name")).booleanValue();
-				final boolean change_save_name = ((Boolean) mi.getData("save_name")).booleanValue();
-				String msg_key_prefix = "MyTorrentsView.menu.rename." + (String) mi.getData("msg_key") + ".enter.";
-				SimpleTextEntryWindow text_entry = new SimpleTextEntryWindow();
-				text_entry.setTitle(msg_key_prefix + "title");
-				text_entry.setMessage(msg_key_prefix + "message");
-				text_entry.setPreenteredText(suggested, false);
-				text_entry.prompt();
-				if (text_entry.hasSubmittedInput()) {
-					String value = text_entry.getSubmittedInput();
-					final String value_to_set = (value.length() == 0) ? null : value;
-					DMTask task = new DMTask(dms) {
-						public void run(DownloadManager dm) {
-							if (rename_all) {
-								try {
-									dm.rename(value_to_set);
-								}
-								catch (Exception e) {
-									Logger.log(new LogAlert(dm, LogAlert.REPEATABLE,
-											"Download data rename operation failed", e));
-								}
-							}
-							if (change_displayed_name) {
-								dm.getDownloadState().setDisplayName(value_to_set);
-							}
-							if (change_save_name) {
-								try {
-									dm.renameDownload((value_to_set == null) ? dm.getDisplayName() : value_to_set);
-								}
-								catch (Exception e) {
-									Logger.log(new LogAlert(dm, LogAlert.REPEATABLE,
-											"Download data rename operation failed", e));
-								}
-							}
-						}
-					};
-					task.go();
-				}
+				AdvRenameWindow window = new AdvRenameWindow();
+				window.open(dms[0]);
 			}
-		};
+		});
 
-		itemRenameDisplayed.addListener(SWT.Selection, rename_listener);
-		itemRenameSavePath.addListener(SWT.Selection, rename_listener);
-		itemRenameBoth.addListener(SWT.Selection, rename_listener);
-		
 		// === advanced > export ===
 		// =========================
 
@@ -1040,38 +1075,41 @@ public class TorrentUtil {
 				SimpleTextEntryWindow entryWindow = new SimpleTextEntryWindow(
 						"MyTorrentsView.dialog.setPosition.title",
 						"MyTorrentsView.dialog.setPosition.text");
-				entryWindow.prompt();
-				if (!entryWindow.hasSubmittedInput()) {
-					return;
-				}
-				String sReturn = entryWindow.getSubmittedInput();
-
-				if (sReturn == null)
-					return;
-
-				int newPosition = -1;
-				try {
-					newPosition = Integer.valueOf(sReturn).intValue();
-				} catch (NumberFormatException er) {
-					// Ignore
-				}
-
-				int size = azureus_core.getGlobalManager().downloadManagerCount(
-						isSeedingView);
-				if (newPosition > size)
-					newPosition = size;
-
-				if (newPosition <= 0) {
-					MessageBox mb = new MessageBox(composite.getShell(), SWT.ICON_ERROR
-							| SWT.OK);
-					mb.setText(MessageText.getString("MyTorrentsView.dialog.NumberError.title"));
-					mb.setMessage(MessageText.getString("MyTorrentsView.dialog.NumberError.text"));
-
-					mb.open();
-					return;
-				}
-
-				moveSelectedTorrentsTo(tv, dms, newPosition);
+				entryWindow.prompt(new UIInputReceiverListener() {
+					public void UIInputReceiverClosed(UIInputReceiver entryWindow) {
+						if (!entryWindow.hasSubmittedInput()) {
+							return;
+						}
+						String sReturn = entryWindow.getSubmittedInput();
+						
+						if (sReturn == null)
+							return;
+						
+						int newPosition = -1;
+						try {
+							newPosition = Integer.valueOf(sReturn).intValue();
+						} catch (NumberFormatException er) {
+							// Ignore
+						}
+						
+						int size = azureus_core.getGlobalManager().downloadManagerCount(
+								isSeedingView);
+						if (newPosition > size)
+							newPosition = size;
+						
+						if (newPosition <= 0) {
+							MessageBox mb = new MessageBox(composite.getShell(), SWT.ICON_ERROR
+									| SWT.OK);
+							mb.setText(MessageText.getString("MyTorrentsView.dialog.NumberError.title"));
+							mb.setMessage(MessageText.getString("MyTorrentsView.dialog.NumberError.text"));
+							
+							mb.open();
+							return;
+						}
+						
+						moveSelectedTorrentsTo(tv, dms, newPosition);
+					}
+				});
 			}
 		});
 
@@ -1400,10 +1438,13 @@ public class TorrentUtil {
 					boolean found = dm.filesExist(true);
 					if (!found && dm.getTorrent() != null
 							&& !dm.getTorrent().isSimpleTorrent()) {
-						sSavePath = fSavePath.getParent();
-						if (sSavePath != null) {
-							dm.setTorrentSaveDir(sSavePath);
+						String parentPath = fSavePath.getParent();
+						if (parentPath != null) {
+							dm.setTorrentSaveDir(parentPath);
 							found = dm.filesExist(true);
+							if (!found) {
+								dm.setTorrentSaveDir(sSavePath);
+							}
 						}
 					}
 
@@ -1506,7 +1547,7 @@ public class TorrentUtil {
 		task.go();
 	}
 	
-	public static void promptUserForComment(DownloadManager[] dms) {
+	public static void promptUserForComment(final DownloadManager[] dms) {
 		if (dms.length == 0) {return;}
 		DownloadManager dm = dms[0];
 		
@@ -1518,18 +1559,21 @@ public class TorrentUtil {
 		text_entry.setMessage(msg_key_prefix + "message");
 		text_entry.setPreenteredText(suggested, false);
 		text_entry.setMultiLine(true);
-		text_entry.prompt();
-		
-		if (text_entry.hasSubmittedInput()) {
-			String value = text_entry.getSubmittedInput();
-			final String value_to_set = (value.length() == 0) ? null : value;
-			DMTask task = new DMTask(dms) {
-				public void run(DownloadManager dm) {
-					dm.getDownloadState().setUserComment(value_to_set);
+		text_entry.prompt(new UIInputReceiverListener() {
+			public void UIInputReceiverClosed(UIInputReceiver text_entry) {
+				if (text_entry.hasSubmittedInput()) {
+					String value = text_entry.getSubmittedInput();
+					final String value_to_set = (value.length() == 0) ? null : value;
+					DMTask task = new DMTask(dms) {
+						public void run(DownloadManager dm) {
+							dm.getDownloadState().setUserComment(value_to_set);
+						}
+					};
+					task.go();
 				}
-			};
-			task.go();
-		}
+			}
+		});
+		
 	}
 
 
@@ -1627,7 +1671,7 @@ public class TorrentUtil {
 		if (!sFirstChunk.startsWith("d")) {
 			if (parentShell != null) {
   			boolean isHTML = sFirstChunk.indexOf("<html") >= 0;
-  			MessageBoxShell boxShell = new MessageBoxShell(parentShell,
+  			MessageBoxShell boxShell = new MessageBoxShell(
   					MessageText.getString("OpenTorrentWindow.mb.notTorrent.title"),
   					MessageText.getString("OpenTorrentWindow.mb.notTorrent.text",
   							new String[] {
@@ -1639,7 +1683,7 @@ public class TorrentUtil {
   			if (isHTML) {
   				boxShell.setHtml(sFirstChunk);
   			}
-  			boxShell.open();
+  			boxShell.open(null);
 			}
 
 			return false;
