@@ -24,6 +24,8 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Shell;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.download.DownloadManager;
@@ -34,6 +36,9 @@ import org.gudy.azureus2.core3.tracker.client.TRTrackerScraperResponse;
 import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 
+import com.aelitis.azureus.core.util.CopyOnWriteList;
+import com.aelitis.azureus.ui.swt.UIFunctionsManagerSWT;
+
 /**
  * @author TuxPaper
  * @created Nov 6, 2006
@@ -43,6 +48,15 @@ public class UIExitUtilsSWT
 {
 	private static boolean skipCloseCheck = false;
 	
+	private static CopyOnWriteList<canCloseListener>	listeners	= new CopyOnWriteList<canCloseListener>();
+	
+	public static void
+	addListener(
+		canCloseListener	l )
+	{
+		listeners.add( l );
+	}
+	
 	public static void setSkipCloseCheck(boolean b) {
 		skipCloseCheck = b;
 	}
@@ -56,12 +70,31 @@ public class UIExitUtilsSWT
 			return true;
 		}
 		
+		Shell mainShell = UIFunctionsManagerSWT.getUIFunctionsSWT().getMainShell();
+		if (mainShell != null
+				&& (!mainShell.isVisible() || mainShell.getMinimized())
+				&& COConfigurationManager.getBooleanParameter("Password enabled")) {
+
+			if (!PasswordWindow.showPasswordWindow(Display.getCurrent())) {
+				return false;
+			}
+		}
+		
+		
 		if (COConfigurationManager.getBooleanParameter("confirmationOnExit")) {
 			if (!getExitConfirmation(bForRestart)) {
 				return false;
 			}
 		}
 
+		for ( canCloseListener listener: listeners ){
+			
+			if ( !listener.canClose()){
+				
+				return( false );
+			}
+		}
+		
 		if (globalManager != null) {
 			ArrayList listUnfinished = new ArrayList();
 			Object[] dms = globalManager.getDownloadManagers().toArray();
@@ -99,16 +132,16 @@ public class UIExitUtilsSWT
 											});
 
 									MessageBoxShell mb = new MessageBoxShell(
-											Utils.findAnyShell(),
 											title,
 											text,
 											new String[] {
 												MessageText.getString("UpdateWindow.quit"),
 												MessageText.getString("Content.alert.notuploaded.button.abort")
-											}, 1, null, null, false, 0);
+											}, 1);
 									mb.setRelatedObject(((DownloadManager) flistUnfinished.get(0)));
 
-									return mb.open() == 0;
+									mb.open(null);
+									return mb.waitUntilClosed() == 0;
 								}
 							}, 0);
 				} else {
@@ -134,15 +167,15 @@ public class UIExitUtilsSWT
 											});
 
 									MessageBoxShell mb = new MessageBoxShell(
-											Utils.findAnyShell(),
 											title,
 											text,
 											new String[] {
 												MessageText.getString("UpdateWindow.quit"),
 												MessageText.getString("Content.alert.notuploaded.button.abort")
-											}, 1, null, null, false, 0);
+											}, 1);
 
-									return mb.open() == 0;
+									mb.open(null);
+									return mb.waitUntilClosed() == 0;
 								}
 							}, 0);
 				}
@@ -159,12 +192,12 @@ public class UIExitUtilsSWT
 	 * @author Rene Leonhardt
 	 */
 	private static boolean getExitConfirmation(boolean for_restart) {
-		int result = Utils.openMessageBox(Utils.findAnyShell(), SWT.ICON_WARNING
-				| SWT.YES | SWT.NO, for_restart
-				? "MainWindow.dialog.restartconfirmation"
+		MessageBoxShell mb = new MessageBoxShell(SWT.ICON_WARNING | SWT.YES
+				| SWT.NO, for_restart ? "MainWindow.dialog.restartconfirmation"
 				: "MainWindow.dialog.exitconfirmation", (String[]) null);
+		mb.open(null);
 
-		return result == SWT.YES;
+		return mb.waitUntilClosed() == SWT.YES;
 	}
 
 	public static void uiShutdown() {
@@ -190,4 +223,11 @@ public class UIExitUtilsSWT
 			close.start();
 		}
 	}
+	
+	public interface
+	canCloseListener
+	{
+		public boolean
+		canClose();
+	}
 }
