@@ -21,12 +21,13 @@
 
 package org.gudy.azureus2.ui.swt;
 
+import java.io.File;
 import java.util.*;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.SWTException;
-import org.eclipse.swt.custom.ScrolledComposite;
+import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.dnd.*;
 import org.eclipse.swt.events.*;
 import org.eclipse.swt.graphics.*;
@@ -38,12 +39,15 @@ import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.util.*;
 import org.gudy.azureus2.core3.util.Timer;
+import org.gudy.azureus2.platform.PlatformManager;
+import org.gudy.azureus2.platform.PlatformManagerCapabilities;
+import org.gudy.azureus2.platform.PlatformManagerFactory;
+import org.gudy.azureus2.plugins.platform.PlatformManagerException;
 import org.gudy.azureus2.ui.swt.mainwindow.Colors;
 import org.gudy.azureus2.ui.swt.mainwindow.SWTThread;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
 import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
-import org.gudy.azureus2.ui.swt.views.utils.VerticalAligner;
 
 import com.aelitis.azureus.ui.swt.UIFunctionsManagerSWT;
 import com.aelitis.azureus.ui.swt.UIFunctionsSWT;
@@ -58,6 +62,10 @@ public class Utils
 	public static final String GOOD_STRING = "(/|,jI~`gy";
 
 	public static final boolean isGTK = SWT.getPlatform().equals("gtk");
+	
+	public static final boolean isCarbon = SWT.getPlatform().equals("carbon");
+
+	public static final boolean isCocoa = SWT.getPlatform().equals("cocoa");
 
 	/** Some platforms expand the last column to fit the remaining width of
 	 * the table.
@@ -67,11 +75,6 @@ public class Utils
 	/** GTK already handles alternating background for tables */
 	public static final boolean TABLE_GRIDLINE_IS_ALTERNATING_COLOR = isGTK;
 
-	private static final boolean DIRECT_SETCHECKED = !Constants.isOSX
-			|| SWT.getVersion() >= 3212;
-
-	public static final boolean SWT32_TABLEPAINT = SWT.getVersion() >= 3200;
-
 	/**
 	 * Debug/Diagnose SWT exec calls.  Provides usefull information like how
 	 * many we are queuing up, and how long each call takes.  Good to turn on
@@ -80,12 +83,14 @@ public class Utils
 	private static final boolean DEBUG_SWTEXEC = System.getProperty(
 			"debug.swtexec", "0").equals("1");
 
-	private static ArrayList queue;
+	private static ArrayList<Runnable> queue;
 
 	private static AEDiagnosticsLogger diag_logger;
 
 	private static Image[] shellIcons = null;
 
+	private static Image icon128;
+
 	private final static String[] shellIconNames = {
 		"azureus",
 		"azureus32",
@@ -97,9 +102,20 @@ public class Utils
 
 	static {
 		if (DEBUG_SWTEXEC) {
-			queue = new ArrayList();
+			queue = new ArrayList<Runnable>();
 			diag_logger = AEDiagnostics.getLogger("swt");
 			diag_logger.log("\n\nSWT Logging Starts");
+			
+			AEDiagnostics.addEvidenceGenerator(new AEDiagnosticsEvidenceGenerator(){
+				public void generate(IndentWriter writer) {
+					writer.println("SWT Queue:");
+					writer.indent();
+					for (Runnable r : queue) {
+						writer.println(r.toString());
+					}
+					writer.exdent();
+				}
+			});
 		} else {
 			queue = null;
 			diag_logger = null;
@@ -156,37 +172,12 @@ public class Utils
 		if (disposeList == null) {
 			return;
 		}
-		boolean bResourceObjectExists = SWT.getVersion() >= 3129;
-
 		for (int i = 0; i < disposeList.length; i++) {
 			Object o = disposeList[i];
 			if (o instanceof Widget && !((Widget) o).isDisposed())
 				((Widget) o).dispose();
-			else if (bResourceObjectExists && (o instanceof Resource)
-					&& !((Resource) o).isDisposed())
+			else if ((o instanceof Resource) && !((Resource) o).isDisposed()) {
 				((Resource) o).dispose();
-			else {
-				try {
-					// For Pre-SWT 3.1
-					if ((o instanceof Cursor) && !((Cursor) o).isDisposed()) {
-						((Cursor) o).dispose();
-					} else if ((o instanceof Font) && !((Font) o).isDisposed()) {
-						((Font) o).dispose();
-					} else if ((o instanceof GC) && !((GC) o).isDisposed()) {
-						((GC) o).dispose();
-					} else if ((o instanceof Image) && !((Image) o).isDisposed()) {
-						((Image) o).dispose();
-					} else if ((o instanceof Region) && !((Region) o).isDisposed()) {
-						((Region) o).dispose(); // 3.0
-					} else if ((o instanceof TextLayout)
-							&& !((TextLayout) o).isDisposed()) {
-						((TextLayout) o).dispose(); // 3.0
-					}
-				} catch (NoClassDefFoundError e) {
-					// ignore
-				}
-				// Path, Pattern, Transform are all 3.1, which will be instances of 
-				// Resource
 			}
 		}
 	}
@@ -232,10 +223,14 @@ public class Utils
 
 	public static void centreWindow(Shell shell) {
 		Rectangle displayArea; // area to center in
-		try {
-			displayArea = shell.getMonitor().getClientArea();
-		} catch (NoSuchMethodError e) {
-			displayArea = shell.getDisplay().getClientArea();
+		if (shell.getParent() != null) {
+			displayArea = shell.getParent().getBounds();
+		} else {
+  		try {
+  			displayArea = shell.getMonitor().getClientArea();
+  		} catch (NoSuchMethodError e) {
+  			displayArea = shell.getDisplay().getClientArea();
+  		}
 		}
 
 		Rectangle shellRect = shell.getBounds();
@@ -293,21 +288,12 @@ public class Utils
 			final boolean bAllowShareAdd, final Text url,
 			DropTargetListener dropTargetListener) {
 
-		Transfer[] transferList;
-		if (SWT.getVersion() >= 3107) {
-			transferList = new Transfer[] {
-				HTMLTransfer.getInstance(),
-				URLTransfer.getInstance(),
-				FileTransfer.getInstance(),
-				TextTransfer.getInstance()
-			};
-		} else {
-			transferList = new Transfer[] {
-				URLTransfer.getInstance(),
-				FileTransfer.getInstance(),
-				TextTransfer.getInstance()
-			};
-		}
+		Transfer[] transferList = new Transfer[] {
+			HTMLTransfer.getInstance(),
+			URLTransfer.getInstance(),
+			FileTransfer.getInstance(),
+			TextTransfer.getInstance()
+		};
 
 		final DropTarget dropTarget = new DropTarget(composite, DND.DROP_DEFAULT
 				| DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_LINK | DND.DROP_TARGET_MOVE);
@@ -394,89 +380,6 @@ public class Utils
 		}
 	}
 
-	/**
-	 * Force label to use more vertical space if wrapped and in a GridLayout
-	 * Place this listener on the _parent_ of the label
-	 * See Eclipse SWT Bug #9866 (GridLayout does not handle wrapped Label properly)
-	 * This workaround only works for labels who:
-	 *   - horizontally span their whole parent 
-	 *     (ie. the parent has 3 columns, the label must span 3 columns)
-	 *   - GridData style has GridData.FILL_HORIZONTAL
-	 *   - Label style has SWT.WRAP
-	 *
-	 * @author TuxPaper
-	 * @note Bug 9866 fixed in 3105 and later
-	 */
-	public static class LabelWrapControlListener
-		extends ControlAdapter
-	{
-		public void controlResized(ControlEvent e) {
-			if (SWT.getVersion() >= 3105)
-				return;
-			Composite parent = (Composite) e.widget;
-			Control children[] = parent.getChildren();
-
-			if (children.length > 0) {
-				GridLayout parentLayout = (GridLayout) parent.getLayout();
-				if (parentLayout != null) {
-					Point size;
-					int marginWidth = parentLayout.marginWidth;
-
-					Composite grandParent = parent.getParent();
-					if (grandParent instanceof ScrolledComposite) {
-						Composite greatGP = grandParent.getParent();
-						if (greatGP != null) {
-							size = greatGP.getSize();
-
-							if (greatGP.getLayout() instanceof GridLayout) {
-								marginWidth += ((GridLayout) greatGP.getLayout()).marginWidth;
-							}
-						} else {
-							// not tested
-							size = grandParent.getSize();
-						}
-
-						if (grandParent.getLayout() instanceof GridLayout) {
-							marginWidth += ((GridLayout) grandParent.getLayout()).marginWidth;
-						}
-
-						ScrollBar sb = grandParent.getVerticalBar();
-						if (sb != null) {
-							// I don't know why, but we have to remove one
-							size.x -= sb.getSize().x + 1;
-						}
-					} else
-						size = parent.getSize();
-
-					boolean oneChanged = false;
-					for (int i = 0; i < children.length; i++) {
-						if ((children[i] instanceof Label)
-								&& (children[i].getStyle() & SWT.WRAP) == SWT.WRAP) {
-							GridData gd = (GridData) children[i].getLayoutData();
-							if (gd != null && gd.horizontalAlignment == GridData.FILL) {
-								if (gd.horizontalSpan == parentLayout.numColumns) {
-									gd.widthHint = size.x - 2 * marginWidth;
-									oneChanged = true;
-								} else {
-									Point pt = children[i].getLocation();
-									gd.widthHint = size.x - pt.x - (2 * marginWidth);
-									oneChanged = true;
-								}
-							}
-						}
-					}
-					if (oneChanged) {
-						parent.layout(true);
-						if (grandParent instanceof ScrolledComposite) {
-							((ScrolledComposite) grandParent).setMinSize(parent.computeSize(
-									SWT.DEFAULT, SWT.DEFAULT, true));
-						}
-					}
-				}
-			} // size
-		} // controlResized
-	} // class
-
 	public static void alternateRowBackground(TableItem item) {
 		if (Utils.TABLE_GRIDLINE_IS_ALTERNATING_COLOR) {
 			if (!item.getParent().getLinesVisible())
@@ -570,6 +473,33 @@ public class Utils
 	 */
 	public static void setShellIcon(Shell shell) {
 		if (Constants.isOSX) {
+			if (true) {
+				return;
+			}
+			if (icon128 == null) {
+  			ImageLoader imageLoader = ImageLoader.getInstance();
+  			icon128 = imageLoader.getImage("azureus128");
+  			if (Constants.isCVSVersion()) {
+  				final int border = 9;
+					Image image = Utils.createAlphaImage(shell.getDisplay(),
+							128 + (border * 2), 128 + (border * 2));
+					image = blitImage(shell.getDisplay(), icon128, null, image, new Point(border,
+							border + 1));
+					imageLoader.releaseImage("azureus128");
+					icon128 = image;
+//  				GC gc = new GC(icon128);
+//  				gc.setTextAntialias(SWT.ON);
+//  				gc.setForeground(shell.getDisplay().getSystemColor(SWT.COLOR_YELLOW));
+//  				Font font = getFontWithHeight(gc.getFont(), gc, 20, SWT.BOLD);
+//  				gc.setFont(font);
+//					GCStringPrinter.printString(gc, Constants.AZUREUS_VERSION,
+//							new Rectangle(0, 0, 128, 128), false, false, SWT.CENTER
+//									| SWT.BOTTOM);
+//  				gc.dispose();
+//  				font.dispose();
+  			}
+			}
+ 			shell.setImage(icon128);
 			return;
 		}
 
@@ -745,9 +675,15 @@ public class Utils
 
 								queue.remove(code);
 
-								diag_logger.log(SystemTime.getCurrentTime()
-										+ "] - Q. size=" + queue.size() + ";wait:" + wait
-										+ "ms;run:" + runTIme + "ms");
+								if (runTIme > 10) {
+									diag_logger.log(SystemTime.getCurrentTime()
+											+ "] - Q. size=" + queue.size() + ";wait:" + wait
+											+ "ms;run:" + runTIme + "ms " + code);
+								} else {
+									diag_logger.log(SystemTime.getCurrentTime()
+											+ "] - Q. size=" + queue.size() + ";wait:" + wait
+											+ "ms;run:" + runTIme + "ms");
+								}
 							}
 						}
 					};
@@ -820,153 +756,6 @@ public class Utils
 		return (display.getThread() == Thread.currentThread());
 	}
 
-	/** Open a messagebox using resource keys for title/text
-	 * 
-	 * @param parent Parent shell for messagebox
-	 * @param style SWT styles for messagebox
-	 * @param keyPrefix message bundle key prefix used to get title and text.  
-	 *         Title will be keyPrefix + ".title", and text will be set to
-	 *         keyPrefix + ".text"
-	 * @param textParams any parameters for text
-	 * 
-	 * @return what the messagebox returns
-	 */
-	public static int openMessageBox(Shell parent, int style, String keyPrefix,
-			String[] textParams) {
-		if ((style & (0x7f << 5)) == 0) {
-			// need at least one button
-			style |= SWT.OK;
-		}
-		Object[] buttonInfo = swtButtonStylesToText(style);
-		MessageBoxShell mb = new MessageBoxShell(parent,
-				MessageText.getString(keyPrefix + ".title"), MessageText.getString(
-						keyPrefix + ".text", textParams), (String[]) buttonInfo[0], 0);
-		mb.setLeftImage(style & 0x1f);
-		int ret = mb.open();
-
-		Integer[] buttonVals = (Integer[]) buttonInfo[1];
-		if (ret < 0 || ret > buttonVals.length) {
-			return SWT.CANCEL;
-		}
-		return buttonVals[ret].intValue();
-	}
-
-	/** Open a messagebox with actual title and text
-	 * 
-	 * @param parent
-	 * @param style
-	 * @param title
-	 * @param text
-	 * @return
-	 */
-	public static int openMessageBox(Shell parent, int style, String title,
-			String text) {
-		if (parent == null) {
-			parent = findAnyShell();
-		}
-		if ((style & (0x7f << 5)) == 0) {
-			// need at least one button
-			style |= SWT.OK;
-		}
-
-		Object[] buttonInfo = swtButtonStylesToText(style);
-		MessageBoxShell mb = new MessageBoxShell(parent, title, text,
-				(String[]) buttonInfo[0], 0);
-		mb.setLeftImage(style & 0x1f);
-		int ret = mb.open();
-
-		Integer[] buttonVals = (Integer[]) buttonInfo[1];
-		if (ret < 0 || ret > buttonVals.length) {
-			return SWT.CANCEL;
-		}
-		return buttonVals[ret].intValue();
-	}
-
-	public static int openMessageBox(Shell parent, int style, int default_style,
-			String title, String text) {
-		if (parent == null) {
-			parent = findAnyShell();
-		}
-		if ((style & (0x7f << 5)) == 0) {
-			// need at least one button
-			style |= SWT.OK;
-		}
-
-		Object[] buttonInfo = swtButtonStylesToText(style);
-
-		Object[] defaultButtonInfo = swtButtonStylesToText(default_style);
-
-		int defaultIndex = 0;
-
-		if (defaultButtonInfo.length > 0) {
-			String name = ((String[]) defaultButtonInfo[0])[0];
-
-			String[] names = (String[]) buttonInfo[0];
-
-			for (int i = 0; i < names.length; i++) {
-				if (names[i].equals(name)) {
-					defaultIndex = i;
-					break;
-				}
-			}
-		}
-		MessageBoxShell mb = new MessageBoxShell(parent, title, text,
-				(String[]) buttonInfo[0], defaultIndex);
-		mb.setLeftImage(style & 0x1f);
-		int ret = mb.open();
-
-		Integer[] buttonVals = (Integer[]) buttonInfo[1];
-		if (ret < 0 || ret > buttonVals.length) {
-			return SWT.CANCEL;
-		}
-		return buttonVals[ret].intValue();
-	}
-
-	private static Object[] swtButtonStylesToText(int style) {
-		List buttons = new ArrayList(2);
-		List buttonVal = new ArrayList(2);
-		int buttonCount = 0;
-		if ((style & SWT.OK) > 0) {
-			buttons.add(MessageText.getString("Button.ok"));
-			buttonVal.add(new Integer(SWT.OK));
-			buttonCount++;
-		}
-		if ((style & SWT.YES) > 0) {
-			buttons.add(MessageText.getString("Button.yes"));
-			buttonVal.add(new Integer(SWT.YES));
-			buttonCount++;
-		}
-		if ((style & SWT.NO) > 0) {
-			buttons.add(MessageText.getString("Button.no"));
-			buttonVal.add(new Integer(SWT.NO));
-			buttonCount++;
-		}
-		if ((style & SWT.CANCEL) > 0) {
-			buttons.add(MessageText.getString("Button.cancel"));
-			buttonVal.add(new Integer(SWT.CANCEL));
-			buttonCount++;
-		}
-		if ((style & SWT.ABORT) > 0) {
-			buttons.add(MessageText.getString("Button.abort"));
-			buttonVal.add(new Integer(SWT.ABORT));
-			buttonCount++;
-		}
-		if ((style & SWT.RETRY) > 0) {
-			buttons.add(MessageText.getString("Button.retry"));
-			buttonVal.add(new Integer(SWT.RETRY));
-			buttonCount++;
-		}
-		if ((style & SWT.IGNORE) > 0) {
-			buttons.add(MessageText.getString("Button.ignore"));
-			buttonVal.add(new Integer(SWT.IGNORE));
-			buttonCount++;
-		}
-		return new Object[] {
-			(String[]) buttons.toArray(new String[buttonCount]),
-			(Integer[]) buttonVal.toArray(new Integer[buttonCount])
-		};
-	}
-
 	/**
 	 * Bottom Index may be negative. Returns bottom index even if invisible.
 	 */
@@ -1023,21 +812,22 @@ public class Utils
 		if (sFile == null || sFile.trim().length() == 0) {
 			return;
 		}
-
-		if (SWT.getVersion() >= 3315 || SWT.getVersion() < 3300
-				|| UrlUtils.isURL(sFile) || sFile.startsWith("mailto:")) {
-			boolean launched = Program.launch(sFile);
-			if (!launched && Constants.isUnix
-					&& (UrlUtils.isURL(sFile) || sFile.startsWith("mailto:"))) {
-				if (!Program.launch("xdg-open " + sFile)) {
-					Program.launch("htmlview " + sFile);
+		
+		if (!Constants.isWindows && new File(sFile).isDirectory()) {
+			PlatformManager mgr = PlatformManagerFactory.getPlatformManager();
+			if (mgr.hasCapability(PlatformManagerCapabilities.ShowFileInBrowser)) {
+				try {
+					PlatformManagerFactory.getPlatformManager().showFile(sFile);
+					return;
+				} catch (PlatformManagerException e) {
 				}
 			}
-		} else {
-			if (Constants.isOSX) {
-				Program.launch("file://" + sFile.replaceAll(" ", "%20"));
-			} else {
-				Program.launch(sFile);
+		}
+
+		boolean launched = Program.launch(sFile);
+		if (!launched && Constants.isUnix) {
+			if (!Program.launch("xdg-open " + sFile)) {
+				Program.launch("htmlview " + sFile);
 			}
 		}
 	}
@@ -1051,29 +841,26 @@ public class Utils
 	 */
 	public static void setCheckedInSetData(final TableItem item,
 			final boolean checked) {
-		if (DIRECT_SETCHECKED) {
-			item.setChecked(checked);
-		} else {
-			item.setChecked(!checked);
-			item.getDisplay().asyncExec(new AERunnable() {
-				public void runSupport() {
-					item.setChecked(checked);
-				}
-			});
-		}
+		item.setChecked(checked);
 
 		if (Constants.isWindowsXP || isGTK) {
 			Rectangle r = item.getBounds(0);
 			Table table = item.getParent();
 			Rectangle rTable = table.getClientArea();
 
-			r.y += VerticalAligner.getTableAdjustVerticalBy(table);
 			table.redraw(0, r.y, rTable.width, r.height, true);
 		}
 	}
 
 	public static boolean linkShellMetricsToConfig(final Shell shell,
 			final String sConfigPrefix) {
+		boolean isMaximized = COConfigurationManager.getBooleanParameter(sConfigPrefix
+				+ ".maximized");
+		
+		if (!isMaximized) {
+			shell.setMaximized(false);
+		}
+
 		String windowRectangle = COConfigurationManager.getStringParameter(
 				sConfigPrefix + ".rectangle", null);
 		boolean bDidResize = false;
@@ -1096,12 +883,9 @@ public class Utils
 			}
 		}
 
-		boolean isMaximized = COConfigurationManager.getBooleanParameter(sConfigPrefix
-				+ ".maximized");
-		if (Constants.isOSX && windowRectangle != null) {
-			isMaximized = false;
+		if (isMaximized) {
+			shell.setMaximized(isMaximized);
 		}
-		shell.setMaximized(isMaximized);
 
 		new ShellMetricsResizeListener(shell, sConfigPrefix);
 
@@ -1130,7 +914,7 @@ public class Utils
 
 		private int calcState(Shell shell) {
 			return shell.getMinimized() ? SWT.MIN : shell.getMaximized()
-					&& !Constants.isOSX ? SWT.MAX : SWT.NONE;
+					&& !isCarbon ? SWT.MAX : SWT.NONE;
 		}
 
 		private void saveMetrics() {
@@ -1918,6 +1702,21 @@ public class Utils
 		return false;
 	}
 
+	public static Shell findFirstShellWithStyle(int styles) {
+		Display display = Display.getCurrent();
+		if (display != null) {
+			Shell[] shells = display.getShells();
+			for (int i = 0; i < shells.length; i++) {
+				Shell shell = shells[i];
+				int style = shell.getStyle();
+				if ((style & styles) == styles && !shell.isDisposed()) {
+					return shell;
+				}
+			}
+		}
+		return null;
+	}
+
 	public static int[] colorToIntArray(Color color) {
 		if (color == null || color.isDisposed()) {
 			return null;
@@ -2284,6 +2083,8 @@ public class Utils
 	
 	
 	private static Map truncatedTextCache = new HashMap();
+
+	private static ThreadPool tp = new ThreadPool("GetOffSWT", 2);
 	
 	private static class TruncatedTextResult {
 		String text;
@@ -2379,7 +2180,6 @@ public class Utils
 	{
 		MessageBoxShell mb = 
 			new MessageBoxShell(
-				findAnyShell(),
 				MessageText.getString("ConfigView.section.security.op.error.title"),
 				MessageText.getString("ConfigView.section.security.op.error",
 						new String[] {
@@ -2390,6 +2190,26 @@ public class Utils
 				},
 				0 );
 		
-		mb.open();
+		mb.open(null);
+	}
+	
+	public static void getOffOfSWTThread(AERunnable runnable) {
+		tp.run(runnable);
+	}
+	
+	public static Browser createSafeBrowser(Composite parent, int style) {
+		try {
+  		Browser browser = new Browser(parent, Utils.getInitialBrowserStyle(style));
+  		browser.addDisposeListener(new DisposeListener() {
+  			public void widgetDisposed(DisposeEvent e) {
+  				((Browser)e.widget).setUrl("about:blank");
+  				((Browser)e.widget).setVisible(false);
+  				while (!e.display.isDisposed() && e.display.readAndDispatch());
+  			}
+  		});
+  		return browser;
+		} catch (Throwable e) {
+		}
+		return null;
 	}
 }
