@@ -41,6 +41,7 @@ import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.SystemTime;
 import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.Utils;
+import org.gudy.azureus2.ui.swt.components.shell.ShellFactory;
 import org.gudy.azureus2.ui.swt.mainwindow.SWTThread;
 
 
@@ -93,7 +94,7 @@ CertificateCreatorWindow
 				return;
 			}
 			
-			shell = new Shell (display,SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
+			shell = ShellFactory.createMainShell(SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
 			
 			Utils.setShellIcon(shell);
 			Messages.setLanguageText(shell, "security.certcreate.title");
