@@ -40,6 +40,7 @@ import org.gudy.azureus2.core3.util.AERunnable;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.Utils;
+import org.gudy.azureus2.ui.swt.components.shell.ShellFactory;
 import org.gudy.azureus2.ui.swt.mainwindow.SWTThread;
 
 
@@ -103,7 +104,7 @@ CertificateTrustWindow
 				return;
 			}
 			
-			shell = new Shell (display,SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
+			shell =  ShellFactory.createMainShell(SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
 			
 			Utils.setShellIcon(shell);
 			shell.setText(MessageText.getString("security.certtruster.title"));
