@@ -26,6 +26,7 @@ import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 import org.gudy.azureus2.core3.config.ParameterListener;
+import org.gudy.azureus2.core3.util.AERunnable;
 import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.mainwindow.Colors;
@@ -70,6 +71,8 @@ BufferedTableRow
 	protected Color     ourForeground;
 	
 	private Point ptIconSize = null;
+
+	private Image imageBG;
 	
 	
 	static {
@@ -283,6 +286,9 @@ BufferedTableRow
 	
 	private boolean _isVisible() {
 		// Least time consuming checks first
+		if (!table.isVisible()) {
+			return false;
+		}
 		
 		int index = table.indexOf(item);
 		if (index == -1)
@@ -305,14 +311,31 @@ BufferedTableRow
 	{
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED))
   	  return null;
+		
+		if (ourForeground == null && table.isSelected(table.indexOf(item))) {
+			return table.getDisplay().getSystemColor(SWT.COLOR_LIST_SELECTION_TEXT);
+		}
 
 		return( item.getForeground());
 	}
 	
+	private static final boolean DEBUG_SET_FOREGROUND = System.getProperty("debug.setforeground") != null;
+	private static void setForegroundDebug(String method_sig, Color c) {
+		if (DEBUG_SET_FOREGROUND && c != null) {
+			Debug.out("BufferedTableRow " + method_sig + " -> " + c);
+		}
+	}
+	private static void setForegroundDebug(String method_sig, int r, int g, int b) {
+		if (DEBUG_SET_FOREGROUND && (!(r == 0 && g == 0 && b == 0))) {
+			Debug.out("BufferedTableRow " + method_sig + " -> " + r + "," + g + "," + b);
+		}
+	}
+	
 	public void
 	setForeground(
 		Color	c )
 	{
+		setForegroundDebug("setForeground(Color)", c);
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED))
 			return;
 
@@ -333,6 +356,7 @@ BufferedTableRow
 	}
 	
 	public void setForeground(int red, int green, int blue) {
+		setForegroundDebug("setForeground(r,g,b)", red, green, blue);
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED)) {
 			return;
 		}
@@ -363,6 +387,7 @@ BufferedTableRow
 	  int index,
 		Color	new_color )
 	{
+		setForegroundDebug("setForeground(int,Color)", new_color);
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED))
 			return false;
 				
@@ -406,8 +431,17 @@ BufferedTableRow
 	{
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED))
   	  return null;
-		if (index >= foreground_colors.length)
-		  return item.getForeground();
+
+		if (index >= foreground_colors.length) {
+		  return getForeground();
+		}
+		
+		if (foreground_colors[index] == null && isSelected()) {
+			Color systemColor = table.getDisplay().getSystemColor(
+					table.isFocusControl() ? SWT.COLOR_LIST_SELECTION_TEXT
+							: SWT.COLOR_WIDGET_FOREGROUND);
+			return systemColor;
+		}
 
 		return foreground_colors[index];
 	}
@@ -474,6 +508,12 @@ BufferedTableRow
   public Color getBackground() {
 		if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED))
       return null;
+		
+		if (isSelected()) {
+			return table.getDisplay().getSystemColor(
+					table.isFocusControl() ? SWT.COLOR_LIST_SELECTION
+							: SWT.COLOR_WIDGET_BACKGROUND);
+		}
     return item.getBackground();
   }
 
@@ -555,6 +595,15 @@ BufferedTableRow
   
   public boolean setTableItem(int newIndex, boolean bCopyFromOld, boolean isVisible) {
   	TableItem newRow;
+
+  	boolean needsNewAltBG = false;
+		if (alternatingColors != null) {
+			int newAltRowNo = newIndex % alternatingColors.length;
+			int oldAltRowNo = item == null ? -1 : table.indexOf(item)
+					% alternatingColors.length;
+			needsNewAltBG = newAltRowNo != oldAltRowNo;
+		}
+  	
   	try {
   		newRow = table.getItem(newIndex);
   	} catch (IllegalArgumentException er) {
@@ -576,8 +625,8 @@ BufferedTableRow
 
   	if (newRow == item) {
   		if (newRow.getData("TableRow") == this) {
-  			if(isVisible)
-  				setAlternatingBGColor(false);
+  			if(isVisible && needsNewAltBG)
+  				setAlternatingBGColor(true);
   			return false;
   		}
   	}
@@ -607,7 +656,7 @@ BufferedTableRow
   		setIconSize(ptIconSize);
   	}
 
-  	if(isVisible)
+  	if(isVisible && needsNewAltBG)
   		setAlternatingBGColor(false);
 
   	try {
@@ -688,11 +737,27 @@ BufferedTableRow
    *
    */
   public void invalidate() {
-  	if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED | REQUIRE_VISIBILITY))
-  		return;
+  	Utils.execSWTThread(new AERunnable() {
+		
+			public void runSupport() {
+		  	if (!checkWidget(REQUIRE_TABLEITEM_INITIALIZED | REQUIRE_VISIBILITY))
+		  		return;
 
-		Rectangle r = item.getBounds(0);
+				Rectangle r = item.getBounds(0);
 
-		table.redraw(0, r.y, table.getClientArea().width, r.height, true);
+				table.redraw(0, r.y, table.getClientArea().width, r.height, true);
+			}
+		});
+  }
+  
+  public void setBackgroundImage(Image image) {
+  	if (imageBG != null && !imageBG.isDisposed()) {
+  		imageBG.dispose();
+  	}
+  	imageBG = image;
+  }
+  
+  public Image getBackgroundImage() {
+  	return imageBG;
   }
 }
