@@ -36,6 +36,8 @@ import org.eclipse.swt.widgets.Listener;
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
 
+import com.aelitis.azureus.ui.swt.utils.ColorCache;
+
 
 /**
  * @author Olivier
@@ -47,17 +49,21 @@ public class ColorParameter extends Parameter implements ParameterListener {
   private Button colorChooser;
   protected String sParamName;
   private Image img;
+  
+  private int r;
+  private int g;
+  private int b;
 
   public ColorParameter(final Composite composite,
                         final String name,
-                        int r, int g, int b) {
+                        int _r, int _g, int _b) {
   	super(name);
     sParamName = name;
     colorChooser = new Button(composite,SWT.PUSH);
-    final int rV = COConfigurationManager.getIntParameter(name+".red",r);
-    final int gV = COConfigurationManager.getIntParameter(name+".green",g);
-    final int bV = COConfigurationManager.getIntParameter(name+".blue",b);
-    updateButtonColor(composite.getDisplay(), rV, gV, bV);
+    r = COConfigurationManager.getIntParameter(name+".red",_r);
+    g = COConfigurationManager.getIntParameter(name+".green",_g);
+    b = COConfigurationManager.getIntParameter(name+".blue",_b);
+    updateButtonColor(composite.getDisplay(), r, g, b);
 
     COConfigurationManager.addParameterListener(sParamName, this);
     
@@ -73,12 +79,13 @@ public class ColorParameter extends Parameter implements ParameterListener {
     colorChooser.addListener(SWT.Selection, new Listener() {
       public void handleEvent(Event e) {
         ColorDialog cd = new ColorDialog(composite.getShell());
-        cd.setRGB(new RGB(rV,gV,bV));
+        cd.setRGB(new RGB(r,g,b));
         RGB newColor = cd.open();
         if (newColor == null)
           return;
         newColorChosen();
         COConfigurationManager.setRGBParameter(name, newColor.red, newColor.green, newColor.blue);
+        newColorSet();
       }
     });
     
@@ -86,13 +93,12 @@ public class ColorParameter extends Parameter implements ParameterListener {
   
   private void updateButtonColor(final Display display, final int rV, final int gV, final int bV) {
     Image oldImg = img;
-    Color color = new Color(display,rV,gV,bV);
+    Color color = ColorCache.getColor(display, rV, gV, bV);
     img = new Image(display,25,10);
     GC gc = new GC(img);
     gc.setBackground(color);
     gc.fillRectangle(0,0,25,10);
     gc.dispose();
-    color.dispose();
     colorChooser.setImage(img);
     if(oldImg != null && ! oldImg.isDisposed())
       oldImg.dispose();
@@ -107,15 +113,19 @@ public class ColorParameter extends Parameter implements ParameterListener {
   }
 
   public void parameterChanged(String parameterName) {
-    final int rV = COConfigurationManager.getIntParameter(sParamName+".red");
-    final int gV = COConfigurationManager.getIntParameter(sParamName+".green");
-    final int bV = COConfigurationManager.getIntParameter(sParamName+".blue");
-    updateButtonColor(colorChooser.getDisplay(), rV, gV, bV);
+    r = COConfigurationManager.getIntParameter(sParamName+".red");
+    g = COConfigurationManager.getIntParameter(sParamName+".green");
+    b = COConfigurationManager.getIntParameter(sParamName+".blue");
+    updateButtonColor(colorChooser.getDisplay(), r, g, b);
   }
   
   public void newColorChosen() {
     // subclasses can write their own code
   }
+  
+  public void newColorSet() {
+	  // subclasses can write their own code
+  }
 
   public void setValue(Object value) {
   	// not needed, we already trap external changes
