@@ -26,6 +26,7 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
+
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.ui.swt.Messages;
@@ -79,6 +80,12 @@ public class FinishPanel extends AbstractWizardPanel {
 	//COConfigurationManager.setParameter("Server.shared.port",cfWizard.serverSharePort);
     COConfigurationManager.setParameter("General_sDefaultTorrent_Directory",cfWizard.torrentPath);
     //COConfigurationManager.setParameter("Use Resume",cfWizard.fastResume);
+    
+    if ( cfWizard.hasDataPathChanged()){
+    	COConfigurationManager.setParameter( "Use default data dir", true );
+    	COConfigurationManager.setParameter( "Default save path", cfWizard.getDataPath());
+    }
+    
     COConfigurationManager.setParameter("Wizard Completed",true);
     COConfigurationManager.save();
     wizard.switchToClose();
