@@ -19,9 +19,6 @@
 
 package org.gudy.azureus2.ui.swt.ipchecker;
 
-import org.eclipse.swt.widgets.Display;
-
-import com.aelitis.azureus.core.*;
 import org.gudy.azureus2.core3.ipchecker.extipchecker.ExternalIPCheckerService;
 import org.gudy.azureus2.ui.swt.wizard.IWizardPanel;
 import org.gudy.azureus2.ui.swt.wizard.Wizard;
@@ -35,10 +32,9 @@ public class IpCheckerWizard extends Wizard {
   IpSetterCallBack callBack;
   
   ExternalIPCheckerService selectedService;
-  String detectedIp;
   
-  public IpCheckerWizard(AzureusCore azureus_core,Display display) {
-    super(azureus_core, "ipCheckerWizard.title");
+  public IpCheckerWizard() {
+    super("ipCheckerWizard.title");
     IWizardPanel panel = new ChooseServicePanel(this,null);
     this.setFirstPanel(panel);
   }
