@@ -68,6 +68,7 @@ public class Colors implements ParameterListener {
   public static Color red;
   public static Color fadedRed;
   public static Color yellow;
+  public static Color fadedYellow;
   public static Color white;
   public static Color background;
   public static Color red_ConsoleView;
@@ -102,10 +103,24 @@ public class Colors implements ParameterListener {
         blues[i] = ColorCache.getColor(display, hslColor.getRed(),
 						hslColor.getGreen(), hslColor.getBlue());
         int iSat = hslColor.getSaturation();
-        if (iSat != 0)
-          hslColor.setSaturation(iSat / 2);
-        else if (bGrayScale) // gray
-        	hslColor.brighten(0.8f);
+        int luminence = hslColor.getLuminence();
+        if (luminence < 20) {
+          if (iSat > 10) {
+            hslColor.setSaturation(iSat / 2);
+            hslColor.brighten(1.25f);
+          } else if (bGrayScale) {
+          	// gray
+          	hslColor.brighten(1.2f);
+          }
+        } else {
+          if (iSat > 10) {
+            hslColor.setSaturation(iSat / 2);
+            hslColor.brighten(0.75f);
+          } else if (bGrayScale) {
+          	// gray
+          	hslColor.brighten(0.8f);
+          }
+        }
 
         faded[i] = ColorCache.getColor(display, hslColor.getRed(),
 						hslColor.getGreen(), hslColor.getBlue());
@@ -212,10 +227,22 @@ public class Colors implements ParameterListener {
 
 				int lum = hslColor.getLuminence();
 				if (lum > 127)
-					lum -= 10;
+					lum -= 16;
 				else
 					lum += 30; // it's usually harder to see difference in darkness
 				hslColor.setLuminence(lum);
+				
+				//HSLColor blueHSL = new HSLColor();
+				//RGB rgb = blues[BLUES_DARKEST].getRGB();
+				//blueHSL.initHSLbyRGB(rgb.red, rgb.green, rgb.blue);
+				//int blueHue = blueHSL.getHue();
+				//int altHue = hslColor.getHue();
+				//if (blueHue > altHue) {
+				//	altHue += 11;
+				//} else {
+				//	altHue -= 11;
+				//}
+				//hslColor.setHue(blueHue);
 				colorAltRow = new AllocateColor("altRow", new RGB(hslColor.getRed(),
 						hslColor.getGreen(), hslColor.getBlue()), colorAltRow).getColor();
 			}
@@ -297,6 +324,7 @@ public class Colors implements ParameterListener {
 		red = ColorCache.getColor(display, 255, 0, 0);
 		fadedRed = ColorCache.getColor(display, 160, 96, 96);
 		yellow = ColorCache.getColor(display, 255, 255, 0);
+		fadedYellow = ColorCache.getColor(display, 255, 255, 221);
 		white = ColorCache.getColor(display, 255, 255, 255);
 		background = ColorCache.getColor(display, 248, 248, 248);
 		red_ConsoleView = ColorCache.getColor(display, 255, 192, 192);
