@@ -20,6 +20,7 @@
 package org.gudy.azureus2.ui.swt.mainwindow;
 
 import java.text.NumberFormat;
+import java.util.ArrayList;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CLabel;
@@ -103,6 +104,8 @@ public class MainStatusBar
 	private CLabel statusUp;
 
 	private Composite plugin_label_composite;
+	
+	private ArrayList<Runnable> listRunAfterInit = new ArrayList<Runnable>();
 
 	private Display display;
 
@@ -168,6 +171,12 @@ public class MainStatusBar
 
 	private String lastSRimageID = null;
 
+	private int last_dl_limit;
+
+	private long last_rec_data = - 1;
+
+	private long last_rec_prot;
+
 	/**
 	 * 
 	 */
@@ -327,8 +336,6 @@ public class MainStatusBar
 			}
 		});
 
-		statusBar.layout();
-
 		this.plugin_label_composite = new Composite(statusBar, SWT.NONE);
 		this.plugin_label_composite.setForeground(fgColor);
 		GridLayout gridLayout = new GridLayout();
@@ -399,7 +406,7 @@ public class MainStatusBar
 
 		statusDown = new CLabelPadding(statusBar, borderFlag);
 		statusDown.setImage(imageLoader.getImage("down"));
-		statusDown.setText(/*MessageText.getString("ConfigView.download.abbreviated") +*/"n/a");
+		//statusDown.setText(/*MessageText.getString("ConfigView.download.abbreviated") +*/"n/a");
 		Messages.setLanguageText(statusDown,
 				"MainWindow.status.updowndetails.tooltip");
 
@@ -411,7 +418,7 @@ public class MainStatusBar
 
 		statusUp = new CLabelPadding(statusBar, borderFlag);
 		statusUp.setImage(imageLoader.getImage("up"));
-		statusUp.setText(/*MessageText.getString("ConfigView.upload.abbreviated") +*/"n/a");
+		//statusUp.setText(/*MessageText.getString("ConfigView.upload.abbreviated") +*/"n/a");
 		Messages.setLanguageText(statusUp,
 				"MainWindow.status.updowndetails.tooltip");
 
@@ -544,6 +551,24 @@ public class MainStatusBar
 		
 		uiFunctions.getUIUpdater().addUpdater(this);
 		
+		ArrayList<Runnable> list;
+		this_mon.enter();
+		try {
+			list = listRunAfterInit;
+			listRunAfterInit = null;
+		} finally {
+			this_mon.exit();
+		}
+		for (Runnable runnable : list) {
+			try {
+				runnable.run();
+			} catch (Exception e) {
+				Debug.out(e);
+			}
+		}
+		
+		statusBar.layout(true);
+
 		return statusBar;
 	}
 
@@ -580,36 +605,39 @@ public class MainStatusBar
 
 		} else if (secs_uptime - last_uptime > 15 * 60) {
 
-			CLabel feedback = createStatusEntry(new CLabelUpdater() {
+			createStatusEntry(new CLabelUpdater() {
 				public void update(CLabel label) {
 				}
-			});
-			
-			feedback.setText(MessageText.getString("statusbar.feedback"));
 
-			Listener feedback_listener = new Listener() {
-				public void handleEvent(Event e) {
-
-					String url = "feedback?" + Utils.getWidgetBGColorURLParam()
+				public void created(CLabel feedback) {
+					feedback.setText(MessageText.getString("statusbar.feedback"));
+					
+					Listener feedback_listener = new Listener() {
+						public void handleEvent(Event e) {
+							
+							String url = "feedback.start?" + Utils.getWidgetBGColorURLParam()
 							+ "&fromWeb=false&os.name=" + UrlUtils.encode(Constants.OSName)
 							+ "&os.version="
 							+ UrlUtils.encode(System.getProperty("os.version"))
 							+ "&java.version=" + UrlUtils.encode(Constants.JAVA_VERSION);
-
-					// Utils.launch( url );
-
-					UIFunctionsManagerSWT.getUIFunctionsSWT().viewURL(url, null, 600,
-							520, true, false);
+							
+							// Utils.launch( url );
+							
+							UIFunctionsManagerSWT.getUIFunctionsSWT().viewURL(url, null, 600,
+									520, true, false);
+						}
+					};
+					
+					feedback.setToolTipText(MessageText.getString("statusbar.feedback.tooltip"));
+					feedback.setCursor(Cursors.handCursor);
+					feedback.setForeground(Colors.blue);
+					feedback.addListener(SWT.MouseUp, feedback_listener);
+					feedback.addListener(SWT.MouseDoubleClick, feedback_listener);
+					
+					feedback.setVisible(true);
 				}
-			};
+			});
 			
-			feedback.setToolTipText(MessageText.getString("statusbar.feedback.tooltip"));
-			feedback.setCursor(Cursors.handCursor);
-			feedback.setForeground(Colors.blue);
-			feedback.addListener(SWT.MouseUp, feedback_listener);
-			feedback.addListener(SWT.MouseDoubleClick, feedback_listener);
-			
-			feedback.setVisible(true);
 		}
 	}
 
@@ -822,12 +850,20 @@ public class MainStatusBar
 			GlobalManagerStats stats = gm.getStats();
 
 			int dl_limit = NetworkManager.getMaxDownloadRateBPS() / 1024;
+			long rec_data = stats.getDataReceiveRate();
+			long rec_prot = stats.getProtocolReceiveRate();
+			
+			if (last_dl_limit != dl_limit || last_rec_data != rec_data || last_rec_prot != rec_prot) {
+				last_dl_limit = dl_limit;
+				last_rec_data = rec_data;
+				last_rec_prot = rec_prot;
 
-			statusDown.setText((dl_limit == 0 ? "" : "[" + dl_limit + "K] ")
-					+ DisplayFormatters.formatDataProtByteCountToKiBEtcPerSec(
-							stats.getDataReceiveRate(), stats.getProtocolReceiveRate()));
+				statusDown.setText((dl_limit == 0 ? "" : "[" + dl_limit + "K] ")
+						+ DisplayFormatters.formatDataProtByteCountToKiBEtcPerSec(rec_data, rec_prot));
+			}
 
-			boolean auto_up = COConfigurationManager.getBooleanParameter(TransferSpeedValidator.getActiveAutoUploadParameter(gm))
+
+			boolean auto_up = TransferSpeedValidator.isAutoSpeedActive(gm)
 					&& TransferSpeedValidator.isAutoUploadAvailable(core);
 
 			int ul_limit_norm = NetworkManager.getMaxUploadRateBPSNormal() / 1024;
@@ -851,9 +887,6 @@ public class MainStatusBar
 					+ DisplayFormatters.formatDataProtByteCountToKiBEtcPerSec(
 							stats.getDataSendRate(), stats.getProtocolSendRate()));
 		}
-
-		// End of Status Sections
-		statusBar.layout();
 	}
 
 	/**
@@ -1146,6 +1179,7 @@ public class MainStatusBar
 
 	public static interface CLabelUpdater
 	{
+		public void created(CLabel label);
 		public void update(CLabel label);
 	}
 
@@ -1180,6 +1214,28 @@ public class MainStatusBar
 			setLayoutData(gridData);
 			setForeground(parent.getForeground());
 		}
+		
+		public void setText(String text) {
+			if (text == null) {
+				text = "";
+			}
+			if (text.equals(getText())) {
+				return;
+			}
+			super.setText(text);
+			int oldWidth = lastWidth;
+			Point pt = super.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
+			pt.x += 4;
+			if (pt.x > oldWidth && text.length() > 0) {
+				statusBar.layout();
+			} else if (pt.x < oldWidth) {
+				Utils.execSWTThreadLater(KEEPWIDTHFOR_MS, new AERunnable() {
+					public void runSupport() {
+						statusBar.layout();
+					}
+				});
+			}
+		}
 
 		/* (non-Javadoc)
 		 * @see org.eclipse.swt.custom.CLabel#computeSize(int, int, boolean)
@@ -1225,21 +1281,26 @@ public class MainStatusBar
 		}
 	}
 
-	public CLabel createStatusEntry(final CLabelUpdater updater) {
-		final CLabel[] result = new CLabel[1];
-		Utils.execSWTThread(new AERunnable() {
+	public void createStatusEntry(final CLabelUpdater updater) {
+		AERunnable r = new AERunnable() {
 			public void runSupport() {
-				try {
-					this_mon.enter();
-					result[0] = new UpdateableCLabel(plugin_label_composite, borderFlag,
-							updater);
-					result[0].setLayoutData(new GridData(GridData.FILL_BOTH));
-				} finally {
-					this_mon.exit();
-				}
+				UpdateableCLabel result = new UpdateableCLabel(plugin_label_composite, borderFlag,
+						updater);
+				result.setLayoutData(new GridData(GridData.FILL_BOTH));
+				updater.created(result);
 			}
-		}, false);
-		return result[0];
+		};
+		this_mon.enter();
+		try {
+			if (listRunAfterInit != null) {
+				listRunAfterInit.add(r);
+				return;
+			}
+		} finally {
+			this_mon.exit();
+		}
+
+		Utils.execSWTThread(r);
 	}
 
 	// =============================================================
