@@ -68,6 +68,7 @@ import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTInstanceImpl;
 import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTViewImpl;
 import org.gudy.azureus2.ui.swt.sharing.progress.ProgressWindow;
 import org.gudy.azureus2.ui.swt.views.*;
+import org.gudy.azureus2.ui.swt.views.clientstats.ClientStatsView;
 import org.gudy.azureus2.ui.swt.views.stats.StatsView;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
 import org.gudy.azureus2.ui.swt.views.table.impl.TableViewTab;
@@ -154,6 +155,8 @@ public class MainWindow
 
 	private Item config;
 
+	private Item viewClientStats;
+	
 	private ConfigView config_view;
 
 	protected AEMonitor this_mon = new AEMonitor("MainWindow");
@@ -287,8 +290,8 @@ public class MainWindow
 
 			globalManager.loadExistingTorrentsNow(true);
 
-			COConfigurationManager.addParameterListener("config.style.useSIUnits",
-					this);
+			COConfigurationManager.addParameterListener("config.style.useSIUnits", this);
+			COConfigurationManager.addParameterListener("config.style.forceSIValues", this);
 
 			mytorrents = null;
 			my_tracker_tab = null;
@@ -598,6 +601,14 @@ public class MainWindow
 			});
 		}
 
+		if (!Constants.isSafeMode && COConfigurationManager.getBooleanParameter("Open Client Stats")) {
+			Utils.execSWTThreadLater(delay += delayInc, new Runnable() {
+				public void run() {
+					showClientStatsView();
+				}
+			});
+		}
+
 		COConfigurationManager.addAndFireParameterListener("IconBar.enabled",
 				new ParameterListener() {
 					public void parameterChanged(String parameterName) {
@@ -673,9 +684,7 @@ public class MainWindow
 			return;
 		}
 
-		// No tray access on OSX yet
-		boolean bEnableTray = COConfigurationManager.getBooleanParameter("Enable System Tray")
-				&& (!Constants.isOSX || SWT.getVersion() > 3300);
+		boolean bEnableTray = COConfigurationManager.getBooleanParameter("Enable System Tray");
 		boolean bPassworded = COConfigurationManager.getBooleanParameter("Password enabled");
 		boolean bStartMinimize = bEnableTray
 				&& (bPassworded || COConfigurationManager.getBooleanParameter("Start Minimized"));
@@ -819,6 +828,23 @@ public class MainWindow
 		refreshTorrentMenu();
 	}
 
+	protected void showClientStatsView() {
+		if (viewClientStats == null) {
+			ClientStatsView view = new ClientStatsView();
+			viewClientStats = mainTabSet.createTabItem(view, true);
+			mainTabSet.getView(viewClientStats).getComposite().addDisposeListener(
+					new DisposeListener() {
+						public void widgetDisposed(DisposeEvent e) {
+							viewClientStats = null;
+						}
+					});
+		} else {
+			mainTabSet.setFocus(viewClientStats);
+		}
+		refreshIconBar();
+		refreshTorrentMenu();
+	}
+
 	protected void showMultiOptionsView(DownloadManager[] managers) {
 		if (multi_options_tab != null) {
 			multi_options_tab.dispose();
@@ -975,7 +1001,9 @@ public class MainWindow
 					}
 
 					if (visible) {
-						shell.setMinimized(false);
+						if (shell.getMinimized()) {
+							shell.setMinimized(false);
+						}
 						if (!currentlyVisible
 								&& COConfigurationManager.getBooleanParameter("window.maximized")) {
 							shell.setMaximized(true);
@@ -1083,8 +1111,9 @@ public class MainWindow
 			shell.dispose();
 		}
 
-		COConfigurationManager.removeParameterListener("config.style.useSIUnits",
-				this);
+		COConfigurationManager.removeParameterListener("config.style.useSIUnits", this);
+		COConfigurationManager.removeParameterListener("config.style.forceSIValues", this);
+		
 		COConfigurationManager.removeParameterListener("Show Download Basket", this);
 
 		UIExitUtilsSWT.uiShutdown();
@@ -1208,7 +1237,7 @@ public class MainWindow
 			}
 		}
 
-		if (parameterName.equals("config.style.useSIUnits")) {
+		if (parameterName.equals("config.style.useSIUnits") || parameterName.equals("config.style.forceSIValues")) {
 			updateComponents();
 		}
 	}
