@@ -38,6 +38,8 @@ import org.gudy.azureus2.ui.swt.nat.NatTestWindow;
 import org.gudy.azureus2.ui.swt.pluginsinstaller.InstallPluginWizard;
 import org.gudy.azureus2.ui.swt.pluginsuninstaller.UnInstallPluginWizard;
 import org.gudy.azureus2.ui.swt.sharing.ShareUtils;
+import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.speedtest.SpeedTestWizard;
 import org.gudy.azureus2.ui.swt.update.UpdateMonitor;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
@@ -47,6 +49,7 @@ import org.gudy.azureus2.ui.swt.welcome.WelcomeWindow;
 
 import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
+import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.core.vuzefile.VuzeFileComponent;
 import com.aelitis.azureus.core.vuzefile.VuzeFileHandler;
 import com.aelitis.azureus.ui.UIFunctions;
@@ -58,8 +61,6 @@ public class MenuFactory
 	implements IMenuConstants
 {
 
-	public static boolean isAZ3_ADV = COConfigurationManager.getBooleanParameter("v3.Start Advanced");
-
 	private static boolean isAZ3 = "az3".equalsIgnoreCase(COConfigurationManager.getStringParameter("ui"));
 
 	public static MenuItem createFileMenuItem(Menu menuParent) {
@@ -105,10 +106,6 @@ public class MenuFactory
 		return createTopLevelMenuItem(menuParent, MENU_ID_VIEW);
 	}
 
-	public static MenuItem createPublishMenuItem(Menu menuParent) {
-		return createTopLevelMenuItem(menuParent, MENU_ID_PUBLISH);
-	}
-
 	public static MenuItem createAdvancedMenuItem(Menu menuParent) {
 		return createTopLevelMenuItem(menuParent, MENU_ID_ADVANCED);
 	}
@@ -568,6 +565,17 @@ public class MenuFactory
 		});
 	}
 
+	public static MenuItem addClientStatsMenuItem(Menu menu) {
+		return addMenuItem(menu, MENU_ID_CLIENT_STATS, new Listener() {
+			public void handleEvent(Event e) {
+				UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+				if (uiFunctions != null) {
+					uiFunctions.openView(UIFunctions.VIEW_PEERS_STATS, null);
+				}
+			}
+		});
+	}
+
 	public static MenuItem addMyTrackerMenuItem(Menu menu) {
 		return addMenuItem(menu, MENU_ID_MY_TRACKERS, new Listener() {
 			public void handleEvent(Event e) {
@@ -685,7 +693,11 @@ public class MenuFactory
 	public static MenuItem addSpeedTestMenuItem(Menu menu) {
 		return addMenuItem(menu, MENU_ID_SPEED_TEST, new Listener() {
 			public void handleEvent(Event e) {
-				new SpeedTestWizard();
+				CoreWaiterSWT.waitForCoreRunning(new AzureusCoreRunningListener() {
+					public void azureusCoreRunning(AzureusCore core) {
+						new SpeedTestWizard();
+					}
+				});
 			}
 		});
 	}
@@ -904,7 +916,7 @@ public class MenuFactory
 	public static MenuItem addAboutMenuItem(Menu menu) {
 		return addMenuItem(menu, MENU_ID_ABOUT, new Listener() {
 			public void handleEvent(Event e) {
-				AboutWindow.show(getDisplay());
+				AboutWindow.show();
 			}
 		});
 	}
@@ -990,13 +1002,10 @@ public class MenuFactory
 
 							public void complete(UpdateCheckInstance instance) {
 								if (instance.getUpdates().length == 0) {
-									Utils.execSWTThread(new AERunnable() {
-										public void runSupport() {
-											Utils.openMessageBox(menu.getShell(),
-													SWT.ICON_INFORMATION | SWT.OK,
-													"window.update.noupdates", (String[]) null);
-										}
-									});
+									MessageBoxShell mb = new MessageBoxShell(
+											SWT.ICON_INFORMATION | SWT.OK,
+											"window.update.noupdates", (String[]) null);
+									mb.open(null);
 								}
 							}
 						});
@@ -1202,6 +1211,10 @@ public class MenuFactory
 	 * @return may return <code>null</code> if not found
 	 */
 	public static MenuItem findMenuItem(Menu menuToStartWith, String idToMatch) {
+		return findMenuItem(menuToStartWith, idToMatch, true);
+	}
+
+	public static MenuItem findMenuItem(Menu menuToStartWith, String idToMatch, boolean deep) {
 		/*
 		 * This is a recursive method; it will start at the given menuToStartWith
 		 * and recursively traverse to all its sub menus until a matching
@@ -1220,12 +1233,14 @@ public class MenuFactory
 				return item;
 			}
 
-			/*
-			 * Go deeper into each child to try and find it
-			 */
-			MenuItem menuItemToFind = findMenuItem(item.getMenu(), idToMatch);
-			if (null != menuItemToFind) {
-				return menuItemToFind;
+			if (deep) {
+  			/*
+  			 * Go deeper into each child to try and find it
+  			 */
+  			MenuItem menuItemToFind = findMenuItem(item.getMenu(), idToMatch);
+  			if (null != menuItemToFind) {
+  				return menuItemToFind;
+  			}
 			}
 		}
 
@@ -1335,8 +1350,6 @@ public class MenuFactory
 		int keys = getEnablementKeys(widget);
 		if (keys <= 0) {
 			return true;
-		} else if (true == isAZ3_ADV) {
-			return ((keys & FOR_AZ3_ADV) != 0);
 		} else if (true == isAZ3) {
 			return ((keys & FOR_AZ3) != 0);
 		} else {
