@@ -23,30 +23,31 @@ package org.gudy.azureus2.ui.swt.maketorrent;
 
 import java.io.File;
 import java.net.URL;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.ProgressBar;
-import org.eclipse.swt.widgets.Text;
+import org.eclipse.swt.widgets.*;
+
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.download.DownloadManager;
-import org.gudy.azureus2.core3.download.DownloadManagerState;
-import org.gudy.azureus2.core3.download.DownloadManagerStateFactory;
 import org.gudy.azureus2.core3.internat.LocaleTorrentUtil;
-import org.gudy.azureus2.core3.internat.LocaleUtil;
 import org.gudy.azureus2.core3.internat.MessageText;
+import org.gudy.azureus2.core3.logging.LogAlert;
+import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.torrent.*;
 import org.gudy.azureus2.core3.tracker.host.TRHostException;
-import org.gudy.azureus2.core3.util.AERunnable;
-import org.gudy.azureus2.core3.util.Debug;
-import org.gudy.azureus2.core3.util.TrackersUtil;
-import org.gudy.azureus2.core3.util.TorrentUtils;
-import org.gudy.azureus2.core3.logging.*;
-import org.gudy.azureus2.ui.swt.wizard.*;
-import org.gudy.azureus2.core3.util.AEThread;
+import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT;
+import org.gudy.azureus2.ui.swt.shells.CoreWaiterSWT.TriggerInThread;
+import org.gudy.azureus2.ui.swt.wizard.AbstractWizardPanel;
+import org.gudy.azureus2.ui.swt.wizard.IWizardPanel;
+
+import com.aelitis.azureus.core.AzureusCore;
+import com.aelitis.azureus.core.AzureusCoreRunningListener;
 
 /**
  * @author Olivier
@@ -109,7 +110,7 @@ public class ProgressPanel extends AbstractWizardPanel implements TOTorrentProgr
   }
   
   public void makeTorrent() {
-  	NewTorrentWizard _wizard = (NewTorrentWizard)wizard;
+  	final NewTorrentWizard _wizard = (NewTorrentWizard)wizard;
   	
   	int	tracker_type = _wizard.getTrackerType();
   	
@@ -178,62 +179,106 @@ public class ProgressPanel extends AbstractWizardPanel implements TOTorrentProgr
       	save_dir = f.getParentFile();
       }
       
+      if(_wizard.useMultiTracker) {
+          this.reportCurrentTask(MessageText.getString("wizard.addingmt"));
+          TorrentUtils.listToAnnounceGroups(_wizard.trackers, torrent);
+         }
+
+      if (_wizard.useWebSeed && _wizard.webseeds.size() > 0 ){
+          this.reportCurrentTask(MessageText.getString("wizard.webseed.adding"));
+          
+          Map	ws = _wizard.webseeds;
+          
+          List	getright = (List)ws.get( "getright" );
+          
+          if ( getright.size() > 0 ){
+          
+        	  for (int i=0;i<getright.size();i++){
+        		  reportCurrentTask( "    GetRight: " + getright.get(i));
+        	  }
+        	  torrent.setAdditionalListProperty( "url-list", new ArrayList( getright ));
+          }
+          
+          List	webseed = (List)ws.get( "webseed" );
+          
+          if ( webseed.size() > 0 ){
+          
+        	  for (int i=0;i<webseed.size();i++){
+        		  reportCurrentTask( "    WebSeed: " + webseed.get(i));
+        	  }
+        	  torrent.setAdditionalListProperty( "httpseeds", new ArrayList( webseed ));
+          }
+          
+      }
+      	// must do this last as it saves a copy of the torrent state for future opening...
+      
+      /*
+       * actually, don't need to do this as the "open-for-seeding" option used when adding the download	
+       * does the job. Reason I stopped doing this is 
+       * https://sourceforge.net/tracker/index.php?func=detail&aid=1721917&group_id=84122&atid=575154
+       * 
 	  DownloadManagerState	download_manager_state = 
 			DownloadManagerStateFactory.getDownloadState( torrent ); 
 
 	  TorrentUtils.setResumeDataCompletelyValid( download_manager_state );
 
 	  download_manager_state.save();
-     
-      if(_wizard.useMultiTracker) {
-        this.reportCurrentTask(MessageText.getString("wizard.addingmt"));
-        TorrentUtils.listToAnnounceGroups(((NewTorrentWizard)wizard).trackers, torrent);
-       }
+     */
+      
       this.reportCurrentTask(MessageText.getString("wizard.savingfile"));
       
-      final File torrent_file = new File(((NewTorrentWizard)wizard).savePath);
+      final File torrent_file = new File(_wizard.savePath);
       
       torrent.serialiseToBEncodedFile(torrent_file);
       this.reportCurrentTask(MessageText.getString("wizard.filesaved"));
 	  wizard.switchToClose();
 	  
-	  if ( ((NewTorrentWizard)wizard).autoOpen ){
-	  	
-        new AEThread("TorrentOpener::openTorrent") 
-		{
-            public void
-			runSupport() 
-            {
-             	boolean	default_start_stopped = COConfigurationManager.getBooleanParameter( "Default Start Torrents Stopped" );
-             	
-             	byte[] hash = null;
-             	try {
-             		hash = torrent.getHash();
-             	} catch (TOTorrentException e1) { }
+	  if ( _wizard.autoOpen ){
+	  	CoreWaiterSWT.waitForCore(TriggerInThread.NEW_THREAD,
+						new AzureusCoreRunningListener() {
+							public void azureusCoreRunning(AzureusCore core) {
+								boolean default_start_stopped = COConfigurationManager.getBooleanParameter("Default Start Torrents Stopped");
 
-                ((NewTorrentWizard)wizard).getAzureusCore().getGlobalManager().addDownloadManager(
-                		torrent_file.toString(),
-                		hash,
-                		save_dir.toString(), 
-						default_start_stopped 	? DownloadManager.STATE_STOPPED 
-												: DownloadManager.STATE_QUEUED,
-						true,	// persistent 
-						true,	// for seeding
-						null );	// no adapter required
-                
-                if ( ((NewTorrentWizard)wizard).autoHost &&  ((NewTorrentWizard)wizard).getTrackerType() != NewTorrentWizard.TT_EXTERNAL ){
-                	
-                	try{
-                		((NewTorrentWizard)wizard).getAzureusCore().getTrackerHost().hostTorrent( torrent, true, false );
-                		
-                	}catch( TRHostException e ){
-                		Logger.log(new LogAlert(LogAlert.REPEATABLE,
-                				"Host operation fails", e));
-                	}
-                }
+								byte[] hash = null;
+								try {
+									hash = torrent.getHash();
+								} catch (TOTorrentException e1) {
+								}
 
-            }
-		}.start();
+								DownloadManager dm = core.getGlobalManager().addDownloadManager(
+										torrent_file.toString(),
+										hash,
+										save_dir.toString(),
+										default_start_stopped ? DownloadManager.STATE_STOPPED
+												: DownloadManager.STATE_QUEUED, true, // persistent 
+										true, // for seeding
+										null); // no adapter required
+
+								if (!default_start_stopped && dm != null) {
+									// We want this to move to seeding ASAP, so move it to the top
+									// of the download list, where it will do the quick check and
+									// move to the seeding list
+									// (the for seeding flag should really be smarter and verify
+									//  it's a seeding torrent and set appropriately) 
+									dm.getGlobalManager().moveTop(new DownloadManager[] {
+										dm
+									});
+								}
+
+								if (_wizard.autoHost
+										&& _wizard.getTrackerType() != NewTorrentWizard.TT_EXTERNAL) {
+
+									try {
+										core.getTrackerHost().hostTorrent(torrent, true, false);
+
+									} catch (TRHostException e) {
+										Logger.log(new LogAlert(LogAlert.REPEATABLE,
+												"Host operation fails", e));
+									}
+								}
+
+							}
+						});
 	  }
 	}
     catch (Exception e) {
@@ -247,7 +292,7 @@ public class ProgressPanel extends AbstractWizardPanel implements TOTorrentProgr
     	  }else{
     		  
     		  reportCurrentTask(MessageText.getString("wizard.operationfailed"));
-    	      reportCurrentTask( TorrentUtils.exceptionToText( te, true ));
+    	      reportCurrentTask( TorrentUtils.exceptionToText( te ));
     	  }
       }else{
       	Debug.printStackTrace( e );
