@@ -30,6 +30,9 @@ import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
 import org.gudy.azureus2.ui.swt.nat.NatTestWindow;
 import org.gudy.azureus2.ui.swt.speedtest.SpeedTestWizard;
 
+import com.aelitis.azureus.core.AzureusCore;
+import com.aelitis.azureus.core.AzureusCoreFactory;
+import com.aelitis.azureus.core.AzureusCoreRunningListener;
 import com.aelitis.azureus.ui.UIFunctions;
 import com.aelitis.azureus.ui.UIFunctionsManager;
 import com.apple.cocoa.application.NSApplication;
@@ -288,7 +291,7 @@ public class CarbonUIEnhancer
 							return OS.noErr;
 						}
 						case kHICommandAbout:
-							AboutWindow.show(display);
+							AboutWindow.show();
 							return OS.noErr;
 						case kHICommandRestart: {
 							UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
@@ -566,7 +569,7 @@ public class CarbonUIEnhancer
 			OS.AECountItems(aeDesc, count);
 			//System.out.println("COUNT: " + count[0]);
 			if (count[0] > 0) {
-				String[] fileNames = new String[count[0]];
+				final String[] fileNames = new String[count[0]];
 				int maximumSize = 80; // size of FSRef
 				int dataPtr = OS.NewPtr(maximumSize);
 				int[] aeKeyword = new int[1];
@@ -580,18 +583,16 @@ public class CarbonUIEnhancer
 						int dirUrl = OS.CFURLCreateFromFSRef(OS.kCFAllocatorDefault, fsRef);
 						int dirString = OS.CFURLCopyFileSystemPath(dirUrl,
 								OS.kCFURLPOSIXPathStyle);
-						OS.CFRelease(dirUrl);
 						int length = OS.CFStringGetLength(dirString);
 						char[] buffer = new char[length];
 						CFRange range = new CFRange();
 						range.length = length;
 						OS.CFStringGetCharacters(dirString, range, buffer);
-						OS.CFRelease(dirString);
 						fileNames[i] = new String(buffer);
-					}
-
-					if (OS.AEGetNthPtr(aeDesc, i + 1, typeText, aeKeyword, typeCode,
-							dataPtr, maximumSize, actualSize) == OS.noErr) {
+						OS.CFRelease(dirString);
+						OS.CFRelease(dirUrl);
+					} else if (OS.AEGetNthPtr(aeDesc, i + 1, typeText, aeKeyword, typeCode,
+							dataPtr, 2048, actualSize) == OS.noErr) {
 						byte[] urlRef = new byte[actualSize[0]];
 						memmove(urlRef, dataPtr, actualSize[0]);
 						fileNames[i] = new String(urlRef);
@@ -600,7 +601,11 @@ public class CarbonUIEnhancer
 					//System.out.println(fileNames[i]);
 				}
 
-				TorrentOpener.openTorrents(fileNames);
+				AzureusCoreFactory.addCoreRunningListener(new AzureusCoreRunningListener() {
+					public void azureusCoreRunning(AzureusCore core) {
+						TorrentOpener.openTorrents(fileNames);
+					}
+				});
 			}
 
 			return OS.noErr;
