@@ -253,10 +253,19 @@ BasicPluginConfigImpl
 										param.removeListener( this );								
 									}else{
 										
-										String hyperlink = ((HyperlinkParameterImpl)param).getHyperlink();
+										final String hyperlink = ((HyperlinkParameterImpl)param).getHyperlink();
 										
 										if (hyperlink != null) {
-											LinkLabel.updateLinkedLabel(f_label, hyperlink);
+											
+											Utils.execSWTThread(
+												new Runnable()
+												{
+													public void
+													run()
+													{
+														LinkLabel.updateLinkedLabel(f_label, hyperlink);
+													}
+												});
 										}
 									}
 								}
@@ -643,6 +652,8 @@ BasicPluginConfigImpl
 				    	
 				    	con.setVisible(false);
 				    	
+				    	con.setSize( 0, 0 );
+				    	
 				    	GridData gridData = new GridData();
 						
 						gridData.heightHint 				= 0;
