@@ -33,13 +33,11 @@ import java.util.WeakHashMap;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.awt.SWT_AWT;
-import org.eclipse.swt.custom.CLabel;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.ImageData;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.widgets.*;
 import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Event;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.download.DownloadManager;
@@ -62,6 +60,7 @@ import org.gudy.azureus2.pluginsimpl.local.download.DownloadImpl;
 import org.gudy.azureus2.pluginsimpl.local.ui.UIManagerImpl;
 import org.gudy.azureus2.ui.common.util.MenuItemManager;
 import org.gudy.azureus2.ui.swt.*;
+import org.gudy.azureus2.ui.swt.components.shell.ShellFactory;
 import org.gudy.azureus2.ui.swt.mainwindow.*;
 import org.gudy.azureus2.ui.swt.minibar.AllTransfersBar;
 import org.gudy.azureus2.ui.swt.minibar.DownloadBar;
@@ -196,35 +195,32 @@ UISWTInstanceImpl
 							}
 							
 
-							Shell shell = uiFunctions.getMainShell();
+							MessageBoxShell mb = new MessageBoxShell(styles, 
+									MessageText.getString((String)params[0]), 
+									MessageText.getString((String)params[1]));
+							mb.open(null);
+							int _r = mb.waitUntilClosed();
 							
-							if ( shell != null ){
+							int	r = 0;
+							
+							if (( _r & SWT.YES ) != 0 ){
 								
-								int _r = Utils.openMessageBox(shell, styles, 
-										MessageText.getString((String)params[0]), 
-										MessageText.getString((String)params[1]));
-								
-								int	r = 0;
-								
-								if (( _r & SWT.YES ) != 0 ){
-									
-									r |= UIManagerEvent.MT_YES;
-								}
-								if (( _r & SWT.NO ) != 0 ){
-									
-									r |= UIManagerEvent.MT_NO;
-								}
-								if (( _r & SWT.OK ) != 0 ){
-									
-									r |= UIManagerEvent.MT_OK;
-								}
-								if (( _r & SWT.CANCEL ) != 0 ){
-									
-									r |= UIManagerEvent.MT_CANCEL;
-								}
-								
-								result[0] = r;
+								r |= UIManagerEvent.MT_YES;
 							}
+							if (( _r & SWT.NO ) != 0 ){
+								
+								r |= UIManagerEvent.MT_NO;
+							}
+							if (( _r & SWT.OK ) != 0 ){
+								
+								r |= UIManagerEvent.MT_OK;
+							}
+							if (( _r & SWT.CANCEL ) != 0 ){
+								
+								r |= UIManagerEvent.MT_CANCEL;
+							}
+							
+							result[0] = r;
 						}
 					}, false );
 				
@@ -539,6 +535,12 @@ UISWTInstanceImpl
 	{
 		return new UISWTGraphicImpl(img);
 	}
+	
+	public Shell createShell(int style) {
+		Shell shell = ShellFactory.createMainShell(style);
+		Utils.setShellIcon(shell);
+		return shell;
+	}
   
 
 	/** @deprecated */
@@ -784,8 +786,12 @@ UISWTInstanceImpl
 	// @see org.gudy.azureus2.plugins.ui.UIInstance#promptUser(java.lang.String, java.lang.String, java.lang.String[], int)
 	public int promptUser(String title, String text, String[] options,
 			int defaultOption) {
-		return MessageBoxShell.open(uiFunctions.getMainShell(), title, text,
-				options, defaultOption);
+		
+		MessageBoxShell mb = new MessageBoxShell(title, text, options,
+				defaultOption);
+		mb.open(null);
+		// bah, no way to change this to use the UserPrompterResultListener trigger
+		return mb.waitUntilClosed();
 	}
 	
 	public void showDownloadBar(Download download, final boolean display) {
@@ -845,25 +851,16 @@ UISWTInstanceImpl
 		final UISWTStatusEntryImpl entry = new UISWTStatusEntryImpl();
 		UIFunctionsSWT functionsSWT = UIFunctionsManagerSWT.getUIFunctionsSWT();
 		if (functionsSWT == null) {
+			Debug.outNoStack("No UIFunctionsSWT on createStatusEntry");
 			return null;
 		}
 		
 		MainStatusBar mainStatusBar = functionsSWT.getMainStatusBar();
 		if (mainStatusBar == null) {
+			Debug.outNoStack("No MainStatusBar on createStatusEntry");
 			return null;
 		}
-		final CLabel label = mainStatusBar.createStatusEntry(entry);
-		final Listener click_listener = new Listener() {
-			public void handleEvent(Event e) {
-				entry.onClick();
-			}
-		};
-
-		Utils.execSWTThread(new AERunnable() {
-			public void runSupport() {
-				label.addListener(SWT.MouseDoubleClick, click_listener);
-			}
-		}, true);
+		mainStatusBar.createStatusEntry(entry);
 		
 		return entry;
 	}
@@ -1030,6 +1027,10 @@ UISWTInstanceImpl
 		public void openConfig(BasicPluginConfigModel model) {
 			delegate.openConfig(model);
 		}
+
+		public Shell createShell(int style) {
+			return delegate.createShell(style);
+		}
 		
 	}
 	
