@@ -76,7 +76,7 @@ public class InstallPluginWizard extends Wizard {
 							public void
 							run()
 							{
-								new InstallPluginWizard( core, display, reason, (StandardPlugin)plugin );
+								new InstallPluginWizard( reason, (StandardPlugin)plugin );
 							}
 						});
 					
@@ -90,11 +90,9 @@ public class InstallPluginWizard extends Wizard {
   }
   
   
-  public InstallPluginWizard(
-      	AzureusCore	azureus_core,	
- 		Display 	display )
+  public InstallPluginWizard()
 	{
-		super(azureus_core,"installPluginsWizard.title");			
+		super("installPluginsWizard.title");			
 				
 		IPWModePanel mode_panel = new IPWModePanel(this,null);
 	
@@ -103,12 +101,10 @@ public class InstallPluginWizard extends Wizard {
   
   	public 
   	InstallPluginWizard(
-  		AzureusCore			azureus_core,	
-  		Display 			display,
   		String				reason,
   		StandardPlugin		plugin )
   	{
-		super(azureus_core,"installPluginsWizard.title");			
+		super("installPluginsWizard.title");			
 			
 		standard_plugins 	= new StandardPlugin[]{ plugin };
 		list_title_text		= reason;
@@ -122,13 +118,13 @@ public class InstallPluginWizard extends Wizard {
 	}
   	
   	protected StandardPlugin[]
-  	getStandardPlugins()
+  	getStandardPlugins(AzureusCore core)
   	
   		throws PluginException
   	{
   		if ( standard_plugins == null ){
   			
-  			standard_plugins = getAzureusCore().getPluginManager().getPluginInstaller().getStandardPlugins();
+  			standard_plugins = core.getPluginManager().getPluginInstaller().getStandardPlugins();
   		}
   		
   		return( standard_plugins );
