@@ -29,6 +29,8 @@ import java.util.List;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.custom.SashForm;
+import org.eclipse.swt.events.DisposeEvent;
+import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.layout.*;
 import org.eclipse.swt.widgets.*;
 
@@ -244,13 +246,15 @@ UpdateWindow
     link_area.getComponent().setLayoutData(fd);
     
     try {
-    	browser = new Browser(cInfoArea, Utils.getInitialBrowserStyle(SWT.BORDER));
-      fd = new FormData();
-      fd.top = new FormAttachment(0, 0);
-      fd.bottom = new FormAttachment(100, 0);
-      fd.right = new FormAttachment(100, 0);
-      fd.left = new FormAttachment(0, 0);
-      browser.setLayoutData(fd);
+    	browser = Utils.createSafeBrowser(cInfoArea, SWT.BORDER);
+    	if (browser != null) {
+        fd = new FormData();
+        fd.top = new FormAttachment(0, 0);
+        fd.bottom = new FormAttachment(100, 0);
+        fd.right = new FormAttachment(100, 0);
+        fd.left = new FormAttachment(0, 0);
+        browser.setLayoutData(fd);
+    	}
     } catch (Throwable t) {
     }
 
