@@ -20,11 +20,7 @@
  */
 package org.gudy.azureus2.ui.swt.views;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.Map;
+import java.util.*;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.SashForm;
@@ -41,17 +37,16 @@ import org.gudy.azureus2.core3.logging.LogEvent;
 import org.gudy.azureus2.core3.logging.LogIDs;
 import org.gudy.azureus2.core3.logging.Logger;
 import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.core3.util.Timer;
+import org.gudy.azureus2.plugins.ui.config.ConfigSection;
+import org.gudy.azureus2.plugins.ui.config.ConfigSectionSWT;
 import org.gudy.azureus2.pluginsimpl.local.ui.config.ConfigSectionRepository;
-import org.gudy.azureus2.ui.swt.ImageRepository;
 import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.plugins.UISWTConfigSection;
 import org.gudy.azureus2.ui.swt.views.configsections.*;
 
-import com.aelitis.azureus.core.AzureusCore;
-
-import org.gudy.azureus2.plugins.ui.config.ConfigSection;
-import org.gudy.azureus2.plugins.ui.config.ConfigSectionSWT;
+import com.aelitis.azureus.ui.swt.imageloader.ImageLoader;
 
 /**
  * @author Olivier
@@ -61,10 +56,9 @@ public class ConfigView extends AbstractIView {
 	private static final LogIDs LOGID = LogIDs.GUI;
   public static final String sSectionPrefix = "ConfigView.section.";
   
-  AzureusCore		azureus_core;
-  
-  
-  Map sections = new HashMap();
+  Map<TreeItem, ConfigSection> sections = new HashMap<TreeItem, ConfigSection>();
+  // Only access on SWT Thread
+  java.util.List<ConfigSection> sectionsCreated = new ArrayList<ConfigSection>(1);
   Composite cConfig;
   Composite cConfigSection;
   StackLayout layoutConfigSection;
@@ -79,23 +73,27 @@ public class ConfigView extends AbstractIView {
 	private String filterText = "";
 	private Label lblX;
 	private Listener scResizeListener;
+	
+	private Image imgSmallX;
+	private Image imgSmallXGray;
 
-  /**
-   * Main Initializer
-   * 
-   * @param _azureus_core
-   */
   public 
-  ConfigView(
-  	AzureusCore		_azureus_core ) 
+  ConfigView() 
   {
-  	azureus_core	= _azureus_core;
   }
-
+  
   /* (non-Javadoc)
    * @see org.gudy.azureus2.ui.swt.IView#initialize(org.eclipse.swt.widgets.Composite)
    */
-  public void initialize(Composite composite) {
+  public void initialize(final Composite composite) {
+  	// need to initalize composite now, since getComposite can
+  	// be called at any time
+    cConfig = new Composite(composite, SWT.NONE);
+		_initialize(composite);
+  }
+  	
+  public void _initialize(Composite composite) {
+  	
     GridData gridData;
     /*
     /--cConfig-----------------------------------------------------------\
@@ -118,7 +116,6 @@ public class ConfigView extends AbstractIView {
     try {
       Display d = composite.getDisplay();
 
-      cConfig = new Composite(composite, SWT.NONE);
       GridLayout configLayout = new GridLayout();
       configLayout.marginHeight = 0;
       configLayout.marginWidth = 0;
@@ -157,10 +154,14 @@ public class ConfigView extends AbstractIView {
 				}
 			});
       txtFilter.setFocus();
+      
+      ImageLoader imageLoader = ImageLoader.getInstance();
+      imgSmallXGray = imageLoader.getImage("smallx-gray");
+      imgSmallX = imageLoader.getImage("smallx");
 
   		lblX = new Label(cFilterArea, SWT.WRAP);
       Messages.setLanguageTooltip(lblX, "MyTorrentsView.clearFilter.tooltip");
-      lblX.setImage(ImageRepository.getImage("smallx-gray"));
+      lblX.setImage(imgSmallXGray);
       lblX.addMouseListener(new MouseAdapter() {
       	public void mouseUp(MouseEvent e) {
       		txtFilter.setText("");
@@ -168,7 +169,7 @@ public class ConfigView extends AbstractIView {
       });
       
       Label lblSearch = new Label(cFilterArea, SWT.NONE);
-      lblSearch.setImage(ImageRepository.getImage("search"));
+      imageLoader.setLabelImage(lblSearch, "search");
   
       tree = new Tree(cLeftSide, SWT.NONE);
       FontData[] fontData = tree.getFont().getFontData();
@@ -294,11 +295,13 @@ public class ConfigView extends AbstractIView {
      */
     pluginSections = ConfigSectionRepository.getInstance().getList();
 
-    ConfigSection[] internalSections = { new ConfigSectionConnection(),
+    ConfigSection[] internalSections = { 
+                                         new ConfigSectionMode(),
+                                         new ConfigSectionConnection(),
                                          new ConfigSectionConnectionProxy(),
                                          new ConfigSectionConnectionAdvanced(),
                                          new ConfigSectionConnectionEncryption(),
-                                         new ConfigSectionTransfer(azureus_core),
+                                         new ConfigSectionTransfer(),
                                          new ConfigSectionTransferAutoSpeedSelect(),
                                          new ConfigSectionTransferAutoSpeed(),
                                          new ConfigSectionTransferAutoSpeedBeta(),
@@ -314,13 +317,14 @@ public class ConfigView extends AbstractIView {
                                          new ConfigSectionInterfaceDisplay(),
                                          new ConfigSectionInterfaceColor(),
                                          new ConfigSectionInterfaceAlerts(),
-                                         new ConfigSectionMode(),
-                                         new ConfigSectionIPFilter(azureus_core),
-                                         new ConfigSectionPlugins(this, azureus_core),
+                                         new ConfigSectionInterfacePassword(),
+                                         new ConfigSectionInterfaceLegacy(),
+                                         new ConfigSectionIPFilter(),
+                                         new ConfigSectionPlugins(this),
                                          new ConfigSectionStats(),
-                                         new ConfigSectionTracker(azureus_core),
+                                         new ConfigSectionTracker(),
                                          new ConfigSectionTrackerClient(),
-                                         new ConfigSectionTrackerServer(azureus_core),
+                                         new ConfigSectionTrackerServer(),
                                          new ConfigSectionSecurity(),
                                          new ConfigSectionSharing(),
                                          new ConfigSectionLogging()
@@ -410,6 +414,7 @@ public class ConfigView extends AbstractIView {
    
             	  c = ((UISWTConfigSection)section).configSectionCreate(sc);
             }
+            sectionsCreated.add(section);
             sc.setContent(c);
           }
           
@@ -434,7 +439,11 @@ public class ConfigView extends AbstractIView {
  
 
 
-    initSaveButton();
+    if (composite instanceof Shell) {
+    	initApplyCloseButton();
+    } else {
+    	initSaveButton();
+    }
 
     TreeItem[] items = { tree.getItems()[0] };
     tree.setSelection(items);
@@ -463,8 +472,7 @@ public class ConfigView extends AbstractIView {
 		}
 		
 		if (lblX != null && !lblX.isDisposed()) {
-			Image img = ImageRepository.getImage(filterText.length() > 0 ? "smallx"
-					: "smallx-gray");
+			Image img = filterText.length() > 0 ? imgSmallX : imgSmallXGray;
 
 			lblX.setImage(img);
 		}
@@ -577,18 +585,19 @@ public class ConfigView extends AbstractIView {
     }
   }
 	
-	private void ensureSectionBuilt(TreeItem section) {
-    ScrolledComposite item = (ScrolledComposite)section.getData("Panel");
+	private void ensureSectionBuilt(TreeItem treeSection) {
+    ScrolledComposite item = (ScrolledComposite)treeSection.getData("Panel");
 
     if (item != null) {
     	
-      ConfigSection configSection = (ConfigSection)section.getData("ConfigSectionSWT");
+      ConfigSection configSection = (ConfigSection)treeSection.getData("ConfigSectionSWT");
       
       if (configSection != null) {
     	  
         Control previous = item.getContent();
         if (previous instanceof Composite) {
         	configSection.configSectionDelete();
+          sectionsCreated.remove(configSection);    	
           Utils.disposeComposite((Composite)previous,true);
         }
         
@@ -602,6 +611,7 @@ public class ConfigView extends AbstractIView {
 
           c = ((UISWTConfigSection)configSection).configSectionCreate(item);
         }
+        sectionsCreated.add(configSection);
         
         item.setContent(c);
       }
@@ -616,7 +626,7 @@ public class ConfigView extends AbstractIView {
 		int maxUsermode = 0;
 		try
 		{
-			ConfigSection sect = (ConfigSection) sections.get(section);
+			ConfigSection sect = sections.get(section);
 			if (sect instanceof UISWTConfigSection)
 			{
 				maxUsermode = ((UISWTConfigSection) sect).maxUserMode();
@@ -733,8 +743,12 @@ public class ConfigView extends AbstractIView {
   }
 
   private TreeItem findTreeItem(Tree tree, String ID) {
-  	if (tree == null)
+  	if (tree == null) {
   		tree = this.tree;
+  	}
+  	if (tree == null) {
+  		return null;
+  	}
     TreeItem[] items = tree.getItems();
     for (int i = 0; i < items.length; i++) {
       String itemID = (String)items[i].getData("ID");
@@ -776,15 +790,50 @@ public class ConfigView extends AbstractIView {
       public void widgetSelected(SelectionEvent event) {
 				// force focusout on osx
 				save.setFocus();
-				COConfigurationManager.setParameter("updated", 1);
-				COConfigurationManager.save();
-
-				for (int i = 0; i < pluginSections.size(); i++)
-					((ConfigSection) pluginSections.get(i)).configSectionSave();
+				save();
 			}
 		});
   }
 
+  private void initApplyCloseButton() {
+  	Composite cButtons = new Composite(cConfig, SWT.NONE);
+  	GridLayout gridLayout = new GridLayout();
+		gridLayout.horizontalSpacing = gridLayout.verticalSpacing = gridLayout.marginHeight = gridLayout.marginWidth = 0;
+		gridLayout.numColumns = 2;
+		cButtons.setLayout(gridLayout);
+		cButtons.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
+  	
+    GridData gridData;
+    final Button apply = new Button(cButtons, SWT.PUSH);
+    Messages.setLanguageText(apply, "Button.apply");
+    gridData = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+    gridData.widthHint = 80;
+    apply.setLayoutData(gridData);
+
+    apply.addSelectionListener(new SelectionAdapter() {
+      public void widgetSelected(SelectionEvent event) {
+				// force focusout on osx
+				apply.setFocus();
+				save();
+			}
+		});
+    
+    final Button close = new Button(cButtons, SWT.PUSH);
+    Messages.setLanguageText(close, "Button.close");
+    gridData = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+    gridData.widthHint = 80;
+    close.setLayoutData(gridData);
+
+    close.addSelectionListener(new SelectionAdapter() {
+      public void widgetSelected(SelectionEvent event) {
+				// force focusout on osx
+				apply.setFocus();
+				save();
+				apply.getShell().dispose();
+			}
+		});
+  }
+  
   /* (non-Javadoc)
    * @see org.gudy.azureus2.ui.swt.IView#getComposite()
    */
@@ -799,13 +848,14 @@ public class ConfigView extends AbstractIView {
   }
 
   public void delete() {
-    for (int i = 0; i < pluginSections.size(); i++) {
+  	for (ConfigSection section : sectionsCreated) {
     	try {
-    		((ConfigSection)pluginSections.get(i)).configSectionDelete();
+    		section.configSectionDelete();
     	} catch (Exception e) {
     		Debug.out("Error while deleting config section", e);
     	}
     }
+  	sectionsCreated.clear();
     pluginSections.clear();
     if(! tree.isDisposed()) {
 	    TreeItem[] items = tree.getItems();
@@ -822,6 +872,10 @@ public class ConfigView extends AbstractIView {
   	Utils.disposeSWTObjects(new Object[] { headerFont, filterFoundFont });
 		headerFont = null;
 		filterFoundFont = null;
+
+    ImageLoader imageLoader = ImageLoader.getInstance();
+    imageLoader.releaseImage("smallx-gray");
+    imageLoader.releaseImage("smallx");
   }
 
   public String getFullTitle() {
@@ -862,4 +916,15 @@ public class ConfigView extends AbstractIView {
 		  }
 	  }
   }
+  
+  public void save() {
+		COConfigurationManager.setParameter("updated", 1);
+		COConfigurationManager.save();
+
+		if (null != pluginSections) {
+			for (int i = 0; i < pluginSections.size(); i++) {
+				((ConfigSection) pluginSections.get(i)).configSectionSave();
+			}
+		}
+	}
 }
