@@ -48,6 +48,7 @@ import org.gudy.azureus2.core3.util.Debug;
 import org.gudy.azureus2.core3.util.FileUtil;
 import org.gudy.azureus2.plugins.ui.tables.TableManager;
 import org.gudy.azureus2.ui.swt.*;
+import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
 import org.gudy.azureus2.ui.swt.views.file.FileInfoView;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
 import org.gudy.azureus2.ui.swt.views.table.TableViewSWTMenuFillListener;
@@ -66,7 +67,7 @@ import com.aelitis.azureus.ui.common.table.*;
  *         2004/Apr/23: extends TableView instead of IAbstractView
  */
 public class FilesView
-	extends TableViewTab
+	extends TableViewTab<DiskManagerFileInfo>
 	implements TableDataSourceChangedListener, TableSelectionListener,
 	TableViewSWTMenuFillListener, TableRefreshListener, DownloadManagerStateAttributeListener,
 	TableLifeCycleListener
@@ -117,11 +118,14 @@ public class FilesView
    * Initialize 
    */
 	public FilesView() {
+		super("FilesView");
+	}
+
+	public TableViewSWT<DiskManagerFileInfo> initYourTableView() {
 		tv = new TableViewSWTImpl<DiskManagerFileInfo>(
 				org.gudy.azureus2.plugins.disk.DiskManagerFileInfo.class,
-				TableManager.TABLE_TORRENT_FILES, "FilesView", basicItems,
+				TableManager.TABLE_TORRENT_FILES, getPropertiesPrefix(), basicItems,
 				"firstpiece", SWT.MULTI | SWT.FULL_SELECTION | SWT.VIRTUAL);
-		setTableView(tv);
 		tv.setRowDefaultIconSize(new Point(16, 16));
 		tv.setEnableTabViews(true);
 		tv.setCoreTabViews(new IView[] { new FileInfoView()
@@ -132,6 +136,8 @@ public class FilesView
 		tv.addSelectionListener(this, false);
 		tv.addMenuFillListener(this);
 		tv.addLifeCycleListener(this);
+
+		return tv;
 	}
 
   
@@ -330,9 +336,10 @@ public class FilesView
     
     Listener rename_listener = new Listener() {
     	public void handleEvent(Event event) {
-    		boolean rename_it = ((Boolean)event.widget.getData("rename")).booleanValue();
-    		boolean retarget_it = ((Boolean)event.widget.getData("retarget")).booleanValue();
-    		rename(tv.getSelectedRows(), rename_it, retarget_it);
+    		final boolean rename_it = ((Boolean)event.widget.getData("rename")).booleanValue();
+    		final boolean retarget_it = ((Boolean)event.widget.getData("retarget")).booleanValue();
+				final TableRowCore[] selectedRows = tv.getSelectedRows();
+				rename(selectedRows, rename_it, retarget_it);
     	}
     };
     
@@ -342,8 +349,13 @@ public class FilesView
     
     Listener priorityListener = new Listener() {
 			public void handleEvent(Event event) {
-				changePriority(((Integer) event.widget.getData("Priority")).intValue(),
-						tv.getSelectedRows());
+				final int priority = ((Integer) event.widget.getData("Priority")).intValue();
+				final TableRowCore[] selectedRows = tv.getSelectedRows();
+				Utils.getOffOfSWTThread(new AERunnable(){
+					public void runSupport() {
+						changePriority(priority, selectedRows);
+					}
+				});
 			}
     };
 
@@ -381,14 +393,18 @@ public class FilesView
 	}
 	
 	private boolean askCanOverwrite(File file) {
-		return MessageBoxWindow.open( 
-				"FilesView.messagebox.rename.id",
-				SWT.OK | SWT.CANCEL,
-				SWT.OK, true,
-				Display.getDefault(), 
-				MessageBoxWindow.ICON_WARNING,
-				MessageText.getString( "FilesView.rename.confirm.delete.title" ),
-				MessageText.getString( "FilesView.rename.confirm.delete.text", new String[]{ file.toString()})) == SWT.OK;
+		MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.CANCEL,
+				MessageText.getString("FilesView.rename.confirm.delete.title"),
+				MessageText.getString("FilesView.rename.confirm.delete.text",
+						new String[] {
+							file.toString()
+						}));
+		mb.setDefaultButtonUsingStyle(SWT.OK);
+		mb.setRememberOnlyIfButton(0);
+		mb.setRemember("FilesView.messagebox.rename.id", true, null);
+		mb.setLeftImage(SWT.ICON_WARNING);
+		mb.open(null);
+		return mb.waitUntilClosed() == SWT.OK;
 	}
 	
 	// same code is used in tableitems.files.NameItem
@@ -408,10 +424,9 @@ public class FilesView
 		is_changing_links = false;
 
 		if (!result[0]){
-			MessageBox mb = new MessageBox(Utils.findAnyShell(), SWT.ICON_ERROR | SWT.OK);
-			mb.setText(MessageText.getString("FilesView.rename.failed.title"));
-			mb.setMessage(MessageText.getString("FilesView.rename.failed.text"));
-			mb.open();	    					
+			new MessageBoxShell(SWT.ICON_ERROR | SWT.OK, 
+					MessageText.getString("FilesView.rename.failed.title"),
+					MessageText.getString("FilesView.rename.failed.text")).open(null);
 		}
 
 	}
@@ -429,8 +444,8 @@ public class FilesView
 		boolean	paused = false;
 		try {
 			for (int i=0; i<rows.length; i++) {
-				TableRowCore row = rows[i];
-				DiskManagerFileInfo fileInfo = (DiskManagerFileInfo)rows[i].getDataSource(true);
+				final TableRowCore row = rows[i];
+				final DiskManagerFileInfo fileInfo = (DiskManagerFileInfo)rows[i].getDataSource(true);
 				File existing_file = fileInfo.getFile(true);
 				File f_target = null;
 				if (rename_it && retarget_it) {
@@ -468,8 +483,13 @@ public class FilesView
     				// no existing file.
     			}
     					
-    			moveFile(fileInfo, f_target);
-    			row.invalidate();
+    			final File ff_target = f_target;
+  				Utils.getOffOfSWTThread(new AERunnable(){
+  					public void runSupport() {
+  						moveFile(fileInfo, ff_target);
+  	    			row.invalidate();
+  					}
+  				});
 			}
 		}
 		finally {
@@ -561,17 +581,22 @@ public class FilesView
 			if (root_exists) {perform_check = true;}
 			else if (FileUtil.isAncestorOf(save_location, existing_file)) {perform_check = false;}
 			else {perform_check = true;}
-						
+
 			if (perform_check && existing_file.exists()) {
-				if (delete_action) {
-					boolean wants_to_delete = MessageBoxWindow.open( 
-							"FilesView.messagebox.delete.id",
-							SWT.OK | SWT.CANCEL,
-							SWT.OK, true,
-							Display.getDefault(), 
-							MessageBoxWindow.ICON_WARNING,
-							MessageText.getString( "FilesView.rename.confirm.delete.title" ),
-							MessageText.getString( "FilesView.rename.confirm.delete.text", new String[]{ existing_file.toString()})) == SWT.OK;
+					if (delete_action) {
+						MessageBoxShell mb = new MessageBoxShell(SWT.OK | SWT.CANCEL,
+								MessageText.getString("FilesView.rename.confirm.delete.title"),
+								MessageText.getString("FilesView.rename.confirm.delete.text",
+										new String[] {
+											existing_file.toString()
+										}));
+						mb.setDefaultButtonUsingStyle(SWT.OK);
+						mb.setRememberOnlyIfButton(0);
+						mb.setRemember("FilesView.messagebox.delete.id", true, null);
+						mb.setLeftImage(SWT.ICON_WARNING);
+						mb.open(null);
+
+					boolean wants_to_delete = mb.waitUntilClosed() == SWT.OK;
 					
 					if (wants_to_delete) {new_storage_type = DiskManagerFileInfo.ST_COMPACT;}
 				}
@@ -699,11 +724,7 @@ public class FilesView
     if (sColumnName.equals("path")) {
       path_item = new MenuItem( menuThisColumn, SWT.CHECK );
       
-      menuThisColumn.addListener( SWT.Show, new Listener() {
-        public void handleEvent(Event e) {
-          path_item.setSelection( show_full_path );
-        }
-      });
+      path_item.setSelection( show_full_path );
       
       Messages.setLanguageText(path_item, "FilesView.fullpath");
       
