@@ -173,7 +173,11 @@ public class GeneralView extends AbstractIView implements ParameterListener,
     genLayout.numColumns = 1;
     genComposite.setLayout(genLayout);
 
-    refreshInfo();
+    Utils.execSWTThreadLater(0, new AERunnable() {
+			public void runSupport() {
+				refreshInfo();
+			}
+		});
     COConfigurationManager.addParameterListener("Graphics Update", this);
   }
   
@@ -696,13 +700,6 @@ public class GeneralView extends AbstractIView implements ParameterListener,
       }
     });
 
-    if( Constants.isOSX ) {
-      Shell shell = genComposite.getShell();
-      Point size = shell.getSize();
-      shell.setSize(size.x-1,size.y-1);
-      shell.setSize(size);
-    }
-    
     genComposite.addDisposeListener(new DisposeListener() {
     	public void widgetDisposed(DisposeEvent e) {
     		menuTracker.dispose();
@@ -724,7 +721,7 @@ public class GeneralView extends AbstractIView implements ParameterListener,
    * @see org.gudy.azureus2.ui.swt.IView#refresh()
    */
   public void refresh() {
-    if(getComposite() == null || getComposite().isDisposed() || manager == null)
+    if(gFile == null || gFile.isDisposed() || manager == null)
       return;
 
     loopFactor++;
@@ -1258,7 +1255,7 @@ public class GeneralView extends AbstractIView implements ParameterListener,
     
     if ( trackerClient != null ){
     	
-    	URL	temp = trackerClient.getTrackerUrl();
+    	URL	temp = trackerClient.getTrackerURL();
     	
     	if ( temp != null ){
     		
