@@ -173,7 +173,7 @@ public class ManagerView
     //Don't ask me why, but without this an exception is thrown further
     // (in folder.dispose() )
     //TODO : Investigate to see if it's a platform (OSX-Carbon) BUG, and report to SWT team.
-    if(Constants.isOSX) {
+    if(Utils.isCarbon) {
       if(folder != null && !folder.isDisposed()) {
         CTabItem[] items = folder.getItems();
         for(int i=0 ; i < items.length ; i++) {
@@ -235,11 +235,12 @@ public class ManagerView
   		iviews_to_use.add(new LoggerView(true));
   	}
   	
-  	IView[] views = (IView[])iviews_to_use.toArray(new IView[iviews_to_use.size()]);
+  	final IView[] views = (IView[])iviews_to_use.toArray(new IView[iviews_to_use.size()]);
 
   	for (int i = 0; i < views.length; i++)
 		addSection(views[i], manager);
 
+
     // Call plugin listeners
 		UIFunctionsSWT uiFunctions = UIFunctionsManagerSWT.getUIFunctionsSWT();
 		if (uiFunctions != null) {
@@ -263,39 +264,47 @@ public class ManagerView
 			}
 		}
 		
-    
+
     // Initialize view when user selects it
     folder.addSelectionListener(new SelectionAdapter() {
       public void widgetSelected(SelectionEvent e) {
-      	// Send one last refresh to previous tab, just in case it
-      	// wants to do something when view goes invisible
-        refresh();
-
-        CTabItem item = (CTabItem)e.item;
-        if (item != null) {
-        	IView view = (IView)item.getData("IView");
-          activeView = view;
-        	
-        	if (item.getControl() == null) {
-          	view.initialize(folder);
-          	item.setControl(view.getComposite());
-        	}
-        	
-        	item.getControl().setFocus();
-        }
-        refresh();
-    		ViewTitleInfoManager.refreshTitleInfo(ManagerView.this);
+      	folder.getShell().setCursor(e.display.getSystemCursor(SWT.CURSOR_WAIT));
+      	try {
+        	// Send one last refresh to previous tab, just in case it
+        	// wants to do something when view goes invisible
+          refresh();
+  
+          CTabItem item = (CTabItem)e.item;
+          if (item != null) {
+          	IView view = (IView)item.getData("IView");
+            activeView = view;
+          	
+          	if (item.getControl() == null) {
+            	view.initialize(folder);
+            	item.setControl(view.getComposite());
+          	}
+          	
+          	item.getControl().setFocus();
+          }
+          refresh();
+      		ViewTitleInfoManager.refreshTitleInfo(ManagerView.this);
+      	} finally {
+      		folder.getShell().setCursor(null);
+      	}
       }
     });
     
-    
-    views[0].initialize(folder);
-    folder.getItem(0).setControl(views[0].getComposite());
-    views[0].refresh();
-    views[0].getComposite().layout(true);
-    views[0].getComposite().setFocus();
-    activeView = views[0];
-		ViewTitleInfoManager.refreshTitleInfo(this);
+    Utils.execSWTThreadLater(0, new AERunnable() {
+			public void runSupport() {
+				views[0].initialize(folder);
+				folder.getItem(0).setControl(views[0].getComposite());
+				views[0].refresh();
+				views[0].getComposite().layout(true);
+				views[0].getComposite().setFocus();
+				activeView = views[0];
+				ViewTitleInfoManager.refreshTitleInfo(ManagerView.this);
+			}
+		});
   }
   
   private IView getActiveView() {
