@@ -24,7 +24,6 @@ package org.gudy.azureus2.ui.swt.views;
 
 import java.util.*;
 import java.util.List;
-import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.eclipse.swt.SWT;
@@ -55,14 +54,10 @@ import org.gudy.azureus2.pluginsimpl.local.PluginInitializer;
 import org.gudy.azureus2.ui.swt.*;
 import org.gudy.azureus2.ui.swt.URLTransfer;
 import org.gudy.azureus2.ui.swt.help.HealthHelpWindow;
-import org.gudy.azureus2.ui.swt.mainwindow.Colors;
 import org.gudy.azureus2.ui.swt.mainwindow.TorrentOpener;
 import org.gudy.azureus2.ui.swt.minibar.DownloadBar;
 import org.gudy.azureus2.ui.swt.views.ViewUtils.SpeedAdapter;
-import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
-import org.gudy.azureus2.ui.swt.views.table.TableViewSWTMenuFillListener;
-import org.gudy.azureus2.ui.swt.views.table.TableViewSWTPanelCreator;
-import org.gudy.azureus2.ui.swt.views.table.impl.TableCellImpl;
+import org.gudy.azureus2.ui.swt.views.table.*;
 import org.gudy.azureus2.ui.swt.views.table.impl.TableViewSWTImpl;
 import org.gudy.azureus2.ui.swt.views.table.impl.TableViewTab;
 import org.gudy.azureus2.ui.swt.views.utils.ManagerUtils;
@@ -101,17 +96,10 @@ public class MyTorrentsView
                   TableSelectionListener,
                   TableViewSWTMenuFillListener,
                   TableRefreshListener,
-                  TableCountChangeListener
+                  TableCountChangeListener,
+                  TableViewFilterCheck
 {
 	private static final LogIDs LOGID = LogIDs.GUI;
-	private static final int ASYOUTYPE_MODE_FIND = 0;
-	private static final int ASYOUTYPE_MODE_FILTER = 1;
-	private static final int ASYOUTYPE_MODE = ASYOUTYPE_MODE_FILTER;
-	private static final int ASYOUTYPE_UPDATEDELAY = 300;
-	
-	/** Experimental Table UI.  When setting to true, some code needs 
-	 *  uncommenting as well */
-	private static final boolean EXPERIMENT = false;
 	
 	private AzureusCore		azureus_core;
 
@@ -135,10 +123,6 @@ public class MyTorrentsView
   private int drag_drop_line_start = -1;
   private TableRowCore[] drag_drop_rows = null;
 
-	private TimerEvent searchUpdateEvent;
-  private String sLastSearch = "";
-  private long lLastSearchTime;
-  private boolean bRegexSearch = false;
 	private boolean bDNDalwaysIncomplete;
 	private TableViewSWT tv;
 	private Composite cTableParentPanel;
@@ -149,8 +133,10 @@ public class MyTorrentsView
 	protected boolean resizeHeaderEventQueued;
 	private Button btnFilter;
 
-	public
-	MyTorrentsView() {
+	private Composite cSizer;
+
+	public MyTorrentsView() {
+		super("MyTorrentsView");
 	}
 	
   /**
@@ -167,23 +153,22 @@ public class MyTorrentsView
   		boolean 					isSeedingView,
       TableColumnCore[]	basicItems) 
   {
+		super("MyTorrentsView");
   	init(_azureus_core, tableID, isSeedingView, basicItems);
   }
   
+  // @see org.gudy.azureus2.ui.swt.views.table.impl.TableViewTab#initYourTableView()
+  public TableViewSWT initYourTableView() {
+  	return tv;
+  }
+  
   public void init(AzureusCore _azureus_core, String tableID,
 			boolean isSeedingView, TableColumnCore[] basicItems) {
 
   	this.isSeedingView 	= isSeedingView;
   	
-  	if (EXPERIMENT) {
-//      tv = new ListView(isSeedingView ? TableManager.TABLE_MYTORRENTS_COMPLETE
-//  				: TableManager.TABLE_MYTORRENTS_INCOMPLETE, SWT.V_SCROLL);
-//      tv.setColumnList(basicItems, "#", false);
-  	} else {
-      tv = createTableView(isSeedingView ? DownloadTypeComplete.class
-  				: DownloadTypeIncomplete.class, tableID, basicItems);
-  	}
-    setTableView(tv);
+    tv = createTableView(isSeedingView ? DownloadTypeComplete.class
+				: DownloadTypeIncomplete.class, tableID, basicItems);
     tv.setRowDefaultIconSize(new Point(16, 16));
     
     /*
@@ -216,16 +201,22 @@ public class MyTorrentsView
 
   // @see com.aelitis.azureus.ui.common.table.TableLifeCycleListener#tableViewInitialized()
   public void tableViewInitialized() {
-    tv.addKeyListener(this);
+ 
+  	tv.addKeyListener(this);
 
     createTabs();
 
+    if (txtFilter == null) {
+    	tv.enableFilterCheck(null, this);
+    }
+
     createDragDrop();
 
     COConfigurationManager.addAndFireParameterListeners(new String[] {
 			"DND Always In Incomplete",
 			"Confirm Data Delete",
 			"MyTorrentsView.alwaysShowHeader",
+			"User Mode"
 		}, this);
 
     if (currentCategory != null) {
@@ -313,17 +304,6 @@ public class MyTorrentsView
     	cTableParentPanel.setLayoutData(new GridData(GridData.FILL_BOTH));
     }
     
-    if (EXPERIMENT) {
-    	Composite cHeaders = new Composite(cTableParentPanel, SWT.NONE);
-    	gridData = new GridData(GridData.FILL_HORIZONTAL);
-    	GC gc = new GC(cHeaders);
-    	int h = gc.textExtent("alyup").y + 2;
-    	gc.dispose();
-    	gridData.heightHint = h;
-    	cHeaders.setLayoutData(gridData);
-    	//((ListView)tv).setHeaderArea(cHeaders, null, null);
-    }
-
     cTablePanel = new Composite(cTableParentPanel, SWT.NULL);
     cTablePanel.setBackground(composite.getDisplay().getSystemColor(SWT.COLOR_LIST_BACKGROUND));
     cTablePanel.setForeground(composite.getDisplay().getSystemColor(SWT.COLOR_LIST_FOREGROUND));
@@ -353,7 +333,7 @@ public class MyTorrentsView
     GridData gridData;
     Category[] categories = CategoryManager.getCategories();
     Arrays.sort(categories);
-    boolean showCat = sLastSearch.length() > 0;
+    boolean showCat = tv.getFilterText().length() > 0;
     if (!showCat) {
 	    for(int i = 0; i < categories.length; i++) {
 	        if(categories[i].getType() == Category.TYPE_USER) {
@@ -375,156 +355,7 @@ public class MyTorrentsView
     
     if (show) {
       if (cCategories == null || cCategories.isDisposed()) {
-        Composite parent = cTableParentPanel;
-
-        cHeader = new Composite(parent, SWT.NONE);
-        gridData = new GridData(GridData.FILL_HORIZONTAL);
-        gridData.horizontalIndent = 5;
-        cHeader.setLayoutData(gridData);
-        cHeader.setLayout(new FormLayout());
-        FormData fd;
-        
-        lblHeader = new Label(cHeader, SWT.WRAP);
-        updateTableLabel();
-        
-        Label lblSep = new Label(cHeader, SWT.SEPARATOR | SWT.VERTICAL);
-        gridData = new GridData(GridData.FILL_VERTICAL);
-        gridData.heightHint = 5;
-        lblSep.setLayoutData(gridData);
-        
-        btnFilter = new Button(cHeader, SWT.TOGGLE);
-        Messages.setLanguageText(btnFilter, "MyTorrentsView.filter");
-        btnFilter.addSelectionListener(new SelectionListener() {
-				
-					public void widgetSelected(SelectionEvent e) {
-						boolean enable = btnFilter.getSelection();
-            cFilterArea.setVisible(enable);
-            if (enable) {
-            	sLastSearch = txtFilter.getText();
-            	txtFilter.setFocus();
-            } else {
-            	sLastSearch = "";
-            	tv.setFocus();
-            }
-            updateLastSearch();
-            resizeHeader();
-					}
-				
-					public void widgetDefaultSelected(SelectionEvent e) {
-					}
-				});
-        btnFilter.setSelection(sLastSearch.length() != 0);
-        
-
-        cFilterArea = new Composite(cHeader, SWT.NONE);
-        cFilterArea.setVisible(sLastSearch.length() != 0);
-        GridLayout layout = new GridLayout();
-        layout.numColumns = 5;
-        cFilterArea.setLayout(layout);
-                
-        cCategories = new Composite(cHeader, SWT.NONE);
-        RowLayout rowLayout = new RowLayout();
-        rowLayout.marginTop = 0;
-        rowLayout.marginBottom = 0;
-        rowLayout.marginLeft = 3;
-        rowLayout.marginRight = 0;
-        rowLayout.spacing = 0;
-        rowLayout.wrap = true;
-        cCategories.setLayout(rowLayout);
-
-
-        fd = new FormData();
-        fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER);
-        lblHeader.setLayoutData(fd);
-
-        fd = new FormData();
-        fd.left = new FormAttachment(lblSep, 10);
-        fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER);
-        btnFilter.setLayoutData(fd);
-
-        fd = new FormData();
-        fd.left = new FormAttachment(lblHeader, 10);
-        fd.top = new FormAttachment(cFilterArea, 3, SWT.TOP);
-        fd.bottom = new FormAttachment(cFilterArea, -3, SWT.BOTTOM);
-        lblSep.setLayoutData(fd);
-
-        fd = new FormData();
-        fd.left = new FormAttachment(btnFilter, 0);
-        fd.right = new FormAttachment(cCategories, -10);
-        cFilterArea.setLayoutData(fd);
-
-        fd = new FormData();
-        fd.right = new FormAttachment(100, -2); 
-        fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER); 
-        fd.bottom = new FormAttachment(cFilterArea, 0, SWT.BOTTOM); 
-        cCategories.setLayoutData(fd);
-        cHeader.addListener(SWT.Resize, new Listener(){
-					public void handleEvent(Event event) {
-						if (!resizeHeaderEventQueued) {
-  		        resizeHeaderEventQueued = true;
-  						Utils.execSWTThreadLater(0, new AERunnable(){
-  							public void runSupport() {
-  								resizeHeader();
-  								resizeHeaderEventQueued = false;
-  							}
-  						});
-						}
-					}
-				});
-
-        
-        txtFilter = new Text(cFilterArea, SWT.BORDER);
-        Messages.setLanguageTooltip(txtFilter, "MyTorrentsView.filter.tooltip");
-        txtFilter.addKeyListener(this);
-        gridData = new GridData(GridData.FILL_HORIZONTAL);
-        txtFilter.setLayoutData(gridData);
-        txtFilter.addModifyListener(new ModifyListener() {
-        	public void modifyText(ModifyEvent e) {
-        		sLastSearch = ((Text)e.widget).getText();
-        		showFilterArea();
-        		updateLastSearch();
-        	}
-        });
-        txtFilter.addKeyListener(new KeyAdapter() {
-        	public void keyPressed(KeyEvent e) {
-        		if (e.keyCode == SWT.ARROW_DOWN) {
-        			tv.setFocus();
-        			e.doit = false;
-        		} else if (e.character == 13) {
-        			if (searchUpdateEvent != null) {
-        				searchUpdateEvent.cancel();
-        			}
-        			searchUpdateEvent = null;
-        			activateCategory(currentCategory);
-        		}
-        	}
-        });
-        
-
-        lblX = new Label(cFilterArea, SWT.WRAP);
-        Messages.setLanguageTooltip(lblX, "MyTorrentsView.clearFilter.tooltip");
-        gridData = new GridData(SWT.TOP);
-        lblX.setLayoutData(gridData);
-        ImageLoader.getInstance().setLabelImage(lblX, "smallx-gray");
-        lblX.setData("ImageID", "smallx-gray");
-        lblX.addMouseListener(new MouseAdapter() {
-        	public void mouseUp(MouseEvent e) {
-        		if (e.y <= 10) {
-          		sLastSearch = "";
-          		txtFilter.setText("");
-          		updateLastSearch();
-        		}
-        	}
-        });
-        
-
-        lblSep = new Label(cFilterArea, SWT.SEPARATOR | SWT.VERTICAL);
-        gridData = new GridData(GridData.FILL_VERTICAL);
-        gridData.heightHint = 5;
-        lblSep.setLayoutData(gridData);
-        
-        cHeader.moveAbove(null);
-        parent.layout(true);
+      	buildHeaderArea();
       } else {
         Control[] controls = cCategories.getChildren();
         for (int i = 0; i < controls.length; i++) {
@@ -550,11 +381,204 @@ public class MyTorrentsView
 	 *
 	 * @since 4.1.0.5
 	 */
+	private void buildHeaderArea() {
+		GridData gridData;
+    Composite parent = cTableParentPanel;
+
+    cHeader = new Composite(parent, SWT.NONE);
+    gridData = new GridData(GridData.FILL_HORIZONTAL);
+    gridData.horizontalIndent = 5;
+    cHeader.setLayoutData(gridData);
+    cHeader.setLayout(new FormLayout());
+    FormData fd;
+    
+    lblHeader = new Label(cHeader, SWT.WRAP);
+    updateTableLabel();
+    
+    Label lblSep = new Label(cHeader, SWT.SEPARATOR | SWT.VERTICAL);
+    gridData = new GridData(GridData.FILL_VERTICAL);
+    gridData.heightHint = 5;
+    lblSep.setLayoutData(gridData);
+    
+    btnFilter = new Button(cHeader, SWT.TOGGLE);
+    Messages.setLanguageText(btnFilter, "MyTorrentsView.filter");
+    btnFilter.addSelectionListener(new SelectionListener() {
+		
+			public void widgetSelected(SelectionEvent e) {
+				boolean enable = btnFilter.getSelection();
+        cFilterArea.setVisible(enable);
+        if (enable) {
+        	tv.setFilterText(txtFilter.getText());
+        	txtFilter.setFocus();
+        } else {
+        	tv.setFilterText("");
+        	tv.setFocus();
+        }
+        resizeHeader();
+			}
+		
+			public void widgetDefaultSelected(SelectionEvent e) {
+			}
+		});
+    boolean hasLastSearch = tv.getFilterText().length() != 0;
+    btnFilter.setSelection(hasLastSearch);
+    
+
+    cFilterArea = new Composite(cHeader, SWT.NONE);
+    cFilterArea.setVisible(hasLastSearch);
+    GridLayout layout = new GridLayout();
+    layout.numColumns = 5;
+    cFilterArea.setLayout(layout);
+            
+    cCategories = new Composite(cHeader, SWT.NONE);
+    RowLayout rowLayout = new RowLayout();
+    rowLayout.marginTop = 0;
+    rowLayout.marginBottom = 0;
+    rowLayout.marginLeft = 3;
+    rowLayout.marginRight = 0;
+    rowLayout.spacing = 0;
+    rowLayout.wrap = true;
+    cCategories.setLayout(rowLayout);
+    
+    cSizer = new Composite(cHeader, SWT.NONE);
+
+    fd = new FormData();
+    fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER);
+    lblHeader.setLayoutData(fd);
+
+    fd = new FormData();
+    fd.left = new FormAttachment(lblSep, 10);
+    fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER);
+    btnFilter.setLayoutData(fd);
+
+    fd = new FormData();
+    fd.left = new FormAttachment(lblHeader, 10);
+    fd.top = new FormAttachment(cFilterArea, 3, SWT.TOP);
+    fd.bottom = new FormAttachment(cFilterArea, -3, SWT.BOTTOM);
+    lblSep.setLayoutData(fd);
+
+    fd = new FormData();
+    fd.left = new FormAttachment(btnFilter, 0);
+    fd.right = new FormAttachment(cCategories, -10);
+    cFilterArea.setLayoutData(fd);
+
+    fd = new FormData();
+    fd.right = new FormAttachment(cSizer, -2); 
+    fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER); 
+    fd.bottom = new FormAttachment(cFilterArea, 0, SWT.BOTTOM); 
+    cCategories.setLayoutData(fd);
+
+		int userMode = COConfigurationManager.getIntParameter("User Mode");
+
+		boolean enableSizer = userMode >= 2 && Constants.IS_CVS_VERSION;
+		
+    fd = new FormData();
+    fd.right = new FormAttachment(100, -2); 
+    fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER); 
+    fd.width = enableSizer ? 100 : 1;
+    fd.height = enableSizer ? 18 : 1;
+    cSizer.setLayoutData(fd);
+
+    if (enableSizer) {
+    	tv.enableSizeSlider(cSizer, 16, 96);
+    }
+
+    cHeader.addListener(SWT.Resize, new Listener(){
+			public void handleEvent(Event event) {
+				if (!resizeHeaderEventQueued) {
+	        resizeHeaderEventQueued = true;
+					Utils.execSWTThreadLater(0, new AERunnable(){
+						public void runSupport() {
+							resizeHeader();
+							resizeHeaderEventQueued = false;
+						}
+					});
+				}
+			}
+		});
+    
+    
+    txtFilter = new Text(cFilterArea, SWT.BORDER);
+    Messages.setLanguageTooltip(txtFilter, "MyTorrentsView.filter.tooltip");
+    gridData = new GridData(GridData.FILL_HORIZONTAL);
+    txtFilter.setLayoutData(gridData);
+    
+
+    lblX = new Label(cFilterArea, SWT.WRAP);
+    Messages.setLanguageTooltip(lblX, "MyTorrentsView.clearFilter.tooltip");
+    gridData = new GridData(SWT.TOP);
+    lblX.setLayoutData(gridData);
+    ImageLoader.getInstance().setLabelImage(lblX, "smallx-gray");
+    lblX.setData("ImageID", "smallx-gray");
+    lblX.addMouseListener(new MouseAdapter() {
+    	public void mouseUp(MouseEvent e) {
+    		if (e.y <= 10) {
+    			tv.setFilterText("");
+      		txtFilter.setText("");
+    		}
+    	}
+    });
+    
+
+    lblSep = new Label(cFilterArea, SWT.SEPARATOR | SWT.VERTICAL);
+    gridData = new GridData(GridData.FILL_VERTICAL);
+    gridData.heightHint = 5;
+    lblSep.setLayoutData(gridData);
+    
+    cHeader.moveAbove(null);
+    parent.layout(true);
+
+    tv.enableFilterCheck(txtFilter, this);
+	}
+
+  private void hideShowSlider() {
+  	if (!Constants.IS_CVS_VERSION) {
+  		return;
+  	}
+  	Utils.execSWTThread(new AERunnable() {
+			public void runSupport() {
+				int userMode = COConfigurationManager.getIntParameter("User Mode");
+				boolean isAdvanced = userMode >= 2;
+				
+				if (cSizer == null || cSizer.isDisposed()) {
+					return;
+				}
+				
+				FormData fd = (FormData) cSizer.getLayoutData();
+				if (isAdvanced) {
+					if (fd.width < 100) {
+						fd.width = 100;
+						fd.height = 16;
+			    	tv.enableSizeSlider(cSizer, 16, 96);
+			    	cSizer.setVisible(false);
+						cSizer.getParent().layout(true);
+					}
+				} else {
+					if (fd.width == 100) {
+						fd.width = 1;
+						fd.height = 1;
+						tv.disableSizeSlider();
+						cSizer.setVisible(true);
+						cSizer.getParent().layout(true);
+					}
+				}
+			}
+		});
+
+		
+	}
+
+
+	/**
+	 * 
+	 *
+	 * @since 4.1.0.5
+	 */
 	protected void showFilterArea() {
-		if (cFilterArea != null && !cFilterArea.isDisposed()) {
+		if (cFilterArea != null && !cFilterArea.isDisposed() && !cFilterArea.isVisible()) {
 			cFilterArea.setVisible(true);
 		}
-		if (btnFilter != null && !btnFilter.isDisposed()) {
+		if (btnFilter != null && !btnFilter.isDisposed() && !btnFilter.getSelection()) {
 			btnFilter.setSelection(true);
 		}
 	}
@@ -577,10 +601,10 @@ public class MyTorrentsView
 		if (onNewLine) {
 			Point prefSizeCat = cCategories.computeSize(SWT.DEFAULT, SWT.DEFAULT);
 			//System.out.println("pref=" + prefSizeCat + ";sz=" + cHeader.getClientArea());
-			if (prefSizeCat.x + posEndFilter < cHeader.getClientArea().width) {
+			if (prefSizeCat.x + posEndFilter + cSizer.getSize().x < cHeader.getClientArea().width) {
 				//System.out.println("MOVE UP");
 				FormData fd = new FormData();
-        fd.right = new FormAttachment(100, -2); 
+        fd.right = new FormAttachment(cSizer, -2); 
         fd.top = new FormAttachment(cFilterArea, 0, SWT.CENTER); 
         fd.bottom = new FormAttachment(cFilterArea, 0, SWT.BOTTOM); 
 				cCategories.setLayoutData(fd);
@@ -608,7 +632,7 @@ public class MyTorrentsView
 
 				fd = new FormData();
         fd.left = new FormAttachment(btnFilter, 0);
-        fd.right = new FormAttachment(100, -10);
+        fd.right = new FormAttachment(cSizer, -10);
         cFilterArea.setLayoutData(fd);
 
 				cHeader.getShell().layout(new Control[] {
@@ -799,7 +823,7 @@ public class MyTorrentsView
 				}
 			});
 
-			final Menu menu = new Menu(getComposite().getShell(), SWT.POP_UP);
+			final Menu menu = new Menu(catButton.getShell(), SWT.POP_UP);
 
 			catButton.setMenu(menu);
 
@@ -1126,15 +1150,13 @@ public class MyTorrentsView
 //				+ dm.getStats().getDownloadCompleted(false) + ";"
 //				+ dm.getStats().getDownloadCompleted(true));
 
-		if (bOurs) {
-			bOurs = filterCheck(dm);
-		}
-
 		return bOurs;
 	}
-	
-	public boolean filterCheck(DownloadManager dm) {
+
+	public boolean filterCheck(Object odm, String sLastSearch, boolean bRegexSearch) {
 		boolean bOurs = true;
+		DownloadManager dm = (DownloadManager) odm;
+
 		if (sLastSearch.length() > 0) {
 			try {
 				String[][] names = {
@@ -1174,6 +1196,30 @@ public class MyTorrentsView
 		}
 		return bOurs;
 	}
+	
+	// @see org.gudy.azureus2.ui.swt.views.table.TableViewFilterCheck#filterSet(java.lang.String)
+	public void filterSet(final String filter) {
+		Utils.execSWTThread(new AERunnable(){
+			public void runSupport() {
+				if (lblX != null && !lblX.isDisposed()) {
+					String oldID = (String) lblX.getData("ImageID");
+					String id = filter.length() > 0 ? "smallx" : "smallx-gray";
+					if (oldID == null || !oldID.equals(id)) {
+						ImageLoader.getInstance().setLabelImage(lblX, id);
+						lblX.setData("ImageID", id);
+					}
+				}
+
+				if (filter.length() > 0) {
+					if (txtFilter == null) {
+				    createTabs();
+					} else {
+						showFilterArea();
+					}
+				}
+			}
+		});
+	}
 
   // @see com.aelitis.azureus.ui.common.table.TableSelectionListener#selected(com.aelitis.azureus.ui.common.table.TableRowCore[])
   public void selected(TableRowCore[] rows) {
@@ -1315,14 +1361,6 @@ public class MyTorrentsView
 			// ---
 			new MenuItem(menu, SWT.SEPARATOR);
 		}
-
-		final MenuItem itemFilter = new MenuItem(menu, SWT.PUSH);
-		Messages.setLanguageText(itemFilter, "MyTorrentsView.menu.filter");
-		itemFilter.addListener(SWT.Selection, new Listener() {
-			public void handleEvent(Event event) {
-				openFilterDialog();
-			}
-		});
 	}
 
 	private void createDragDrop() {
@@ -1382,14 +1420,9 @@ public class MyTorrentsView
 			dropTarget = tv.createDropTarget(DND.DROP_DEFAULT | DND.DROP_MOVE
 					| DND.DROP_COPY | DND.DROP_LINK | DND.DROP_TARGET_MOVE);
 			if (dropTarget != null) {
-				if (SWT.getVersion() >= 3107) {
-					dropTarget.setTransfer(new Transfer[] { HTMLTransfer.getInstance(),
-							URLTransfer.getInstance(), FileTransfer.getInstance(),
-							TextTransfer.getInstance() });
-				} else {
-					dropTarget.setTransfer(new Transfer[] { URLTransfer.getInstance(),
-							FileTransfer.getInstance(), TextTransfer.getInstance() });
-				}
+				dropTarget.setTransfer(new Transfer[] { HTMLTransfer.getInstance(),
+						URLTransfer.getInstance(), FileTransfer.getInstance(),
+						TextTransfer.getInstance() });
 
 				dropTarget.addDropListener(new DropTargetAdapter() {
 					public void dropAccept(DropTargetEvent event) {
@@ -1465,6 +1498,9 @@ public class MyTorrentsView
     for (int i = 0; i < rows.length; i++) {
 			TableRowCore row = rows[i];
       DownloadManager dm = (DownloadManager)row.getDataSource(true);
+      if (dm == null) {
+      	continue;
+      }
       int iOldPos = dm.getPosition();
       
       globalManager.moveTo(dm, iNewPos);
@@ -1534,10 +1570,6 @@ public class MyTorrentsView
 						e.doit = false;
 					}
 					break;
-				case 'f': // CTRL+F Find/Filter
-					openFilterDialog();
-					e.doit = false;
-					break;
 				case 'i': // CTRL+I Info/Details
 					showSelectedDetails();
 					e.doit = false;
@@ -1580,11 +1612,6 @@ public class MyTorrentsView
 							cTablePanel.getShell());
 					e.doit = false;
 					break;
-				case 'x': // CTRL+X: RegEx search switch
-					bRegexSearch = !bRegexSearch;
-					e.doit = false;
-					updateLastSearch();
-					break;
 			}
 
 			if (!e.doit)
@@ -1602,142 +1629,6 @@ public class MyTorrentsView
 			if ((e.stateMask & (~SWT.SHIFT)) != 0 || e.character < 32)
 				return;
 		}
-		
-		if (e.widget == txtFilter)
-			return;
-
-		// normal character: jump to next item with a name beginning with this character
-		if (ASYOUTYPE_MODE == ASYOUTYPE_MODE_FIND) {
-			if (System.currentTimeMillis() - lLastSearchTime > 3000)
-				sLastSearch = "";
-		}
-
-		if (e.keyCode == SWT.BS) {
-			if (e.stateMask == SWT.CONTROL)
-				sLastSearch = "";
-			else if (sLastSearch.length() > 0)
-				sLastSearch = sLastSearch.substring(0, sLastSearch.length() - 1);
-		} else
-			sLastSearch += String.valueOf(e.character);
-
-		if (ASYOUTYPE_MODE == ASYOUTYPE_MODE_FILTER) {
-			showFilterArea();
-			if (txtFilter != null && !txtFilter.isDisposed()) {
-				txtFilter.setFocus();
-			}
-			updateLastSearch();
-		} else {
-			TableCellCore[] cells = tv.getColumnCells("name");
-
-			//System.out.println(sLastSearch);
-
-			Arrays.sort(cells, TableCellImpl.TEXT_COMPARATOR);
-			int index = Arrays.binarySearch(cells, sLastSearch,
-					TableCellImpl.TEXT_COMPARATOR);
-			if (index < 0) {
-
-				int iEarliest = -1;
-				String s = bRegexSearch ? sLastSearch : "\\Q" + sLastSearch + "\\E"; 
-				Pattern pattern = Pattern.compile(s, Pattern.CASE_INSENSITIVE);
-				for (int i = 0; i < cells.length; i++) {
-					Matcher m = pattern.matcher(cells[i].getText());
-					if (m.find() && (m.start() < iEarliest || iEarliest == -1)) {
-						iEarliest = m.start();
-						index = i;
-					}
-				}
-
-				if (index < 0)
-					// Insertion Point (best guess)
-					index = -1 * index - 1;
-			}
-
-			if (index >= 0) {
-				if (index >= cells.length)
-					index = cells.length - 1;
-				TableRowCore row = cells[index].getTableRowCore();
-				int iTableIndex = row.getIndex();
-				if (iTableIndex >= 0) {
-					tv.setSelectedRows(new TableRowCore[] { row });
-				}
-			}
-			lLastSearchTime = System.currentTimeMillis();
-			updateTableLabel();
-		}
-		e.doit = false;
-	}
-
-	private void openFilterDialog() {
-		SimpleTextEntryWindow entryWindow = new SimpleTextEntryWindow();
-		entryWindow.initTexts("MyTorrentsView.dialog.setFilter.title",
-				new String[] {
-					MessageText.getString(tv.getTableID() + "View" + ".header")
-				}, "MyTorrentsView.dialog.setFilter.text", null);
-		entryWindow.setPreenteredText(sLastSearch, false);
-		entryWindow.prompt();
-		if (!entryWindow.hasSubmittedInput()) {
-			return;
-		}
-		String message = entryWindow.getSubmittedInput();
-
-		if (message == null) {
-			message = "";
-		}
-		
-		sLastSearch = message;
-		updateLastSearch();
-	}
-	
-	private void updateLastSearch() {
-		if (lblHeader == null || lblHeader.isDisposed())
-			createTabs();
-		
-		if (txtFilter != null && !txtFilter.isDisposed() && txtFilter.isVisible()) {
-			if (!sLastSearch.equals(txtFilter.getText())) {
-				txtFilter.setText(sLastSearch);
-				txtFilter.setSelection(sLastSearch.length());
-			}
-
-			if (bRegexSearch) {
-				try {
-					Pattern.compile(sLastSearch, Pattern.CASE_INSENSITIVE);
-					txtFilter.setBackground(Colors.colorAltRow);
-					Messages.setLanguageTooltip(txtFilter,
-							"MyTorrentsView.filter.tooltip");
-				} catch (Exception e) {
-					txtFilter.setBackground(Colors.colorErrorBG);
-					txtFilter.setToolTipText(e.getMessage());
-				}
-			} else {
-				txtFilter.setBackground(null);
-				Messages.setLanguageTooltip(txtFilter, "MyTorrentsView.filter.tooltip");
-			}
-		}
-		if (lblX != null && !lblX.isDisposed()) {
-
-			String oldID = (String) lblX.getData("ImageID");
-      String id = sLastSearch.length() > 0 ? "smallx" : "smallx-gray";
-      if (oldID == null || !oldID.equals(id)) {
-      	ImageLoader.getInstance().setLabelImage(lblX, id);
-      	lblX.setData("ImageID", id);
-      }
-		}
-
-		if (searchUpdateEvent != null) {
-			searchUpdateEvent.cancel();
-		}
-		searchUpdateEvent = SimpleTimer.addEvent("SearchUpdate",
-				SystemTime.getOffsetTime(ASYOUTYPE_UPDATEDELAY),
-				new TimerEventPerformer() {
-					public void perform(TimerEvent event) {
-						if (searchUpdateEvent.isCancelled()) {
-							searchUpdateEvent = null;
-							return;
-						}
-						searchUpdateEvent = null;
-						activateCategory(currentCategory);
-					}
-				});
 	}
 
 	public void keyReleased(KeyEvent e) {
@@ -1873,9 +1764,12 @@ public class MyTorrentsView
 		if (parameterName == null || parameterName.equals("MyTorrentsView.alwaysShowHeader")) {
 			setForceHeaderVisible(COConfigurationManager.getBooleanParameter("MyTorrentsView.alwaysShowHeader"));
 		}
+		if (parameterName == null || parameterName.equals("User Mode")) {
+			hideShowSlider();
+		}
 	}
 
-  private boolean top,bottom,up,down,run,start,stop,remove;
+	private boolean top,bottom,up,down,run,start,stop,remove;
 
   private void computePossibleActions() {
     Object[] dataSources = tv.getSelectedDataSources().toArray();
@@ -2065,14 +1959,14 @@ public class MyTorrentsView
 		}
 		
 		Object[] managers = globalManager.getDownloadManagers().toArray();
-		List list = tv.getDataSources();
+		Set existing = new HashSet(tv.getDataSources());
 		List listRemoves = new ArrayList();
 		List listAdds = new ArrayList();
 		
 		for (int i = 0; i < managers.length; i++) {
 			DownloadManager dm = (DownloadManager) managers[i];
 		
-			boolean bHave = list.contains(dm);
+			boolean bHave = existing.contains(dm);
 			if (!isOurDownloadManager(dm)) {
 				if (bHave) {
 					listRemoves.add(dm);
@@ -2218,7 +2112,7 @@ public class MyTorrentsView
 	protected TableViewSWT createTableView(Class forDataSourceType, String tableID,
 			TableColumnCore[] basicItems) {
 		int tableExtraStyle = COConfigurationManager.getIntParameter("MyTorrentsView.table.style");
-		return new TableViewSWTImpl(forDataSourceType, tableID, "MyTorrentsView",
+		return new TableViewSWTImpl(forDataSourceType, tableID, getPropertiesPrefix(),
 				basicItems, "#", tableExtraStyle | SWT.MULTI | SWT.FULL_SELECTION
 						| SWT.VIRTUAL) {
 			protected void setSelectedRowIndexes(int[] newSelectedRowIndices) {
