@@ -24,9 +24,8 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Group;
-import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.*;
+
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.impl.ConfigurationManager;
 import org.gudy.azureus2.core3.internat.MessageText;
@@ -37,7 +36,6 @@ import org.gudy.azureus2.platform.PlatformManagerFactory;
 import org.gudy.azureus2.plugins.platform.PlatformManagerException;
 import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 import org.gudy.azureus2.ui.swt.Messages;
-import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.components.LinkLabel;
 import org.gudy.azureus2.ui.swt.config.*;
 import org.gudy.azureus2.ui.swt.mainwindow.Colors;
@@ -119,6 +117,7 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		glayout.numColumns = 2;
 		gSocket.setLayout(glayout);
 
+			// max simultaneous
 		
 		Label lmaxout = new Label(gSocket, SWT.NULL);
 		Messages.setLanguageText(lmaxout, "ConfigView.section.connection.network.max.simultaneous.connect.attempts");
@@ -128,10 +127,24 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		IntParameter max_connects = new IntParameter(gSocket,
 				"network.max.simultaneous.connect.attempts", 1, 100);    
 		gridData = new GridData();
-		gridData.widthHint = 30;
 		max_connects.setLayoutData(gridData);
 
+			// // max pending
+		
+		Label lmaxpout = new Label(gSocket, SWT.NULL);
+		Messages.setLanguageText(lmaxpout, "ConfigView.section.connection.network.max.outstanding.connect.attempts");
+		gridData = new GridData();
+		lmaxpout.setLayoutData( gridData );
 
+		IntParameter max_pending_connects = new IntParameter(gSocket,
+				"network.tcp.max.connections.outstanding", 1, 65536 );    
+		gridData = new GridData();
+		max_pending_connects.setLayoutData(gridData);
+		
+		
+
+			// bind ip
+		
 		Label lbind = new Label(gSocket, SWT.NULL);
 		Messages.setLanguageText(lbind, "ConfigView.label.bindip" );
 		lbind.setLayoutData(new GridData());
@@ -141,19 +154,22 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		gridData.widthHint = 100;
 		bindip.setLayoutData(gridData);
 
-		Label lbind2 = new Label(gSocket, SWT.WRAP);
+		Text lbind2 = new Text(gSocket, SWT.READ_ONLY | SWT.MULTI);
+		lbind2.setTabs(8);
 		Messages.setLanguageText(
 				lbind2,
 				"ConfigView.label.bindip.details",
 				new String[] {NetworkAdmin.getSingleton().getNetworkInterfacesAsString() });
-		lbind2.setLayoutData(Utils.getWrappableLabelGridData(2, 0));
+		gridData = new GridData();
+		gridData.horizontalSpan = 2;
+		lbind2.setLayoutData(gridData);
+
 
 		Label lpbind = new Label(gSocket, SWT.NULL);
 		Messages.setLanguageText(lpbind, CFG_PREFIX + "bind_port");
 		final IntParameter port_bind = new IntParameter(gSocket,
 				"network.bind.local.port", 0, 65535);
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		port_bind.setLayoutData(gridData);
 		
 		
@@ -162,7 +178,6 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		final IntParameter mtu_size = new IntParameter(gSocket,"network.tcp.mtu.size");
 		mtu_size.setMaximumValue(512 * 1024);
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		mtu_size.setLayoutData(gridData);
 
 
@@ -170,7 +185,6 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		Messages.setLanguageText(lsend, CFG_PREFIX + "SO_SNDBUF");
 		final IntParameter SO_SNDBUF = new IntParameter(gSocket,	"network.tcp.socket.SO_SNDBUF");
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		SO_SNDBUF.setLayoutData(gridData);
 
 
@@ -178,7 +192,6 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		Messages.setLanguageText(lreceiv, CFG_PREFIX + "SO_RCVBUF");
 		final IntParameter SO_RCVBUF = new IntParameter(gSocket,	"network.tcp.socket.SO_RCVBUF");
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		SO_RCVBUF.setLayoutData(gridData);
 		
 
@@ -186,7 +199,7 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		Messages.setLanguageText(ltos, CFG_PREFIX + "IPDiffServ");
 		final StringParameter IPDiffServ = new StringParameter(gSocket,	"network.tcp.socket.IPDiffServ");
 		gridData = new GridData();
-		gridData.widthHint = 30;
+		gridData.widthHint = 100;
 		IPDiffServ.setLayoutData(gridData);
 
 
@@ -233,20 +246,30 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		Messages.setLanguageText(lreadsel, CFG_PREFIX + "read_select", new String[]{ String.valueOf( COConfigurationManager.getDefault("network.tcp.read.select.time"))});
 		final IntParameter read_select = new IntParameter(gSocket,	"network.tcp.read.select.time", 10, 250);
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		read_select.setLayoutData(gridData);
 		
+		Label lreadselmin = new Label(gSocket, SWT.NULL);
+		Messages.setLanguageText(lreadselmin, CFG_PREFIX + "read_select_min", new String[]{ String.valueOf( COConfigurationManager.getDefault("network.tcp.read.select.min.time"))});
+		final IntParameter read_select_min = new IntParameter(gSocket,	"network.tcp.read.select.min.time", 0, 100 );
+		gridData = new GridData();
+		read_select_min.setLayoutData(gridData);
+
 			// write select
 				
 		Label lwritesel = new Label(gSocket, SWT.NULL);
 		Messages.setLanguageText(lwritesel, CFG_PREFIX + "write_select", new String[]{ String.valueOf( COConfigurationManager.getDefault("network.tcp.write.select.time"))});
 		final IntParameter write_select = new IntParameter(gSocket,	"network.tcp.write.select.time", 10, 250);
 		gridData = new GridData();
-		gridData.widthHint = 40;
 		write_select.setLayoutData(gridData);
 		
-		
-		
+		Label lwriteselmin = new Label(gSocket, SWT.NULL);
+		Messages.setLanguageText(lwriteselmin, CFG_PREFIX + "write_select_min", new String[]{ String.valueOf( COConfigurationManager.getDefault("network.tcp.write.select.min.time"))});
+		final IntParameter write_select_min = new IntParameter(gSocket,	"network.tcp.write.select.min.time", 0, 100 );
+		gridData = new GridData();
+		write_select_min.setLayoutData(gridData);
+
+		new BooleanParameter( cSection, "IPV6 Enable Support", "network.ipv6.enable.support"  );
+
 		
 		new BooleanParameter( cSection, "IPV6 Prefer Addresses", "network.ipv6.prefer.addresses"  );
 		
@@ -262,7 +285,7 @@ public class ConfigSectionConnectionAdvanced implements UISWTConfigSection {
 		PlatformManager mgr = PlatformManagerFactory.getPlatformManager();
 
 		if (mgr.hasCapability(PlatformManagerCapabilities.SetTCPTOSEnabled)) { 
-			//see http://azureus.aelitis.com/wiki/index.php/AdvancedNetworkSettings
+			//see http://www.azureuswiki.com/index.php/AdvancedNetworkSettings
 			try {
 				mgr.setTCPTOSEnabled(enable);
 			} catch (PlatformManagerException pe) {
