@@ -30,18 +30,12 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.*;
 
 import org.gudy.azureus2.core3.config.COConfigurationManager;
-import org.gudy.azureus2.core3.internat.MessageText;
+import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 import org.gudy.azureus2.ui.swt.Messages;
 import org.gudy.azureus2.ui.swt.UISwitcherUtil;
 import org.gudy.azureus2.ui.swt.config.BooleanParameter;
 import org.gudy.azureus2.ui.swt.config.ChangeSelectionActionPerformer;
 import org.gudy.azureus2.ui.swt.plugins.UISWTConfigSection;
-import org.gudy.azureus2.ui.swt.shells.MessageBoxShell;
-
-import com.aelitis.azureus.ui.UIFunctions;
-import com.aelitis.azureus.ui.UIFunctionsManager;
-
-import org.gudy.azureus2.plugins.ui.config.ConfigSection;
 
 public class ConfigSectionInterfaceStart implements UISWTConfigSection {
   public String configSectionGetParentSection() {
@@ -99,11 +93,6 @@ public class ConfigSectionInterfaceStart implements UISWTConfigSection {
     new BooleanParameter(cStart, "Open Transfer Bar On Start", "ConfigView.label.open_transfer_bar_on_start");
     new BooleanParameter(cStart, "Start Minimized", "ConfigView.label.startminimized");
     
-    if (isAZ3) {
-			new BooleanParameter(cStart, "v3.Start Advanced",
-					"ConfigView.interface.start.library");
-		}
-  
 	// UI switcher window.
     Composite cUISwitcher = new Composite(cStart, SWT.NONE);
     layout = new GridLayout(2, false);
@@ -120,23 +109,7 @@ public class ConfigSectionInterfaceStart implements UISWTConfigSection {
 
 		ui_switcher_button.addListener(SWT.Selection, new Listener() {
 			public void handleEvent(Event event) {
-				String uiOld = COConfigurationManager.getStringParameter("ui");
-				String uiNew = UISwitcherUtil.openSwitcherWindow(true);
-				if (!uiOld.equals(uiNew)) {
-  				int result = MessageBoxShell.open(parent.getShell(),
-  						MessageText.getString("dialog.uiswitcher.restart.title"),
-  						MessageText.getString("dialog.uiswitcher.restart.text"),
-  						new String[] {
-  							MessageText.getString("UpdateWindow.restart"),
-  							MessageText.getString("UpdateWindow.restartLater"),
-  						}, 0);
-  				if (result == 0) {
-  					UIFunctions uif = UIFunctionsManager.getUIFunctions();
-  					if (uif != null) {
-  						uif.dispose(true, false);
-  					}
-  				}
-				}
+				UISwitcherUtil.openSwitcherWindow();
 			}
 		});
     
