@@ -19,6 +19,7 @@ import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
+import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.SWT;
@@ -121,6 +122,13 @@ public class ConfigSectionTransferAutoSpeedSelect
 
         Composite cSection = new Composite(parent, SWT.NULL);
         
+        if (!AzureusCoreFactory.isCoreRunning()) {
+        	cSection.setLayout(new FillLayout());
+        	Label lblNotAvail = new Label(cSection, SWT.WRAP);
+        	Messages.setLanguageText(lblNotAvail, "core.not.available");
+        	return cSection;
+        }
+        
         gridData = new GridData(GridData.VERTICAL_ALIGN_FILL|GridData.HORIZONTAL_ALIGN_FILL);
         cSection.setLayoutData(gridData);
         GridLayout subPanel = new GridLayout();
@@ -147,19 +155,22 @@ public class ConfigSectionTransferAutoSpeedSelect
         Label label = new Label(modeGroup, SWT.NULL);
         Messages.setLanguageText(label,"ConfigTransferAutoSpeed.algorithm");
         gridData = new GridData();
-        gridData.widthHint = 50;
         label.setLayoutData(gridData);
 
         String AutoSpeedClassic = MessageText.getString("ConfigTransferAutoSpeed.auto.speed.classic");
         String AutoSpeedBeta = MessageText.getString("ConfigTransferAutoSpeed.auto.speed.beta");
+        String AutoSpeedNeural = MessageText.getString("ConfigTransferAutoSpeed.auto.speed.neural");
+        
         String[] modeNames = {
                 AutoSpeedClassic,
-                AutoSpeedBeta
+                AutoSpeedBeta,
+                AutoSpeedNeural,
                };
         
         String[] modes = {
                 "1",
                 "2",
+                "3",
         };
 
         //versionList = new StringListParameter(modeGroup,
@@ -174,6 +185,9 @@ public class ConfigSectionTransferAutoSpeedSelect
         }else if( verNum==2 ){
             //SpeedManagerAlgorithmProviderV2
             versionList.setValue(modes[1]);
+        }else if( verNum==3 ){
+            //SpeedManagerAlgorithmProviderV2
+            versionList.setValue(modes[2]);
         }else{
             //Default is currently version ...V1.
             versionList.setValue(modes[0]);
@@ -270,6 +284,7 @@ public class ConfigSectionTransferAutoSpeedSelect
         gridData.horizontalSpan = 4;
         down_cap.setLayoutData(gridData);
 
+        // Core avail: We check at top
         final SpeedManager sm = AzureusCoreFactory.getSingleton().getSpeedManager();  
         
         final TransferStatsView.limitToTextHelper	limit_to_text = new TransferStatsView.limitToTextHelper();
@@ -313,7 +328,6 @@ public class ConfigSectionTransferAutoSpeedSelect
 	    	
 		final Label upload_bits = new Label(networkGroup, SWT.NULL);
 	    gridData = new GridData();
-	    gridData.widthHint = 80;
 	    upload_bits.setLayoutData(gridData);
 	    upload_bits.setText(getMBitLimit(limit_to_text,(up_lim.getBytesPerSec()/1024)*1024));
 		
@@ -390,7 +404,6 @@ public class ConfigSectionTransferAutoSpeedSelect
 	    
 		final Label download_bits = new Label(networkGroup, SWT.NULL);
 	    gridData = new GridData();
-	    gridData.widthHint = 80;
 	    download_bits.setLayoutData(gridData);
 	    download_bits.setText(getMBitLimit(limit_to_text,(down_lim.getBytesPerSec()/1024)*1024));
 	    
@@ -525,6 +538,20 @@ public class ConfigSectionTransferAutoSpeedSelect
         //Add listeners to disable setting when needed.
                 
 
+	      //spacer
+       
+	   spacer = new Label(cSection, SWT.NULL);
+	   gridData = new GridData();
+	   gridData.horizontalSpan=3;
+	   spacer.setLayoutData(gridData);
+       
+		BooleanParameter debug_au = new BooleanParameter(
+				cSection, "Auto Upload Speed Debug Enabled",
+				CFG_PREFIX + "enabledebug" );
+		gridData = new GridData();
+		gridData.horizontalSpan = 3;
+		debug_au.setLayoutData(gridData);	
+		
         //spacer
         
         spacer = new Label(cSection, SWT.NULL);
@@ -537,22 +564,21 @@ public class ConfigSectionTransferAutoSpeedSelect
         /////////////////////////////////////////
         Group azWiki = new Group(cSection, SWT.WRAP);
         gridData = new GridData();
-        gridData.widthHint = 350;
         azWiki.setLayoutData(gridData);
         GridLayout layout = new GridLayout();
         layout.numColumns = 1;
         layout.marginHeight = 1;
+        layout.marginWidth = 20;
         azWiki.setLayout(layout);
 
         azWiki.setText(MessageText.getString("Utils.link.visit"));
 
         final Label linkLabel = new Label(azWiki, SWT.NULL);
         linkLabel.setText( Constants.APP_NAME + " Wiki AutoSpeed (beta)" );
-        linkLabel.setData("http://azureus.aelitis.com/wiki/index.php/Auto_Speed");
+        linkLabel.setData("http://www.azureuswiki.com/index.php/Auto_Speed");
         linkLabel.setCursor(Cursors.handCursor);
         linkLabel.setForeground(Colors.blue);
         gridData = new GridData();
-        gridData.horizontalIndent = 10;
         linkLabel.setLayoutData( gridData );
 	    linkLabel.addMouseListener(new MouseAdapter() {
 	      public void mouseDoubleClick(MouseEvent arg0) {
