@@ -26,33 +26,44 @@
 package org.gudy.azureus2.ui.swt.views.table.impl;
 
 import java.text.Collator;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Comparator;
+import java.util.Iterator;
+import java.util.Locale;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.*;
-
 import org.gudy.azureus2.core3.config.COConfigurationManager;
 import org.gudy.azureus2.core3.config.ParameterListener;
 import org.gudy.azureus2.core3.internat.MessageText;
 import org.gudy.azureus2.core3.logging.LogEvent;
 import org.gudy.azureus2.core3.logging.LogIDs;
 import org.gudy.azureus2.core3.logging.Logger;
-import org.gudy.azureus2.core3.util.*;
+import org.gudy.azureus2.core3.util.AEMonitor;
+import org.gudy.azureus2.core3.util.AERunnable;
+import org.gudy.azureus2.core3.util.Constants;
+import org.gudy.azureus2.core3.util.Debug;
+import org.gudy.azureus2.core3.util.SystemTime;
+import org.gudy.azureus2.plugins.ui.Graphic;
+import org.gudy.azureus2.plugins.ui.UIRuntimeException;
+import org.gudy.azureus2.plugins.ui.SWT.GraphicSWT;
+import org.gudy.azureus2.plugins.ui.tables.*;
 import org.gudy.azureus2.ui.swt.Utils;
 import org.gudy.azureus2.ui.swt.components.*;
 import org.gudy.azureus2.ui.swt.debug.ObfusticateCellText;
 import org.gudy.azureus2.ui.swt.mainwindow.Colors;
 import org.gudy.azureus2.ui.swt.plugins.UISWTGraphic;
 import org.gudy.azureus2.ui.swt.pluginsimpl.UISWTGraphicImpl;
-import org.gudy.azureus2.ui.swt.views.table.*;
+import org.gudy.azureus2.ui.swt.views.table.TableCellSWT;
+import org.gudy.azureus2.ui.swt.views.table.TableCellSWTPaintListener;
+import org.gudy.azureus2.ui.swt.views.table.TableRowSWT;
+import org.gudy.azureus2.ui.swt.views.table.TableViewSWT;
 import org.gudy.azureus2.ui.swt.views.table.utils.TableColumnSWTUtils;
 
-import com.aelitis.azureus.ui.common.table.*;
-
-import org.gudy.azureus2.plugins.ui.Graphic;
-import org.gudy.azureus2.plugins.ui.UIRuntimeException;
-import org.gudy.azureus2.plugins.ui.SWT.GraphicSWT;
-import org.gudy.azureus2.plugins.ui.tables.*;
+import com.aelitis.azureus.ui.common.table.TableColumnCore;
+import com.aelitis.azureus.ui.common.table.TableColumnSortObject;
+import com.aelitis.azureus.ui.common.table.TableRowCore;
+import com.aelitis.azureus.ui.common.table.TableView;
 
 
 /** TableCellImpl represents one cell in the table.  
@@ -494,7 +505,7 @@ public class TableCellImpl
 				&& ((Long) sortValue).longValue() == valueToSort)
 			return false;
 
-		return _setSortValue(new Long(valueToSort));
+		return _setSortValue(Long.valueOf(valueToSort));
   }
   
   public boolean setSortValue( float valueToSort ) {
@@ -1144,7 +1155,7 @@ public class TableCellImpl
 			  if (bDebug)
 				  debug("invoke refresh; wasValid? " + bWasValid);
 
-			  long lTimeStart = SystemTime.getMonotonousTime();
+			  long lTimeStart = Constants.isCVSVersion()?SystemTime.getMonotonousTime():0;
 			  tableColumn.invokeCellRefreshListeners(this, !bCellVisible);
 			  if (refreshListeners != null) {
 				  for (int i = 0; i < refreshListeners.size(); i++) {
@@ -1155,9 +1166,11 @@ public class TableCellImpl
 						  l.refresh(this);
 				  }
 			  }
-			  long lTimeEnd = SystemTime.getMonotonousTime();
-			  tableColumn.addRefreshTime(lTimeEnd - lTimeStart);
-
+			  if ( Constants.isCVSVersion()){
+				  long lTimeEnd = SystemTime.getMonotonousTime();
+				  tableColumn.addRefreshTime(lTimeEnd - lTimeStart);
+			  }
+			  
 			  // Change to valid only if we weren't valid before the listener calls
 			  // This is in case the listeners set valid to false when it was true
 			  if (!bWasValid && !hasFlag(FLAG_MUSTREFRESH)) {
