@@ -22,6 +22,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.files;
 
 import org.gudy.azureus2.core3.disk.DiskManagerFileInfo;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 import org.gudy.azureus2.core3.internat.MessageText;
 
@@ -40,6 +41,12 @@ public class PriorityItem
     setRefreshInterval(INTERVAL_LIVE);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_CONTENT,
+		});
+	}
+
   public void refresh(TableCell cell) {
 		DiskManagerFileInfo fileInfo = (DiskManagerFileInfo) cell.getDataSource();
 		String tmp;
@@ -48,16 +55,20 @@ public class PriorityItem
 			tmp = "";
 		else
 		{
-			if (fileInfo.isSkipped())
+			if(fileInfo.getStorageType() == DiskManagerFileInfo.ST_COMPACT && fileInfo.isSkipped())
+			{
+				tmp = MessageText.getString("FileItem.delete");
+				sortval = 1;				
+			} else if (fileInfo.isSkipped())
 			{
 				tmp = MessageText.getString("FileItem.donotdownload");
-				sortval = 1;
+				sortval = 2;
 			} else if (fileInfo.isPriority()) {
 				tmp = MessageText.getString("FileItem.high");
-				sortval = 3;
+				sortval = 4;
 			} else {
 				tmp = MessageText.getString("FileItem.normal");
-				sortval = 2;
+				sortval = 3;
 			}
 				
 		}
