@@ -24,11 +24,15 @@
 
 package org.gudy.azureus2.ui.swt.views.tableitems.mytorrents;
 
-import org.gudy.azureus2.core3.peer.PEPeerManager;
 import org.gudy.azureus2.core3.download.DownloadManager;
-import org.gudy.azureus2.plugins.ui.tables.*;
+import org.gudy.azureus2.core3.peer.PEPeerManager;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.download.Download;
+import org.gudy.azureus2.plugins.ui.tables.TableCell;
+import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
+import org.gudy.azureus2.plugins.ui.tables.TableColumnInfo;
+
 /** Avg Avail/"Seeing Copies/peer" Column
  *
  * @author MjrTom
@@ -39,16 +43,19 @@ public class AvgAvailItem
        extends CoreTableColumn 
        implements TableCellRefreshListener
 {
+	public static final Class DATASOURCE_TYPE = Download.class;
+
   // If you want more decimals, just add a zero
   private static final String zeros = "0000";
   // # decimal places == numZeros - 1
   private static final int numZeros = zeros.length();
+	public static final String COLUMN_ID = "AvgAvail";
 
   private int iTimesBy;
   
   /** Default Constructor */
   public AvgAvailItem(String sTableID) {
-    super("AvgAvail", ALIGN_TRAIL, POSITION_INVISIBLE, 50, sTableID);
+    super(DATASOURCE_TYPE, COLUMN_ID, ALIGN_TRAIL, 50, sTableID);
     setRefreshInterval(INTERVAL_LIVE);
     setMinWidthAuto(true);
 
@@ -57,6 +64,12 @@ public class AvgAvailItem
       iTimesBy *= 10;
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_SWARM
+		});
+	}
+
   public void refresh(TableCell cell) {
     String sText = "";
     DownloadManager dm = (DownloadManager)cell.getDataSource();
