@@ -24,11 +24,15 @@
  
 package org.gudy.azureus2.ui.swt.views.tableitems.mytorrents;
 
-import org.gudy.azureus2.core3.util.DisplayFormatters;
 import org.gudy.azureus2.core3.download.DownloadManager;
-import org.gudy.azureus2.plugins.ui.tables.*;
+import org.gudy.azureus2.core3.util.DisplayFormatters;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.download.DownloadTypeIncomplete;
+import org.gudy.azureus2.plugins.ui.tables.TableCell;
+import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
+import org.gudy.azureus2.plugins.ui.tables.TableColumnInfo;
+
 
 /**
  *
@@ -39,9 +43,17 @@ public class ETAItem
        extends CoreTableColumn 
        implements TableCellRefreshListener
 {
-  /** Default Constructor */
-  public ETAItem() {
-    super("eta", ALIGN_TRAIL, POSITION_LAST, 60, TableManager.TABLE_MYTORRENTS_INCOMPLETE);
+	public static final Class DATASOURCE_TYPE = DownloadTypeIncomplete.class;
+
+  public static final String COLUMN_ID = "eta";
+
+  public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] { CAT_ESSENTIAL });
+	}
+
+	/** Default Constructor */
+  public ETAItem(String sTableID) {
+    super(DATASOURCE_TYPE, COLUMN_ID, ALIGN_TRAIL, 60, sTableID);
     setRefreshInterval(INTERVAL_LIVE);
   }
 
