@@ -24,11 +24,15 @@
  
 package org.gudy.azureus2.ui.swt.views.tableitems.mytorrents;
 
-import org.gudy.azureus2.core3.util.TimeFormatter;
 import org.gudy.azureus2.core3.download.DownloadManager;
-import org.gudy.azureus2.plugins.ui.tables.*;
+import org.gudy.azureus2.core3.util.TimeFormatter;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.download.Download;
+import org.gudy.azureus2.plugins.ui.tables.TableCell;
+import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
+import org.gudy.azureus2.plugins.ui.tables.TableColumnInfo;
+
 /**
  *
  * @author TuxPaper
@@ -38,9 +42,18 @@ public class OnlyCDing4Item
        extends CoreTableColumn 
        implements TableCellRefreshListener
 {
-  /** Default Constructor */
+	public static final Class DATASOURCE_TYPE = Download.class;
+
+  public static final String COLUMN_ID = "OnlyCDing4";
+
+  public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] { CAT_SHARING });
+		info.setProficiency(TableColumnInfo.PROFICIENCY_INTERMEDIATE);
+	}
+
+	/** Default Constructor */
   public OnlyCDing4Item(String sTableID) {
-    super("OnlyCDing4", ALIGN_TRAIL, POSITION_INVISIBLE, 70, sTableID);
+    super(DATASOURCE_TYPE, COLUMN_ID, ALIGN_TRAIL, 70, sTableID);
     setRefreshInterval(INTERVAL_LIVE);
     setMinWidthAuto(true);
   }
