@@ -28,9 +28,11 @@ import java.util.HashMap;
 
 import org.gudy.azureus2.core3.download.DownloadManager;
 import org.gudy.azureus2.core3.util.TimeFormatter;
-import org.gudy.azureus2.plugins.ui.tables.*;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.download.Download;
+import org.gudy.azureus2.plugins.ui.tables.*;
+
 /**
  * @author Olivier
  *
@@ -40,14 +42,25 @@ public class TrackerNextAccessItem
        implements TableCellRefreshListener, TableCellDisposeListener,
                   TableCellToolTipListener
 {
+	public static final Class DATASOURCE_TYPE = Download.class;
+
+	public static final String COLUMN_ID = "trackernextaccess";
 	HashMap map = new HashMap();
 	
   public TrackerNextAccessItem(String sTableID) {
-    super("trackernextaccess", ALIGN_TRAIL, POSITION_INVISIBLE, 70, sTableID);
+    super(DATASOURCE_TYPE, COLUMN_ID, ALIGN_TRAIL, 70, sTableID);
     setRefreshInterval(INTERVAL_LIVE);
     setMinWidthAuto(true);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_TRACKER,
+			CAT_TIME,
+		});
+		info.setProficiency(TableColumnInfo.PROFICIENCY_INTERMEDIATE);
+	}
+
   public void refresh(TableCell cell) {
     DownloadManager dm = (DownloadManager)cell.getDataSource();
     if (cell.isValid() && map.containsKey(dm)) {
@@ -72,13 +85,13 @@ public class TrackerNextAccessItem
     if (value > 60)
     	sText = "< " + sText;
     
-  	TrackerCellUtils.updateColor(cell, dm);
+  	TrackerCellUtils.updateColor(cell, dm, false);
     cell.setText(sText);
   }
 
 	public void cellHover(TableCell cell) {
 		DownloadManager dm = (DownloadManager) cell.getDataSource();
-		cell.setToolTip(TrackerCellUtils.getTooltipText(cell, dm));
+		cell.setToolTip(TrackerCellUtils.getTooltipText(cell, dm, false));
 	}
 
 	public void cellHoverComplete(TableCell cell) {
