@@ -24,17 +24,15 @@ package org.gudy.azureus2.ui.swt.views.tableitems.mytracker;
 
 import org.gudy.azureus2.core3.category.Category;
 import org.gudy.azureus2.core3.download.DownloadManager;
+import org.gudy.azureus2.core3.global.GlobalManager;
 import org.gudy.azureus2.core3.torrent.TOTorrent;
 import org.gudy.azureus2.core3.tracker.host.TRHostTorrent;
 import org.gudy.azureus2.core3.util.TorrentUtils;
-import org.gudy.azureus2.plugins.torrent.TorrentAttribute;
 import org.gudy.azureus2.plugins.ui.tables.TableCell;
 import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
 import org.gudy.azureus2.plugins.ui.tables.TableManager;
-import org.gudy.azureus2.pluginsimpl.local.torrent.TorrentManagerImpl;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
-import com.aelitis.azureus.core.AzureusCore;
 import com.aelitis.azureus.core.AzureusCoreFactory;
 
 /**
@@ -49,10 +47,7 @@ CategoryItem
 {
 		/** Default Constructor */
 	
-	protected static final TorrentAttribute	category_attribute = 
-		TorrentManagerImpl.getSingleton().getAttribute( TorrentAttribute.TA_CATEGORY );
-	
-	protected static final AzureusCore	azureus_core = AzureusCoreFactory.getSingleton();
+	protected static GlobalManager gm;
 	
 	public 
 	CategoryItem() 
@@ -75,7 +70,14 @@ CategoryItem
 			
 			TOTorrent	torrent = tr_torrent.getTorrent();
 			
-			DownloadManager dm = azureus_core.getGlobalManager().getDownloadManager( torrent );
+			if (gm == null) {
+				if (AzureusCoreFactory.isCoreRunning()) {
+					return;
+				}
+				gm = AzureusCoreFactory.getSingleton().getGlobalManager();
+			}
+
+			DownloadManager dm = gm.getDownloadManager( torrent );
 
 			String	cat_str = null;
 
