@@ -25,9 +25,12 @@
 package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
-import org.gudy.azureus2.plugins.ui.tables.*;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.ui.tables.TableCell;
+import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
+import org.gudy.azureus2.plugins.ui.tables.TableColumnInfo;
+
 /**
  *
  * @author Olivier
@@ -37,9 +40,17 @@ public class ChokingItem
        extends CoreTableColumn 
        implements TableCellRefreshListener
 {
-  /** Default Constructor */
+	private static final String COLUMN_ID = "C2";
+
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_PROTOCOL,
+		});
+	}
+
+	/** Default Constructor */
   public ChokingItem(String table_id) {
-    super("C2", ALIGN_CENTER, POSITION_INVISIBLE, 20, table_id);
+    super(COLUMN_ID, ALIGN_CENTER, POSITION_INVISIBLE, 20, table_id);
     setRefreshInterval(INTERVAL_LIVE);
   }
 
