@@ -21,9 +21,12 @@
 package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
-import org.gudy.azureus2.plugins.ui.tables.*;
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
+import org.gudy.azureus2.plugins.ui.tables.TableCell;
+import org.gudy.azureus2.plugins.ui.tables.TableCellRefreshListener;
+import org.gudy.azureus2.plugins.ui.tables.TableColumnInfo;
+
 /**
  * 
  */
@@ -31,9 +34,17 @@ public class EncryptionItem
        extends CoreTableColumn 
        implements TableCellRefreshListener
 {
+	public static final String COLUMN_ID = "Encryption";
+
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_CONNECTION,
+		});
+	}
+
   /** Default Constructor */
   public EncryptionItem(String table_id) {
-    super("Encryption", ALIGN_CENTER, POSITION_INVISIBLE, 20, table_id);
+    super(COLUMN_ID, ALIGN_CENTER, POSITION_INVISIBLE, 20, table_id);
     setRefreshInterval(INTERVAL_LIVE);
   }
 
