@@ -26,6 +26,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -42,6 +43,12 @@ public class PeerSourceItem
     super("source", ALIGN_TRAIL, POSITION_INVISIBLE, 40, table_id);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_PEER_IDENTIFICATION,
+		});
+	}
+
   public void refresh(TableCell cell) {
     PEPeer peer = (PEPeer)cell.getDataSource();
     String value = (peer == null) ? "" : peer.getPeerSource();
