@@ -26,6 +26,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -42,7 +43,13 @@ public class PieceItem
   public PieceItem(String table_id) {
     super("piece", ALIGN_TRAIL, POSITION_INVISIBLE, 40, table_id);
     setRefreshInterval(INTERVAL_LIVE);
-}
+  }
+
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_CONTENT,
+		});
+	}
 
   public void refresh(TableCell cell) {
     PEPeer peer = (PEPeer)cell.getDataSource();
