@@ -24,12 +24,12 @@
 
 package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
+
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Rectangle;
 
-import org.gudy.azureus2.core3.disk.DiskManager;
-import org.gudy.azureus2.core3.disk.DiskManagerPiece;
+import org.gudy.azureus2.core3.disk.*;
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.core3.peer.impl.PEPeerTransport;
 import org.gudy.azureus2.core3.util.Debug;
@@ -52,7 +52,7 @@ import org.gudy.azureus2.plugins.ui.tables.*;
  */
 public class PiecesItem
        extends CoreTableColumn 
-       implements TableCellAddedListener, TableCellRefreshListener, TableCellDisposeListener
+       implements TableCellAddedListener, TableCellRefreshListener, TableCellDisposeListener, DiskManagerListener
 {
   private final static int INDEX_COLOR_FADEDSTARTS = Colors.BLUES_DARKEST + 1;
   // only supports 0 or 1 border width
@@ -60,18 +60,43 @@ public class PiecesItem
   private final static int borderVerticalSize = 1;
   private final static int borderSplit = 1;
   private final static int completionHeight = 2;
-
+  
+  private int row_count;
+  
   /** Default Constructor */
   public PiecesItem(String table_id) {
     super("pieces", table_id);
     initializeAsGraphic(POSITION_LAST, 200);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_CONTENT,
+		});
+	}
+
   public void cellAdded(TableCell cell) {
+	synchronized( this ){
+		row_count++;
+	}
     cell.setFillCell(true);
+    Object ds = cell.getDataSource();
+    if (ds instanceof PEPeer) {
+			PEPeer peer = (PEPeer) ds;
+			DiskManager diskmanager = peer.getManager().getDiskManager();
+			
+			if ( diskmanager.getRemaining() > 0 ){
+				if ( !diskmanager.hasListener( this )){
+					diskmanager.addListener( this );
+				}
+			}
+		}
   }
 
   public void dispose(TableCell cell) {
+	synchronized( this ){
+	  row_count--;
+	}
     // Named infoObj so code can be copied easily to the other PiecesItem
     PEPeer infoObj = (PEPeer)cell.getDataSource();
     if (infoObj == null)
@@ -94,7 +119,7 @@ public class PiecesItem
     // Named infoObj so code can be copied easily to the other PiecesItem
     PEPeer infoObj = (PEPeer)cell.getDataSource();
     long lCompleted = (infoObj == null) ? 0 : infoObj.getPercentDoneInThousandNotation();
-    
+
     if( !cell.setSortValue( lCompleted ) && cell.isValid() ) {
       return;
     }
@@ -176,7 +201,6 @@ public class PiecesItem
       int nbPieces = available.length;
       
       DiskManager disk_manager = infoObj.getManager().getDiskManager();
-      
       DiskManagerPiece[]  pieces = disk_manager==null?null:disk_manager.getPieces();
                       
       
@@ -236,9 +260,9 @@ public class PiecesItem
             if (iLastIndex == imageBuffer[i]) {
               iWidth++;
             } else {
-              if (iLastIndex >= INDEX_COLOR_FADEDSTARTS)
+              if (iLastIndex >= INDEX_COLOR_FADEDSTARTS) {
                 gcImage.setBackground(Colors.faded[iLastIndex - INDEX_COLOR_FADEDSTARTS]);
-              else
+              } else
                 gcImage.setBackground(Colors.blues[iLastIndex]);
               gcImage.fillRectangle(i - iWidth + x0, y0, iWidth, y1 - y0 + 1);
               iWidth = 1;
@@ -284,9 +308,46 @@ public class PiecesItem
 			} else {
 				cell.setGraphic(new UISWTGraphicImpl(image));
 			}
+			if (bImageChanged || image != oldImage) {
+				cell.invalidate();
+			}
       infoObj.setData("PiecesImage", image);
       infoObj.setData("PiecesImageBuffer", imageBuffer);
     }
   }
+
+	// @see org.gudy.azureus2.core3.disk.DiskManagerListener#fileAccessModeChanged(org.gudy.azureus2.core3.disk.DiskManagerFileInfo, int, int)
+	public void fileAccessModeChanged(DiskManagerFileInfo file, int old_mode,
+			int new_mode) {
+	}
+
+	// @see org.gudy.azureus2.core3.disk.DiskManagerListener#filePriorityChanged(org.gudy.azureus2.core3.disk.DiskManagerFileInfo)
+	public void filePriorityChanged(DiskManagerFileInfo file) {
+	}
+
+	// @see org.gudy.azureus2.core3.disk.DiskManagerListener#pieceDoneChanged(org.gudy.azureus2.core3.disk.DiskManagerPiece)
+	public void pieceDoneChanged(DiskManagerPiece piece) {
+		DiskManager diskmanager = piece.getManager();
+
+		boolean	remove_listener;
+		synchronized( this ){
+			remove_listener = row_count==0;
+		}
+		
+		if ( remove_listener ){
+			diskmanager.removeListener( this );
+		}else{
+			invalidateCells();
+	
+			if ( diskmanager.getRemaining() == 0 ){
+				
+				diskmanager.removeListener(this);
+			}
+		}
+	}
+
+	// @see org.gudy.azureus2.core3.disk.DiskManagerListener#stateChanged(int, int)
+	public void stateChanged(int oldState, int newState) {
+	}
   
 }
