@@ -26,6 +26,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.peers;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -38,10 +39,16 @@ public class PortItem
        implements TableCellRefreshListener
 {
   /** Default Constructor */
-  public PortItem() {
-    super("port", ALIGN_TRAIL, POSITION_INVISIBLE, 40, TableManager.TABLE_TORRENT_PEERS);
+  public PortItem(String table_id) {
+    super("port", ALIGN_TRAIL, POSITION_INVISIBLE, 40, table_id);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_CONNECTION,
+		});
+	}
+
   public void refresh(TableCell cell) {
     PEPeer peer = (PEPeer)cell.getDataSource();
     int value = (peer == null) ? 0 : peer.getPort();
