@@ -25,6 +25,7 @@ import org.gudy.azureus2.core3.util.Constants;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -42,6 +43,12 @@ public class UpDownRatioItem
     setRefreshInterval(INTERVAL_LIVE);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_SHARING,
+		});
+	}
+
   public void refresh(TableCell cell) {
     PEPeer peer = (PEPeer)cell.getDataSource();
     float value = 0;
@@ -56,16 +63,16 @@ public class UpDownRatioItem
         if (value == 0)
           value = -1;
       } else if (lDivident > 0)
-        value = Constants.INFINITY_AS_INT;
+        value = Float.MAX_VALUE;
     }
 
-    if (!cell.setSortValue((long)(value * 1000)) && cell.isValid())
+    if (!cell.setSortValue((long)(value * 1000.0d )) && cell.isValid())
       return;
 
     String s;
     if (lDivisor <= 0) 
       s = "";
-    else if (value == Constants.INFINITY_AS_INT)
+    else if (value == Float.MAX_VALUE )
       s = Constants.INFINITY_STRING + ":1";
     else if (value == -1)
       s = "1:" + Constants.INFINITY_STRING;
