@@ -28,6 +28,7 @@ import org.gudy.azureus2.core3.util.DisplayFormatters;
 
 import org.gudy.azureus2.core3.peer.PEPeer;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -45,6 +46,12 @@ public class UpSpeedItem
     setRefreshInterval(INTERVAL_LIVE);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_BYTES,
+		});
+	}
+
   public void refresh(TableCell cell) {
     PEPeer peer = (PEPeer)cell.getDataSource();
     long data_value	= 0;
