@@ -22,6 +22,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.pieces;
 
 import org.gudy.azureus2.core3.peer.PEPiece;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -39,6 +40,12 @@ public class AvailabilityItem
     setRefreshInterval(INTERVAL_LIVE);
   }
 
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_SWARM,
+		});
+	}
+
   public void refresh(TableCell cell) {
     PEPiece piece = (PEPiece)cell.getDataSource();
     long value = (piece == null) ? 0 : piece.getAvailability();
