@@ -24,6 +24,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.pieces;
 
 import org.gudy.azureus2.core3.peer.PEPiece;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -41,6 +42,12 @@ public class RequestedItem
         setRefreshInterval(INTERVAL_LIVE);
     }
 
+  	public void fillTableColumnInfo(TableColumnInfo info) {
+  		info.addCategories(new String[] {
+  			CAT_SWARM,
+  		});
+  	}
+
     public void refresh(TableCell cell)
     {
         boolean value =false;
