@@ -22,6 +22,7 @@ package org.gudy.azureus2.ui.swt.views.tableitems.pieces;
 
 import org.gudy.azureus2.core3.peer.PEPiece;
 import org.gudy.azureus2.plugins.ui.tables.*;
+
 import org.gudy.azureus2.ui.swt.views.table.utils.CoreTableColumn;
 
 /**
@@ -39,6 +40,12 @@ implements TableCellRefreshListener
 		super("speed", ALIGN_TRAIL, POSITION_LAST, 80, TableManager.TABLE_TORRENT_PIECES);
 		setRefreshInterval(INTERVAL_LIVE);
 	}
+
+	public void fillTableColumnInfo(TableColumnInfo info) {
+		info.addCategories(new String[] {
+			CAT_BYTES,
+		});
+	}
 	
 	public void refresh(TableCell cell) {
 		PEPiece piece = (PEPiece)cell.getDataSource();
