@@ -40,32 +40,48 @@ import org.gudy.azureus2.plugins.ui.*;
 import org.gudy.azureus2.plugins.ui.config.*;
 import org.gudy.azureus2.plugins.ui.model.*;
 
+import com.aelitis.azureus.core.pairing.PairedService;
+import com.aelitis.azureus.core.pairing.PairingConnectionData;
+import com.aelitis.azureus.core.pairing.PairingManager;
+import com.aelitis.azureus.core.pairing.PairingManagerFactory;
+import com.aelitis.azureus.core.pairing.PairingManagerListener;
 import com.aelitis.azureus.plugins.upnp.UPnPPlugin;
 
 public class 
 WebPlugin
 	implements Plugin, TrackerWebPageGenerator
 {
+	public static final String	PR_ENABLE					= "Enable";						// Boolean
+	public static final String	PR_DISABLABLE				= "Disablable";					// Boolean
 	public static final String	PR_PORT						= "Port";						// Integer
 	public static final String	PR_BIND_IP					= "Bind IP";					// String
 	public static final String	PR_ROOT_RESOURCE			= "Root Resource";				// String
+	public static final String	PR_ROOT_DIR					= "Root Dir";					// String
+	public static final String	PR_ACCESS					= "Access";						// String
 	public static final String	PR_LOG						= "DefaultLoggerChannel";		// LoggerChannel
-	public static final String	PR_CONFIG_MODEL				= "DefaultConfigModel";			// BasicPluginConfigModel
+	public static final String	PR_CONFIG_MODEL_PARAMS		= "DefaultConfigModelParams";	// String[] params to use when creating config model
 	public static final String	PR_VIEW_MODEL				= "DefaultViewModel";			// BasicPluginViewModel
 	public static final String	PR_HIDE_RESOURCE_CONFIG		= "DefaultHideResourceConfig";	// Boolean
 	public static final String	PR_ENABLE_KEEP_ALIVE		= "DefaultEnableKeepAlive";		// Boolean
+	public static final String	PR_PAIRING_SID				= "PairingSID";					// String
 	
 	public static final String	PROPERTIES_MIGRATED		= "Properties Migrated";
 	public static final String	CONFIG_MIGRATED			= "Config Migrated";
 	
 	public static final String	CONFIG_PASSWORD_ENABLE			= "Password Enable";
-	public        final boolean	CONFIG_PASSWORD_ENABLE_DEFAULT	= false;
+	public static final boolean	CONFIG_PASSWORD_ENABLE_DEFAULT	= false;
 	
-	public static final String	CONFIG_USER				= "User";
-	public        final String	CONFIG_USER_DEFAULT		= "";
+	public static final String	CONFIG_PAIRING_ENABLE			= "Pairing Enable";
+	public static final boolean	CONFIG_PAIRING_ENABLE_DEFAULT	= true;
+
+	public static final String	CONFIG_ENABLE					= PR_ENABLE;
+	public  			boolean	CONFIG_ENABLE_DEFAULT			= true;
 	
-	public static final String	CONFIG_PASSWORD			= "Password";
-	public        final byte[]	CONFIG_PASSWORD_DEFAULT	= {};
+	public static final String	CONFIG_USER						= "User";
+	public static final String	CONFIG_USER_DEFAULT				= "";
+	
+	public static final String	CONFIG_PASSWORD					= "Password";
+	public static final byte[]	CONFIG_PASSWORD_DEFAULT			= {};
 	
 	public static final String 	CONFIG_PORT						= PR_PORT;
 	public int			 		CONFIG_PORT_DEFAULT				= 8089;
@@ -74,26 +90,26 @@ WebPlugin
 	public String		 		CONFIG_BIND_IP_DEFAULT			= "";
 
 	public static final String 	CONFIG_PROTOCOL					= "Protocol";
-	public 		  final String 	CONFIG_PROTOCOL_DEFAULT			= "HTTP";
+	public static final String 	CONFIG_PROTOCOL_DEFAULT			= "HTTP";
 
 	public static final String	CONFIG_UPNP_ENABLE				= "UPnP Enable";
-	public    	  final boolean	CONFIG_UPNP_ENABLE_DEFAULT		= true;
+	public static final boolean	CONFIG_UPNP_ENABLE_DEFAULT		= true;
 
 	public static final String 	CONFIG_HOME_PAGE				= "Home Page";
-	public        final String 	CONFIG_HOME_PAGE_DEFAULT		= "index.html";
+	public static final String 	CONFIG_HOME_PAGE_DEFAULT		= "index.html";
 	
-	public static final String 	CONFIG_ROOT_DIR					= "Root Dir";
-	public        final String 	CONFIG_ROOT_DIR_DEFAULT			= "";
+	public static final String 	CONFIG_ROOT_DIR					= PR_ROOT_DIR;
+	public        		String 	CONFIG_ROOT_DIR_DEFAULT			= "";
 	
 	public static final String 	CONFIG_ROOT_RESOURCE			= PR_ROOT_RESOURCE;
 	public              String 	CONFIG_ROOT_RESOURCE_DEFAULT	= "";
 	
 	public static final String 	CONFIG_MODE						= "Mode";
 	public static final String 	CONFIG_MODE_FULL				= "full";
-	public        final String 	CONFIG_MODE_DEFAULT				= CONFIG_MODE_FULL;
+	public static final String 	CONFIG_MODE_DEFAULT				= CONFIG_MODE_FULL;
 	
-	public static final String 	CONFIG_ACCESS					= "Access";
-	public        final String 	CONFIG_ACCESS_DEFAULT			= "all";
+	public static final String 	CONFIG_ACCESS					= PR_ACCESS;
+	public        		String 	CONFIG_ACCESS_DEFAULT			= "all";
 	
 	protected static final String	NL			= "\r\n";
 	
@@ -106,12 +122,15 @@ WebPlugin
 	private BasicPluginViewModel 	view_model;
 	private BasicPluginConfigModel	config_model;
 	
+	private IntParameter			param_port;
+	private StringListParameter		param_protocol;
+	
 	private String				home_page;
 	private String				file_root;
 	private String				resource_root;
 	
 	private boolean				ip_range_all	= false;
-	private IPRange				ip_range;
+	private List<IPRange>		ip_ranges;
 	
 	private Properties	properties;
 	
@@ -136,6 +155,13 @@ WebPlugin
 	{	
 		plugin_interface	= _plugin_interface;
 		
+		Boolean	pr_enable = (Boolean)properties.get(PR_ENABLE);
+		
+		if ( pr_enable != null ){
+		
+			CONFIG_ENABLE_DEFAULT	= pr_enable.booleanValue();
+		}
+		
 		Integer	pr_port = (Integer)properties.get(PR_PORT);
 		
 		if ( pr_port != null ){
@@ -157,6 +183,20 @@ WebPlugin
 			CONFIG_ROOT_RESOURCE_DEFAULT	= pr_root_resource;
 		}
 		
+		String	pr_root_dir = (String)properties.get( PR_ROOT_DIR );
+		
+		if( pr_root_dir != null ){
+			
+			CONFIG_ROOT_DIR_DEFAULT	= pr_root_dir;
+		}
+		
+		String	pr_access = (String)properties.get( PR_ACCESS );
+		
+		if( pr_access != null ){
+			
+			CONFIG_ACCESS_DEFAULT	= pr_access;
+		}
+		
 		Boolean	pr_hide_resource_config = (Boolean)properties.get( PR_HIDE_RESOURCE_CONFIG );
 		
 		log = (LoggerChannel)properties.get( PR_LOG );
@@ -205,11 +245,19 @@ WebPlugin
 		
 		PluginConfig	plugin_config = plugin_interface.getPluginconfig();
 		
-		config_model = (BasicPluginConfigModel)properties.get( PR_CONFIG_MODEL );
+		String[] cm_params = (String[])properties.get( PR_CONFIG_MODEL_PARAMS );
 
-		if ( config_model == null ){
+		if ( cm_params == null || cm_params.length == 0 ){
 			
 			config_model = ui_manager.createBasicPluginConfigModel(ConfigSection.SECTION_PLUGINS, sConfigSectionID);
+			
+		}else if ( cm_params.length == 1 ){
+			
+			config_model = ui_manager.createBasicPluginConfigModel( cm_params[0] );
+
+		}else{
+			
+			config_model = ui_manager.createBasicPluginConfigModel( cm_params[0], cm_params[1] );
 		}
 		
 		boolean	save_needed = false;
@@ -317,12 +365,28 @@ WebPlugin
 			plugin_config.save();
 		}
 		
-		config_model.addLabelParameter2( "webui.restart.info" );
+		final LabelParameter param_info = config_model.addLabelParameter2( "webui.restart.info" );
 
-		IntParameter	param_port = config_model.addIntParameter2(		CONFIG_PORT, "webui.port", CONFIG_PORT_DEFAULT );
+		Boolean	disablable = (Boolean)properties.get( PR_DISABLABLE );
+		
+		boolean	enabled = true;
+		
+		BooleanParameter	param_enable = null;
+		
+		if ( disablable != null && disablable ){
+			
+			param_enable = 
+				config_model.addBooleanParameter2( CONFIG_ENABLE, "webui.enable", CONFIG_ENABLE_DEFAULT );
+
+			enabled	= param_enable.getValue();
+		}
+			// connection group
+		
+		param_port = config_model.addIntParameter2(		CONFIG_PORT, "webui.port", CONFIG_PORT_DEFAULT );
+		
 		StringParameter	param_bind = config_model.addStringParameter2(	CONFIG_BIND_IP, "webui.bindip", CONFIG_BIND_IP_DEFAULT );
 		
-		StringListParameter	param_protocol = 
+		param_protocol = 
 			config_model.addStringListParameter2(
 					CONFIG_PROTOCOL, "webui.protocol", new String[]{ "http", "https" }, CONFIG_PROTOCOL_DEFAULT );
 		
@@ -333,6 +397,75 @@ WebPlugin
 							"webui.upnpenable",
 							CONFIG_UPNP_ENABLE_DEFAULT );
 
+		final String p_sid = (String)properties.get( PR_PAIRING_SID );
+		
+		final LabelParameter	pairing_info;
+		final BooleanParameter	pairing_enable;
+		
+		if ( p_sid != null ){
+			
+			PairingManager pm = PairingManagerFactory.getSingleton();
+
+			pairing_info = config_model.addLabelParameter2( "webui.pairing.info." + (pm.isEnabled()?"y":"n"));
+				
+			pairing_enable = 
+				config_model.addBooleanParameter2( 
+						CONFIG_PAIRING_ENABLE, 
+								"webui.pairingenable",
+								CONFIG_PAIRING_ENABLE_DEFAULT );
+
+			pairing_enable.addListener(
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						Parameter param ) 
+					{
+						setupPairing( p_sid, pairing_enable.getValue());
+					}
+				});
+			
+			pairing_enable.setEnabled( pm.isEnabled());
+			
+			pm.addListener(
+				new PairingManagerListener()
+				{
+					public void 
+					somethingChanged(
+						PairingManager pm ) 
+					{
+						pairing_info.setLabelKey( "webui.pairing.info." + (pm.isEnabled()?"y":"n"));
+
+						pairing_enable.setEnabled( pm.isEnabled());
+					}		
+				});
+			
+			setupPairing( p_sid, pairing_enable.getValue());
+			
+			ParameterListener update_pairing_listener = 
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						Parameter param ) 
+					{
+						updatePairing( p_sid );
+					}
+				};
+				
+			param_port.addListener( update_pairing_listener );
+			param_protocol.addListener( update_pairing_listener );
+		}else{
+			pairing_info	= null;
+			pairing_enable 	= null;
+		}
+			
+		config_model.createGroup(
+			"ConfigView.section.server",
+			new Parameter[]{
+				param_port, param_bind, param_protocol, upnp_enable, pairing_info, pairing_enable,
+			});
+		
 		StringParameter	param_home 		= config_model.addStringParameter2(	CONFIG_HOME_PAGE, "webui.homepage", CONFIG_HOME_PAGE_DEFAULT );
 		StringParameter	param_rootdir 	= config_model.addStringParameter2(	CONFIG_ROOT_DIR, "webui.rootdir", CONFIG_ROOT_DIR_DEFAULT );
 		StringParameter	param_rootres	= config_model.addStringParameter2(	CONFIG_ROOT_RESOURCE, "webui.rootres", CONFIG_ROOT_RESOURCE_DEFAULT );
@@ -344,12 +477,15 @@ WebPlugin
 			param_rootres.setVisible( false );
 		}
 		
-		config_model.addLabelParameter2( "webui.mode.info" ); 
-		config_model.addStringListParameter2(	
+			// access group
+		
+		LabelParameter a_label1 = config_model.addLabelParameter2( "webui.mode.info" ); 
+		StringListParameter param_mode = 
+			config_model.addStringListParameter2(	
 					CONFIG_MODE, "webui.mode", new String[]{ "full", "view" }, CONFIG_MODE_DEFAULT );
 		
 		
-		config_model.addLabelParameter2( "webui.access.info" );
+		LabelParameter a_label2 = config_model.addLabelParameter2( "webui.access.info" );
 		StringParameter	param_access	= config_model.addStringParameter2(	CONFIG_ACCESS, "webui.access", CONFIG_ACCESS_DEFAULT );
 		
 		
@@ -375,6 +511,89 @@ WebPlugin
 		pw_enable.addEnabledOnSelection( user_name );
 		pw_enable.addEnabledOnSelection( password );
 		
+
+		config_model.createGroup(
+			"webui.group.access",
+			new Parameter[]{
+				a_label1, param_mode, a_label2, param_access,
+				pw_enable, user_name, password,
+			});
+			    
+		if ( param_enable != null ){
+						
+			final List<Parameter> changed_params = new ArrayList<Parameter>();
+			
+			if ( !enabled ){
+				
+				Parameter[] params = config_model.getParameters();
+
+				for ( Parameter param: params ){
+					
+					if ( param == param_enable || param == param_info ){
+						
+						continue;
+					}
+					
+					if ( param.isEnabled()){
+						
+						changed_params.add( param );
+					
+						param.setEnabled( false );
+					}
+				}
+			}
+			
+			param_enable.addListener(
+				new ParameterListener()
+				{
+					public void 
+					parameterChanged(
+						Parameter e_p )
+					{
+							// this doesn't quite work as tne enabler/disabler parameter logic is implemented
+							// badly and only toggles the UI component, not the enabled state of the
+							// underlying parameter. grr. better than nothing though
+						
+						boolean	is_enabled = ((BooleanParameter)e_p).getValue();
+						
+						if ( is_enabled ){
+						
+							for ( Parameter p: changed_params ){
+								
+								p.setEnabled( true );
+							}
+						}else{
+							
+							changed_params.clear();
+							
+							Parameter[] params = config_model.getParameters();
+							
+							for ( Parameter param: params ){
+								
+								if ( param == e_p || param == param_info ){
+									
+									continue;
+								}
+								
+								if ( param.isEnabled()){
+									
+									changed_params.add( param );
+								
+									param.setEnabled( false );
+								}
+							}
+						}
+					}
+				});
+			
+			if ( !enabled ){
+				
+				return;
+			}
+		}
+		
+			// end config
+		
 		tracker = plugin_interface.getTracker();
 		
 		home_page = param_home.getValue().trim();
@@ -419,8 +638,29 @@ WebPlugin
 				
 			}else{
 				
-				file_root = SystemProperties.getUserPath() + "web" + File.separator + root_dir;
+				if ( File.separatorChar != '/' && root_dir.contains( "/" )){
+					
+					root_dir = root_dir.replace( '/', File.separatorChar );
+				}
 				
+					// try relative to plugin dir
+				
+				file_root = plugin_interface.getPluginDirectoryName();
+
+				if ( file_root != null ){
+					
+					file_root = file_root + File.separator + root_dir;
+					
+					if ( !new File(file_root).exists()){
+						
+						file_root = null;
+					}
+				}
+				
+				if ( file_root == null ){
+					
+					file_root = SystemProperties.getUserPath() + "web" + File.separator + root_dir;
+				}
 			}
 		}
 
@@ -481,32 +721,55 @@ WebPlugin
 		
 		String	access_str = param_access.getValue().trim();
 		
+		String ip_ranges_str = "";
+		
 		if ( access_str.length() > 7 && Character.isDigit(access_str.charAt(0))){
 			
-			ip_range	= plugin_interface.getIPFilter().createRange(true);
+			String[] ranges = access_str.replace( ';', ',' ).split( "," );
 			
-			int	sep = access_str.indexOf("-");
+			ip_ranges = new ArrayList<IPRange>();
+			
+			for ( String range: ranges ){
 				
-			if ( sep == -1 ){
+				range = range.trim();
 				
-				ip_range.setStartIP( access_str );
+				if ( range.length() > 7 ){
+					
+					IPRange ip_range	= plugin_interface.getIPFilter().createRange(true);
+			
+					int	sep = range.indexOf("-");
 				
-				ip_range.setEndIP( access_str );
+					if ( sep == -1 ){
 				
-			}else{				
+						ip_range.setStartIP( range );
 				
-				ip_range.setStartIP( access_str.substring(0,sep).trim());
+						ip_range.setEndIP( range );
 				
-				ip_range.setEndIP( access_str.substring( sep+1 ).trim());
+					}else{				
+				
+						ip_range.setStartIP( range.substring(0,sep).trim());
+				
+						ip_range.setEndIP( range.substring( sep+1 ).trim());
+					}
+			
+					ip_range.checkValid();
+			
+					if (!ip_range.isValid()){
+			
+						log.log( LoggerChannel.LT_ERROR, "Access parameter '" + range + "' is invalid" );
+						
+					}else{
+						
+						ip_ranges.add( ip_range );
+						
+						ip_ranges_str += (ip_ranges_str.length()==0?"":", ") + ip_range.getStartIP() + " - " + ip_range.getEndIP();
+					}
+				}
 			}
 			
-			ip_range.checkValid();
-			
-			if (!ip_range.isValid()){
-			
-				log.log( LoggerChannel.LT_ERROR, "Access parameter '" + access_str + "' is invalid" );
-			
-				ip_range	= null;
+			if ( ip_ranges.size() == 0 ){
+				
+				ip_ranges = null;
 			}
 		}else{
 			
@@ -517,10 +780,10 @@ WebPlugin
 		}
 		
 		log.log( 	LoggerChannel.LT_INFORMATION, 
-					"acceptable IP range = " +
-						( ip_range==null?
+					"Acceptable IP range = " +
+						( ip_ranges==null?
 							(ip_range_all?"all":"local"):
-							(ip_range.getStartIP() + " - " + ip_range.getEndIP())));
+							(ip_ranges_str)));
 				
 							
 		try{
@@ -627,6 +890,82 @@ WebPlugin
 			});
 	}
 	
+	protected void
+	setupPairing(
+		String		sid,
+		boolean		enable )
+	{
+		PairingManager pm = PairingManagerFactory.getSingleton();
+		
+		PairedService service = pm.getService( sid );
+		
+		if ( enable ){
+			
+			if ( service == null ){
+				
+				service =  pm.addService( sid ); 
+				
+				PairingConnectionData cd = service.getConnectionData();
+
+				try{					
+					updatePairing( cd );
+				
+				}finally{
+				
+					cd.sync();
+				}
+			}
+		}else{
+			
+			if ( service != null ){
+				
+				service.remove();
+			}
+		}
+	}
+		
+	protected void
+	updatePairing(
+		String		sid )
+	{
+		PairingManager pm = PairingManagerFactory.getSingleton();
+		
+		PairedService service = pm.getService( sid );
+		
+		if ( service != null ){
+			
+			PairingConnectionData cd = service.getConnectionData();
+			
+			try{
+				updatePairing( cd );
+				
+			}finally{
+				
+				cd.sync();
+			}
+		}
+	}
+
+	protected void
+	updatePairing(
+		PairingConnectionData		cd )
+	{
+		cd.setAttribute( PairingConnectionData.ATTR_PORT, 		String.valueOf( param_port.getValue()));
+		cd.setAttribute( PairingConnectionData.ATTR_PROTOCOL, 	param_protocol.getValue());
+	}
+
+	protected int
+	getPort()
+	{
+		return( param_port.getValue());
+	}
+	
+	protected String
+	getProtocol()
+	{
+		return( param_protocol.getValue());
+	}
+	
 	public boolean
 	generateSupport(
 		TrackerWebPageRequest		request,
@@ -654,7 +993,7 @@ WebPlugin
 				boolean valid_ip = true;
 				InetAddress ia = InetAddress.getByName( client );
 				
-				if ( ip_range == null ){
+				if ( ip_ranges == null ){
 					
 					if ( !ia.isLoopbackAddress()){
 				
@@ -663,7 +1002,17 @@ WebPlugin
 					}
 				}else{
 					
-					if ( !ip_range.isInRange( ia.getHostAddress())){
+					boolean ok = false;
+					
+					for ( IPRange range: ip_ranges ){
+						
+						if ( range.isInRange( ia.getHostAddress())){
+						
+							ok = true;
+						}
+					}
+					
+					if ( !ok ){
 						
 						log.log( LoggerChannel.LT_ERROR, "Client '" + client + "' (" + ia.getHostAddress() + ") is not in range, rejecting" );
 						valid_ip = false;
@@ -787,4 +1136,19 @@ WebPlugin
 	protected BasicPluginViewModel getViewModel() {
 		return this.view_model;
 	}
+	
+	protected void
+	log(
+		String	str )
+	{
+		log.log( str );
+	}
+	
+	protected void
+	log(
+		String		str,
+		Throwable 	e )
+	{
+		log.log( str, e );
+	}
 }
